/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<private/qquick3dxrabstracthapticeffect_p.h>)
#  include <private/qquick3dxrabstracthapticeffect_p.h>
#endif
#if __has_include(<private/qquick3dxractionmapper_p.h>)
#  include <private/qquick3dxractionmapper_p.h>
#endif
#if __has_include(<private/qquick3dxrcamera_p.h>)
#  include <private/qquick3dxrcamera_p.h>
#endif
#if __has_include(<private/qquick3dxrcontroller_p.h>)
#  include <private/qquick3dxrcontroller_p.h>
#endif
#if __has_include(<private/qquick3dxrhandmodel_p.h>)
#  include <private/qquick3dxrhandmodel_p.h>
#endif
#if __has_include(<private/qquick3dxritem_p.h>)
#  include <private/qquick3dxritem_p.h>
#endif
#if __has_include(<private/qquick3dxrorigin_p.h>)
#  include <private/qquick3dxrorigin_p.h>
#endif
#if __has_include(<private/qquick3dxrruntimeinfo_p.h>)
#  include <private/qquick3dxrruntimeinfo_p.h>
#endif
#if __has_include(<private/qquick3dxrspatialanchor_p.h>)
#  include <private/qquick3dxrspatialanchor_p.h>
#endif
#if __has_include(<private/qquick3dxrspatialanchorlistmodel_p.h>)
#  include <private/qquick3dxrspatialanchorlistmodel_p.h>
#endif
#if __has_include(<private/qquick3dxrview_p.h>)
#  include <private/qquick3dxrview_p.h>
#endif
#if __has_include(<private/qquick3dxrvirtualmouse_p.h>)
#  include <private/qquick3dxrvirtualmouse_p.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_QtQuick3D_Xr()
{
    qmlRegisterModule("QtQuick3D.Xr", 6, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<QQuick3DXrAbstractHapticEffect>("QtQuick3D.Xr", 6);
    qmlRegisterTypesAndRevisions<QQuick3DXrCamera>("QtQuick3D.Xr", 6);
    qmlRegisterAnonymousTypesAndRevisions<QQuick3DNode>("QtQuick3D.Xr", 6);
    qmlRegisterTypesAndRevisions<QQuick3DXrController>("QtQuick3D.Xr", 6);
    qmlRegisterEnum<QQuick3DXrController::Controller>("QQuick3DXrController::Controller");
    qmlRegisterEnum<QQuick3DXrController::HandPoseSpace>("QQuick3DXrController::HandPoseSpace");
    qmlRegisterTypesAndRevisions<QQuick3DXrHandModel>("QtQuick3D.Xr", 6);
    qmlRegisterAnonymousTypesAndRevisions<QQuick3DModel>("QtQuick3D.Xr", 6);
    qmlRegisterEnum<QQuick3DXrHandModel::Hand>("QQuick3DXrHandModel::Hand");
    qmlRegisterTypesAndRevisions<QQuick3DXrHapticFeedback>("QtQuick3D.Xr", 6);
    qmlRegisterEnum<QQuick3DXrHapticFeedback::Controller>("QQuick3DXrHapticFeedback::Controller");
    qmlRegisterEnum<QQuick3DXrHapticFeedback::Condition>("QQuick3DXrHapticFeedback::Condition");
    qmlRegisterTypesAndRevisions<QQuick3DXrInputAction>("QtQuick3D.Xr", 6);
    qmlRegisterEnum<QQuick3DXrInputAction::Controller>("QQuick3DXrInputAction::Controller");
    qmlRegisterEnum<QQuick3DXrInputAction::Action>("QQuick3DXrInputAction::Action");
    qmlRegisterTypesAndRevisions<QQuick3DXrItem>("QtQuick3D.Xr", 6);
    qmlRegisterTypesAndRevisions<QQuick3DXrOrigin>("QtQuick3D.Xr", 6);
    qmlRegisterTypesAndRevisions<QQuick3DXrRuntimeInfo>("QtQuick3D.Xr", 6);
    qmlRegisterTypesAndRevisions<QQuick3DXrSimpleHapticEffect>("QtQuick3D.Xr", 6);
    qmlRegisterTypesAndRevisions<QQuick3DXrSpatialAnchor>("QtQuick3D.Xr", 6);
    qmlRegisterEnum<QQuick3DXrSpatialAnchor::Classification>("QQuick3DXrSpatialAnchor::Classification");
    qmlRegisterTypesAndRevisions<QQuick3DXrSpatialAnchorListModel>("QtQuick3D.Xr", 6);
    qmlRegisterAnonymousTypesAndRevisions<QAbstractItemModel>("QtQuick3D.Xr", 6);
    qmlRegisterEnum<QQuick3DXrSpatialAnchorListModel::FilterMode>("QQuick3DXrSpatialAnchorListModel::FilterMode");
    qmlRegisterEnum<QQuick3DXrSpatialAnchorListModel::ClassificationFlag>("QQuick3DXrSpatialAnchorListModel::ClassificationFlag");
    qmlRegisterEnum<QQuick3DXrSpatialAnchorListModel::ClassificationFlags>("QQuick3DXrSpatialAnchorListModel::ClassificationFlags");
    qmlRegisterEnum<QQuick3DXrSpatialAnchorListModel::ClassificationFlag>("QQuick3DXrSpatialAnchorListModel::ClassificationFlag");
    qmlRegisterTypesAndRevisions<QQuick3DXrView>("QtQuick3D.Xr", 6);
    qmlRegisterEnum<QQuick3DXrView::FoveationLevel>("QQuick3DXrView::FoveationLevel");
    qmlRegisterEnum<QQuick3DXrView::ReferenceSpace>("QQuick3DXrView::ReferenceSpace");
    qmlRegisterTypesAndRevisions<QQuick3DXrVirtualMouse>("QtQuick3D.Xr", 6);
    QT_WARNING_POP
    qmlRegisterModule("QtQuick3D.Xr", 6, 11);
}

static const QQmlModuleRegistration qtQuick3DXrRegistration("QtQuick3D.Xr", qml_register_types_QtQuick3D_Xr);
