/****************************************************************************
** Meta object code from reading C++ file 'proceduralmesh_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtquick3d/src/helpers/proceduralmesh_p.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'proceduralmesh_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN20ProceduralMeshSubsetE_t {};
} // unnamed namespace

template <> constexpr inline auto ProceduralMeshSubset::qt_create_metaobjectdata<qt_meta_tag_ZN20ProceduralMeshSubsetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ProceduralMeshSubset",
        "QML.Element",
        "QML.AddedInVersion",
        "1542",
        "offsetChanged",
        "",
        "countChanged",
        "nameChanged",
        "isDirty",
        "offset",
        "count",
        "name"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'offsetChanged'
        QtMocHelpers::SignalData<void()>(4, 5, QMC::AccessPublic, QMetaType::Void),
        // Signal 'countChanged'
        QtMocHelpers::SignalData<void()>(6, 5, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void()>(7, 5, QMC::AccessPublic, QMetaType::Void),
        // Signal 'isDirty'
        QtMocHelpers::SignalData<void()>(8, 5, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'offset'
        QtMocHelpers::PropertyData<uint>(9, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 0),
        // property 'count'
        QtMocHelpers::PropertyData<uint>(10, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 1),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(11, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 2),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    0 },
            {    2,    3 },
    });
    return QtMocHelpers::metaObjectData<ProceduralMeshSubset, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject ProceduralMeshSubset::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20ProceduralMeshSubsetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20ProceduralMeshSubsetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20ProceduralMeshSubsetE_t>.metaTypes,
    nullptr
} };

void ProceduralMeshSubset::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ProceduralMeshSubset *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->offsetChanged(); break;
        case 1: _t->countChanged(); break;
        case 2: _t->nameChanged(); break;
        case 3: _t->isDirty(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ProceduralMeshSubset::*)()>(_a, &ProceduralMeshSubset::offsetChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProceduralMeshSubset::*)()>(_a, &ProceduralMeshSubset::countChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProceduralMeshSubset::*)()>(_a, &ProceduralMeshSubset::nameChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProceduralMeshSubset::*)()>(_a, &ProceduralMeshSubset::isDirty, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<uint*>(_v) = _t->offset(); break;
        case 1: *reinterpret_cast<uint*>(_v) = _t->count(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setOffset(*reinterpret_cast<uint*>(_v)); break;
        case 1: _t->setCount(*reinterpret_cast<uint*>(_v)); break;
        case 2: _t->setName(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *ProceduralMeshSubset::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ProceduralMeshSubset::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20ProceduralMeshSubsetE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ProceduralMeshSubset::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void ProceduralMeshSubset::offsetChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ProceduralMeshSubset::countChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ProceduralMeshSubset::nameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void ProceduralMeshSubset::isDirty()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
namespace {
struct qt_meta_tag_ZN14ProceduralMeshE_t {};
} // unnamed namespace

template <> constexpr inline auto ProceduralMesh::qt_create_metaobjectdata<qt_meta_tag_ZN14ProceduralMeshE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ProceduralMesh",
        "QML.Element",
        "auto",
        "QML.AddedInVersion",
        "1542",
        "positionsChanged",
        "",
        "primitiveModeChanged",
        "indexesChanged",
        "normalsChanged",
        "tangentsChanged",
        "binormalsChanged",
        "uv0sChanged",
        "uv1sChanged",
        "colorsChanged",
        "jointsChanged",
        "weightsChanged",
        "requestUpdate",
        "updateGeometry",
        "subsetDestroyed",
        "subset",
        "positions",
        "QList<QVector3D>",
        "normals",
        "tangents",
        "binormals",
        "uv0s",
        "QList<QVector2D>",
        "uv1s",
        "colors",
        "QList<QVector4D>",
        "joints",
        "weights",
        "indexes",
        "QList<uint>",
        "subsets",
        "QQmlListProperty<ProceduralMeshSubset>",
        "primitiveMode",
        "PrimitiveMode",
        "Points",
        "LineStrip",
        "Lines",
        "TriangleStrip",
        "TriangleFan",
        "Triangles"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'positionsChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'primitiveModeChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'indexesChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'normalsChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'tangentsChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'binormalsChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'uv0sChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'uv1sChanged'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'colorsChanged'
        QtMocHelpers::SignalData<void()>(14, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'jointsChanged'
        QtMocHelpers::SignalData<void()>(15, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'weightsChanged'
        QtMocHelpers::SignalData<void()>(16, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'requestUpdate'
        QtMocHelpers::SlotData<void()>(17, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateGeometry'
        QtMocHelpers::SlotData<void()>(18, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'subsetDestroyed'
        QtMocHelpers::SlotData<void(QObject *)>(19, 6, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QObjectStar, 20 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'positions'
        QtMocHelpers::PropertyData<QList<QVector3D>>(21, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 0),
        // property 'normals'
        QtMocHelpers::PropertyData<QList<QVector3D>>(23, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 3),
        // property 'tangents'
        QtMocHelpers::PropertyData<QList<QVector3D>>(24, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 4),
        // property 'binormals'
        QtMocHelpers::PropertyData<QList<QVector3D>>(25, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 5),
        // property 'uv0s'
        QtMocHelpers::PropertyData<QList<QVector2D>>(26, 0x80000000 | 27, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 6),
        // property 'uv1s'
        QtMocHelpers::PropertyData<QList<QVector2D>>(28, 0x80000000 | 27, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 7),
        // property 'colors'
        QtMocHelpers::PropertyData<QList<QVector4D>>(29, 0x80000000 | 30, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 8),
        // property 'joints'
        QtMocHelpers::PropertyData<QList<QVector4D>>(31, 0x80000000 | 30, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 9),
        // property 'weights'
        QtMocHelpers::PropertyData<QList<QVector4D>>(32, 0x80000000 | 30, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 10),
        // property 'indexes'
        QtMocHelpers::PropertyData<QList<uint>>(33, 0x80000000 | 34, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 2),
        // property 'subsets'
        QtMocHelpers::PropertyData<QQmlListProperty<ProceduralMeshSubset>>(35, 0x80000000 | 36, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final),
        // property 'primitiveMode'
        QtMocHelpers::PropertyData<enum PrimitiveMode>(37, 0x80000000 | 38, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 1),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'PrimitiveMode'
        QtMocHelpers::EnumData<enum PrimitiveMode>(38, 38, QMC::EnumFlags{}).add({
            {   39, PrimitiveMode::Points },
            {   40, PrimitiveMode::LineStrip },
            {   41, PrimitiveMode::Lines },
            {   42, PrimitiveMode::TriangleStrip },
            {   43, PrimitiveMode::TriangleFan },
            {   44, PrimitiveMode::Triangles },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<ProceduralMesh, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject ProceduralMesh::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuick3DGeometry::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14ProceduralMeshE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14ProceduralMeshE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14ProceduralMeshE_t>.metaTypes,
    nullptr
} };

void ProceduralMesh::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ProceduralMesh *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->positionsChanged(); break;
        case 1: _t->primitiveModeChanged(); break;
        case 2: _t->indexesChanged(); break;
        case 3: _t->normalsChanged(); break;
        case 4: _t->tangentsChanged(); break;
        case 5: _t->binormalsChanged(); break;
        case 6: _t->uv0sChanged(); break;
        case 7: _t->uv1sChanged(); break;
        case 8: _t->colorsChanged(); break;
        case 9: _t->jointsChanged(); break;
        case 10: _t->weightsChanged(); break;
        case 11: _t->requestUpdate(); break;
        case 12: _t->updateGeometry(); break;
        case 13: _t->subsetDestroyed((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ProceduralMesh::*)()>(_a, &ProceduralMesh::positionsChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProceduralMesh::*)()>(_a, &ProceduralMesh::primitiveModeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProceduralMesh::*)()>(_a, &ProceduralMesh::indexesChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProceduralMesh::*)()>(_a, &ProceduralMesh::normalsChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProceduralMesh::*)()>(_a, &ProceduralMesh::tangentsChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProceduralMesh::*)()>(_a, &ProceduralMesh::binormalsChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProceduralMesh::*)()>(_a, &ProceduralMesh::uv0sChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProceduralMesh::*)()>(_a, &ProceduralMesh::uv1sChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProceduralMesh::*)()>(_a, &ProceduralMesh::colorsChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProceduralMesh::*)()>(_a, &ProceduralMesh::jointsChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProceduralMesh::*)()>(_a, &ProceduralMesh::weightsChanged, 10))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 9:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<uint> >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QList<QVector3D>*>(_v) = _t->positions(); break;
        case 1: *reinterpret_cast<QList<QVector3D>*>(_v) = _t->normals(); break;
        case 2: *reinterpret_cast<QList<QVector3D>*>(_v) = _t->tangents(); break;
        case 3: *reinterpret_cast<QList<QVector3D>*>(_v) = _t->binormals(); break;
        case 4: *reinterpret_cast<QList<QVector2D>*>(_v) = _t->uv0s(); break;
        case 5: *reinterpret_cast<QList<QVector2D>*>(_v) = _t->uv1s(); break;
        case 6: *reinterpret_cast<QList<QVector4D>*>(_v) = _t->colors(); break;
        case 7: *reinterpret_cast<QList<QVector4D>*>(_v) = _t->joints(); break;
        case 8: *reinterpret_cast<QList<QVector4D>*>(_v) = _t->weights(); break;
        case 9: *reinterpret_cast<QList<uint>*>(_v) = _t->indexes(); break;
        case 10: *reinterpret_cast<QQmlListProperty<ProceduralMeshSubset>*>(_v) = _t->subsets(); break;
        case 11: *reinterpret_cast<enum PrimitiveMode*>(_v) = _t->primitiveMode(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setPositions(*reinterpret_cast<QList<QVector3D>*>(_v)); break;
        case 1: _t->setNormals(*reinterpret_cast<QList<QVector3D>*>(_v)); break;
        case 2: _t->setTangents(*reinterpret_cast<QList<QVector3D>*>(_v)); break;
        case 3: _t->setBinormals(*reinterpret_cast<QList<QVector3D>*>(_v)); break;
        case 4: _t->setUv0s(*reinterpret_cast<QList<QVector2D>*>(_v)); break;
        case 5: _t->setUv1s(*reinterpret_cast<QList<QVector2D>*>(_v)); break;
        case 6: _t->setColors(*reinterpret_cast<QList<QVector4D>*>(_v)); break;
        case 7: _t->setJoints(*reinterpret_cast<QList<QVector4D>*>(_v)); break;
        case 8: _t->setWeights(*reinterpret_cast<QList<QVector4D>*>(_v)); break;
        case 9: _t->setIndexes(*reinterpret_cast<QList<uint>*>(_v)); break;
        case 11: _t->setPrimitiveMode(*reinterpret_cast<enum PrimitiveMode*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *ProceduralMesh::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ProceduralMesh::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14ProceduralMeshE_t>.strings))
        return static_cast<void*>(this);
    return QQuick3DGeometry::qt_metacast(_clname);
}

int ProceduralMesh::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuick3DGeometry::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 14;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void ProceduralMesh::positionsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ProceduralMesh::primitiveModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ProceduralMesh::indexesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void ProceduralMesh::normalsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void ProceduralMesh::tangentsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void ProceduralMesh::binormalsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void ProceduralMesh::uv0sChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void ProceduralMesh::uv1sChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void ProceduralMesh::colorsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void ProceduralMesh::jointsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void ProceduralMesh::weightsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}
QT_WARNING_POP
