/****************************************************************************
** Meta object code from reading C++ file 'qquick3dparticlespritesequence_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtquick3d/src/quick3dparticles/qquick3dparticlespritesequence_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquick3dparticlespritesequence_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN30QQuick3DParticleSpriteSequenceE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DParticleSpriteSequence::qt_create_metaobjectdata<qt_meta_tag_ZN30QQuick3DParticleSpriteSequenceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DParticleSpriteSequence",
        "QML.Element",
        "SpriteSequence3D",
        "QML.AddedInVersion",
        "1538",
        "frameCountChanged",
        "",
        "frameIndexChanged",
        "interpolateChanged",
        "durationChanged",
        "durationVariationChanged",
        "randomStartChanged",
        "animationDirectionChanged",
        "setFrameCount",
        "frameCount",
        "setFrameIndex",
        "frameIndex",
        "setInterpolate",
        "interpolate",
        "setDuration",
        "duration",
        "setDurationVariation",
        "durationVariation",
        "setRandomStart",
        "randomStart",
        "setAnimationDirection",
        "QQuick3DParticleSpriteSequence::AnimationDirection",
        "animationDirection",
        "AnimationDirection",
        "Normal",
        "Reverse",
        "Alternate",
        "AlternateReverse",
        "SingleFrame"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'frameCountChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'frameIndexChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'interpolateChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'durationChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'durationVariationChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'randomStartChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'animationDirectionChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setFrameCount'
        QtMocHelpers::SlotData<void(int)>(13, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 14 },
        }}),
        // Slot 'setFrameIndex'
        QtMocHelpers::SlotData<void(int)>(15, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 16 },
        }}),
        // Slot 'setInterpolate'
        QtMocHelpers::SlotData<void(bool)>(17, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 18 },
        }}),
        // Slot 'setDuration'
        QtMocHelpers::SlotData<void(int)>(19, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 20 },
        }}),
        // Slot 'setDurationVariation'
        QtMocHelpers::SlotData<void(int)>(21, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 22 },
        }}),
        // Slot 'setRandomStart'
        QtMocHelpers::SlotData<void(bool)>(23, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 24 },
        }}),
        // Slot 'setAnimationDirection'
        QtMocHelpers::SlotData<void(QQuick3DParticleSpriteSequence::AnimationDirection)>(25, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 26, 27 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'frameCount'
        QtMocHelpers::PropertyData<int>(14, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'frameIndex'
        QtMocHelpers::PropertyData<int>(16, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'interpolate'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'duration'
        QtMocHelpers::PropertyData<int>(20, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'durationVariation'
        QtMocHelpers::PropertyData<int>(22, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'randomStart'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'animationDirection'
        QtMocHelpers::PropertyData<enum AnimationDirection>(27, 0x80000000 | 28, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 6),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'AnimationDirection'
        QtMocHelpers::EnumData<enum AnimationDirection>(28, 28, QMC::EnumFlags{}).add({
            {   29, AnimationDirection::Normal },
            {   30, AnimationDirection::Reverse },
            {   31, AnimationDirection::Alternate },
            {   32, AnimationDirection::AlternateReverse },
            {   33, AnimationDirection::SingleFrame },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DParticleSpriteSequence, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DParticleSpriteSequence::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN30QQuick3DParticleSpriteSequenceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN30QQuick3DParticleSpriteSequenceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN30QQuick3DParticleSpriteSequenceE_t>.metaTypes,
    nullptr
} };

void QQuick3DParticleSpriteSequence::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DParticleSpriteSequence *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->frameCountChanged(); break;
        case 1: _t->frameIndexChanged(); break;
        case 2: _t->interpolateChanged(); break;
        case 3: _t->durationChanged(); break;
        case 4: _t->durationVariationChanged(); break;
        case 5: _t->randomStartChanged(); break;
        case 6: _t->animationDirectionChanged(); break;
        case 7: _t->setFrameCount((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->setFrameIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->setInterpolate((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->setDuration((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->setDurationVariation((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 12: _t->setRandomStart((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->setAnimationDirection((*reinterpret_cast<std::add_pointer_t<QQuick3DParticleSpriteSequence::AnimationDirection>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleSpriteSequence::*)()>(_a, &QQuick3DParticleSpriteSequence::frameCountChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleSpriteSequence::*)()>(_a, &QQuick3DParticleSpriteSequence::frameIndexChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleSpriteSequence::*)()>(_a, &QQuick3DParticleSpriteSequence::interpolateChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleSpriteSequence::*)()>(_a, &QQuick3DParticleSpriteSequence::durationChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleSpriteSequence::*)()>(_a, &QQuick3DParticleSpriteSequence::durationVariationChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleSpriteSequence::*)()>(_a, &QQuick3DParticleSpriteSequence::randomStartChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleSpriteSequence::*)()>(_a, &QQuick3DParticleSpriteSequence::animationDirectionChanged, 6))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->frameCount(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->frameIndex(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->interpolate(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->duration(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->durationVariation(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->randomStart(); break;
        case 6: *reinterpret_cast<enum AnimationDirection*>(_v) = _t->animationDirection(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setFrameCount(*reinterpret_cast<int*>(_v)); break;
        case 1: _t->setFrameIndex(*reinterpret_cast<int*>(_v)); break;
        case 2: _t->setInterpolate(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setDuration(*reinterpret_cast<int*>(_v)); break;
        case 4: _t->setDurationVariation(*reinterpret_cast<int*>(_v)); break;
        case 5: _t->setRandomStart(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setAnimationDirection(*reinterpret_cast<enum AnimationDirection*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DParticleSpriteSequence::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DParticleSpriteSequence::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN30QQuick3DParticleSpriteSequenceE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return QObject::qt_metacast(_clname);
}

int QQuick3DParticleSpriteSequence::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 14;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void QQuick3DParticleSpriteSequence::frameCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QQuick3DParticleSpriteSequence::frameIndexChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QQuick3DParticleSpriteSequence::interpolateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QQuick3DParticleSpriteSequence::durationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QQuick3DParticleSpriteSequence::durationVariationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QQuick3DParticleSpriteSequence::randomStartChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QQuick3DParticleSpriteSequence::animationDirectionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
