/****************************************************************************
** Meta object code from reading C++ file 'qquick3dinstancing_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtquick3d/src/quick3d/qquick3dinstancing_p.h"
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquick3dinstancing_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN25QQuick3DInstanceListEntryE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DInstanceListEntry::qt_create_metaobjectdata<qt_meta_tag_ZN25QQuick3DInstanceListEntryE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DInstanceListEntry",
        "QML.AddedInVersion",
        "1538",
        "QML.Element",
        "InstanceListEntry",
        "positionChanged",
        "",
        "scaleChanged",
        "eulerRotationChanged",
        "rotationChanged",
        "colorChanged",
        "customDataChanged",
        "changed",
        "setPosition",
        "QVector3D",
        "position",
        "setScale",
        "scale",
        "setEulerRotation",
        "eulerRotation",
        "setRotation",
        "QQuaternion",
        "rotation",
        "setColor",
        "QColor",
        "color",
        "setCustomData",
        "QVector4D",
        "customData"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'positionChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scaleChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'eulerRotationChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'rotationChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'colorChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'customDataChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'changed'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setPosition'
        QtMocHelpers::SlotData<void(QVector3D)>(13, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Slot 'setScale'
        QtMocHelpers::SlotData<void(QVector3D)>(16, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 17 },
        }}),
        // Slot 'setEulerRotation'
        QtMocHelpers::SlotData<void(QVector3D)>(18, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 19 },
        }}),
        // Slot 'setRotation'
        QtMocHelpers::SlotData<void(QQuaternion)>(20, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 22 },
        }}),
        // Slot 'setColor'
        QtMocHelpers::SlotData<void(QColor)>(23, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 24, 25 },
        }}),
        // Slot 'setCustomData'
        QtMocHelpers::SlotData<void(QVector4D)>(26, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 27, 28 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'position'
        QtMocHelpers::PropertyData<QVector3D>(15, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'scale'
        QtMocHelpers::PropertyData<QVector3D>(17, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'eulerRotation'
        QtMocHelpers::PropertyData<QVector3D>(19, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'rotation'
        QtMocHelpers::PropertyData<QQuaternion>(22, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'color'
        QtMocHelpers::PropertyData<QColor>(25, 0x80000000 | 24, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 4),
        // property 'customData'
        QtMocHelpers::PropertyData<QVector4D>(28, 0x80000000 | 27, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DInstanceListEntry, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DInstanceListEntry::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuick3DObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25QQuick3DInstanceListEntryE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25QQuick3DInstanceListEntryE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN25QQuick3DInstanceListEntryE_t>.metaTypes,
    nullptr
} };

void QQuick3DInstanceListEntry::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DInstanceListEntry *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->positionChanged(); break;
        case 1: _t->scaleChanged(); break;
        case 2: _t->eulerRotationChanged(); break;
        case 3: _t->rotationChanged(); break;
        case 4: _t->colorChanged(); break;
        case 5: _t->customDataChanged(); break;
        case 6: _t->changed(); break;
        case 7: _t->setPosition((*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[1]))); break;
        case 8: _t->setScale((*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[1]))); break;
        case 9: _t->setEulerRotation((*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[1]))); break;
        case 10: _t->setRotation((*reinterpret_cast<std::add_pointer_t<QQuaternion>>(_a[1]))); break;
        case 11: _t->setColor((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 12: _t->setCustomData((*reinterpret_cast<std::add_pointer_t<QVector4D>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuick3DInstanceListEntry::*)()>(_a, &QQuick3DInstanceListEntry::positionChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DInstanceListEntry::*)()>(_a, &QQuick3DInstanceListEntry::scaleChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DInstanceListEntry::*)()>(_a, &QQuick3DInstanceListEntry::eulerRotationChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DInstanceListEntry::*)()>(_a, &QQuick3DInstanceListEntry::rotationChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DInstanceListEntry::*)()>(_a, &QQuick3DInstanceListEntry::colorChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DInstanceListEntry::*)()>(_a, &QQuick3DInstanceListEntry::customDataChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DInstanceListEntry::*)()>(_a, &QQuick3DInstanceListEntry::changed, 6))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QVector3D*>(_v) = _t->position(); break;
        case 1: *reinterpret_cast<QVector3D*>(_v) = _t->scale(); break;
        case 2: *reinterpret_cast<QVector3D*>(_v) = _t->eulerRotation(); break;
        case 3: *reinterpret_cast<QQuaternion*>(_v) = _t->rotation(); break;
        case 4: *reinterpret_cast<QColor*>(_v) = _t->color(); break;
        case 5: *reinterpret_cast<QVector4D*>(_v) = _t->customData(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setPosition(*reinterpret_cast<QVector3D*>(_v)); break;
        case 1: _t->setScale(*reinterpret_cast<QVector3D*>(_v)); break;
        case 2: _t->setEulerRotation(*reinterpret_cast<QVector3D*>(_v)); break;
        case 3: _t->setRotation(*reinterpret_cast<QQuaternion*>(_v)); break;
        case 4: _t->setColor(*reinterpret_cast<QColor*>(_v)); break;
        case 5: _t->setCustomData(*reinterpret_cast<QVector4D*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DInstanceListEntry::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DInstanceListEntry::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25QQuick3DInstanceListEntryE_t>.strings))
        return static_cast<void*>(this);
    return QQuick3DObject::qt_metacast(_clname);
}

int QQuick3DInstanceListEntry::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuick3DObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 13;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void QQuick3DInstanceListEntry::positionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QQuick3DInstanceListEntry::scaleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QQuick3DInstanceListEntry::eulerRotationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QQuick3DInstanceListEntry::rotationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QQuick3DInstanceListEntry::colorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QQuick3DInstanceListEntry::customDataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QQuick3DInstanceListEntry::changed()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
namespace {
struct qt_meta_tag_ZN20QQuick3DInstanceListE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DInstanceList::qt_create_metaobjectdata<qt_meta_tag_ZN20QQuick3DInstanceListE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DInstanceList",
        "QML.Element",
        "InstanceList",
        "QML.AddedInVersion",
        "1538",
        "DefaultProperty",
        "instances",
        "instanceCountChanged",
        "",
        "handleInstanceChange",
        "onInstanceDestroyed",
        "object",
        "QQmlListProperty<QQuick3DInstanceListEntry>",
        "instanceCount"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'instanceCountChanged'
        QtMocHelpers::SignalData<void()>(7, 8, QMC::AccessPublic, QMetaType::Void),
        // Slot 'handleInstanceChange'
        QtMocHelpers::SlotData<void()>(9, 8, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onInstanceDestroyed'
        QtMocHelpers::SlotData<void(QObject *)>(10, 8, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QObjectStar, 11 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'instances'
        QtMocHelpers::PropertyData<QQmlListProperty<QQuick3DInstanceListEntry>>(6, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'instanceCount'
        QtMocHelpers::PropertyData<int>(13, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DInstanceList, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DInstanceList::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuick3DInstancing::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20QQuick3DInstanceListE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20QQuick3DInstanceListE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20QQuick3DInstanceListE_t>.metaTypes,
    nullptr
} };

void QQuick3DInstanceList::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DInstanceList *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->instanceCountChanged(); break;
        case 1: _t->handleInstanceChange(); break;
        case 2: _t->onInstanceDestroyed((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuick3DInstanceList::*)()>(_a, &QQuick3DInstanceList::instanceCountChanged, 0))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QQmlListProperty<QQuick3DInstanceListEntry>*>(_v) = _t->instances(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->instanceCount(); break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DInstanceList::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DInstanceList::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20QQuick3DInstanceListE_t>.strings))
        return static_cast<void*>(this);
    return QQuick3DInstancing::qt_metacast(_clname);
}

int QQuick3DInstanceList::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuick3DInstancing::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void QQuick3DInstanceList::instanceCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
namespace {
struct qt_meta_tag_ZN22QQuick3DFileInstancingE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DFileInstancing::qt_create_metaobjectdata<qt_meta_tag_ZN22QQuick3DFileInstancingE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DFileInstancing",
        "QML.Element",
        "FileInstancing",
        "QML.AddedInVersion",
        "1538",
        "instanceCountChanged",
        "",
        "sourceChanged",
        "source",
        "QUrl",
        "instanceCount"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'instanceCountChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sourceChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'source'
        QtMocHelpers::PropertyData<QUrl>(8, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'instanceCount'
        QtMocHelpers::PropertyData<int>(10, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DFileInstancing, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DFileInstancing::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuick3DInstancing::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22QQuick3DFileInstancingE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22QQuick3DFileInstancingE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22QQuick3DFileInstancingE_t>.metaTypes,
    nullptr
} };

void QQuick3DFileInstancing::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DFileInstancing *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->instanceCountChanged(); break;
        case 1: _t->sourceChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuick3DFileInstancing::*)()>(_a, &QQuick3DFileInstancing::instanceCountChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DFileInstancing::*)()>(_a, &QQuick3DFileInstancing::sourceChanged, 1))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QUrl*>(_v) = _t->source(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->instanceCount(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setSource(*reinterpret_cast<QUrl*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DFileInstancing::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DFileInstancing::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22QQuick3DFileInstancingE_t>.strings))
        return static_cast<void*>(this);
    return QQuick3DInstancing::qt_metacast(_clname);
}

int QQuick3DFileInstancing::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuick3DInstancing::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void QQuick3DFileInstancing::instanceCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QQuick3DFileInstancing::sourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
