/****************************************************************************
** Meta object code from reading C++ file 'qquick3dxrspatialanchorlistmodel_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../qtquick3d/src/xr/quick3dxr/qquick3dxrspatialanchorlistmodel_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquick3dxrspatialanchorlistmodel_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN32QQuick3DXrSpatialAnchorListModelE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DXrSpatialAnchorListModel::qt_create_metaobjectdata<qt_meta_tag_ZN32QQuick3DXrSpatialAnchorListModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DXrSpatialAnchorListModel",
        "QML.Element",
        "XrSpatialAnchorListModel",
        "QML.AddedInVersion",
        "1544",
        "filterModeChanged",
        "",
        "identifierFilterChanged",
        "classificationFilterChanged",
        "classificationStringFilterChanged",
        "handleAnchorAdded",
        "QQuick3DXrSpatialAnchor*",
        "anchor",
        "handleAnchorRemoved",
        "QUuid",
        "uuid",
        "handleAnchorUpdated",
        "requestSceneCapture",
        "queryAnchors",
        "filterMode",
        "FilterMode",
        "classificationFilter",
        "ClassificationFlags",
        "classificationStringFilter",
        "identifierFilter",
        "All",
        "Classification",
        "Identifier",
        "ClassificationFlag",
        "Wall",
        "Ceiling",
        "Floor",
        "Table",
        "Seat",
        "Window",
        "Door",
        "Other"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'filterModeChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'identifierFilterChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'classificationFilterChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'classificationStringFilterChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'handleAnchorAdded'
        QtMocHelpers::SlotData<void(QQuick3DXrSpatialAnchor *)>(10, 6, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'handleAnchorRemoved'
        QtMocHelpers::SlotData<void(QUuid)>(13, 6, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Slot 'handleAnchorUpdated'
        QtMocHelpers::SlotData<void(QQuick3DXrSpatialAnchor *)>(16, 6, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Method 'requestSceneCapture'
        QtMocHelpers::MethodData<void()>(17, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'queryAnchors'
        QtMocHelpers::MethodData<void()>(18, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'filterMode'
        QtMocHelpers::PropertyData<enum FilterMode>(19, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 0),
        // property 'classificationFilter'
        QtMocHelpers::PropertyData<ClassificationFlags>(21, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 2),
        // property 'classificationStringFilter'
        QtMocHelpers::PropertyData<QStringList>(23, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 3),
        // property 'identifierFilter'
        QtMocHelpers::PropertyData<QStringList>(24, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 1),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'FilterMode'
        QtMocHelpers::EnumData<enum FilterMode>(20, 20, QMC::EnumIsScoped).add({
            {   25, FilterMode::All },
            {   26, FilterMode::Classification },
            {   27, FilterMode::Identifier },
        }),
        // enum 'ClassificationFlag'
        QtMocHelpers::EnumData<enum ClassificationFlag>(28, 28, QMC::EnumFlags{}).add({
            {   29, ClassificationFlag::Wall },
            {   30, ClassificationFlag::Ceiling },
            {   31, ClassificationFlag::Floor },
            {   32, ClassificationFlag::Table },
            {   33, ClassificationFlag::Seat },
            {   34, ClassificationFlag::Window },
            {   35, ClassificationFlag::Door },
            {   36, ClassificationFlag::Other },
        }),
        // flag 'ClassificationFlags'
        QtMocHelpers::EnumData<ClassificationFlags>(22, 28, QMC::EnumIsFlag).add({
            {   29, ClassificationFlag::Wall },
            {   30, ClassificationFlag::Ceiling },
            {   31, ClassificationFlag::Floor },
            {   32, ClassificationFlag::Table },
            {   33, ClassificationFlag::Seat },
            {   34, ClassificationFlag::Window },
            {   35, ClassificationFlag::Door },
            {   36, ClassificationFlag::Other },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DXrSpatialAnchorListModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DXrSpatialAnchorListModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN32QQuick3DXrSpatialAnchorListModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN32QQuick3DXrSpatialAnchorListModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN32QQuick3DXrSpatialAnchorListModelE_t>.metaTypes,
    nullptr
} };

void QQuick3DXrSpatialAnchorListModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DXrSpatialAnchorListModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->filterModeChanged(); break;
        case 1: _t->identifierFilterChanged(); break;
        case 2: _t->classificationFilterChanged(); break;
        case 3: _t->classificationStringFilterChanged(); break;
        case 4: _t->handleAnchorAdded((*reinterpret_cast<std::add_pointer_t<QQuick3DXrSpatialAnchor*>>(_a[1]))); break;
        case 5: _t->handleAnchorRemoved((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1]))); break;
        case 6: _t->handleAnchorUpdated((*reinterpret_cast<std::add_pointer_t<QQuick3DXrSpatialAnchor*>>(_a[1]))); break;
        case 7: _t->requestSceneCapture(); break;
        case 8: _t->queryAnchors(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuick3DXrSpatialAnchorListModel::*)()>(_a, &QQuick3DXrSpatialAnchorListModel::filterModeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DXrSpatialAnchorListModel::*)()>(_a, &QQuick3DXrSpatialAnchorListModel::identifierFilterChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DXrSpatialAnchorListModel::*)()>(_a, &QQuick3DXrSpatialAnchorListModel::classificationFilterChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DXrSpatialAnchorListModel::*)()>(_a, &QQuick3DXrSpatialAnchorListModel::classificationStringFilterChanged, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<enum FilterMode*>(_v) = _t->filterMode(); break;
        case 1: QtMocHelpers::assignFlags<ClassificationFlags>(_v, _t->classificationFilter()); break;
        case 2: *reinterpret_cast<QStringList*>(_v) = _t->classificationStringFilter(); break;
        case 3: *reinterpret_cast<QStringList*>(_v) = _t->identifierFilter(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setFilterMode(*reinterpret_cast<enum FilterMode*>(_v)); break;
        case 1: _t->setClassificationFilter(*reinterpret_cast<ClassificationFlags*>(_v)); break;
        case 2: _t->setClassificationStringFilter(*reinterpret_cast<QStringList*>(_v)); break;
        case 3: _t->setIdentifierFilter(*reinterpret_cast<QStringList*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DXrSpatialAnchorListModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DXrSpatialAnchorListModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN32QQuick3DXrSpatialAnchorListModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int QQuick3DXrSpatialAnchorListModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void QQuick3DXrSpatialAnchorListModel::filterModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QQuick3DXrSpatialAnchorListModel::identifierFilterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QQuick3DXrSpatialAnchorListModel::classificationFilterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QQuick3DXrSpatialAnchorListModel::classificationStringFilterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
