/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<private/qquick3druntimeloader_p.h>)
#  include <private/qquick3druntimeloader_p.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_QtQuick3D_AssetUtils()
{
    qmlRegisterModule("QtQuick3D.AssetUtils", 6, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<QQuick3DRuntimeLoader>("QtQuick3D.AssetUtils", 6);
    qmlRegisterAnonymousTypesAndRevisions<QQuick3DNode>("QtQuick3D.AssetUtils", 6);
    qmlRegisterEnum<QQuick3DRuntimeLoader::Status>("QQuick3DRuntimeLoader::Status");
    QT_WARNING_POP
    qmlRegisterModule("QtQuick3D.AssetUtils", 6, 11);
}

static const QQmlModuleRegistration qtQuick3DAssetUtilsRegistration("QtQuick3D.AssetUtils", qml_register_types_QtQuick3D_AssetUtils);
