/****************************************************************************
** Meta object code from reading C++ file 'qquick3dparticlemodelblendparticle_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtquick3d/src/quick3dparticles/qquick3dparticlemodelblendparticle_p.h"
#include <QtGui/qtextcursor.h>
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquick3dparticlemodelblendparticle_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN34QQuick3DParticleModelBlendParticleE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DParticleModelBlendParticle::qt_create_metaobjectdata<qt_meta_tag_ZN34QQuick3DParticleModelBlendParticleE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DParticleModelBlendParticle",
        "QML.Element",
        "ModelBlendParticle3D",
        "QML.AddedInVersion",
        "1538",
        "delegateChanged",
        "",
        "blendFactorChanged",
        "endNodeChanged",
        "modelBlendModeChanged",
        "endTimeChanged",
        "activationNodeChanged",
        "emitModeChanged",
        "setDelegate",
        "QQmlComponent*",
        "setEndNode",
        "QQuick3DNode*",
        "endNode",
        "setEndTime",
        "endTime",
        "setModelBlendMode",
        "ModelBlendMode",
        "mode",
        "setActivationNode",
        "activationNode",
        "setEmitMode",
        "ModelBlendEmitMode",
        "emitMode",
        "delegate",
        "modelBlendMode",
        "Explode",
        "Construct",
        "Transfer",
        "Sequential",
        "Random",
        "Activation"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'delegateChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'blendFactorChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'endNodeChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'modelBlendModeChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'endTimeChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'activationNodeChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'emitModeChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setDelegate'
        QtMocHelpers::SlotData<void(QQmlComponent *)>(13, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 13 },
        }}),
        // Slot 'setEndNode'
        QtMocHelpers::SlotData<void(QQuick3DNode *)>(15, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Slot 'setEndTime'
        QtMocHelpers::SlotData<void(int)>(18, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 19 },
        }}),
        // Slot 'setModelBlendMode'
        QtMocHelpers::SlotData<void(enum ModelBlendMode)>(20, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 22 },
        }}),
        // Slot 'setActivationNode'
        QtMocHelpers::SlotData<void(QQuick3DNode *)>(23, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 24 },
        }}),
        // Slot 'setEmitMode'
        QtMocHelpers::SlotData<void(enum ModelBlendEmitMode)>(25, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 26, 27 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'delegate'
        QtMocHelpers::PropertyData<QQmlComponent*>(28, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'endNode'
        QtMocHelpers::PropertyData<QQuick3DNode*>(17, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'modelBlendMode'
        QtMocHelpers::PropertyData<enum ModelBlendMode>(29, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'endTime'
        QtMocHelpers::PropertyData<int>(19, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'activationNode'
        QtMocHelpers::PropertyData<QQuick3DNode*>(24, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5),
        // property 'emitMode'
        QtMocHelpers::PropertyData<enum ModelBlendEmitMode>(27, 0x80000000 | 26, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 6),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'ModelBlendMode'
        QtMocHelpers::EnumData<enum ModelBlendMode>(21, 21, QMC::EnumFlags{}).add({
            {   30, ModelBlendMode::Explode },
            {   31, ModelBlendMode::Construct },
            {   32, ModelBlendMode::Transfer },
        }),
        // enum 'ModelBlendEmitMode'
        QtMocHelpers::EnumData<enum ModelBlendEmitMode>(26, 26, QMC::EnumFlags{}).add({
            {   33, ModelBlendEmitMode::Sequential },
            {   34, ModelBlendEmitMode::Random },
            {   35, ModelBlendEmitMode::Activation },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DParticleModelBlendParticle, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DParticleModelBlendParticle::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuick3DParticle::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN34QQuick3DParticleModelBlendParticleE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN34QQuick3DParticleModelBlendParticleE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN34QQuick3DParticleModelBlendParticleE_t>.metaTypes,
    nullptr
} };

void QQuick3DParticleModelBlendParticle::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DParticleModelBlendParticle *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->delegateChanged(); break;
        case 1: _t->blendFactorChanged(); break;
        case 2: _t->endNodeChanged(); break;
        case 3: _t->modelBlendModeChanged(); break;
        case 4: _t->endTimeChanged(); break;
        case 5: _t->activationNodeChanged(); break;
        case 6: _t->emitModeChanged(); break;
        case 7: _t->setDelegate((*reinterpret_cast<std::add_pointer_t<QQmlComponent*>>(_a[1]))); break;
        case 8: _t->setEndNode((*reinterpret_cast<std::add_pointer_t<QQuick3DNode*>>(_a[1]))); break;
        case 9: _t->setEndTime((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->setModelBlendMode((*reinterpret_cast<std::add_pointer_t<enum ModelBlendMode>>(_a[1]))); break;
        case 11: _t->setActivationNode((*reinterpret_cast<std::add_pointer_t<QQuick3DNode*>>(_a[1]))); break;
        case 12: _t->setEmitMode((*reinterpret_cast<std::add_pointer_t<enum ModelBlendEmitMode>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQmlComponent* >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DNode* >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DNode* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleModelBlendParticle::*)()>(_a, &QQuick3DParticleModelBlendParticle::delegateChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleModelBlendParticle::*)()>(_a, &QQuick3DParticleModelBlendParticle::blendFactorChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleModelBlendParticle::*)()>(_a, &QQuick3DParticleModelBlendParticle::endNodeChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleModelBlendParticle::*)()>(_a, &QQuick3DParticleModelBlendParticle::modelBlendModeChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleModelBlendParticle::*)()>(_a, &QQuick3DParticleModelBlendParticle::endTimeChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleModelBlendParticle::*)()>(_a, &QQuick3DParticleModelBlendParticle::activationNodeChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleModelBlendParticle::*)()>(_a, &QQuick3DParticleModelBlendParticle::emitModeChanged, 6))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQmlComponent* >(); break;
        case 4:
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuick3DNode* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QQmlComponent**>(_v) = _t->delegate(); break;
        case 1: *reinterpret_cast<QQuick3DNode**>(_v) = _t->endNode(); break;
        case 2: *reinterpret_cast<enum ModelBlendMode*>(_v) = _t->modelBlendMode(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->endTime(); break;
        case 4: *reinterpret_cast<QQuick3DNode**>(_v) = _t->activationNode(); break;
        case 5: *reinterpret_cast<enum ModelBlendEmitMode*>(_v) = _t->emitMode(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setDelegate(*reinterpret_cast<QQmlComponent**>(_v)); break;
        case 1: _t->setEndNode(*reinterpret_cast<QQuick3DNode**>(_v)); break;
        case 2: _t->setModelBlendMode(*reinterpret_cast<enum ModelBlendMode*>(_v)); break;
        case 3: _t->setEndTime(*reinterpret_cast<int*>(_v)); break;
        case 4: _t->setActivationNode(*reinterpret_cast<QQuick3DNode**>(_v)); break;
        case 5: _t->setEmitMode(*reinterpret_cast<enum ModelBlendEmitMode*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DParticleModelBlendParticle::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DParticleModelBlendParticle::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN34QQuick3DParticleModelBlendParticleE_t>.strings))
        return static_cast<void*>(this);
    return QQuick3DParticle::qt_metacast(_clname);
}

int QQuick3DParticleModelBlendParticle::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuick3DParticle::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void QQuick3DParticleModelBlendParticle::delegateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QQuick3DParticleModelBlendParticle::blendFactorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QQuick3DParticleModelBlendParticle::endNodeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QQuick3DParticleModelBlendParticle::modelBlendModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QQuick3DParticleModelBlendParticle::endTimeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QQuick3DParticleModelBlendParticle::activationNodeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QQuick3DParticleModelBlendParticle::emitModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
