/****************************************************************************
** Meta object code from reading C++ file 'qquick3dobject.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtquick3d/src/quick3d/qquick3dobject.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquick3dobject.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14QQuick3DObjectE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DObject::qt_create_metaobjectdata<qt_meta_tag_ZN14QQuick3DObjectE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DObject",
        "DefaultProperty",
        "data",
        "qt_QmlJSWrapperFactoryMethod",
        "_q_createJSWrapper(QQmlV4ExecutionEnginePtr)",
        "QML.Element",
        "Object3D",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Object3D is Abstract",
        "parentChanged",
        "",
        "childrenChanged",
        "stateChanged",
        "update",
        "setParentItem",
        "QQuick3DObject*",
        "parentItem",
        "_q_resourceObjectDeleted",
        "_q_createJSWrapper",
        "QQmlV4ExecutionEnginePtr",
        "_q_cleanupContentItem2D",
        "parent",
        "QQmlListProperty<QObject>",
        "resources",
        "children",
        "QQmlListProperty<QQuick3DObject>",
        "states",
        "QQmlListProperty<QQuickState>",
        "transitions",
        "QQmlListProperty<QQuickTransition>",
        "state"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'parentChanged'
        QtMocHelpers::SignalData<void()>(11, 12, QMC::AccessPublic, QMetaType::Void),
        // Signal 'childrenChanged'
        QtMocHelpers::SignalData<void()>(13, 12, QMC::AccessPublic, QMetaType::Void),
        // Signal 'stateChanged'
        QtMocHelpers::SignalData<void()>(14, 12, QMC::AccessPublic, QMetaType::Void),
        // Slot 'update'
        QtMocHelpers::SlotData<void()>(15, 12, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setParentItem'
        QtMocHelpers::SlotData<void(QQuick3DObject *)>(16, 12, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot '_q_resourceObjectDeleted'
        QtMocHelpers::SlotData<void(QObject *)>(19, 12, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QObjectStar, 12 },
        }}),
        // Slot '_q_createJSWrapper'
        QtMocHelpers::SlotData<quint64(QQmlV4ExecutionEnginePtr)>(20, 12, QMC::AccessPrivate, QMetaType::ULongLong, {{
            { 0x80000000 | 21, 12 },
        }}),
        // Slot '_q_cleanupContentItem2D'
        QtMocHelpers::SlotData<void()>(22, 12, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'parent'
        QtMocHelpers::PropertyData<QQuick3DObject*>(23, 0x80000000 | 17, QMC::Readable | QMC::Writable | QMC::Scriptable | QMC::Stored | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'data'
        QtMocHelpers::PropertyData<QQmlListProperty<QObject>>(2, 0x80000000 | 24, QMC::Readable | QMC::Scriptable | QMC::Stored | QMC::EnumOrFlag),
        // property 'resources'
        QtMocHelpers::PropertyData<QQmlListProperty<QObject>>(25, 0x80000000 | 24, QMC::Readable | QMC::Scriptable | QMC::Stored | QMC::EnumOrFlag),
        // property 'children'
        QtMocHelpers::PropertyData<QQmlListProperty<QQuick3DObject>>(26, 0x80000000 | 27, QMC::Readable | QMC::Scriptable | QMC::Stored | QMC::EnumOrFlag, 1),
        // property 'states'
        QtMocHelpers::PropertyData<QQmlListProperty<QQuickState>>(28, 0x80000000 | 29, QMC::Readable | QMC::Scriptable | QMC::Stored | QMC::EnumOrFlag),
        // property 'transitions'
        QtMocHelpers::PropertyData<QQmlListProperty<QQuickTransition>>(30, 0x80000000 | 31, QMC::Readable | QMC::Scriptable | QMC::Stored | QMC::EnumOrFlag),
        // property 'state'
        QtMocHelpers::PropertyData<QString>(32, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
            {    7,    8 },
            {    9,   10 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DObject, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DObject::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14QQuick3DObjectE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14QQuick3DObjectE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14QQuick3DObjectE_t>.metaTypes,
    nullptr
} };

void QQuick3DObject::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DObject *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->parentChanged(); break;
        case 1: _t->childrenChanged(); break;
        case 2: _t->stateChanged(); break;
        case 3: _t->update(); break;
        case 4: _t->setParentItem((*reinterpret_cast<std::add_pointer_t<QQuick3DObject*>>(_a[1]))); break;
        case 5: _t->d_func()->_q_resourceObjectDeleted((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        case 6: { quint64 _r = _t->d_func()->_q_createJSWrapper((*reinterpret_cast<std::add_pointer_t<QQmlV4ExecutionEnginePtr>>(_a[1])));
            if (_a[0]) *reinterpret_cast<quint64*>(_a[0]) = std::move(_r); }  break;
        case 7: _t->d_func()->_q_cleanupContentItem2D(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DObject* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuick3DObject::*)()>(_a, &QQuick3DObject::parentChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DObject::*)()>(_a, &QQuick3DObject::childrenChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DObject::*)()>(_a, &QQuick3DObject::stateChanged, 2))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQmlListProperty<QQuick3DObject> >(); break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuick3DObject* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QQuick3DObject**>(_v) = _t->parentItem(); break;
        case 1: *reinterpret_cast<QQmlListProperty<QObject>*>(_v) = _t->QQuick3DObject::d_func()->data(); break;
        case 2: *reinterpret_cast<QQmlListProperty<QObject>*>(_v) = _t->QQuick3DObject::d_func()->resources(); break;
        case 3: *reinterpret_cast<QQmlListProperty<QQuick3DObject>*>(_v) = _t->QQuick3DObject::d_func()->children(); break;
        case 4: *reinterpret_cast<QQmlListProperty<QQuickState>*>(_v) = _t->QQuick3DObject::d_func()->states(); break;
        case 5: *reinterpret_cast<QQmlListProperty<QQuickTransition>*>(_v) = _t->QQuick3DObject::d_func()->transitions(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->state(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setParentItem(*reinterpret_cast<QQuick3DObject**>(_v)); break;
        case 6: _t->setState(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DObject::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DObject::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14QQuick3DObjectE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return QObject::qt_metacast(_clname);
}

int QQuick3DObject::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void QQuick3DObject::parentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QQuick3DObject::childrenChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QQuick3DObject::stateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
