/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<private/capsulegeometry_p.h>)
#  include <private/capsulegeometry_p.h>
#endif
#if __has_include(<private/conegeometry_p.h>)
#  include <private/conegeometry_p.h>
#endif
#if __has_include(<private/cuboidgeometry_p.h>)
#  include <private/cuboidgeometry_p.h>
#endif
#if __has_include(<private/cylindergeometry_p.h>)
#  include <private/cylindergeometry_p.h>
#endif
#if __has_include(<private/extrudedtextgeometry_p.h>)
#  include <private/extrudedtextgeometry_p.h>
#endif
#if __has_include(<private/gridgeometry_p.h>)
#  include <private/gridgeometry_p.h>
#endif
#if __has_include(<private/heightfieldgeometry_p.h>)
#  include <private/heightfieldgeometry_p.h>
#endif
#if __has_include(<private/infinitegrid_p.h>)
#  include <private/infinitegrid_p.h>
#endif
#if __has_include(<private/instancerepeater_p.h>)
#  include <private/instancerepeater_p.h>
#endif
#if __has_include(<private/lookatnode_p.h>)
#  include <private/lookatnode_p.h>
#endif
#if __has_include(<private/planegeometry_p.h>)
#  include <private/planegeometry_p.h>
#endif
#if __has_include(<private/proceduralmesh_p.h>)
#  include <private/proceduralmesh_p.h>
#endif
#if __has_include(<private/proceduralskytexturedata_p.h>)
#  include <private/proceduralskytexturedata_p.h>
#endif
#if __has_include(<private/qquick3drenderoutputprovider_p.h>)
#  include <private/qquick3drenderoutputprovider_p.h>
#endif
#if __has_include(<private/qquick3dsimplequadrenderpass_p.h>)
#  include <private/qquick3dsimplequadrenderpass_p.h>
#endif
#if __has_include(<private/qquick3dtexturedatafrontend_p.h>)
#  include <private/qquick3dtexturedatafrontend_p.h>
#endif
#if __has_include(<private/randominstancing_p.h>)
#  include <private/randominstancing_p.h>
#endif
#if __has_include(<private/spheregeometry_p.h>)
#  include <private/spheregeometry_p.h>
#endif
#if __has_include(<private/torusgeometry_p.h>)
#  include <private/torusgeometry_p.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_QtQuick3D_Helpers()
{
    qmlRegisterModule("QtQuick3D.Helpers", 1, 0);
    qmlRegisterModule("QtQuick3D.Helpers", 1, 254);
    qmlRegisterModule("QtQuick3D.Helpers", 6, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<CapsuleGeometry>("QtQuick3D.Helpers", 6);
    qmlRegisterAnonymousTypesAndRevisions<QQuick3DGeometry>("QtQuick3D.Helpers", 6);
    qmlRegisterEnum<CapsuleGeometry::Status>("CapsuleGeometry::Status");
    qmlRegisterEnum<CapsuleGeometry::UVProfile>("CapsuleGeometry::UVProfile");
    qmlRegisterTypesAndRevisions<ConeGeometry>("QtQuick3D.Helpers", 6);
    qmlRegisterEnum<ConeGeometry::Status>("ConeGeometry::Status");
    qmlRegisterTypesAndRevisions<CuboidGeometry>("QtQuick3D.Helpers", 6);
    qmlRegisterEnum<CuboidGeometry::Status>("CuboidGeometry::Status");
    qmlRegisterTypesAndRevisions<CylinderGeometry>("QtQuick3D.Helpers", 6);
    qmlRegisterEnum<CylinderGeometry::Status>("CylinderGeometry::Status");
    qmlRegisterTypesAndRevisions<ExtrudedTextGeometry>("QtQuick3D.Helpers", 6);
    qmlRegisterEnum<ExtrudedTextGeometry::Status>("ExtrudedTextGeometry::Status");
    qmlRegisterTypesAndRevisions<GridGeometry>("QtQuick3D.Helpers", 6);
    qmlRegisterTypesAndRevisions<HeightFieldGeometry>("QtQuick3D.Helpers", 6);
    qmlRegisterTypesAndRevisions<InstanceModel>("QtQuick3D.Helpers", 6);
    qmlRegisterAnonymousTypesAndRevisions<QAbstractItemModel>("QtQuick3D.Helpers", 6);
    qmlRegisterTypesAndRevisions<InstanceRepeater>("QtQuick3D.Helpers", 6);
    qmlRegisterAnonymousTypesAndRevisions<QQuick3DRepeater>("QtQuick3D.Helpers", 6);
    qmlRegisterAnonymousTypesAndRevisions<QQuick3DNode>("QtQuick3D.Helpers", 6);
    qmlRegisterTypesAndRevisions<LookAtNode>("QtQuick3D.Helpers", 6);
    qmlRegisterTypesAndRevisions<PlaneGeometry>("QtQuick3D.Helpers", 6);
    qmlRegisterEnum<PlaneGeometry::Status>("PlaneGeometry::Status");
    qmlRegisterEnum<PlaneGeometry::Plane>("PlaneGeometry::Plane");
    qmlRegisterTypesAndRevisions<ProceduralMesh>("QtQuick3D.Helpers", 6);
    qmlRegisterEnum<ProceduralMesh::PrimitiveMode>("ProceduralMesh::PrimitiveMode");
    qmlRegisterTypesAndRevisions<ProceduralMeshSubset>("QtQuick3D.Helpers", 6);
    qmlRegisterTypesAndRevisions<ProceduralSkyTextureData>("QtQuick3D.Helpers", 6);
    qmlRegisterEnum<ProceduralSkyTextureData::SkyTextureQuality>("ProceduralSkyTextureData::SkyTextureQuality");
    qmlRegisterTypesAndRevisions<QQuick3DInfiniteGrid>("QtQuick3D.Helpers", 6);
    qmlRegisterTypesAndRevisions<QQuick3DInstanceRange>("QtQuick3D.Helpers", 6);
    qmlRegisterTypesAndRevisions<QQuick3DRandomInstancing>("QtQuick3D.Helpers", 6);
    qmlRegisterAnonymousTypesAndRevisions<QQuick3DInstancing>("QtQuick3D.Helpers", 6);
    qmlRegisterEnum<QQuick3DRandomInstancing::ColorModel>("QQuick3DRandomInstancing::ColorModel");
    qmlRegisterTypesAndRevisions<QQuick3DRenderOutputProvider>("QtQuick3D.Helpers", 6);
    qmlRegisterEnum<QQuick3DRenderOutputProvider::TextureSource>("QQuick3DRenderOutputProvider::TextureSource");
    qmlRegisterEnum<QQuick3DRenderOutputProvider::AttachmentSelector>("QQuick3DRenderOutputProvider::AttachmentSelector");
    qmlRegisterTypesAndRevisions<QQuick3DSimpleQuadRenderer>("QtQuick3D.Helpers", 6);
    qmlRegisterTypesAndRevisions<QQuick3DTextureDataFrontend>("QtQuick3D.Helpers", 6);
    qmlRegisterTypesAndRevisions<SphereGeometry>("QtQuick3D.Helpers", 6);
    qmlRegisterEnum<SphereGeometry::Status>("SphereGeometry::Status");
    qmlRegisterTypesAndRevisions<TorusGeometry>("QtQuick3D.Helpers", 6);
    qmlRegisterEnum<TorusGeometry::Status>("TorusGeometry::Status");
    QT_WARNING_POP
    qmlRegisterModule("QtQuick3D.Helpers", 6, 11);
}

static const QQmlModuleRegistration qtQuick3DHelpersRegistration("QtQuick3D.Helpers", qml_register_types_QtQuick3D_Helpers);
