/****************************************************************************
** Meta object code from reading C++ file 'qquick3drenderpass_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtquick3d/src/quick3d/qquick3drenderpass_p.h"
#include <QtNetwork/QSslError>
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquick3drenderpass_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18QQuick3DRenderPassE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DRenderPass::qt_create_metaobjectdata<qt_meta_tag_ZN18QQuick3DRenderPassE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DRenderPass",
        "QML.Element",
        "RenderPass",
        "QML.AddedInVersion",
        "1547",
        "outputChanged",
        "",
        "materialModeChanged",
        "clearColorChanged",
        "overrideMaterialChanged",
        "augmentShaderChanged",
        "passModeChanged",
        "depthClearValueChanged",
        "stencilClearValueChanged",
        "renderTargetFlagsChanged",
        "onMaterialDestroyed",
        "object",
        "onCommandChanged",
        "commands",
        "QQmlListProperty<QQuick3DShaderUtilsRenderCommand>",
        "materialMode",
        "MaterialModes",
        "clearColor",
        "QColor",
        "depthClearValue",
        "stencilClearValue",
        "overrideMaterial",
        "QQuick3DMaterial*",
        "augmentShader",
        "QUrl",
        "passMode",
        "PassMode",
        "renderTargetFlags",
        "RenderTargetFlags",
        "OriginalMaterial",
        "AugmentMaterial",
        "OverrideMaterial",
        "UserPass",
        "SkyboxPass",
        "Item2DPass",
        "RenderTargetFlag",
        "None",
        "PreserveColorContents",
        "PreserveDepthStencilContents",
        "DoNotStoreDepthStencilContents"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'outputChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'materialModeChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'clearColorChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'overrideMaterialChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'augmentShaderChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'passModeChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'depthClearValueChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'stencilClearValueChanged'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'renderTargetFlagsChanged'
        QtMocHelpers::SignalData<void()>(14, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onMaterialDestroyed'
        QtMocHelpers::SlotData<void(QObject *)>(15, 6, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QObjectStar, 16 },
        }}),
        // Slot 'onCommandChanged'
        QtMocHelpers::SlotData<void()>(17, 6, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'commands'
        QtMocHelpers::PropertyData<QQmlListProperty<QQuick3DShaderUtilsRenderCommand>>(18, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'materialMode'
        QtMocHelpers::PropertyData<enum MaterialModes>(20, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'clearColor'
        QtMocHelpers::PropertyData<QColor>(22, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'depthClearValue'
        QtMocHelpers::PropertyData<float>(24, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'stencilClearValue'
        QtMocHelpers::PropertyData<quint32>(25, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'overrideMaterial'
        QtMocHelpers::PropertyData<QQuick3DMaterial*>(26, 0x80000000 | 27, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'augmentShader'
        QtMocHelpers::PropertyData<QUrl>(28, 0x80000000 | 29, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 4),
        // property 'passMode'
        QtMocHelpers::PropertyData<enum PassMode>(30, 0x80000000 | 31, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5),
        // property 'renderTargetFlags'
        QtMocHelpers::PropertyData<RenderTargetFlags>(32, 0x80000000 | 33, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 8),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'MaterialModes'
        QtMocHelpers::EnumData<enum MaterialModes>(21, 21, QMC::EnumFlags{}).add({
            {   34, MaterialModes::OriginalMaterial },
            {   35, MaterialModes::AugmentMaterial },
            {   36, MaterialModes::OverrideMaterial },
        }),
        // enum 'PassMode'
        QtMocHelpers::EnumData<enum PassMode>(31, 31, QMC::EnumFlags{}).add({
            {   37, PassMode::UserPass },
            {   38, PassMode::SkyboxPass },
            {   39, PassMode::Item2DPass },
        }),
        // flag 'RenderTargetFlags'
        QtMocHelpers::EnumData<RenderTargetFlags>(33, 40, QMC::EnumIsFlag | QMC::EnumIsScoped).add({
            {   41, RenderTargetFlag::None },
            {   42, RenderTargetFlag::PreserveColorContents },
            {   43, RenderTargetFlag::PreserveDepthStencilContents },
            {   44, RenderTargetFlag::DoNotStoreDepthStencilContents },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DRenderPass, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DRenderPass::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuick3DObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18QQuick3DRenderPassE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18QQuick3DRenderPassE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18QQuick3DRenderPassE_t>.metaTypes,
    nullptr
} };

void QQuick3DRenderPass::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DRenderPass *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->outputChanged(); break;
        case 1: _t->materialModeChanged(); break;
        case 2: _t->clearColorChanged(); break;
        case 3: _t->overrideMaterialChanged(); break;
        case 4: _t->augmentShaderChanged(); break;
        case 5: _t->passModeChanged(); break;
        case 6: _t->depthClearValueChanged(); break;
        case 7: _t->stencilClearValueChanged(); break;
        case 8: _t->renderTargetFlagsChanged(); break;
        case 9: _t->onMaterialDestroyed((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        case 10: _t->onCommandChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuick3DRenderPass::*)()>(_a, &QQuick3DRenderPass::outputChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DRenderPass::*)()>(_a, &QQuick3DRenderPass::materialModeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DRenderPass::*)()>(_a, &QQuick3DRenderPass::clearColorChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DRenderPass::*)()>(_a, &QQuick3DRenderPass::overrideMaterialChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DRenderPass::*)()>(_a, &QQuick3DRenderPass::augmentShaderChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DRenderPass::*)()>(_a, &QQuick3DRenderPass::passModeChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DRenderPass::*)()>(_a, &QQuick3DRenderPass::depthClearValueChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DRenderPass::*)()>(_a, &QQuick3DRenderPass::stencilClearValueChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DRenderPass::*)()>(_a, &QQuick3DRenderPass::renderTargetFlagsChanged, 8))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 5:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuick3DMaterial* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QQmlListProperty<QQuick3DShaderUtilsRenderCommand>*>(_v) = _t->commands(); break;
        case 1: *reinterpret_cast<enum MaterialModes*>(_v) = _t->materialMode(); break;
        case 2: *reinterpret_cast<QColor*>(_v) = _t->clearColor(); break;
        case 3: *reinterpret_cast<float*>(_v) = _t->depthClearValue(); break;
        case 4: *reinterpret_cast<quint32*>(_v) = _t->stencilClearValue(); break;
        case 5: *reinterpret_cast<QQuick3DMaterial**>(_v) = _t->overrideMaterial(); break;
        case 6: *reinterpret_cast<QUrl*>(_v) = _t->augmentShader(); break;
        case 7: *reinterpret_cast<enum PassMode*>(_v) = _t->passMode(); break;
        case 8: QtMocHelpers::assignFlags<RenderTargetFlags>(_v, _t->renderTargetFlags()); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setMaterialMode(*reinterpret_cast<enum MaterialModes*>(_v)); break;
        case 2: _t->setClearColor(*reinterpret_cast<QColor*>(_v)); break;
        case 3: _t->setDepthClearValue(*reinterpret_cast<float*>(_v)); break;
        case 4: _t->setStencilClearValue(*reinterpret_cast<quint32*>(_v)); break;
        case 5: _t->setOverrideMaterial(*reinterpret_cast<QQuick3DMaterial**>(_v)); break;
        case 6: _t->setAugmentShader(*reinterpret_cast<QUrl*>(_v)); break;
        case 7: _t->setPassMode(*reinterpret_cast<enum PassMode*>(_v)); break;
        case 8: _t->setRenderTargetFlags(*reinterpret_cast<RenderTargetFlags*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DRenderPass::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DRenderPass::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18QQuick3DRenderPassE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQuick3DPropertyChangedTracker"))
        return static_cast< QQuick3DPropertyChangedTracker*>(this);
    return QQuick3DObject::qt_metacast(_clname);
}

int QQuick3DRenderPass::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuick3DObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void QQuick3DRenderPass::outputChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QQuick3DRenderPass::materialModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QQuick3DRenderPass::clearColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QQuick3DRenderPass::overrideMaterialChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QQuick3DRenderPass::augmentShaderChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QQuick3DRenderPass::passModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QQuick3DRenderPass::depthClearValueChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void QQuick3DRenderPass::stencilClearValueChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void QQuick3DRenderPass::renderTargetFlagsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
QT_WARNING_POP
