/****************************************************************************
** Meta object code from reading C++ file 'qquick3dcustommaterial_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtquick3d/src/quick3d/qquick3dcustommaterial_p.h"
#include <QtGui/qtextcursor.h>
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquick3dcustommaterial_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN22QQuick3DCustomMaterialE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DCustomMaterial::qt_create_metaobjectdata<qt_meta_tag_ZN22QQuick3DCustomMaterialE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DCustomMaterial",
        "QML.Element",
        "CustomMaterial",
        "shadingModeChanged",
        "",
        "vertexShaderChanged",
        "fragmentShaderChanged",
        "vertexShaderCodeChanged",
        "fragmentShaderCodeChanged",
        "srcBlendChanged",
        "dstBlendChanged",
        "srcAlphaBlendChanged",
        "dstAlphaBlendChanged",
        "alwaysDirtyChanged",
        "lineWidthChanged",
        "setShadingMode",
        "QQuick3DCustomMaterial::ShadingMode",
        "mode",
        "setVertexShader",
        "QUrl",
        "url",
        "setFragmentShader",
        "setVertexShaderCode",
        "code",
        "setFragmentShaderCode",
        "setSrcBlend",
        "QQuick3DCustomMaterial::BlendMode",
        "setDstBlend",
        "setSrcAlphaBlend",
        "setDstAlphaBlend",
        "setAlwaysDirty",
        "alwaysDirty",
        "setLineWidth",
        "width",
        "onPropertyDirty",
        "onTextureDirty",
        "shadingMode",
        "ShadingMode",
        "fragmentShader",
        "vertexShader",
        "__fragmentShaderCode",
        "__vertexShaderCode",
        "sourceBlend",
        "BlendMode",
        "destinationBlend",
        "sourceAlphaBlend",
        "destinationAlphaBlend",
        "lineWidth",
        "Unshaded",
        "Shaded",
        "NoBlend",
        "Zero",
        "One",
        "SrcColor",
        "OneMinusSrcColor",
        "DstColor",
        "OneMinusDstColor",
        "SrcAlpha",
        "OneMinusSrcAlpha",
        "DstAlpha",
        "OneMinusDstAlpha",
        "ConstantColor",
        "OneMinusConstantColor",
        "ConstantAlpha",
        "OneMinusConstantAlpha",
        "SrcAlphaSaturate"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'shadingModeChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'vertexShaderChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fragmentShaderChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'vertexShaderCodeChanged'
        QtMocHelpers::RevisionedSignalData<void()>(7, 4, QMC::AccessPublic, 0x608, QMetaType::Void),
        // Signal 'fragmentShaderCodeChanged'
        QtMocHelpers::RevisionedSignalData<void()>(8, 4, QMC::AccessPublic, 0x608, QMetaType::Void),
        // Signal 'srcBlendChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dstBlendChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'srcAlphaBlendChanged'
        QtMocHelpers::RevisionedSignalData<void()>(11, 4, QMC::AccessPublic, 0x607, QMetaType::Void),
        // Signal 'dstAlphaBlendChanged'
        QtMocHelpers::RevisionedSignalData<void()>(12, 4, QMC::AccessPublic, 0x607, QMetaType::Void),
        // Signal 'alwaysDirtyChanged'
        QtMocHelpers::SignalData<void()>(13, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lineWidthChanged'
        QtMocHelpers::SignalData<void()>(14, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setShadingMode'
        QtMocHelpers::SlotData<void(QQuick3DCustomMaterial::ShadingMode)>(15, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Slot 'setVertexShader'
        QtMocHelpers::SlotData<void(const QUrl &)>(18, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Slot 'setFragmentShader'
        QtMocHelpers::SlotData<void(const QUrl &)>(21, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Slot 'setVertexShaderCode'
        QtMocHelpers::RevisionedSlotData<void(const QString &)>(22, 4, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { QMetaType::QString, 23 },
        }}),
        // Slot 'setFragmentShaderCode'
        QtMocHelpers::RevisionedSlotData<void(const QString &)>(24, 4, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { QMetaType::QString, 23 },
        }}),
        // Slot 'setSrcBlend'
        QtMocHelpers::SlotData<void(QQuick3DCustomMaterial::BlendMode)>(25, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 26, 17 },
        }}),
        // Slot 'setDstBlend'
        QtMocHelpers::SlotData<void(QQuick3DCustomMaterial::BlendMode)>(27, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 26, 17 },
        }}),
        // Slot 'setSrcAlphaBlend'
        QtMocHelpers::RevisionedSlotData<void(QQuick3DCustomMaterial::BlendMode)>(28, 4, QMC::AccessPublic, 0x607, QMetaType::Void, {{
            { 0x80000000 | 26, 17 },
        }}),
        // Slot 'setDstAlphaBlend'
        QtMocHelpers::RevisionedSlotData<void(QQuick3DCustomMaterial::BlendMode)>(29, 4, QMC::AccessPublic, 0x607, QMetaType::Void, {{
            { 0x80000000 | 26, 17 },
        }}),
        // Slot 'setAlwaysDirty'
        QtMocHelpers::SlotData<void(bool)>(30, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 31 },
        }}),
        // Slot 'setLineWidth'
        QtMocHelpers::SlotData<void(float)>(32, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 33 },
        }}),
        // Slot 'onPropertyDirty'
        QtMocHelpers::SlotData<void()>(34, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onTextureDirty'
        QtMocHelpers::SlotData<void()>(35, 4, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'shadingMode'
        QtMocHelpers::PropertyData<enum ShadingMode>(36, 0x80000000 | 37, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'fragmentShader'
        QtMocHelpers::PropertyData<QUrl>(38, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'vertexShader'
        QtMocHelpers::PropertyData<QUrl>(39, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property '__fragmentShaderCode'
        QtMocHelpers::PropertyData<QString>(40, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 4, 0x608),
        // property '__vertexShaderCode'
        QtMocHelpers::PropertyData<QString>(41, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 3, 0x608),
        // property 'sourceBlend'
        QtMocHelpers::PropertyData<enum BlendMode>(42, 0x80000000 | 43, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 5),
        // property 'destinationBlend'
        QtMocHelpers::PropertyData<enum BlendMode>(44, 0x80000000 | 43, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 6),
        // property 'sourceAlphaBlend'
        QtMocHelpers::PropertyData<enum BlendMode>(45, 0x80000000 | 43, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 7, 0x607),
        // property 'destinationAlphaBlend'
        QtMocHelpers::PropertyData<enum BlendMode>(46, 0x80000000 | 43, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 8, 0x607),
        // property 'alwaysDirty'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'lineWidth'
        QtMocHelpers::PropertyData<float>(47, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'ShadingMode'
        QtMocHelpers::EnumData<enum ShadingMode>(37, 37, QMC::EnumIsScoped).add({
            {   48, ShadingMode::Unshaded },
            {   49, ShadingMode::Shaded },
        }),
        // enum 'BlendMode'
        QtMocHelpers::EnumData<enum BlendMode>(43, 43, QMC::EnumIsScoped).add({
            {   50, BlendMode::NoBlend },
            {   51, BlendMode::Zero },
            {   52, BlendMode::One },
            {   53, BlendMode::SrcColor },
            {   54, BlendMode::OneMinusSrcColor },
            {   55, BlendMode::DstColor },
            {   56, BlendMode::OneMinusDstColor },
            {   57, BlendMode::SrcAlpha },
            {   58, BlendMode::OneMinusSrcAlpha },
            {   59, BlendMode::DstAlpha },
            {   60, BlendMode::OneMinusDstAlpha },
            {   61, BlendMode::ConstantColor },
            {   62, BlendMode::OneMinusConstantColor },
            {   63, BlendMode::ConstantAlpha },
            {   64, BlendMode::OneMinusConstantAlpha },
            {   65, BlendMode::SrcAlphaSaturate },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DCustomMaterial, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DCustomMaterial::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuick3DMaterial::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22QQuick3DCustomMaterialE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22QQuick3DCustomMaterialE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22QQuick3DCustomMaterialE_t>.metaTypes,
    nullptr
} };

void QQuick3DCustomMaterial::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DCustomMaterial *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->shadingModeChanged(); break;
        case 1: _t->vertexShaderChanged(); break;
        case 2: _t->fragmentShaderChanged(); break;
        case 3: _t->vertexShaderCodeChanged(); break;
        case 4: _t->fragmentShaderCodeChanged(); break;
        case 5: _t->srcBlendChanged(); break;
        case 6: _t->dstBlendChanged(); break;
        case 7: _t->srcAlphaBlendChanged(); break;
        case 8: _t->dstAlphaBlendChanged(); break;
        case 9: _t->alwaysDirtyChanged(); break;
        case 10: _t->lineWidthChanged(); break;
        case 11: _t->setShadingMode((*reinterpret_cast<std::add_pointer_t<QQuick3DCustomMaterial::ShadingMode>>(_a[1]))); break;
        case 12: _t->setVertexShader((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 13: _t->setFragmentShader((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 14: _t->setVertexShaderCode((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 15: _t->setFragmentShaderCode((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 16: _t->setSrcBlend((*reinterpret_cast<std::add_pointer_t<QQuick3DCustomMaterial::BlendMode>>(_a[1]))); break;
        case 17: _t->setDstBlend((*reinterpret_cast<std::add_pointer_t<QQuick3DCustomMaterial::BlendMode>>(_a[1]))); break;
        case 18: _t->setSrcAlphaBlend((*reinterpret_cast<std::add_pointer_t<QQuick3DCustomMaterial::BlendMode>>(_a[1]))); break;
        case 19: _t->setDstAlphaBlend((*reinterpret_cast<std::add_pointer_t<QQuick3DCustomMaterial::BlendMode>>(_a[1]))); break;
        case 20: _t->setAlwaysDirty((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 21: _t->setLineWidth((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 22: _t->onPropertyDirty(); break;
        case 23: _t->onTextureDirty(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuick3DCustomMaterial::*)()>(_a, &QQuick3DCustomMaterial::shadingModeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DCustomMaterial::*)()>(_a, &QQuick3DCustomMaterial::vertexShaderChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DCustomMaterial::*)()>(_a, &QQuick3DCustomMaterial::fragmentShaderChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DCustomMaterial::*)()>(_a, &QQuick3DCustomMaterial::vertexShaderCodeChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DCustomMaterial::*)()>(_a, &QQuick3DCustomMaterial::fragmentShaderCodeChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DCustomMaterial::*)()>(_a, &QQuick3DCustomMaterial::srcBlendChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DCustomMaterial::*)()>(_a, &QQuick3DCustomMaterial::dstBlendChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DCustomMaterial::*)()>(_a, &QQuick3DCustomMaterial::srcAlphaBlendChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DCustomMaterial::*)()>(_a, &QQuick3DCustomMaterial::dstAlphaBlendChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DCustomMaterial::*)()>(_a, &QQuick3DCustomMaterial::alwaysDirtyChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DCustomMaterial::*)()>(_a, &QQuick3DCustomMaterial::lineWidthChanged, 10))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<enum ShadingMode*>(_v) = _t->shadingMode(); break;
        case 1: *reinterpret_cast<QUrl*>(_v) = _t->fragmentShader(); break;
        case 2: *reinterpret_cast<QUrl*>(_v) = _t->vertexShader(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->fragmentShaderCode(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->vertexShaderCode(); break;
        case 5: *reinterpret_cast<enum BlendMode*>(_v) = _t->srcBlend(); break;
        case 6: *reinterpret_cast<enum BlendMode*>(_v) = _t->dstBlend(); break;
        case 7: *reinterpret_cast<enum BlendMode*>(_v) = _t->srcAlphaBlend(); break;
        case 8: *reinterpret_cast<enum BlendMode*>(_v) = _t->dstAlphaBlend(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->alwaysDirty(); break;
        case 10: *reinterpret_cast<float*>(_v) = _t->lineWidth(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setShadingMode(*reinterpret_cast<enum ShadingMode*>(_v)); break;
        case 1: _t->setFragmentShader(*reinterpret_cast<QUrl*>(_v)); break;
        case 2: _t->setVertexShader(*reinterpret_cast<QUrl*>(_v)); break;
        case 3: _t->setFragmentShaderCode(*reinterpret_cast<QString*>(_v)); break;
        case 4: _t->setVertexShaderCode(*reinterpret_cast<QString*>(_v)); break;
        case 5: _t->setSrcBlend(*reinterpret_cast<enum BlendMode*>(_v)); break;
        case 6: _t->setDstBlend(*reinterpret_cast<enum BlendMode*>(_v)); break;
        case 7: _t->setSrcAlphaBlend(*reinterpret_cast<enum BlendMode*>(_v)); break;
        case 8: _t->setDstAlphaBlend(*reinterpret_cast<enum BlendMode*>(_v)); break;
        case 9: _t->setAlwaysDirty(*reinterpret_cast<bool*>(_v)); break;
        case 10: _t->setLineWidth(*reinterpret_cast<float*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DCustomMaterial::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DCustomMaterial::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22QQuick3DCustomMaterialE_t>.strings))
        return static_cast<void*>(this);
    return QQuick3DMaterial::qt_metacast(_clname);
}

int QQuick3DCustomMaterial::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuick3DMaterial::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 24)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 24)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 24;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void QQuick3DCustomMaterial::shadingModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QQuick3DCustomMaterial::vertexShaderChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QQuick3DCustomMaterial::fragmentShaderChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QQuick3DCustomMaterial::vertexShaderCodeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QQuick3DCustomMaterial::fragmentShaderCodeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QQuick3DCustomMaterial::srcBlendChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QQuick3DCustomMaterial::dstBlendChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void QQuick3DCustomMaterial::srcAlphaBlendChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void QQuick3DCustomMaterial::dstAlphaBlendChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void QQuick3DCustomMaterial::alwaysDirtyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void QQuick3DCustomMaterial::lineWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}
QT_WARNING_POP
