/****************************************************************************
** Meta object code from reading C++ file 'qquick3dmaterial_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtquick3d/src/quick3d/qquick3dmaterial_p.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquick3dmaterial_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16QQuick3DMaterialE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DMaterial::qt_create_metaobjectdata<qt_meta_tag_ZN16QQuick3DMaterialE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DMaterial",
        "QML.Element",
        "Material",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Material is Abstract",
        "lightProbeChanged",
        "",
        "QQuick3DTexture*",
        "lightProbe",
        "cullModeChanged",
        "QQuick3DMaterial::CullMode",
        "cullMode",
        "depthDrawModeChanged",
        "QQuick3DMaterial::DepthDrawMode",
        "depthDrawMode",
        "setLightProbe",
        "setCullMode",
        "setDepthDrawMode",
        "CullMode",
        "DepthDrawMode",
        "BackFaceCulling",
        "FrontFaceCulling",
        "NoCulling",
        "TextureChannelMapping",
        "R",
        "G",
        "B",
        "A",
        "OpaqueOnlyDepthDraw",
        "AlwaysDepthDraw",
        "NeverDepthDraw",
        "OpaquePrePassDepthDraw",
        "VertexColorMask",
        "NoMask",
        "RoughnessMask",
        "NormalStrengthMask",
        "SpecularAmountMask",
        "ClearcoatAmountMask",
        "ClearcoatRoughnessAmountMask",
        "ClearcoatNormalStrengthMask",
        "HeightAmountMask",
        "MetalnessMask",
        "OcclusionAmountMask",
        "ThicknessFactorMask",
        "TransmissionFactorMask",
        "VertexColorMaskFlags"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'lightProbeChanged'
        QtMocHelpers::SignalData<void(QQuick3DTexture *)>(7, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'cullModeChanged'
        QtMocHelpers::SignalData<void(QQuick3DMaterial::CullMode)>(11, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Signal 'depthDrawModeChanged'
        QtMocHelpers::SignalData<void(QQuick3DMaterial::DepthDrawMode)>(14, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Slot 'setLightProbe'
        QtMocHelpers::SlotData<void(QQuick3DTexture *)>(17, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'setCullMode'
        QtMocHelpers::SlotData<void(QQuick3DMaterial::CullMode)>(18, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'setDepthDrawMode'
        QtMocHelpers::SlotData<void(QQuick3DMaterial::DepthDrawMode)>(19, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'lightProbe'
        QtMocHelpers::PropertyData<QQuick3DTexture*>(10, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'cullMode'
        QtMocHelpers::PropertyData<enum CullMode>(13, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'depthDrawMode'
        QtMocHelpers::PropertyData<enum DepthDrawMode>(16, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'CullMode'
        QtMocHelpers::EnumData<enum CullMode>(20, 20, QMC::EnumFlags{}).add({
            {   22, CullMode::BackFaceCulling },
            {   23, CullMode::FrontFaceCulling },
            {   24, CullMode::NoCulling },
        }),
        // enum 'TextureChannelMapping'
        QtMocHelpers::EnumData<enum TextureChannelMapping>(25, 25, QMC::EnumFlags{}).add({
            {   26, TextureChannelMapping::R },
            {   27, TextureChannelMapping::G },
            {   28, TextureChannelMapping::B },
            {   29, TextureChannelMapping::A },
        }),
        // enum 'DepthDrawMode'
        QtMocHelpers::EnumData<enum DepthDrawMode>(21, 21, QMC::EnumFlags{}).add({
            {   30, DepthDrawMode::OpaqueOnlyDepthDraw },
            {   31, DepthDrawMode::AlwaysDepthDraw },
            {   32, DepthDrawMode::NeverDepthDraw },
            {   33, DepthDrawMode::OpaquePrePassDepthDraw },
        }),
        // enum 'VertexColorMask'
        QtMocHelpers::EnumData<enum VertexColorMask>(34, 34, QMC::EnumFlags{}).add({
            {   35, VertexColorMask::NoMask },
            {   36, VertexColorMask::RoughnessMask },
            {   37, VertexColorMask::NormalStrengthMask },
            {   38, VertexColorMask::SpecularAmountMask },
            {   39, VertexColorMask::ClearcoatAmountMask },
            {   40, VertexColorMask::ClearcoatRoughnessAmountMask },
            {   41, VertexColorMask::ClearcoatNormalStrengthMask },
            {   42, VertexColorMask::HeightAmountMask },
            {   43, VertexColorMask::MetalnessMask },
            {   44, VertexColorMask::OcclusionAmountMask },
            {   45, VertexColorMask::ThicknessFactorMask },
            {   46, VertexColorMask::TransmissionFactorMask },
        }),
        // flag 'VertexColorMaskFlags'
        QtMocHelpers::EnumData<VertexColorMaskFlags>(47, 34, QMC::EnumIsFlag).add({
            {   35, VertexColorMask::NoMask },
            {   36, VertexColorMask::RoughnessMask },
            {   37, VertexColorMask::NormalStrengthMask },
            {   38, VertexColorMask::SpecularAmountMask },
            {   39, VertexColorMask::ClearcoatAmountMask },
            {   40, VertexColorMask::ClearcoatRoughnessAmountMask },
            {   41, VertexColorMask::ClearcoatNormalStrengthMask },
            {   42, VertexColorMask::HeightAmountMask },
            {   43, VertexColorMask::MetalnessMask },
            {   44, VertexColorMask::OcclusionAmountMask },
            {   45, VertexColorMask::ThicknessFactorMask },
            {   46, VertexColorMask::TransmissionFactorMask },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DMaterial, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DMaterial::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuick3DObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16QQuick3DMaterialE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16QQuick3DMaterialE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16QQuick3DMaterialE_t>.metaTypes,
    nullptr
} };

void QQuick3DMaterial::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DMaterial *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->lightProbeChanged((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 1: _t->cullModeChanged((*reinterpret_cast<std::add_pointer_t<QQuick3DMaterial::CullMode>>(_a[1]))); break;
        case 2: _t->depthDrawModeChanged((*reinterpret_cast<std::add_pointer_t<QQuick3DMaterial::DepthDrawMode>>(_a[1]))); break;
        case 3: _t->setLightProbe((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 4: _t->setCullMode((*reinterpret_cast<std::add_pointer_t<QQuick3DMaterial::CullMode>>(_a[1]))); break;
        case 5: _t->setDepthDrawMode((*reinterpret_cast<std::add_pointer_t<QQuick3DMaterial::DepthDrawMode>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuick3DMaterial::*)(QQuick3DTexture * )>(_a, &QQuick3DMaterial::lightProbeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DMaterial::*)(QQuick3DMaterial::CullMode )>(_a, &QQuick3DMaterial::cullModeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DMaterial::*)(QQuick3DMaterial::DepthDrawMode )>(_a, &QQuick3DMaterial::depthDrawModeChanged, 2))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuick3DTexture* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QQuick3DTexture**>(_v) = _t->lightProbe(); break;
        case 1: *reinterpret_cast<enum CullMode*>(_v) = _t->cullMode(); break;
        case 2: *reinterpret_cast<enum DepthDrawMode*>(_v) = _t->depthDrawMode(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setLightProbe(*reinterpret_cast<QQuick3DTexture**>(_v)); break;
        case 1: _t->setCullMode(*reinterpret_cast<enum CullMode*>(_v)); break;
        case 2: _t->setDepthDrawMode(*reinterpret_cast<enum DepthDrawMode*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DMaterial::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DMaterial::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16QQuick3DMaterialE_t>.strings))
        return static_cast<void*>(this);
    return QQuick3DObject::qt_metacast(_clname);
}

int QQuick3DMaterial::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuick3DObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void QQuick3DMaterial::lightProbeChanged(QQuick3DTexture * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void QQuick3DMaterial::cullModeChanged(QQuick3DMaterial::CullMode _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void QQuick3DMaterial::depthDrawModeChanged(QQuick3DMaterial::DepthDrawMode _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
