/****************************************************************************
** Meta object code from reading C++ file 'qquick3dparticleaffector_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtquick3d/src/quick3dparticles/qquick3dparticleaffector_p.h"
#include <QtGui/qtextcursor.h>
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquick3dparticleaffector_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN24QQuick3DParticleAffectorE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DParticleAffector::qt_create_metaobjectdata<qt_meta_tag_ZN24QQuick3DParticleAffectorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DParticleAffector",
        "QML.Element",
        "Affector3D",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Affector3D is abstract",
        "QML.AddedInVersion",
        "1538",
        "update",
        "",
        "systemChanged",
        "enabledChanged",
        "setSystem",
        "QQuick3DParticleSystem*",
        "system",
        "setEnabled",
        "enabled",
        "particles",
        "QQmlListProperty<QQuick3DParticle>"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'update'
        QtMocHelpers::SignalData<void()>(9, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'systemChanged'
        QtMocHelpers::SignalData<void()>(11, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enabledChanged'
        QtMocHelpers::SignalData<void()>(12, 10, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setSystem'
        QtMocHelpers::SlotData<void(QQuick3DParticleSystem *)>(13, 10, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Slot 'setEnabled'
        QtMocHelpers::SlotData<void(bool)>(16, 10, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 17 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'system'
        QtMocHelpers::PropertyData<QQuick3DParticleSystem*>(15, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'particles'
        QtMocHelpers::PropertyData<QQmlListProperty<QQuick3DParticle>>(18, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'enabled'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
            {    7,    8 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DParticleAffector, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DParticleAffector::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuick3DNode::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24QQuick3DParticleAffectorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24QQuick3DParticleAffectorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN24QQuick3DParticleAffectorE_t>.metaTypes,
    nullptr
} };

void QQuick3DParticleAffector::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DParticleAffector *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->update(); break;
        case 1: _t->systemChanged(); break;
        case 2: _t->enabledChanged(); break;
        case 3: _t->setSystem((*reinterpret_cast<std::add_pointer_t<QQuick3DParticleSystem*>>(_a[1]))); break;
        case 4: _t->setEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DParticleSystem* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleAffector::*)()>(_a, &QQuick3DParticleAffector::update, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleAffector::*)()>(_a, &QQuick3DParticleAffector::systemChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleAffector::*)()>(_a, &QQuick3DParticleAffector::enabledChanged, 2))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuick3DParticleSystem* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QQuick3DParticleSystem**>(_v) = _t->system(); break;
        case 1: *reinterpret_cast<QQmlListProperty<QQuick3DParticle>*>(_v) = _t->particles(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->enabled(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setSystem(*reinterpret_cast<QQuick3DParticleSystem**>(_v)); break;
        case 2: _t->setEnabled(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DParticleAffector::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DParticleAffector::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24QQuick3DParticleAffectorE_t>.strings))
        return static_cast<void*>(this);
    return QQuick3DNode::qt_metacast(_clname);
}

int QQuick3DParticleAffector::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuick3DNode::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void QQuick3DParticleAffector::update()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QQuick3DParticleAffector::systemChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QQuick3DParticleAffector::enabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
