/****************************************************************************
** Meta object code from reading C++ file 'qquick3dparticle_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtquick3d/src/quick3dparticles/qquick3dparticle_p.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquick3dparticle_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16QQuick3DParticleE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DParticle::qt_create_metaobjectdata<qt_meta_tag_ZN16QQuick3DParticleE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DParticle",
        "QML.Element",
        "Particle3D",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Particle3D is abstract",
        "QML.AddedInVersion",
        "1538",
        "systemChanged",
        "",
        "maxAmountChanged",
        "colorChanged",
        "colorVariationChanged",
        "unifiedColorVariationChanged",
        "fadeInEffectChanged",
        "fadeOutEffectChanged",
        "fadeInDurationChanged",
        "fadeOutDurationChanged",
        "alignModeChanged",
        "alignTargetPositionChanged",
        "hasTransparencyChanged",
        "sortModeChanged",
        "setSystem",
        "QQuick3DParticleSystem*",
        "system",
        "setMaxAmount",
        "maxAmount",
        "setColor",
        "QColor",
        "color",
        "setColorVariation",
        "QVector4D",
        "colorVariation",
        "setUnifiedColorVariation",
        "unified",
        "setFadeInEffect",
        "QQuick3DParticle::FadeType",
        "fadeInEffect",
        "setFadeOutEffect",
        "fadeOutEffect",
        "setFadeInDuration",
        "fadeInDuration",
        "setFadeOutDuration",
        "fadeOutDuration",
        "setAlignMode",
        "QQuick3DParticle::AlignMode",
        "alignMode",
        "setAlignTargetPosition",
        "QVector3D",
        "alignPosition",
        "setHasTransparency",
        "transparency",
        "setSortMode",
        "QQuick3DParticle::SortMode",
        "sortMode",
        "unifiedColorVariation",
        "FadeType",
        "AlignMode",
        "alignTargetPosition",
        "hasTransparency",
        "SortMode",
        "FadeNone",
        "FadeOpacity",
        "FadeScale",
        "AlignNone",
        "AlignTowardsTarget",
        "AlignTowardsStartVelocity",
        "SortNone",
        "SortNewest",
        "SortOldest",
        "SortDistance"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'systemChanged'
        QtMocHelpers::SignalData<void()>(9, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'maxAmountChanged'
        QtMocHelpers::SignalData<void()>(11, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'colorChanged'
        QtMocHelpers::SignalData<void()>(12, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'colorVariationChanged'
        QtMocHelpers::SignalData<void()>(13, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'unifiedColorVariationChanged'
        QtMocHelpers::SignalData<void()>(14, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fadeInEffectChanged'
        QtMocHelpers::SignalData<void()>(15, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fadeOutEffectChanged'
        QtMocHelpers::SignalData<void()>(16, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fadeInDurationChanged'
        QtMocHelpers::SignalData<void()>(17, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fadeOutDurationChanged'
        QtMocHelpers::SignalData<void()>(18, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'alignModeChanged'
        QtMocHelpers::SignalData<void()>(19, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'alignTargetPositionChanged'
        QtMocHelpers::SignalData<void()>(20, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hasTransparencyChanged'
        QtMocHelpers::SignalData<void()>(21, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sortModeChanged'
        QtMocHelpers::SignalData<void()>(22, 10, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setSystem'
        QtMocHelpers::SlotData<void(QQuick3DParticleSystem *)>(23, 10, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 24, 25 },
        }}),
        // Slot 'setMaxAmount'
        QtMocHelpers::SlotData<void(int)>(26, 10, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 27 },
        }}),
        // Slot 'setColor'
        QtMocHelpers::SlotData<void(QColor)>(28, 10, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 29, 30 },
        }}),
        // Slot 'setColorVariation'
        QtMocHelpers::SlotData<void(QVector4D)>(31, 10, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 32, 33 },
        }}),
        // Slot 'setUnifiedColorVariation'
        QtMocHelpers::SlotData<void(bool)>(34, 10, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 35 },
        }}),
        // Slot 'setFadeInEffect'
        QtMocHelpers::SlotData<void(QQuick3DParticle::FadeType)>(36, 10, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 37, 38 },
        }}),
        // Slot 'setFadeOutEffect'
        QtMocHelpers::SlotData<void(QQuick3DParticle::FadeType)>(39, 10, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 37, 40 },
        }}),
        // Slot 'setFadeInDuration'
        QtMocHelpers::SlotData<void(int)>(41, 10, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 42 },
        }}),
        // Slot 'setFadeOutDuration'
        QtMocHelpers::SlotData<void(int)>(43, 10, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 44 },
        }}),
        // Slot 'setAlignMode'
        QtMocHelpers::SlotData<void(QQuick3DParticle::AlignMode)>(45, 10, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 46, 47 },
        }}),
        // Slot 'setAlignTargetPosition'
        QtMocHelpers::SlotData<void(const QVector3D &)>(48, 10, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 49, 50 },
        }}),
        // Slot 'setHasTransparency'
        QtMocHelpers::SlotData<void(bool)>(51, 10, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 52 },
        }}),
        // Slot 'setSortMode'
        QtMocHelpers::SlotData<void(QQuick3DParticle::SortMode)>(53, 10, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 54, 55 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'maxAmount'
        QtMocHelpers::PropertyData<int>(27, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'color'
        QtMocHelpers::PropertyData<QColor>(30, 0x80000000 | 29, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'colorVariation'
        QtMocHelpers::PropertyData<QVector4D>(33, 0x80000000 | 32, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'unifiedColorVariation'
        QtMocHelpers::PropertyData<bool>(56, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'fadeInEffect'
        QtMocHelpers::PropertyData<enum FadeType>(38, 0x80000000 | 57, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5),
        // property 'fadeOutEffect'
        QtMocHelpers::PropertyData<enum FadeType>(40, 0x80000000 | 57, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 6),
        // property 'fadeInDuration'
        QtMocHelpers::PropertyData<int>(42, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'fadeOutDuration'
        QtMocHelpers::PropertyData<int>(44, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'alignMode'
        QtMocHelpers::PropertyData<enum AlignMode>(47, 0x80000000 | 58, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 9),
        // property 'alignTargetPosition'
        QtMocHelpers::PropertyData<QVector3D>(59, 0x80000000 | 49, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 10),
        // property 'hasTransparency'
        QtMocHelpers::PropertyData<bool>(60, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'sortMode'
        QtMocHelpers::PropertyData<enum SortMode>(55, 0x80000000 | 61, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 12),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'FadeType'
        QtMocHelpers::EnumData<enum FadeType>(57, 57, QMC::EnumFlags{}).add({
            {   62, FadeType::FadeNone },
            {   63, FadeType::FadeOpacity },
            {   64, FadeType::FadeScale },
        }),
        // enum 'AlignMode'
        QtMocHelpers::EnumData<enum AlignMode>(58, 58, QMC::EnumFlags{}).add({
            {   65, AlignMode::AlignNone },
            {   66, AlignMode::AlignTowardsTarget },
            {   67, AlignMode::AlignTowardsStartVelocity },
        }),
        // enum 'SortMode'
        QtMocHelpers::EnumData<enum SortMode>(61, 61, QMC::EnumFlags{}).add({
            {   68, SortMode::SortNone },
            {   69, SortMode::SortNewest },
            {   70, SortMode::SortOldest },
            {   71, SortMode::SortDistance },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
            {    7,    8 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DParticle, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DParticle::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuick3DObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16QQuick3DParticleE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16QQuick3DParticleE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16QQuick3DParticleE_t>.metaTypes,
    nullptr
} };

void QQuick3DParticle::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DParticle *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->systemChanged(); break;
        case 1: _t->maxAmountChanged(); break;
        case 2: _t->colorChanged(); break;
        case 3: _t->colorVariationChanged(); break;
        case 4: _t->unifiedColorVariationChanged(); break;
        case 5: _t->fadeInEffectChanged(); break;
        case 6: _t->fadeOutEffectChanged(); break;
        case 7: _t->fadeInDurationChanged(); break;
        case 8: _t->fadeOutDurationChanged(); break;
        case 9: _t->alignModeChanged(); break;
        case 10: _t->alignTargetPositionChanged(); break;
        case 11: _t->hasTransparencyChanged(); break;
        case 12: _t->sortModeChanged(); break;
        case 13: _t->setSystem((*reinterpret_cast<std::add_pointer_t<QQuick3DParticleSystem*>>(_a[1]))); break;
        case 14: _t->setMaxAmount((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 15: _t->setColor((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 16: _t->setColorVariation((*reinterpret_cast<std::add_pointer_t<QVector4D>>(_a[1]))); break;
        case 17: _t->setUnifiedColorVariation((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 18: _t->setFadeInEffect((*reinterpret_cast<std::add_pointer_t<QQuick3DParticle::FadeType>>(_a[1]))); break;
        case 19: _t->setFadeOutEffect((*reinterpret_cast<std::add_pointer_t<QQuick3DParticle::FadeType>>(_a[1]))); break;
        case 20: _t->setFadeInDuration((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 21: _t->setFadeOutDuration((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 22: _t->setAlignMode((*reinterpret_cast<std::add_pointer_t<QQuick3DParticle::AlignMode>>(_a[1]))); break;
        case 23: _t->setAlignTargetPosition((*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[1]))); break;
        case 24: _t->setHasTransparency((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 25: _t->setSortMode((*reinterpret_cast<std::add_pointer_t<QQuick3DParticle::SortMode>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DParticleSystem* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticle::*)()>(_a, &QQuick3DParticle::systemChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticle::*)()>(_a, &QQuick3DParticle::maxAmountChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticle::*)()>(_a, &QQuick3DParticle::colorChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticle::*)()>(_a, &QQuick3DParticle::colorVariationChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticle::*)()>(_a, &QQuick3DParticle::unifiedColorVariationChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticle::*)()>(_a, &QQuick3DParticle::fadeInEffectChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticle::*)()>(_a, &QQuick3DParticle::fadeOutEffectChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticle::*)()>(_a, &QQuick3DParticle::fadeInDurationChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticle::*)()>(_a, &QQuick3DParticle::fadeOutDurationChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticle::*)()>(_a, &QQuick3DParticle::alignModeChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticle::*)()>(_a, &QQuick3DParticle::alignTargetPositionChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticle::*)()>(_a, &QQuick3DParticle::hasTransparencyChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticle::*)()>(_a, &QQuick3DParticle::sortModeChanged, 12))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->maxAmount(); break;
        case 1: *reinterpret_cast<QColor*>(_v) = _t->color(); break;
        case 2: *reinterpret_cast<QVector4D*>(_v) = _t->colorVariation(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->unifiedColorVariation(); break;
        case 4: *reinterpret_cast<enum FadeType*>(_v) = _t->fadeInEffect(); break;
        case 5: *reinterpret_cast<enum FadeType*>(_v) = _t->fadeOutEffect(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->fadeInDuration(); break;
        case 7: *reinterpret_cast<int*>(_v) = _t->fadeOutDuration(); break;
        case 8: *reinterpret_cast<enum AlignMode*>(_v) = _t->alignMode(); break;
        case 9: *reinterpret_cast<QVector3D*>(_v) = _t->alignTargetPosition(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->hasTransparency(); break;
        case 11: *reinterpret_cast<enum SortMode*>(_v) = _t->sortMode(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setMaxAmount(*reinterpret_cast<int*>(_v)); break;
        case 1: _t->setColor(*reinterpret_cast<QColor*>(_v)); break;
        case 2: _t->setColorVariation(*reinterpret_cast<QVector4D*>(_v)); break;
        case 3: _t->setUnifiedColorVariation(*reinterpret_cast<bool*>(_v)); break;
        case 4: _t->setFadeInEffect(*reinterpret_cast<enum FadeType*>(_v)); break;
        case 5: _t->setFadeOutEffect(*reinterpret_cast<enum FadeType*>(_v)); break;
        case 6: _t->setFadeInDuration(*reinterpret_cast<int*>(_v)); break;
        case 7: _t->setFadeOutDuration(*reinterpret_cast<int*>(_v)); break;
        case 8: _t->setAlignMode(*reinterpret_cast<enum AlignMode*>(_v)); break;
        case 9: _t->setAlignTargetPosition(*reinterpret_cast<QVector3D*>(_v)); break;
        case 10: _t->setHasTransparency(*reinterpret_cast<bool*>(_v)); break;
        case 11: _t->setSortMode(*reinterpret_cast<enum SortMode*>(_v)); break;
        default: break;
        }
    }
    if (_c == QMetaObject::ResetProperty) {
        switch (_id) {
        case 1: _t->resetColor(); break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DParticle::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DParticle::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16QQuick3DParticleE_t>.strings))
        return static_cast<void*>(this);
    return QQuick3DObject::qt_metacast(_clname);
}

int QQuick3DParticle::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuick3DObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void QQuick3DParticle::systemChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QQuick3DParticle::maxAmountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QQuick3DParticle::colorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QQuick3DParticle::colorVariationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QQuick3DParticle::unifiedColorVariationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QQuick3DParticle::fadeInEffectChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QQuick3DParticle::fadeOutEffectChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void QQuick3DParticle::fadeInDurationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void QQuick3DParticle::fadeOutDurationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void QQuick3DParticle::alignModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void QQuick3DParticle::alignTargetPositionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void QQuick3DParticle::hasTransparencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void QQuick3DParticle::sortModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}
QT_WARNING_POP
