/****************************************************************************
** Meta object code from reading C++ file 'qopenxrinputmanager_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../qtquick3d/src/xr/quick3dxr/openxr/qopenxrinputmanager_p.h"
#include <QtGui/qtextcursor.h>
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qopenxrinputmanager_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN29QQuick3DXrInputManagerPrivateE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DXrInputManagerPrivate::qt_create_metaobjectdata<qt_meta_tag_ZN29QQuick3DXrInputManagerPrivateE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DXrInputManagerPrivate",
        "ActionPaths",
        "leftGripPose",
        "leftAimPose",
        "leftHaptic",
        "rightGripPose",
        "rightAimPose",
        "rightHaptic",
        "InputNames",
        "AClick",
        "BClick",
        "ATouch",
        "BTouch",
        "XClick",
        "YClick",
        "XTouch",
        "YTouch",
        "MenuClick",
        "SystemClick",
        "SystemTouch",
        "SqueezeValue",
        "SqueezeForce",
        "SqueezeClick",
        "TriggerValue",
        "TriggerTouch",
        "TriggerClick",
        "ThumbstickX",
        "ThumbstickY",
        "ThumbstickClick",
        "ThumbstickTouch",
        "ThumbrestTouch",
        "TrackpadX",
        "TrackpadY",
        "TrackpadForce",
        "TrackpadClick",
        "TrackpadTouch"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'ActionPaths'
        QtMocHelpers::EnumData<enum ActionPaths>(1, 1, QMC::EnumIsScoped).add({
            {    2, ActionPaths::leftGripPose },
            {    3, ActionPaths::leftAimPose },
            {    4, ActionPaths::leftHaptic },
            {    5, ActionPaths::rightGripPose },
            {    6, ActionPaths::rightAimPose },
            {    7, ActionPaths::rightHaptic },
        }),
        // enum 'InputNames'
        QtMocHelpers::EnumData<enum InputNames>(8, 8, QMC::EnumIsScoped).add({
            {    9, InputNames::AClick },
            {   10, InputNames::BClick },
            {   11, InputNames::ATouch },
            {   12, InputNames::BTouch },
            {   13, InputNames::XClick },
            {   14, InputNames::YClick },
            {   15, InputNames::XTouch },
            {   16, InputNames::YTouch },
            {   17, InputNames::MenuClick },
            {   18, InputNames::SystemClick },
            {   19, InputNames::SystemTouch },
            {   20, InputNames::SqueezeValue },
            {   21, InputNames::SqueezeForce },
            {   22, InputNames::SqueezeClick },
            {   23, InputNames::TriggerValue },
            {   24, InputNames::TriggerTouch },
            {   25, InputNames::TriggerClick },
            {   26, InputNames::ThumbstickX },
            {   27, InputNames::ThumbstickY },
            {   28, InputNames::ThumbstickClick },
            {   29, InputNames::ThumbstickTouch },
            {   30, InputNames::ThumbrestTouch },
            {   31, InputNames::TrackpadX },
            {   32, InputNames::TrackpadY },
            {   33, InputNames::TrackpadForce },
            {   34, InputNames::TrackpadClick },
            {   35, InputNames::TrackpadTouch },
        }),
    };
    return QtMocHelpers::metaObjectData<QQuick3DXrInputManagerPrivate, qt_meta_tag_ZN29QQuick3DXrInputManagerPrivateE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QQuick3DXrInputManagerPrivate::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29QQuick3DXrInputManagerPrivateE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29QQuick3DXrInputManagerPrivateE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN29QQuick3DXrInputManagerPrivateE_t>.metaTypes,
    nullptr
} };

void QQuick3DXrInputManagerPrivate::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DXrInputManagerPrivate *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *QQuick3DXrInputManagerPrivate::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DXrInputManagerPrivate::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29QQuick3DXrInputManagerPrivateE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QQuick3DXrInputManagerPrivate::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
