/****************************************************************************
** Meta object code from reading C++ file 'gridgeometry_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtquick3d/src/helpers/gridgeometry_p.h"
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'gridgeometry_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12GridGeometryE_t {};
} // unnamed namespace

template <> constexpr inline auto GridGeometry::qt_create_metaobjectdata<qt_meta_tag_ZN12GridGeometryE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "GridGeometry",
        "QML.Element",
        "horizontalLinesChanged",
        "",
        "verticalLinesChanged",
        "horizontalStepChanged",
        "verticalStepChanged",
        "setHorizontalLines",
        "count",
        "setVerticalLines",
        "setHorizontalStep",
        "step",
        "setVerticalStep",
        "horizontalLines",
        "verticalLines",
        "horizontalStep",
        "verticalStep"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'horizontalLinesChanged'
        QtMocHelpers::SignalData<void()>(2, 3, QMC::AccessPublic, QMetaType::Void),
        // Signal 'verticalLinesChanged'
        QtMocHelpers::SignalData<void()>(4, 3, QMC::AccessPublic, QMetaType::Void),
        // Signal 'horizontalStepChanged'
        QtMocHelpers::SignalData<void()>(5, 3, QMC::AccessPublic, QMetaType::Void),
        // Signal 'verticalStepChanged'
        QtMocHelpers::SignalData<void()>(6, 3, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setHorizontalLines'
        QtMocHelpers::SlotData<void(int)>(7, 3, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 8 },
        }}),
        // Slot 'setVerticalLines'
        QtMocHelpers::SlotData<void(int)>(9, 3, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 8 },
        }}),
        // Slot 'setHorizontalStep'
        QtMocHelpers::SlotData<void(float)>(10, 3, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 11 },
        }}),
        // Slot 'setVerticalStep'
        QtMocHelpers::SlotData<void(float)>(12, 3, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 11 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'horizontalLines'
        QtMocHelpers::PropertyData<int>(13, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'verticalLines'
        QtMocHelpers::PropertyData<int>(14, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'horizontalStep'
        QtMocHelpers::PropertyData<float>(15, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'verticalStep'
        QtMocHelpers::PropertyData<float>(16, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    0 },
    });
    return QtMocHelpers::metaObjectData<GridGeometry, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject GridGeometry::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuick3DGeometry::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12GridGeometryE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12GridGeometryE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12GridGeometryE_t>.metaTypes,
    nullptr
} };

void GridGeometry::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<GridGeometry *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->horizontalLinesChanged(); break;
        case 1: _t->verticalLinesChanged(); break;
        case 2: _t->horizontalStepChanged(); break;
        case 3: _t->verticalStepChanged(); break;
        case 4: _t->setHorizontalLines((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->setVerticalLines((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->setHorizontalStep((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 7: _t->setVerticalStep((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (GridGeometry::*)()>(_a, &GridGeometry::horizontalLinesChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (GridGeometry::*)()>(_a, &GridGeometry::verticalLinesChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (GridGeometry::*)()>(_a, &GridGeometry::horizontalStepChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (GridGeometry::*)()>(_a, &GridGeometry::verticalStepChanged, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->horizontalLines(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->verticalLines(); break;
        case 2: *reinterpret_cast<float*>(_v) = _t->horizontalStep(); break;
        case 3: *reinterpret_cast<float*>(_v) = _t->verticalStep(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setHorizontalLines(*reinterpret_cast<int*>(_v)); break;
        case 1: _t->setVerticalLines(*reinterpret_cast<int*>(_v)); break;
        case 2: _t->setHorizontalStep(*reinterpret_cast<float*>(_v)); break;
        case 3: _t->setVerticalStep(*reinterpret_cast<float*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *GridGeometry::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *GridGeometry::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12GridGeometryE_t>.strings))
        return static_cast<void*>(this);
    return QQuick3DGeometry::qt_metacast(_clname);
}

int GridGeometry::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuick3DGeometry::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void GridGeometry::horizontalLinesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void GridGeometry::verticalLinesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void GridGeometry::horizontalStepChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void GridGeometry::verticalStepChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
