/****************************************************************************
** Meta object code from reading C++ file 'lightmapfile.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtquick3d/tools/lightmapviewer/lightmapfile.h"
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'lightmapfile.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12LightmapFileE_t {};
} // unnamed namespace

template <> constexpr inline auto LightmapFile::qt_create_metaobjectdata<qt_meta_tag_ZN12LightmapFileE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "LightmapFile",
        "dataListChanged",
        "",
        "sourceChanged",
        "metadataChanged",
        "loadData",
        "metadataFor",
        "QVariantList",
        "QVariant",
        "selectedEntry",
        "keysReferencingMesh",
        "meshKey",
        "textureDataFor",
        "QQuick3DTextureData*",
        "key",
        "tag",
        "texturesAvailableFor",
        "dataList",
        "source",
        "QUrl",
        "qtVersion",
        "bakeStart",
        "bakeDuration",
        "options"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'dataListChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sourceChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'metadataChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'loadData'
        QtMocHelpers::MethodData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'metadataFor'
        QtMocHelpers::MethodData<QVariantList(const QVariant &)>(6, 2, QMC::AccessPublic, 0x80000000 | 7, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Method 'keysReferencingMesh'
        QtMocHelpers::MethodData<QStringList(const QString &) const>(10, 2, QMC::AccessPublic, QMetaType::QStringList, {{
            { QMetaType::QString, 11 },
        }}),
        // Method 'textureDataFor'
        QtMocHelpers::MethodData<QQuick3DTextureData *(const QString &, quint32)>(12, 2, QMC::AccessPublic, 0x80000000 | 13, {{
            { QMetaType::QString, 14 }, { QMetaType::UInt, 15 },
        }}),
        // Method 'texturesAvailableFor'
        QtMocHelpers::MethodData<QVariantList(const QString &) const>(16, 2, QMC::AccessPublic, 0x80000000 | 7, {{
            { QMetaType::QString, 14 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'dataList'
        QtMocHelpers::PropertyData<QVariantList>(17, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'source'
        QtMocHelpers::PropertyData<QUrl>(18, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 1),
        // property 'qtVersion'
        QtMocHelpers::PropertyData<QString>(20, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Final, 2),
        // property 'bakeStart'
        QtMocHelpers::PropertyData<QString>(21, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Final, 2),
        // property 'bakeDuration'
        QtMocHelpers::PropertyData<QString>(22, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Final, 2),
        // property 'options'
        QtMocHelpers::PropertyData<QVariantList>(23, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 2),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<LightmapFile, qt_meta_tag_ZN12LightmapFileE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject LightmapFile::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12LightmapFileE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12LightmapFileE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12LightmapFileE_t>.metaTypes,
    nullptr
} };

void LightmapFile::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<LightmapFile *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->dataListChanged(); break;
        case 1: _t->sourceChanged(); break;
        case 2: _t->metadataChanged(); break;
        case 3: _t->loadData(); break;
        case 4: { QVariantList _r = _t->metadataFor((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 5: { QStringList _r = _t->keysReferencingMesh((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 6: { QQuick3DTextureData* _r = _t->textureDataFor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<quint32>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QQuick3DTextureData**>(_a[0]) = std::move(_r); }  break;
        case 7: { QVariantList _r = _t->texturesAvailableFor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVariantList*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (LightmapFile::*)()>(_a, &LightmapFile::dataListChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (LightmapFile::*)()>(_a, &LightmapFile::sourceChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (LightmapFile::*)()>(_a, &LightmapFile::metadataChanged, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QVariantList*>(_v) = _t->dataList(); break;
        case 1: *reinterpret_cast<QUrl*>(_v) = _t->source(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->qtVersion(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->bakeStart(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->bakeDuration(); break;
        case 5: *reinterpret_cast<QVariantList*>(_v) = _t->options(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setSource(*reinterpret_cast<QUrl*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *LightmapFile::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *LightmapFile::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12LightmapFileE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int LightmapFile::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void LightmapFile::dataListChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void LightmapFile::sourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void LightmapFile::metadataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
