/****************************************************************************
** Meta object code from reading C++ file 'qquick3dreflectionprobe_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtquick3d/src/quick3d/qquick3dreflectionprobe_p.h"
#include <QtNetwork/QSslError>
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquick3dreflectionprobe_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN23QQuick3DReflectionProbeE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DReflectionProbe::qt_create_metaobjectdata<qt_meta_tag_ZN23QQuick3DReflectionProbeE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DReflectionProbe",
        "QML.Element",
        "ReflectionProbe",
        "QML.AddedInVersion",
        "1539",
        "qualityChanged",
        "",
        "clearColorChanged",
        "refreshModeChanged",
        "timeSlicingChanged",
        "parallaxCorrectionChanged",
        "boxSizeChanged",
        "debugViewChanged",
        "boxOffsetChanged",
        "textureChanged",
        "setQuality",
        "ReflectionQuality",
        "reflectionQuality",
        "setClearColor",
        "QColor",
        "clearColor",
        "setRefreshMode",
        "ReflectionRefreshMode",
        "newRefreshMode",
        "setTimeSlicing",
        "ReflectionTimeSlicing",
        "newTimeSlicing",
        "setParallaxCorrection",
        "parallaxCorrection",
        "setBoxSize",
        "QVector3D",
        "newBoxSize",
        "setDebugView",
        "debugView",
        "setBoxOffset",
        "boxOffset",
        "setTexture",
        "QQuick3DCubeMapTexture*",
        "newTexture",
        "scheduleUpdate",
        "quality",
        "refreshMode",
        "timeSlicing",
        "boxSize",
        "texture",
        "VeryLow",
        "Low",
        "Medium",
        "High",
        "VeryHigh",
        "FirstFrame",
        "EveryFrame",
        "None",
        "AllFacesAtOnce",
        "IndividualFaces"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'qualityChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'clearColorChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'refreshModeChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'timeSlicingChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'parallaxCorrectionChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'boxSizeChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'debugViewChanged'
        QtMocHelpers::RevisionedSignalData<void()>(12, 6, QMC::AccessPublic, 0x604, QMetaType::Void),
        // Signal 'boxOffsetChanged'
        QtMocHelpers::RevisionedSignalData<void()>(13, 6, QMC::AccessPublic, 0x604, QMetaType::Void),
        // Signal 'textureChanged'
        QtMocHelpers::RevisionedSignalData<void()>(14, 6, QMC::AccessPublic, 0x605, QMetaType::Void),
        // Slot 'setQuality'
        QtMocHelpers::SlotData<void(enum ReflectionQuality)>(15, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Slot 'setClearColor'
        QtMocHelpers::SlotData<void(const QColor &)>(18, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Slot 'setRefreshMode'
        QtMocHelpers::SlotData<void(enum ReflectionRefreshMode)>(21, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Slot 'setTimeSlicing'
        QtMocHelpers::SlotData<void(enum ReflectionTimeSlicing)>(24, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 25, 26 },
        }}),
        // Slot 'setParallaxCorrection'
        QtMocHelpers::SlotData<void(bool)>(27, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 28 },
        }}),
        // Slot 'setBoxSize'
        QtMocHelpers::SlotData<void(const QVector3D &)>(29, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 30, 31 },
        }}),
        // Slot 'setDebugView'
        QtMocHelpers::RevisionedSlotData<void(bool)>(32, 6, QMC::AccessPublic, 0x604, QMetaType::Void, {{
            { QMetaType::Bool, 33 },
        }}),
        // Slot 'setBoxOffset'
        QtMocHelpers::RevisionedSlotData<void(const QVector3D &)>(34, 6, QMC::AccessPublic, 0x604, QMetaType::Void, {{
            { 0x80000000 | 30, 35 },
        }}),
        // Slot 'setTexture'
        QtMocHelpers::RevisionedSlotData<void(QQuick3DCubeMapTexture *)>(36, 6, QMC::AccessPublic, 0x605, QMetaType::Void, {{
            { 0x80000000 | 37, 38 },
        }}),
        // Method 'scheduleUpdate'
        QtMocHelpers::RevisionedMethodData<void()>(39, 6, QMC::AccessPublic, 0x604, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'quality'
        QtMocHelpers::PropertyData<enum ReflectionQuality>(40, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'clearColor'
        QtMocHelpers::PropertyData<QColor>(20, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'refreshMode'
        QtMocHelpers::PropertyData<enum ReflectionRefreshMode>(41, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'timeSlicing'
        QtMocHelpers::PropertyData<enum ReflectionTimeSlicing>(42, 0x80000000 | 25, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'parallaxCorrection'
        QtMocHelpers::PropertyData<bool>(28, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'boxSize'
        QtMocHelpers::PropertyData<QVector3D>(43, 0x80000000 | 30, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5),
        // property 'boxOffset'
        QtMocHelpers::PropertyData<QVector3D>(35, 0x80000000 | 30, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 7, 0x604),
        // property 'debugView'
        QtMocHelpers::PropertyData<bool>(33, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6, 0x604),
        // property 'texture'
        QtMocHelpers::PropertyData<QQuick3DCubeMapTexture*>(44, 0x80000000 | 37, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 8, 0x605),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'ReflectionQuality'
        QtMocHelpers::EnumData<enum ReflectionQuality>(16, 16, QMC::EnumIsScoped).add({
            {   45, ReflectionQuality::VeryLow },
            {   46, ReflectionQuality::Low },
            {   47, ReflectionQuality::Medium },
            {   48, ReflectionQuality::High },
            {   49, ReflectionQuality::VeryHigh },
        }),
        // enum 'ReflectionRefreshMode'
        QtMocHelpers::EnumData<enum ReflectionRefreshMode>(22, 22, QMC::EnumIsScoped).add({
            {   50, ReflectionRefreshMode::FirstFrame },
            {   51, ReflectionRefreshMode::EveryFrame },
        }),
        // enum 'ReflectionTimeSlicing'
        QtMocHelpers::EnumData<enum ReflectionTimeSlicing>(25, 25, QMC::EnumIsScoped).add({
            {   52, ReflectionTimeSlicing::None },
            {   53, ReflectionTimeSlicing::AllFacesAtOnce },
            {   54, ReflectionTimeSlicing::IndividualFaces },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DReflectionProbe, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DReflectionProbe::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuick3DNode::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23QQuick3DReflectionProbeE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23QQuick3DReflectionProbeE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23QQuick3DReflectionProbeE_t>.metaTypes,
    nullptr
} };

void QQuick3DReflectionProbe::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DReflectionProbe *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->qualityChanged(); break;
        case 1: _t->clearColorChanged(); break;
        case 2: _t->refreshModeChanged(); break;
        case 3: _t->timeSlicingChanged(); break;
        case 4: _t->parallaxCorrectionChanged(); break;
        case 5: _t->boxSizeChanged(); break;
        case 6: _t->debugViewChanged(); break;
        case 7: _t->boxOffsetChanged(); break;
        case 8: _t->textureChanged(); break;
        case 9: _t->setQuality((*reinterpret_cast<std::add_pointer_t<enum ReflectionQuality>>(_a[1]))); break;
        case 10: _t->setClearColor((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 11: _t->setRefreshMode((*reinterpret_cast<std::add_pointer_t<enum ReflectionRefreshMode>>(_a[1]))); break;
        case 12: _t->setTimeSlicing((*reinterpret_cast<std::add_pointer_t<enum ReflectionTimeSlicing>>(_a[1]))); break;
        case 13: _t->setParallaxCorrection((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 14: _t->setBoxSize((*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[1]))); break;
        case 15: _t->setDebugView((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 16: _t->setBoxOffset((*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[1]))); break;
        case 17: _t->setTexture((*reinterpret_cast<std::add_pointer_t<QQuick3DCubeMapTexture*>>(_a[1]))); break;
        case 18: _t->scheduleUpdate(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DCubeMapTexture* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuick3DReflectionProbe::*)()>(_a, &QQuick3DReflectionProbe::qualityChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DReflectionProbe::*)()>(_a, &QQuick3DReflectionProbe::clearColorChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DReflectionProbe::*)()>(_a, &QQuick3DReflectionProbe::refreshModeChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DReflectionProbe::*)()>(_a, &QQuick3DReflectionProbe::timeSlicingChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DReflectionProbe::*)()>(_a, &QQuick3DReflectionProbe::parallaxCorrectionChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DReflectionProbe::*)()>(_a, &QQuick3DReflectionProbe::boxSizeChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DReflectionProbe::*)()>(_a, &QQuick3DReflectionProbe::debugViewChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DReflectionProbe::*)()>(_a, &QQuick3DReflectionProbe::boxOffsetChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DReflectionProbe::*)()>(_a, &QQuick3DReflectionProbe::textureChanged, 8))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 8:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuick3DCubeMapTexture* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<enum ReflectionQuality*>(_v) = _t->quality(); break;
        case 1: *reinterpret_cast<QColor*>(_v) = _t->clearColor(); break;
        case 2: *reinterpret_cast<enum ReflectionRefreshMode*>(_v) = _t->refreshMode(); break;
        case 3: *reinterpret_cast<enum ReflectionTimeSlicing*>(_v) = _t->timeSlicing(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->parallaxCorrection(); break;
        case 5: *reinterpret_cast<QVector3D*>(_v) = _t->boxSize(); break;
        case 6: *reinterpret_cast<QVector3D*>(_v) = _t->boxOffset(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->debugView(); break;
        case 8: *reinterpret_cast<QQuick3DCubeMapTexture**>(_v) = _t->texture(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setQuality(*reinterpret_cast<enum ReflectionQuality*>(_v)); break;
        case 1: _t->setClearColor(*reinterpret_cast<QColor*>(_v)); break;
        case 2: _t->setRefreshMode(*reinterpret_cast<enum ReflectionRefreshMode*>(_v)); break;
        case 3: _t->setTimeSlicing(*reinterpret_cast<enum ReflectionTimeSlicing*>(_v)); break;
        case 4: _t->setParallaxCorrection(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setBoxSize(*reinterpret_cast<QVector3D*>(_v)); break;
        case 6: _t->setBoxOffset(*reinterpret_cast<QVector3D*>(_v)); break;
        case 7: _t->setDebugView(*reinterpret_cast<bool*>(_v)); break;
        case 8: _t->setTexture(*reinterpret_cast<QQuick3DCubeMapTexture**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DReflectionProbe::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DReflectionProbe::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23QQuick3DReflectionProbeE_t>.strings))
        return static_cast<void*>(this);
    return QQuick3DNode::qt_metacast(_clname);
}

int QQuick3DReflectionProbe::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuick3DNode::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void QQuick3DReflectionProbe::qualityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QQuick3DReflectionProbe::clearColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QQuick3DReflectionProbe::refreshModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QQuick3DReflectionProbe::timeSlicingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QQuick3DReflectionProbe::parallaxCorrectionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QQuick3DReflectionProbe::boxSizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QQuick3DReflectionProbe::debugViewChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void QQuick3DReflectionProbe::boxOffsetChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void QQuick3DReflectionProbe::textureChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
QT_WARNING_POP
