/****************************************************************************
** Meta object code from reading C++ file 'qquick3dabstractlight_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtquick3d/src/quick3d/qquick3dabstractlight_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquick3dabstractlight_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN21QQuick3DAbstractLightE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DAbstractLight::qt_create_metaobjectdata<qt_meta_tag_ZN21QQuick3DAbstractLightE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DAbstractLight",
        "QML.Element",
        "Light",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Light is Abstract",
        "colorChanged",
        "",
        "ambientColorChanged",
        "brightnessChanged",
        "scopeChanged",
        "castsShadowChanged",
        "shadowBiasChanged",
        "shadowFactorChanged",
        "shadowMapQualityChanged",
        "shadowMapFarChanged",
        "shadowFilterChanged",
        "bakeModeChanged",
        "softShadowQualityChanged",
        "pcfFactorChanged",
        "use32BitShadowmapChanged",
        "setColor",
        "QColor",
        "color",
        "setAmbientColor",
        "ambientColor",
        "setBrightness",
        "brightness",
        "setScope",
        "QQuick3DNode*",
        "scope",
        "setCastsShadow",
        "castsShadow",
        "setShadowBias",
        "shadowBias",
        "setShadowFactor",
        "shadowFactor",
        "setShadowMapQuality",
        "QQuick3DAbstractLight::QSSGShadowMapQuality",
        "shadowMapQuality",
        "setShadowMapFar",
        "shadowMapFar",
        "setShadowFilter",
        "shadowFilter",
        "setBakeMode",
        "QQuick3DAbstractLight::QSSGBakeMode",
        "bakeMode",
        "setSoftShadowQuality",
        "QQuick3DAbstractLight::QSSGSoftShadowQuality",
        "softShadowQuality",
        "setPcfFactor",
        "pcfFactor",
        "setUse32BitShadowmap",
        "use32BitShadowmap",
        "QSSGShadowMapQuality",
        "QSSGBakeMode",
        "QSSGSoftShadowQuality",
        "ShadowMapQualityLow",
        "ShadowMapQualityMedium",
        "ShadowMapQualityHigh",
        "ShadowMapQualityVeryHigh",
        "ShadowMapQualityUltra",
        "Hard",
        "PCF4",
        "PCF8",
        "PCF16",
        "PCF32",
        "PCF64",
        "BakeModeDisabled",
        "BakeModeIndirect",
        "BakeModeAll"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'colorChanged'
        QtMocHelpers::SignalData<void()>(7, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ambientColorChanged'
        QtMocHelpers::SignalData<void()>(9, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'brightnessChanged'
        QtMocHelpers::SignalData<void()>(10, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scopeChanged'
        QtMocHelpers::SignalData<void()>(11, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'castsShadowChanged'
        QtMocHelpers::SignalData<void()>(12, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'shadowBiasChanged'
        QtMocHelpers::SignalData<void()>(13, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'shadowFactorChanged'
        QtMocHelpers::SignalData<void()>(14, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'shadowMapQualityChanged'
        QtMocHelpers::SignalData<void()>(15, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'shadowMapFarChanged'
        QtMocHelpers::SignalData<void()>(16, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'shadowFilterChanged'
        QtMocHelpers::SignalData<void()>(17, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'bakeModeChanged'
        QtMocHelpers::SignalData<void()>(18, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'softShadowQualityChanged'
        QtMocHelpers::RevisionedSignalData<void()>(19, 8, QMC::AccessPublic, 0x608, QMetaType::Void),
        // Signal 'pcfFactorChanged'
        QtMocHelpers::RevisionedSignalData<void()>(20, 8, QMC::AccessPublic, 0x608, QMetaType::Void),
        // Signal 'use32BitShadowmapChanged'
        QtMocHelpers::RevisionedSignalData<void()>(21, 8, QMC::AccessPublic, 0x609, QMetaType::Void),
        // Slot 'setColor'
        QtMocHelpers::SlotData<void(const QColor &)>(22, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 23, 24 },
        }}),
        // Slot 'setAmbientColor'
        QtMocHelpers::SlotData<void(const QColor &)>(25, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 23, 26 },
        }}),
        // Slot 'setBrightness'
        QtMocHelpers::SlotData<void(float)>(27, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 28 },
        }}),
        // Slot 'setScope'
        QtMocHelpers::SlotData<void(QQuick3DNode *)>(29, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 30, 31 },
        }}),
        // Slot 'setCastsShadow'
        QtMocHelpers::SlotData<void(bool)>(32, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 33 },
        }}),
        // Slot 'setShadowBias'
        QtMocHelpers::SlotData<void(float)>(34, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 35 },
        }}),
        // Slot 'setShadowFactor'
        QtMocHelpers::SlotData<void(float)>(36, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 37 },
        }}),
        // Slot 'setShadowMapQuality'
        QtMocHelpers::SlotData<void(QQuick3DAbstractLight::QSSGShadowMapQuality)>(38, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 39, 40 },
        }}),
        // Slot 'setShadowMapFar'
        QtMocHelpers::SlotData<void(float)>(41, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 42 },
        }}),
        // Slot 'setShadowFilter'
        QtMocHelpers::SlotData<void(float)>(43, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 44 },
        }}),
        // Slot 'setBakeMode'
        QtMocHelpers::SlotData<void(QQuick3DAbstractLight::QSSGBakeMode)>(45, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 46, 47 },
        }}),
        // Slot 'setSoftShadowQuality'
        QtMocHelpers::RevisionedSlotData<void(QQuick3DAbstractLight::QSSGSoftShadowQuality)>(48, 8, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { 0x80000000 | 49, 50 },
        }}),
        // Slot 'setPcfFactor'
        QtMocHelpers::RevisionedSlotData<void(float)>(51, 8, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { QMetaType::Float, 52 },
        }}),
        // Slot 'setUse32BitShadowmap'
        QtMocHelpers::RevisionedSlotData<void(bool)>(53, 8, QMC::AccessPublic, 0x609, QMetaType::Void, {{
            { QMetaType::Bool, 54 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'color'
        QtMocHelpers::PropertyData<QColor>(24, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'ambientColor'
        QtMocHelpers::PropertyData<QColor>(26, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'brightness'
        QtMocHelpers::PropertyData<float>(28, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'scope'
        QtMocHelpers::PropertyData<QQuick3DNode*>(31, 0x80000000 | 30, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'castsShadow'
        QtMocHelpers::PropertyData<bool>(33, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'shadowBias'
        QtMocHelpers::PropertyData<float>(35, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'shadowFactor'
        QtMocHelpers::PropertyData<float>(37, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'shadowMapQuality'
        QtMocHelpers::PropertyData<enum QSSGShadowMapQuality>(40, 0x80000000 | 55, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 7),
        // property 'shadowMapFar'
        QtMocHelpers::PropertyData<float>(42, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'shadowFilter'
        QtMocHelpers::PropertyData<float>(44, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'bakeMode'
        QtMocHelpers::PropertyData<enum QSSGBakeMode>(47, 0x80000000 | 56, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 10),
        // property 'softShadowQuality'
        QtMocHelpers::PropertyData<enum QSSGSoftShadowQuality>(50, 0x80000000 | 57, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 11, 0x608),
        // property 'pcfFactor'
        QtMocHelpers::PropertyData<float>(52, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 12, 0x608),
        // property 'use32BitShadowmap'
        QtMocHelpers::PropertyData<bool>(54, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 13, 0x609),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'QSSGShadowMapQuality'
        QtMocHelpers::EnumData<enum QSSGShadowMapQuality>(55, 55, QMC::EnumIsScoped).add({
            {   58, QSSGShadowMapQuality::ShadowMapQualityLow },
            {   59, QSSGShadowMapQuality::ShadowMapQualityMedium },
            {   60, QSSGShadowMapQuality::ShadowMapQualityHigh },
            {   61, QSSGShadowMapQuality::ShadowMapQualityVeryHigh },
            {   62, QSSGShadowMapQuality::ShadowMapQualityUltra },
        }),
        // enum 'QSSGSoftShadowQuality'
        QtMocHelpers::EnumData<enum QSSGSoftShadowQuality>(57, 57, QMC::EnumIsScoped).add({
            {   63, QSSGSoftShadowQuality::Hard },
            {   64, QSSGSoftShadowQuality::PCF4 },
            {   65, QSSGSoftShadowQuality::PCF8 },
            {   66, QSSGSoftShadowQuality::PCF16 },
            {   67, QSSGSoftShadowQuality::PCF32 },
            {   68, QSSGSoftShadowQuality::PCF64 },
        }),
        // enum 'QSSGBakeMode'
        QtMocHelpers::EnumData<enum QSSGBakeMode>(56, 56, QMC::EnumIsScoped).add({
            {   69, QSSGBakeMode::BakeModeDisabled },
            {   70, QSSGBakeMode::BakeModeIndirect },
            {   71, QSSGBakeMode::BakeModeAll },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DAbstractLight, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DAbstractLight::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuick3DNode::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21QQuick3DAbstractLightE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21QQuick3DAbstractLightE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21QQuick3DAbstractLightE_t>.metaTypes,
    nullptr
} };

void QQuick3DAbstractLight::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DAbstractLight *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->colorChanged(); break;
        case 1: _t->ambientColorChanged(); break;
        case 2: _t->brightnessChanged(); break;
        case 3: _t->scopeChanged(); break;
        case 4: _t->castsShadowChanged(); break;
        case 5: _t->shadowBiasChanged(); break;
        case 6: _t->shadowFactorChanged(); break;
        case 7: _t->shadowMapQualityChanged(); break;
        case 8: _t->shadowMapFarChanged(); break;
        case 9: _t->shadowFilterChanged(); break;
        case 10: _t->bakeModeChanged(); break;
        case 11: _t->softShadowQualityChanged(); break;
        case 12: _t->pcfFactorChanged(); break;
        case 13: _t->use32BitShadowmapChanged(); break;
        case 14: _t->setColor((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 15: _t->setAmbientColor((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 16: _t->setBrightness((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 17: _t->setScope((*reinterpret_cast<std::add_pointer_t<QQuick3DNode*>>(_a[1]))); break;
        case 18: _t->setCastsShadow((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 19: _t->setShadowBias((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 20: _t->setShadowFactor((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 21: _t->setShadowMapQuality((*reinterpret_cast<std::add_pointer_t<QQuick3DAbstractLight::QSSGShadowMapQuality>>(_a[1]))); break;
        case 22: _t->setShadowMapFar((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 23: _t->setShadowFilter((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 24: _t->setBakeMode((*reinterpret_cast<std::add_pointer_t<QQuick3DAbstractLight::QSSGBakeMode>>(_a[1]))); break;
        case 25: _t->setSoftShadowQuality((*reinterpret_cast<std::add_pointer_t<QQuick3DAbstractLight::QSSGSoftShadowQuality>>(_a[1]))); break;
        case 26: _t->setPcfFactor((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 27: _t->setUse32BitShadowmap((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DNode* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuick3DAbstractLight::*)()>(_a, &QQuick3DAbstractLight::colorChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DAbstractLight::*)()>(_a, &QQuick3DAbstractLight::ambientColorChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DAbstractLight::*)()>(_a, &QQuick3DAbstractLight::brightnessChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DAbstractLight::*)()>(_a, &QQuick3DAbstractLight::scopeChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DAbstractLight::*)()>(_a, &QQuick3DAbstractLight::castsShadowChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DAbstractLight::*)()>(_a, &QQuick3DAbstractLight::shadowBiasChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DAbstractLight::*)()>(_a, &QQuick3DAbstractLight::shadowFactorChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DAbstractLight::*)()>(_a, &QQuick3DAbstractLight::shadowMapQualityChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DAbstractLight::*)()>(_a, &QQuick3DAbstractLight::shadowMapFarChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DAbstractLight::*)()>(_a, &QQuick3DAbstractLight::shadowFilterChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DAbstractLight::*)()>(_a, &QQuick3DAbstractLight::bakeModeChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DAbstractLight::*)()>(_a, &QQuick3DAbstractLight::softShadowQualityChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DAbstractLight::*)()>(_a, &QQuick3DAbstractLight::pcfFactorChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DAbstractLight::*)()>(_a, &QQuick3DAbstractLight::use32BitShadowmapChanged, 13))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuick3DNode* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QColor*>(_v) = _t->color(); break;
        case 1: *reinterpret_cast<QColor*>(_v) = _t->ambientColor(); break;
        case 2: *reinterpret_cast<float*>(_v) = _t->brightness(); break;
        case 3: *reinterpret_cast<QQuick3DNode**>(_v) = _t->scope(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->castsShadow(); break;
        case 5: *reinterpret_cast<float*>(_v) = _t->shadowBias(); break;
        case 6: *reinterpret_cast<float*>(_v) = _t->shadowFactor(); break;
        case 7: *reinterpret_cast<enum QSSGShadowMapQuality*>(_v) = _t->shadowMapQuality(); break;
        case 8: *reinterpret_cast<float*>(_v) = _t->shadowMapFar(); break;
        case 9: *reinterpret_cast<float*>(_v) = _t->shadowFilter(); break;
        case 10: *reinterpret_cast<enum QSSGBakeMode*>(_v) = _t->bakeMode(); break;
        case 11: *reinterpret_cast<enum QSSGSoftShadowQuality*>(_v) = _t->softShadowQuality(); break;
        case 12: *reinterpret_cast<float*>(_v) = _t->pcfFactor(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->use32BitShadowmap(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setColor(*reinterpret_cast<QColor*>(_v)); break;
        case 1: _t->setAmbientColor(*reinterpret_cast<QColor*>(_v)); break;
        case 2: _t->setBrightness(*reinterpret_cast<float*>(_v)); break;
        case 3: _t->setScope(*reinterpret_cast<QQuick3DNode**>(_v)); break;
        case 4: _t->setCastsShadow(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setShadowBias(*reinterpret_cast<float*>(_v)); break;
        case 6: _t->setShadowFactor(*reinterpret_cast<float*>(_v)); break;
        case 7: _t->setShadowMapQuality(*reinterpret_cast<enum QSSGShadowMapQuality*>(_v)); break;
        case 8: _t->setShadowMapFar(*reinterpret_cast<float*>(_v)); break;
        case 9: _t->setShadowFilter(*reinterpret_cast<float*>(_v)); break;
        case 10: _t->setBakeMode(*reinterpret_cast<enum QSSGBakeMode*>(_v)); break;
        case 11: _t->setSoftShadowQuality(*reinterpret_cast<enum QSSGSoftShadowQuality*>(_v)); break;
        case 12: _t->setPcfFactor(*reinterpret_cast<float*>(_v)); break;
        case 13: _t->setUse32BitShadowmap(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DAbstractLight::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DAbstractLight::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21QQuick3DAbstractLightE_t>.strings))
        return static_cast<void*>(this);
    return QQuick3DNode::qt_metacast(_clname);
}

int QQuick3DAbstractLight::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuick3DNode::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 28)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 28;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 28)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 28;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void QQuick3DAbstractLight::colorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QQuick3DAbstractLight::ambientColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QQuick3DAbstractLight::brightnessChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QQuick3DAbstractLight::scopeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QQuick3DAbstractLight::castsShadowChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QQuick3DAbstractLight::shadowBiasChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QQuick3DAbstractLight::shadowFactorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void QQuick3DAbstractLight::shadowMapQualityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void QQuick3DAbstractLight::shadowMapFarChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void QQuick3DAbstractLight::shadowFilterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void QQuick3DAbstractLight::bakeModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void QQuick3DAbstractLight::softShadowQualityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void QQuick3DAbstractLight::pcfFactorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void QQuick3DAbstractLight::use32BitShadowmapChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}
QT_WARNING_POP
