/****************************************************************************
** Meta object code from reading C++ file 'qquick3dorthographiccamera_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtquick3d/src/quick3d/qquick3dorthographiccamera_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquick3dorthographiccamera_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN26QQuick3DOrthographicCameraE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DOrthographicCamera::qt_create_metaobjectdata<qt_meta_tag_ZN26QQuick3DOrthographicCameraE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DOrthographicCamera",
        "QML.Element",
        "OrthographicCamera",
        "clipNearChanged",
        "",
        "clipFarChanged",
        "horizontalMagnificationChanged",
        "verticalMagnificationChanged",
        "setClipNear",
        "clipNear",
        "setClipFar",
        "clipFar",
        "setHorizontalMagnification",
        "horizontalMagnification",
        "setVerticalMagnification",
        "verticalMagnification"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'clipNearChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'clipFarChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'horizontalMagnificationChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'verticalMagnificationChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setClipNear'
        QtMocHelpers::SlotData<void(float)>(8, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 9 },
        }}),
        // Slot 'setClipFar'
        QtMocHelpers::SlotData<void(float)>(10, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 11 },
        }}),
        // Slot 'setHorizontalMagnification'
        QtMocHelpers::SlotData<void(float)>(12, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 13 },
        }}),
        // Slot 'setVerticalMagnification'
        QtMocHelpers::SlotData<void(float)>(14, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 13 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'clipNear'
        QtMocHelpers::PropertyData<float>(9, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'clipFar'
        QtMocHelpers::PropertyData<float>(11, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'horizontalMagnification'
        QtMocHelpers::PropertyData<float>(13, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'verticalMagnification'
        QtMocHelpers::PropertyData<float>(15, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DOrthographicCamera, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DOrthographicCamera::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuick3DCamera::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26QQuick3DOrthographicCameraE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26QQuick3DOrthographicCameraE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN26QQuick3DOrthographicCameraE_t>.metaTypes,
    nullptr
} };

void QQuick3DOrthographicCamera::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DOrthographicCamera *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->clipNearChanged(); break;
        case 1: _t->clipFarChanged(); break;
        case 2: _t->horizontalMagnificationChanged(); break;
        case 3: _t->verticalMagnificationChanged(); break;
        case 4: _t->setClipNear((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 5: _t->setClipFar((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 6: _t->setHorizontalMagnification((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 7: _t->setVerticalMagnification((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuick3DOrthographicCamera::*)()>(_a, &QQuick3DOrthographicCamera::clipNearChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DOrthographicCamera::*)()>(_a, &QQuick3DOrthographicCamera::clipFarChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DOrthographicCamera::*)()>(_a, &QQuick3DOrthographicCamera::horizontalMagnificationChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DOrthographicCamera::*)()>(_a, &QQuick3DOrthographicCamera::verticalMagnificationChanged, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<float*>(_v) = _t->clipNear(); break;
        case 1: *reinterpret_cast<float*>(_v) = _t->clipFar(); break;
        case 2: *reinterpret_cast<float*>(_v) = _t->horizontalMagnification(); break;
        case 3: *reinterpret_cast<float*>(_v) = _t->verticalMagnification(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setClipNear(*reinterpret_cast<float*>(_v)); break;
        case 1: _t->setClipFar(*reinterpret_cast<float*>(_v)); break;
        case 2: _t->setHorizontalMagnification(*reinterpret_cast<float*>(_v)); break;
        case 3: _t->setVerticalMagnification(*reinterpret_cast<float*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DOrthographicCamera::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DOrthographicCamera::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26QQuick3DOrthographicCameraE_t>.strings))
        return static_cast<void*>(this);
    return QQuick3DCamera::qt_metacast(_clname);
}

int QQuick3DOrthographicCamera::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuick3DCamera::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void QQuick3DOrthographicCamera::clipNearChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QQuick3DOrthographicCamera::clipFarChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QQuick3DOrthographicCamera::horizontalMagnificationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QQuick3DOrthographicCamera::verticalMagnificationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
