/****************************************************************************
** Meta object code from reading C++ file 'qquick3dparticlescaleaffector_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtquick3d/src/quick3dparticles/qquick3dparticlescaleaffector_p.h"
#include <QtGui/qtextcursor.h>
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquick3dparticlescaleaffector_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN29QQuick3DParticleScaleAffectorE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DParticleScaleAffector::qt_create_metaobjectdata<qt_meta_tag_ZN29QQuick3DParticleScaleAffectorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DParticleScaleAffector",
        "QML.Element",
        "ScaleAffector3D",
        "QML.AddedInVersion",
        "1540",
        "minSizeChanged",
        "",
        "maxSizeChanged",
        "durationChanged",
        "typeChanged",
        "easingCurveChanged",
        "setMinSize",
        "size",
        "setMaxSize",
        "setDuration",
        "duration",
        "setType",
        "ScalingType",
        "type",
        "setEasingCurve",
        "QEasingCurve",
        "curve",
        "minSize",
        "maxSize",
        "easingCurve",
        "Linear",
        "SewSaw",
        "SineWave",
        "AbsSineWave",
        "Step",
        "SmoothStep"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'minSizeChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'maxSizeChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'durationChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'typeChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'easingCurveChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setMinSize'
        QtMocHelpers::SlotData<void(float)>(11, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 12 },
        }}),
        // Slot 'setMaxSize'
        QtMocHelpers::SlotData<void(float)>(13, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 12 },
        }}),
        // Slot 'setDuration'
        QtMocHelpers::SlotData<void(int)>(14, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 15 },
        }}),
        // Slot 'setType'
        QtMocHelpers::SlotData<void(enum ScalingType)>(16, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'setEasingCurve'
        QtMocHelpers::SlotData<void(const QEasingCurve &)>(19, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'minSize'
        QtMocHelpers::PropertyData<float>(22, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'maxSize'
        QtMocHelpers::PropertyData<float>(23, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'duration'
        QtMocHelpers::PropertyData<int>(15, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'type'
        QtMocHelpers::PropertyData<enum ScalingType>(18, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'easingCurve'
        QtMocHelpers::PropertyData<QEasingCurve>(24, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 4),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'ScalingType'
        QtMocHelpers::EnumData<enum ScalingType>(17, 17, QMC::EnumFlags{}).add({
            {   25, ScalingType::Linear },
            {   26, ScalingType::SewSaw },
            {   27, ScalingType::SineWave },
            {   28, ScalingType::AbsSineWave },
            {   29, ScalingType::Step },
            {   30, ScalingType::SmoothStep },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DParticleScaleAffector, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DParticleScaleAffector::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuick3DParticleAffector::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29QQuick3DParticleScaleAffectorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29QQuick3DParticleScaleAffectorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN29QQuick3DParticleScaleAffectorE_t>.metaTypes,
    nullptr
} };

void QQuick3DParticleScaleAffector::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DParticleScaleAffector *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->minSizeChanged(); break;
        case 1: _t->maxSizeChanged(); break;
        case 2: _t->durationChanged(); break;
        case 3: _t->typeChanged(); break;
        case 4: _t->easingCurveChanged(); break;
        case 5: _t->setMinSize((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 6: _t->setMaxSize((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 7: _t->setDuration((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->setType((*reinterpret_cast<std::add_pointer_t<enum ScalingType>>(_a[1]))); break;
        case 9: _t->setEasingCurve((*reinterpret_cast<std::add_pointer_t<QEasingCurve>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleScaleAffector::*)()>(_a, &QQuick3DParticleScaleAffector::minSizeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleScaleAffector::*)()>(_a, &QQuick3DParticleScaleAffector::maxSizeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleScaleAffector::*)()>(_a, &QQuick3DParticleScaleAffector::durationChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleScaleAffector::*)()>(_a, &QQuick3DParticleScaleAffector::typeChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleScaleAffector::*)()>(_a, &QQuick3DParticleScaleAffector::easingCurveChanged, 4))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<float*>(_v) = _t->minSize(); break;
        case 1: *reinterpret_cast<float*>(_v) = _t->maxSize(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->duration(); break;
        case 3: *reinterpret_cast<enum ScalingType*>(_v) = _t->type(); break;
        case 4: *reinterpret_cast<QEasingCurve*>(_v) = _t->easingCurve(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setMinSize(*reinterpret_cast<float*>(_v)); break;
        case 1: _t->setMaxSize(*reinterpret_cast<float*>(_v)); break;
        case 2: _t->setDuration(*reinterpret_cast<int*>(_v)); break;
        case 3: _t->setType(*reinterpret_cast<enum ScalingType*>(_v)); break;
        case 4: _t->setEasingCurve(*reinterpret_cast<QEasingCurve*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DParticleScaleAffector::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DParticleScaleAffector::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29QQuick3DParticleScaleAffectorE_t>.strings))
        return static_cast<void*>(this);
    return QQuick3DParticleAffector::qt_metacast(_clname);
}

int QQuick3DParticleScaleAffector::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuick3DParticleAffector::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void QQuick3DParticleScaleAffector::minSizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QQuick3DParticleScaleAffector::maxSizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QQuick3DParticleScaleAffector::durationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QQuick3DParticleScaleAffector::typeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QQuick3DParticleScaleAffector::easingCurveChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
