/****************************************************************************
** Meta object code from reading C++ file 'qquick3dlightmapper_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtquick3d/src/quick3d/qquick3dlightmapper_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquick3dlightmapper_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19QQuick3DLightmapperE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DLightmapper::qt_create_metaobjectdata<qt_meta_tag_ZN19QQuick3DLightmapperE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DLightmapper",
        "QML.Element",
        "Lightmapper",
        "changed",
        "",
        "opacityThresholdChanged",
        "biasChanged",
        "adaptiveBiasEnabledChanged",
        "indirectLightEnabledChanged",
        "samplesChanged",
        "indirectLightWorkgroupSizeChanged",
        "bouncesChanged",
        "indirectLightFactorChanged",
        "sourceChanged",
        "denoiseSigmaChanged",
        "texelsPerUnitChanged",
        "setOpacityThreshold",
        "opacity",
        "setBias",
        "bias",
        "setAdaptiveBiasEnabled",
        "enabled",
        "setIndirectLightEnabled",
        "setSamples",
        "count",
        "setIndirectLightWorkgroupSize",
        "size",
        "setBounces",
        "setIndirectLightFactor",
        "factor",
        "setSource",
        "QUrl",
        "source",
        "setDenoiseSigma",
        "newDenoiseSigma",
        "setTexelsPerUnit",
        "newTexelsPerUnit",
        "opacityThreshold",
        "adaptiveBiasEnabled",
        "indirectLightEnabled",
        "samples",
        "indirectLightWorkgroupSize",
        "bounces",
        "indirectLightFactor",
        "denoiseSigma",
        "texelsPerUnit"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'changed'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'opacityThresholdChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'biasChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'adaptiveBiasEnabledChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'indirectLightEnabledChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'samplesChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'indirectLightWorkgroupSizeChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'bouncesChanged'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'indirectLightFactorChanged'
        QtMocHelpers::SignalData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sourceChanged'
        QtMocHelpers::RevisionedSignalData<void()>(13, 4, QMC::AccessPublic, 0x60a, QMetaType::Void),
        // Signal 'denoiseSigmaChanged'
        QtMocHelpers::RevisionedSignalData<void()>(14, 4, QMC::AccessPublic, 0x60a, QMetaType::Void),
        // Signal 'texelsPerUnitChanged'
        QtMocHelpers::RevisionedSignalData<void()>(15, 4, QMC::AccessPublic, 0x60a, QMetaType::Void),
        // Slot 'setOpacityThreshold'
        QtMocHelpers::SlotData<void(float)>(16, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 17 },
        }}),
        // Slot 'setBias'
        QtMocHelpers::SlotData<void(float)>(18, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 19 },
        }}),
        // Slot 'setAdaptiveBiasEnabled'
        QtMocHelpers::SlotData<void(bool)>(20, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 21 },
        }}),
        // Slot 'setIndirectLightEnabled'
        QtMocHelpers::SlotData<void(bool)>(22, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 21 },
        }}),
        // Slot 'setSamples'
        QtMocHelpers::SlotData<void(int)>(23, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 24 },
        }}),
        // Slot 'setIndirectLightWorkgroupSize'
        QtMocHelpers::SlotData<void(int)>(25, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 26 },
        }}),
        // Slot 'setBounces'
        QtMocHelpers::SlotData<void(int)>(27, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 24 },
        }}),
        // Slot 'setIndirectLightFactor'
        QtMocHelpers::SlotData<void(float)>(28, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 29 },
        }}),
        // Slot 'setSource'
        QtMocHelpers::RevisionedSlotData<void(const QUrl &)>(30, 4, QMC::AccessPublic, 0x60a, QMetaType::Void, {{
            { 0x80000000 | 31, 32 },
        }}),
        // Slot 'setDenoiseSigma'
        QtMocHelpers::RevisionedSlotData<void(float)>(33, 4, QMC::AccessPublic, 0x60a, QMetaType::Void, {{
            { QMetaType::Float, 34 },
        }}),
        // Slot 'setTexelsPerUnit'
        QtMocHelpers::RevisionedSlotData<void(float)>(35, 4, QMC::AccessPublic, 0x60a, QMetaType::Void, {{
            { QMetaType::Float, 36 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'opacityThreshold'
        QtMocHelpers::PropertyData<float>(37, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'bias'
        QtMocHelpers::PropertyData<float>(19, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'adaptiveBiasEnabled'
        QtMocHelpers::PropertyData<bool>(38, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'indirectLightEnabled'
        QtMocHelpers::PropertyData<bool>(39, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'samples'
        QtMocHelpers::PropertyData<int>(40, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'indirectLightWorkgroupSize'
        QtMocHelpers::PropertyData<int>(41, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'bounces'
        QtMocHelpers::PropertyData<int>(42, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'indirectLightFactor'
        QtMocHelpers::PropertyData<float>(43, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'source'
        QtMocHelpers::PropertyData<QUrl>(32, 0x80000000 | 31, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 9, 0x60a),
        // property 'denoiseSigma'
        QtMocHelpers::PropertyData<float>(44, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 10, 0x60a),
        // property 'texelsPerUnit'
        QtMocHelpers::PropertyData<float>(45, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 11, 0x60a),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DLightmapper, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DLightmapper::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19QQuick3DLightmapperE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19QQuick3DLightmapperE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19QQuick3DLightmapperE_t>.metaTypes,
    nullptr
} };

void QQuick3DLightmapper::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DLightmapper *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->changed(); break;
        case 1: _t->opacityThresholdChanged(); break;
        case 2: _t->biasChanged(); break;
        case 3: _t->adaptiveBiasEnabledChanged(); break;
        case 4: _t->indirectLightEnabledChanged(); break;
        case 5: _t->samplesChanged(); break;
        case 6: _t->indirectLightWorkgroupSizeChanged(); break;
        case 7: _t->bouncesChanged(); break;
        case 8: _t->indirectLightFactorChanged(); break;
        case 9: _t->sourceChanged(); break;
        case 10: _t->denoiseSigmaChanged(); break;
        case 11: _t->texelsPerUnitChanged(); break;
        case 12: _t->setOpacityThreshold((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 13: _t->setBias((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 14: _t->setAdaptiveBiasEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 15: _t->setIndirectLightEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 16: _t->setSamples((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 17: _t->setIndirectLightWorkgroupSize((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 18: _t->setBounces((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 19: _t->setIndirectLightFactor((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 20: _t->setSource((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 21: _t->setDenoiseSigma((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 22: _t->setTexelsPerUnit((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuick3DLightmapper::*)()>(_a, &QQuick3DLightmapper::changed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DLightmapper::*)()>(_a, &QQuick3DLightmapper::opacityThresholdChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DLightmapper::*)()>(_a, &QQuick3DLightmapper::biasChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DLightmapper::*)()>(_a, &QQuick3DLightmapper::adaptiveBiasEnabledChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DLightmapper::*)()>(_a, &QQuick3DLightmapper::indirectLightEnabledChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DLightmapper::*)()>(_a, &QQuick3DLightmapper::samplesChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DLightmapper::*)()>(_a, &QQuick3DLightmapper::indirectLightWorkgroupSizeChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DLightmapper::*)()>(_a, &QQuick3DLightmapper::bouncesChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DLightmapper::*)()>(_a, &QQuick3DLightmapper::indirectLightFactorChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DLightmapper::*)()>(_a, &QQuick3DLightmapper::sourceChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DLightmapper::*)()>(_a, &QQuick3DLightmapper::denoiseSigmaChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DLightmapper::*)()>(_a, &QQuick3DLightmapper::texelsPerUnitChanged, 11))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<float*>(_v) = _t->opacityThreshold(); break;
        case 1: *reinterpret_cast<float*>(_v) = _t->bias(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->isAdaptiveBiasEnabled(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isIndirectLightEnabled(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->samples(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->indirectLightWorkgroupSize(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->bounces(); break;
        case 7: *reinterpret_cast<float*>(_v) = _t->indirectLightFactor(); break;
        case 8: *reinterpret_cast<QUrl*>(_v) = _t->source(); break;
        case 9: *reinterpret_cast<float*>(_v) = _t->denoiseSigma(); break;
        case 10: *reinterpret_cast<float*>(_v) = _t->texelsPerUnit(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setOpacityThreshold(*reinterpret_cast<float*>(_v)); break;
        case 1: _t->setBias(*reinterpret_cast<float*>(_v)); break;
        case 2: _t->setAdaptiveBiasEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setIndirectLightEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 4: _t->setSamples(*reinterpret_cast<int*>(_v)); break;
        case 5: _t->setIndirectLightWorkgroupSize(*reinterpret_cast<int*>(_v)); break;
        case 6: _t->setBounces(*reinterpret_cast<int*>(_v)); break;
        case 7: _t->setIndirectLightFactor(*reinterpret_cast<float*>(_v)); break;
        case 8: _t->setSource(*reinterpret_cast<QUrl*>(_v)); break;
        case 9: _t->setDenoiseSigma(*reinterpret_cast<float*>(_v)); break;
        case 10: _t->setTexelsPerUnit(*reinterpret_cast<float*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DLightmapper::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DLightmapper::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19QQuick3DLightmapperE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QQuick3DLightmapper::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 23)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 23)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 23;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void QQuick3DLightmapper::changed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QQuick3DLightmapper::opacityThresholdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QQuick3DLightmapper::biasChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QQuick3DLightmapper::adaptiveBiasEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QQuick3DLightmapper::indirectLightEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QQuick3DLightmapper::samplesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QQuick3DLightmapper::indirectLightWorkgroupSizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void QQuick3DLightmapper::bouncesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void QQuick3DLightmapper::indirectLightFactorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void QQuick3DLightmapper::sourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void QQuick3DLightmapper::denoiseSigmaChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void QQuick3DLightmapper::texelsPerUnitChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}
QT_WARNING_POP
