/****************************************************************************
** Meta object code from reading C++ file 'qquick3dquaternionanimation_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtquick3d/src/quick3d/qquick3dquaternionanimation_p.h"
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquick3dquaternionanimation_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN27QQuick3DQuaternionAnimationE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DQuaternionAnimation::qt_create_metaobjectdata<qt_meta_tag_ZN27QQuick3DQuaternionAnimationE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DQuaternionAnimation",
        "QML.Element",
        "QuaternionAnimation",
        "typeChanged",
        "",
        "QQuick3DQuaternionAnimation::Type",
        "type",
        "fromXRotationChanged",
        "value",
        "fromYRotationChanged",
        "fromZRotationChanged",
        "toXRotationChanged",
        "toYRotationChanged",
        "toZRotationChanged",
        "from",
        "QQuaternion",
        "to",
        "Type",
        "fromXRotation",
        "fromYRotation",
        "fromZRotation",
        "toXRotation",
        "toYRotation",
        "toZRotation",
        "Slerp",
        "Nlerp"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'typeChanged'
        QtMocHelpers::SignalData<void(QQuick3DQuaternionAnimation::Type)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'fromXRotationChanged'
        QtMocHelpers::SignalData<void(float)>(7, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 8 },
        }}),
        // Signal 'fromYRotationChanged'
        QtMocHelpers::SignalData<void(float)>(9, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 8 },
        }}),
        // Signal 'fromZRotationChanged'
        QtMocHelpers::SignalData<void(float)>(10, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 8 },
        }}),
        // Signal 'toXRotationChanged'
        QtMocHelpers::SignalData<void(float)>(11, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 8 },
        }}),
        // Signal 'toYRotationChanged'
        QtMocHelpers::SignalData<void(float)>(12, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 8 },
        }}),
        // Signal 'toZRotationChanged'
        QtMocHelpers::SignalData<void(float)>(13, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 8 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'from'
        QtMocHelpers::PropertyData<QQuaternion>(14, 0x80000000 | 15, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Override),
        // property 'to'
        QtMocHelpers::PropertyData<QQuaternion>(16, 0x80000000 | 15, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Override),
        // property 'type'
        QtMocHelpers::PropertyData<enum Type>(6, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'fromXRotation'
        QtMocHelpers::PropertyData<float>(18, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'fromYRotation'
        QtMocHelpers::PropertyData<float>(19, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'fromZRotation'
        QtMocHelpers::PropertyData<float>(20, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'toXRotation'
        QtMocHelpers::PropertyData<float>(21, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'toYRotation'
        QtMocHelpers::PropertyData<float>(22, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'toZRotation'
        QtMocHelpers::PropertyData<float>(23, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Type'
        QtMocHelpers::EnumData<enum Type>(17, 17, QMC::EnumFlags{}).add({
            {   24, Type::Slerp },
            {   25, Type::Nlerp },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DQuaternionAnimation, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DQuaternionAnimation::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickPropertyAnimation::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN27QQuick3DQuaternionAnimationE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN27QQuick3DQuaternionAnimationE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN27QQuick3DQuaternionAnimationE_t>.metaTypes,
    nullptr
} };

void QQuick3DQuaternionAnimation::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DQuaternionAnimation *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->typeChanged((*reinterpret_cast<std::add_pointer_t<QQuick3DQuaternionAnimation::Type>>(_a[1]))); break;
        case 1: _t->fromXRotationChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 2: _t->fromYRotationChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 3: _t->fromZRotationChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 4: _t->toXRotationChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 5: _t->toYRotationChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 6: _t->toZRotationChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuick3DQuaternionAnimation::*)(QQuick3DQuaternionAnimation::Type )>(_a, &QQuick3DQuaternionAnimation::typeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DQuaternionAnimation::*)(float )>(_a, &QQuick3DQuaternionAnimation::fromXRotationChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DQuaternionAnimation::*)(float )>(_a, &QQuick3DQuaternionAnimation::fromYRotationChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DQuaternionAnimation::*)(float )>(_a, &QQuick3DQuaternionAnimation::fromZRotationChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DQuaternionAnimation::*)(float )>(_a, &QQuick3DQuaternionAnimation::toXRotationChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DQuaternionAnimation::*)(float )>(_a, &QQuick3DQuaternionAnimation::toYRotationChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DQuaternionAnimation::*)(float )>(_a, &QQuick3DQuaternionAnimation::toZRotationChanged, 6))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QQuaternion*>(_v) = _t->from(); break;
        case 1: *reinterpret_cast<QQuaternion*>(_v) = _t->to(); break;
        case 2: *reinterpret_cast<enum Type*>(_v) = _t->type(); break;
        case 3: *reinterpret_cast<float*>(_v) = _t->fromXRotation(); break;
        case 4: *reinterpret_cast<float*>(_v) = _t->fromYRotation(); break;
        case 5: *reinterpret_cast<float*>(_v) = _t->fromZRotation(); break;
        case 6: *reinterpret_cast<float*>(_v) = _t->toXRotation(); break;
        case 7: *reinterpret_cast<float*>(_v) = _t->toYRotation(); break;
        case 8: *reinterpret_cast<float*>(_v) = _t->toZRotation(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setFrom(*reinterpret_cast<QQuaternion*>(_v)); break;
        case 1: _t->setTo(*reinterpret_cast<QQuaternion*>(_v)); break;
        case 2: _t->setType(*reinterpret_cast<enum Type*>(_v)); break;
        case 3: _t->setFromXRotation(*reinterpret_cast<float*>(_v)); break;
        case 4: _t->setFromYRotation(*reinterpret_cast<float*>(_v)); break;
        case 5: _t->setFromZRotation(*reinterpret_cast<float*>(_v)); break;
        case 6: _t->setToXRotation(*reinterpret_cast<float*>(_v)); break;
        case 7: _t->setToYRotation(*reinterpret_cast<float*>(_v)); break;
        case 8: _t->setToZRotation(*reinterpret_cast<float*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DQuaternionAnimation::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DQuaternionAnimation::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN27QQuick3DQuaternionAnimationE_t>.strings))
        return static_cast<void*>(this);
    return QQuickPropertyAnimation::qt_metacast(_clname);
}

int QQuick3DQuaternionAnimation::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickPropertyAnimation::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void QQuick3DQuaternionAnimation::typeChanged(QQuick3DQuaternionAnimation::Type _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void QQuick3DQuaternionAnimation::fromXRotationChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void QQuick3DQuaternionAnimation::fromYRotationChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void QQuick3DQuaternionAnimation::fromZRotationChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void QQuick3DQuaternionAnimation::toXRotationChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void QQuick3DQuaternionAnimation::toYRotationChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void QQuick3DQuaternionAnimation::toZRotationChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}
QT_WARNING_POP
