/****************************************************************************
** Meta object code from reading C++ file 'qquick3dxrcontroller_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../qtquick3d/src/xr/quick3dxr/qquick3dxrcontroller_p.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquick3dxrcontroller_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN20QQuick3DXrControllerE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DXrController::qt_create_metaobjectdata<qt_meta_tag_ZN20QQuick3DXrControllerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DXrController",
        "QML.Element",
        "XrController",
        "QML.AddedInVersion",
        "1544",
        "controllerChanged",
        "",
        "actionMapperChanged",
        "poseSpaceChanged",
        "pokePositionChanged",
        "jointPositionsChanged",
        "jointRotationsChanged",
        "jointDataUpdated",
        "isActiveChanged",
        "controller",
        "Controller",
        "isActive",
        "poseSpace",
        "HandPoseSpace",
        "pokePosition",
        "QVector3D",
        "jointPositions",
        "QList<QVector3D>",
        "jointRotations",
        "QList<QQuaternion>",
        "ControllerLeft",
        "ControllerRight",
        "ControllerNone",
        "LeftController",
        "RightController",
        "LeftHand",
        "RightHand",
        "UnknownController",
        "GripPose",
        "AimPose"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'controllerChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'actionMapperChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'poseSpaceChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pokePositionChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'jointPositionsChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'jointRotationsChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'jointDataUpdated'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'isActiveChanged'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'controller'
        QtMocHelpers::PropertyData<enum Controller>(14, 0x80000000 | 15, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 0),
        // property 'isActive'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Final, 7),
        // property 'poseSpace'
        QtMocHelpers::PropertyData<enum HandPoseSpace>(17, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 2),
        // property 'pokePosition'
        QtMocHelpers::PropertyData<QVector3D>(19, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 3),
        // property 'jointPositions'
        QtMocHelpers::PropertyData<QList<QVector3D>>(21, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 4),
        // property 'jointRotations'
        QtMocHelpers::PropertyData<QList<QQuaternion>>(23, 0x80000000 | 24, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 5),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Controller'
        QtMocHelpers::EnumData<enum Controller>(15, 15, QMC::EnumFlags{}).add({
            {   25, Controller::ControllerLeft },
            {   26, Controller::ControllerRight },
            {   27, Controller::ControllerNone },
            {   28, Controller::LeftController },
            {   29, Controller::RightController },
            {   30, Controller::LeftHand },
            {   31, Controller::RightHand },
            {   32, Controller::UnknownController },
        }),
        // enum 'HandPoseSpace'
        QtMocHelpers::EnumData<enum HandPoseSpace>(18, 18, QMC::EnumIsScoped).add({
            {   33, HandPoseSpace::GripPose },
            {   34, HandPoseSpace::AimPose },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DXrController, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DXrController::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuick3DNode::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20QQuick3DXrControllerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20QQuick3DXrControllerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20QQuick3DXrControllerE_t>.metaTypes,
    nullptr
} };

void QQuick3DXrController::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DXrController *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->controllerChanged(); break;
        case 1: _t->actionMapperChanged(); break;
        case 2: _t->poseSpaceChanged(); break;
        case 3: _t->pokePositionChanged(); break;
        case 4: _t->jointPositionsChanged(); break;
        case 5: _t->jointRotationsChanged(); break;
        case 6: _t->jointDataUpdated(); break;
        case 7: _t->isActiveChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuick3DXrController::*)()>(_a, &QQuick3DXrController::controllerChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DXrController::*)()>(_a, &QQuick3DXrController::actionMapperChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DXrController::*)()>(_a, &QQuick3DXrController::poseSpaceChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DXrController::*)()>(_a, &QQuick3DXrController::pokePositionChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DXrController::*)()>(_a, &QQuick3DXrController::jointPositionsChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DXrController::*)()>(_a, &QQuick3DXrController::jointRotationsChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DXrController::*)()>(_a, &QQuick3DXrController::jointDataUpdated, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DXrController::*)()>(_a, &QQuick3DXrController::isActiveChanged, 7))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<enum Controller*>(_v) = _t->controller(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isActive(); break;
        case 2: *reinterpret_cast<enum HandPoseSpace*>(_v) = _t->poseSpace(); break;
        case 3: *reinterpret_cast<QVector3D*>(_v) = _t->pokePosition(); break;
        case 4: *reinterpret_cast<QList<QVector3D>*>(_v) = _t->jointPositions(); break;
        case 5: *reinterpret_cast<QList<QQuaternion>*>(_v) = _t->jointRotations(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setController(*reinterpret_cast<enum Controller*>(_v)); break;
        case 2: _t->setPoseSpace(*reinterpret_cast<enum HandPoseSpace*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DXrController::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DXrController::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20QQuick3DXrControllerE_t>.strings))
        return static_cast<void*>(this);
    return QQuick3DNode::qt_metacast(_clname);
}

int QQuick3DXrController::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuick3DNode::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void QQuick3DXrController::controllerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QQuick3DXrController::actionMapperChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QQuick3DXrController::poseSpaceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QQuick3DXrController::pokePositionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QQuick3DXrController::jointPositionsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QQuick3DXrController::jointRotationsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QQuick3DXrController::jointDataUpdated()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void QQuick3DXrController::isActiveChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
QT_WARNING_POP
