/****************************************************************************
** Meta object code from reading C++ file 'qquick3drenderstats_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtquick3d/src/quick3d/qquick3drenderstats_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquick3drenderstats_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19QQuick3DRenderStatsE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DRenderStats::qt_create_metaobjectdata<qt_meta_tag_ZN19QQuick3DRenderStatsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DRenderStats",
        "QML.Element",
        "RenderStats",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "The type is internal and only intended to be accessed by user thro"
        "ugh a View3D.",
        "QML.AddedInVersion",
        "1546",
        "fpsChanged",
        "",
        "frameTimeChanged",
        "renderTimeChanged",
        "syncTimeChanged",
        "maxFrameTimeChanged",
        "extendedDataCollectionEnabledChanged",
        "drawCallCountChanged",
        "drawVertexCountChanged",
        "imageDataSizeChanged",
        "meshDataSizeChanged",
        "renderPassCountChanged",
        "renderPassDetailsChanged",
        "textureDetailsChanged",
        "meshDetailsChanged",
        "pipelineCountChanged",
        "materialGenerationTimeChanged",
        "effectGenerationTimeChanged",
        "pipelineCreationTimeChanged",
        "vmemAllocCountChanged",
        "vmemUsedBytesChanged",
        "graphicsApiNameChanged",
        "lastCompletedGpuTimeChanged",
        "onFrameSwapped",
        "releaseCachedResources",
        "fps",
        "frameTime",
        "renderTime",
        "renderPrepareTime",
        "syncTime",
        "maxFrameTime",
        "extendedDataCollectionEnabled",
        "drawCallCount",
        "drawVertexCount",
        "imageDataSize",
        "meshDataSize",
        "renderPassCount",
        "renderPassDetails",
        "textureDetails",
        "meshDetails",
        "pipelineCount",
        "materialGenerationTime",
        "effectGenerationTime",
        "pipelineCreationTime",
        "vmemAllocCount",
        "vmemUsedBytes",
        "graphicsApiName",
        "lastCompletedGpuTime"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'fpsChanged'
        QtMocHelpers::SignalData<void()>(9, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'frameTimeChanged'
        QtMocHelpers::SignalData<void()>(11, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'renderTimeChanged'
        QtMocHelpers::SignalData<void()>(12, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'syncTimeChanged'
        QtMocHelpers::SignalData<void()>(13, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'maxFrameTimeChanged'
        QtMocHelpers::SignalData<void()>(14, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'extendedDataCollectionEnabledChanged'
        QtMocHelpers::SignalData<void()>(15, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'drawCallCountChanged'
        QtMocHelpers::SignalData<void()>(16, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'drawVertexCountChanged'
        QtMocHelpers::SignalData<void()>(17, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'imageDataSizeChanged'
        QtMocHelpers::SignalData<void()>(18, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'meshDataSizeChanged'
        QtMocHelpers::SignalData<void()>(19, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'renderPassCountChanged'
        QtMocHelpers::SignalData<void()>(20, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'renderPassDetailsChanged'
        QtMocHelpers::SignalData<void()>(21, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'textureDetailsChanged'
        QtMocHelpers::SignalData<void()>(22, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'meshDetailsChanged'
        QtMocHelpers::SignalData<void()>(23, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pipelineCountChanged'
        QtMocHelpers::SignalData<void()>(24, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'materialGenerationTimeChanged'
        QtMocHelpers::SignalData<void()>(25, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'effectGenerationTimeChanged'
        QtMocHelpers::SignalData<void()>(26, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pipelineCreationTimeChanged'
        QtMocHelpers::SignalData<void()>(27, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'vmemAllocCountChanged'
        QtMocHelpers::SignalData<void()>(28, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'vmemUsedBytesChanged'
        QtMocHelpers::SignalData<void()>(29, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'graphicsApiNameChanged'
        QtMocHelpers::SignalData<void()>(30, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lastCompletedGpuTimeChanged'
        QtMocHelpers::SignalData<void()>(31, 10, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onFrameSwapped'
        QtMocHelpers::SlotData<void()>(32, 10, QMC::AccessPrivate, QMetaType::Void),
        // Method 'releaseCachedResources'
        QtMocHelpers::MethodData<void()>(33, 10, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'fps'
        QtMocHelpers::PropertyData<int>(34, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
        // property 'frameTime'
        QtMocHelpers::PropertyData<float>(35, QMetaType::Float, QMC::DefaultPropertyFlags, 1),
        // property 'renderTime'
        QtMocHelpers::PropertyData<float>(36, QMetaType::Float, QMC::DefaultPropertyFlags, 2),
        // property 'renderPrepareTime'
        QtMocHelpers::PropertyData<float>(37, QMetaType::Float, QMC::DefaultPropertyFlags, 2),
        // property 'syncTime'
        QtMocHelpers::PropertyData<float>(38, QMetaType::Float, QMC::DefaultPropertyFlags, 3),
        // property 'maxFrameTime'
        QtMocHelpers::PropertyData<float>(39, QMetaType::Float, QMC::DefaultPropertyFlags, 4),
        // property 'extendedDataCollectionEnabled'
        QtMocHelpers::PropertyData<bool>(40, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'drawCallCount'
        QtMocHelpers::PropertyData<quint64>(41, QMetaType::ULongLong, QMC::DefaultPropertyFlags, 6),
        // property 'drawVertexCount'
        QtMocHelpers::PropertyData<quint64>(42, QMetaType::ULongLong, QMC::DefaultPropertyFlags, 7),
        // property 'imageDataSize'
        QtMocHelpers::PropertyData<quint64>(43, QMetaType::ULongLong, QMC::DefaultPropertyFlags, 8),
        // property 'meshDataSize'
        QtMocHelpers::PropertyData<quint64>(44, QMetaType::ULongLong, QMC::DefaultPropertyFlags, 9),
        // property 'renderPassCount'
        QtMocHelpers::PropertyData<int>(45, QMetaType::Int, QMC::DefaultPropertyFlags, 10),
        // property 'renderPassDetails'
        QtMocHelpers::PropertyData<QString>(46, QMetaType::QString, QMC::DefaultPropertyFlags, 11),
        // property 'textureDetails'
        QtMocHelpers::PropertyData<QString>(47, QMetaType::QString, QMC::DefaultPropertyFlags, 12),
        // property 'meshDetails'
        QtMocHelpers::PropertyData<QString>(48, QMetaType::QString, QMC::DefaultPropertyFlags, 13),
        // property 'pipelineCount'
        QtMocHelpers::PropertyData<int>(49, QMetaType::Int, QMC::DefaultPropertyFlags, 14),
        // property 'materialGenerationTime'
        QtMocHelpers::PropertyData<qint64>(50, QMetaType::LongLong, QMC::DefaultPropertyFlags, 15),
        // property 'effectGenerationTime'
        QtMocHelpers::PropertyData<qint64>(51, QMetaType::LongLong, QMC::DefaultPropertyFlags, 16),
        // property 'pipelineCreationTime'
        QtMocHelpers::PropertyData<qint64>(52, QMetaType::LongLong, QMC::DefaultPropertyFlags, 17),
        // property 'vmemAllocCount'
        QtMocHelpers::PropertyData<quint32>(53, QMetaType::UInt, QMC::DefaultPropertyFlags, 18),
        // property 'vmemUsedBytes'
        QtMocHelpers::PropertyData<quint64>(54, QMetaType::ULongLong, QMC::DefaultPropertyFlags, 19),
        // property 'graphicsApiName'
        QtMocHelpers::PropertyData<QString>(55, QMetaType::QString, QMC::DefaultPropertyFlags, 20),
        // property 'lastCompletedGpuTime'
        QtMocHelpers::PropertyData<float>(56, QMetaType::Float, QMC::DefaultPropertyFlags, 21),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
            {    7,    8 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DRenderStats, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DRenderStats::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19QQuick3DRenderStatsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19QQuick3DRenderStatsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19QQuick3DRenderStatsE_t>.metaTypes,
    nullptr
} };

void QQuick3DRenderStats::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DRenderStats *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->fpsChanged(); break;
        case 1: _t->frameTimeChanged(); break;
        case 2: _t->renderTimeChanged(); break;
        case 3: _t->syncTimeChanged(); break;
        case 4: _t->maxFrameTimeChanged(); break;
        case 5: _t->extendedDataCollectionEnabledChanged(); break;
        case 6: _t->drawCallCountChanged(); break;
        case 7: _t->drawVertexCountChanged(); break;
        case 8: _t->imageDataSizeChanged(); break;
        case 9: _t->meshDataSizeChanged(); break;
        case 10: _t->renderPassCountChanged(); break;
        case 11: _t->renderPassDetailsChanged(); break;
        case 12: _t->textureDetailsChanged(); break;
        case 13: _t->meshDetailsChanged(); break;
        case 14: _t->pipelineCountChanged(); break;
        case 15: _t->materialGenerationTimeChanged(); break;
        case 16: _t->effectGenerationTimeChanged(); break;
        case 17: _t->pipelineCreationTimeChanged(); break;
        case 18: _t->vmemAllocCountChanged(); break;
        case 19: _t->vmemUsedBytesChanged(); break;
        case 20: _t->graphicsApiNameChanged(); break;
        case 21: _t->lastCompletedGpuTimeChanged(); break;
        case 22: _t->onFrameSwapped(); break;
        case 23: _t->releaseCachedResources(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuick3DRenderStats::*)()>(_a, &QQuick3DRenderStats::fpsChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DRenderStats::*)()>(_a, &QQuick3DRenderStats::frameTimeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DRenderStats::*)()>(_a, &QQuick3DRenderStats::renderTimeChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DRenderStats::*)()>(_a, &QQuick3DRenderStats::syncTimeChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DRenderStats::*)()>(_a, &QQuick3DRenderStats::maxFrameTimeChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DRenderStats::*)()>(_a, &QQuick3DRenderStats::extendedDataCollectionEnabledChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DRenderStats::*)()>(_a, &QQuick3DRenderStats::drawCallCountChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DRenderStats::*)()>(_a, &QQuick3DRenderStats::drawVertexCountChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DRenderStats::*)()>(_a, &QQuick3DRenderStats::imageDataSizeChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DRenderStats::*)()>(_a, &QQuick3DRenderStats::meshDataSizeChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DRenderStats::*)()>(_a, &QQuick3DRenderStats::renderPassCountChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DRenderStats::*)()>(_a, &QQuick3DRenderStats::renderPassDetailsChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DRenderStats::*)()>(_a, &QQuick3DRenderStats::textureDetailsChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DRenderStats::*)()>(_a, &QQuick3DRenderStats::meshDetailsChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DRenderStats::*)()>(_a, &QQuick3DRenderStats::pipelineCountChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DRenderStats::*)()>(_a, &QQuick3DRenderStats::materialGenerationTimeChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DRenderStats::*)()>(_a, &QQuick3DRenderStats::effectGenerationTimeChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DRenderStats::*)()>(_a, &QQuick3DRenderStats::pipelineCreationTimeChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DRenderStats::*)()>(_a, &QQuick3DRenderStats::vmemAllocCountChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DRenderStats::*)()>(_a, &QQuick3DRenderStats::vmemUsedBytesChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DRenderStats::*)()>(_a, &QQuick3DRenderStats::graphicsApiNameChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DRenderStats::*)()>(_a, &QQuick3DRenderStats::lastCompletedGpuTimeChanged, 21))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->fps(); break;
        case 1: *reinterpret_cast<float*>(_v) = _t->frameTime(); break;
        case 2: *reinterpret_cast<float*>(_v) = _t->renderTime(); break;
        case 3: *reinterpret_cast<float*>(_v) = _t->renderPrepareTime(); break;
        case 4: *reinterpret_cast<float*>(_v) = _t->syncTime(); break;
        case 5: *reinterpret_cast<float*>(_v) = _t->maxFrameTime(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->extendedDataCollectionEnabled(); break;
        case 7: *reinterpret_cast<quint64*>(_v) = _t->drawCallCount(); break;
        case 8: *reinterpret_cast<quint64*>(_v) = _t->drawVertexCount(); break;
        case 9: *reinterpret_cast<quint64*>(_v) = _t->imageDataSize(); break;
        case 10: *reinterpret_cast<quint64*>(_v) = _t->meshDataSize(); break;
        case 11: *reinterpret_cast<int*>(_v) = _t->renderPassCount(); break;
        case 12: *reinterpret_cast<QString*>(_v) = _t->renderPassDetails(); break;
        case 13: *reinterpret_cast<QString*>(_v) = _t->textureDetails(); break;
        case 14: *reinterpret_cast<QString*>(_v) = _t->meshDetails(); break;
        case 15: *reinterpret_cast<int*>(_v) = _t->pipelineCount(); break;
        case 16: *reinterpret_cast<qint64*>(_v) = _t->materialGenerationTime(); break;
        case 17: *reinterpret_cast<qint64*>(_v) = _t->effectGenerationTime(); break;
        case 18: *reinterpret_cast<qint64*>(_v) = _t->pipelineCreationTime(); break;
        case 19: *reinterpret_cast<quint32*>(_v) = _t->vmemAllocCount(); break;
        case 20: *reinterpret_cast<quint64*>(_v) = _t->vmemUsedBytes(); break;
        case 21: *reinterpret_cast<QString*>(_v) = _t->graphicsApiName(); break;
        case 22: *reinterpret_cast<float*>(_v) = _t->lastCompletedGpuTime(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 6: _t->setExtendedDataCollectionEnabled(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DRenderStats::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DRenderStats::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19QQuick3DRenderStatsE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QQuick3DRenderStats::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 24)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 24)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 24;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    }
    return _id;
}

// SIGNAL 0
void QQuick3DRenderStats::fpsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QQuick3DRenderStats::frameTimeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QQuick3DRenderStats::renderTimeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QQuick3DRenderStats::syncTimeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QQuick3DRenderStats::maxFrameTimeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QQuick3DRenderStats::extendedDataCollectionEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QQuick3DRenderStats::drawCallCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void QQuick3DRenderStats::drawVertexCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void QQuick3DRenderStats::imageDataSizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void QQuick3DRenderStats::meshDataSizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void QQuick3DRenderStats::renderPassCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void QQuick3DRenderStats::renderPassDetailsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void QQuick3DRenderStats::textureDetailsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void QQuick3DRenderStats::meshDetailsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void QQuick3DRenderStats::pipelineCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void QQuick3DRenderStats::materialGenerationTimeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void QQuick3DRenderStats::effectGenerationTimeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void QQuick3DRenderStats::pipelineCreationTimeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void QQuick3DRenderStats::vmemAllocCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void QQuick3DRenderStats::vmemUsedBytesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void QQuick3DRenderStats::graphicsApiNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void QQuick3DRenderStats::lastCompletedGpuTimeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}
QT_WARNING_POP
