/****************************************************************************
** Meta object code from reading C++ file 'qquick3dspecularglossymaterial_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtquick3d/src/quick3d/qquick3dspecularglossymaterial_p.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquick3dspecularglossymaterial_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN30QQuick3DSpecularGlossyMaterialE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DSpecularGlossyMaterial::qt_create_metaobjectdata<qt_meta_tag_ZN30QQuick3DSpecularGlossyMaterialE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DSpecularGlossyMaterial",
        "QML.Element",
        "SpecularGlossyMaterial",
        "QML.AddedInVersion",
        "1540",
        "lightingChanged",
        "",
        "blendModeChanged",
        "albedoColorChanged",
        "albedoMapChanged",
        "albedoSingleChannelEnabledChanged",
        "albedoChannelChanged",
        "specularSingleChannelEnabledChanged",
        "specularChannelChanged",
        "emissiveSingleChannelEnabledChanged",
        "emissiveChannelChanged",
        "emissiveMapChanged",
        "emissiveFactorChanged",
        "glossinessChanged",
        "glossinessMapChanged",
        "invertOpacityMapValueChanged",
        "opacityChanged",
        "opacityMapChanged",
        "normalMapChanged",
        "specularColorChanged",
        "specularMapChanged",
        "normalStrengthChanged",
        "occlusionMapChanged",
        "occlusionAmountChanged",
        "alphaModeChanged",
        "alphaCutoffChanged",
        "glossinessChannelChanged",
        "opacityChannelChanged",
        "occlusionChannelChanged",
        "pointSizeChanged",
        "lineWidthChanged",
        "heightMapChanged",
        "heightChannelChanged",
        "heightAmountChanged",
        "minHeightMapSamplesChanged",
        "maxHeightMapSamplesChanged",
        "clearcoatAmountChanged",
        "clearcoatMapChanged",
        "clearcoatChannelChanged",
        "clearcoatRoughnessAmountChanged",
        "clearcoatRoughnessChannelChanged",
        "clearcoatRoughnessMapChanged",
        "clearcoatNormalMapChanged",
        "clearcoatNormalStrengthChanged",
        "transmissionFactorChanged",
        "transmissionMapChanged",
        "transmissionChannelChanged",
        "thicknessFactorChanged",
        "thicknessMapChanged",
        "thicknessChannelChanged",
        "attenuationDistanceChanged",
        "attenuationColorChanged",
        "vertexColorsEnabledChanged",
        "vertexColorsEnabled",
        "fresnelScaleBiasEnabledChanged",
        "fresnelScaleBiasEnabled",
        "fresnelScaleChanged",
        "fresnelScale",
        "fresnelBiasChanged",
        "fresnelBias",
        "fresnelPowerChanged",
        "fresnelPower",
        "clearcoatFresnelScaleBiasEnabledChanged",
        "clearcoatFresnelScaleBiasEnabled",
        "clearcoatFresnelScaleChanged",
        "clearcoatFresnelScale",
        "clearcoatFresnelBiasChanged",
        "clearcoatFresnelBias",
        "clearcoatFresnelPowerChanged",
        "clearcoatFresnelPower",
        "vertexColorsMaskEnabledChanged",
        "vertexColorRedMaskChanged",
        "vertexColorGreenMaskChanged",
        "vertexColorBlueMaskChanged",
        "vertexColorAlphaMaskChanged",
        "setLighting",
        "QQuick3DSpecularGlossyMaterial::Lighting",
        "lighting",
        "setBlendMode",
        "QQuick3DSpecularGlossyMaterial::BlendMode",
        "blendMode",
        "setAlbedoColor",
        "QColor",
        "albedo",
        "setAlbedoMap",
        "QQuick3DTexture*",
        "albedoMap",
        "setAlbedoSingleChannelEnabled",
        "albedoSingleChannelEnabled",
        "setAlbedoChannel",
        "QQuick3DMaterial::TextureChannelMapping",
        "channel",
        "setSpecularSingleChannelEnabled",
        "specularSingleChannelEnabled",
        "setSpecularChannel",
        "setEmissiveSingleChannelEnabled",
        "emissiveSingleChannelEnabled",
        "setEmissiveChannel",
        "setEmissiveMap",
        "emissiveMap",
        "setEmissiveFactor",
        "QVector3D",
        "emissiveFactor",
        "setGlossiness",
        "glossiness",
        "setGlossinessMap",
        "glossinessMap",
        "setInvertOpacityMapValue",
        "invertOpacityMapValue",
        "setOpacity",
        "opacity",
        "setOpacityMap",
        "opacityMap",
        "setNormalMap",
        "normalMap",
        "setSpecularColor",
        "specular",
        "setSpecularMap",
        "specularMap",
        "setNormalStrength",
        "normalStrength",
        "setOcclusionMap",
        "occlusionMap",
        "setOcclusionAmount",
        "occlusionAmount",
        "setAlphaMode",
        "QQuick3DSpecularGlossyMaterial::AlphaMode",
        "alphaMode",
        "setAlphaCutoff",
        "alphaCutoff",
        "setGlossinessChannel",
        "setOpacityChannel",
        "setOcclusionChannel",
        "setPointSize",
        "size",
        "setLineWidth",
        "width",
        "setHeightMap",
        "heightMap",
        "setHeightChannel",
        "setHeightAmount",
        "heightAmount",
        "setMinHeightMapSamples",
        "samples",
        "setMaxHeightMapSamples",
        "setClearcoatAmount",
        "newClearcoatAmount",
        "setClearcoatMap",
        "newClearcoatMap",
        "setClearcoatChannel",
        "newClearcoatChannel",
        "setClearcoatRoughnessAmount",
        "newClearcoatRoughnessAmount",
        "setClearcoatRoughnessChannel",
        "newClearcoatRoughnessChannel",
        "setClearcoatRoughnessMap",
        "newClearcoatRoughnessMap",
        "setClearcoatNormalMap",
        "newClearcoatNormalMap",
        "setClearcoatNormalStrength",
        "newClearcoatNormalStrength",
        "setTransmissionFactor",
        "newTransmissionFactor",
        "setTransmissionMap",
        "newTransmissionMap",
        "setTransmissionChannel",
        "newTransmissionChannel",
        "setThicknessFactor",
        "newThicknessFactor",
        "setThicknessMap",
        "newThicknessMap",
        "setThicknessChannel",
        "newThicknessChannel",
        "setAttenuationDistance",
        "newAttenuationDistance",
        "setAttenuationColor",
        "newAttenuationColor",
        "setFresnelScaleBiasEnabled",
        "fresnelScaleBias",
        "setFresnelScale",
        "setFresnelBias",
        "setFresnelPower",
        "setClearcoatFresnelScaleBiasEnabled",
        "clearcoatFresnelScaleBias",
        "setClearcoatFresnelScale",
        "setClearcoatFresnelBias",
        "setClearcoatFresnelPower",
        "setVertexColorsEnabled",
        "setVertexColorsMaskEnabled",
        "vertexColorsMaskEnabled",
        "setVertexColorRedMask",
        "VertexColorMaskFlags",
        "vertexColorRedMask",
        "setVertexColorGreenMask",
        "vertexColorGreenMask",
        "setVertexColorBlueMask",
        "vertexColorBlueMask",
        "setVertexColorAlphaMask",
        "vertexColorAlphaMask",
        "Lighting",
        "BlendMode",
        "albedoColor",
        "albedoChannel",
        "specularColor",
        "specularChannel",
        "glossinessChannel",
        "emissiveChannel",
        "opacityChannel",
        "occlusionChannel",
        "AlphaMode",
        "pointSize",
        "lineWidth",
        "heightChannel",
        "minHeightMapSamples",
        "maxHeightMapSamples",
        "clearcoatAmount",
        "clearcoatMap",
        "clearcoatChannel",
        "clearcoatRoughnessAmount",
        "clearcoatRoughnessChannel",
        "clearcoatRoughnessMap",
        "clearcoatNormalMap",
        "clearcoatNormalStrength",
        "transmissionFactor",
        "transmissionMap",
        "transmissionChannel",
        "thicknessFactor",
        "thicknessMap",
        "thicknessChannel",
        "attenuationDistance",
        "attenuationColor",
        "NoLighting",
        "FragmentLighting",
        "SourceOver",
        "Screen",
        "Multiply",
        "Default",
        "Mask",
        "Blend",
        "Opaque",
        "VertexColorMask",
        "NoMask",
        "GlossinessMask",
        "NormalStrengthMask",
        "ClearcoatAmountMask",
        "ClearcoatRoughnessAmountMask",
        "ClearcoatNormalStrengthMask",
        "HeightAmountMask",
        "OcclusionAmountMask",
        "ThicknessFactorMask",
        "TransmissionFactorMask"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'lightingChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'blendModeChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'albedoColorChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'albedoMapChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'albedoSingleChannelEnabledChanged'
        QtMocHelpers::RevisionedSignalData<void()>(10, 6, QMC::AccessPublic, 0x608, QMetaType::Void),
        // Signal 'albedoChannelChanged'
        QtMocHelpers::RevisionedSignalData<void()>(11, 6, QMC::AccessPublic, 0x608, QMetaType::Void),
        // Signal 'specularSingleChannelEnabledChanged'
        QtMocHelpers::RevisionedSignalData<void()>(12, 6, QMC::AccessPublic, 0x608, QMetaType::Void),
        // Signal 'specularChannelChanged'
        QtMocHelpers::RevisionedSignalData<void()>(13, 6, QMC::AccessPublic, 0x608, QMetaType::Void),
        // Signal 'emissiveSingleChannelEnabledChanged'
        QtMocHelpers::RevisionedSignalData<void()>(14, 6, QMC::AccessPublic, 0x608, QMetaType::Void),
        // Signal 'emissiveChannelChanged'
        QtMocHelpers::RevisionedSignalData<void()>(15, 6, QMC::AccessPublic, 0x608, QMetaType::Void),
        // Signal 'emissiveMapChanged'
        QtMocHelpers::SignalData<void()>(16, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'emissiveFactorChanged'
        QtMocHelpers::SignalData<void()>(17, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'glossinessChanged'
        QtMocHelpers::SignalData<void()>(18, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'glossinessMapChanged'
        QtMocHelpers::SignalData<void()>(19, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'invertOpacityMapValueChanged'
        QtMocHelpers::RevisionedSignalData<void()>(20, 6, QMC::AccessPublic, 0x608, QMetaType::Void),
        // Signal 'opacityChanged'
        QtMocHelpers::SignalData<void()>(21, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'opacityMapChanged'
        QtMocHelpers::SignalData<void()>(22, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'normalMapChanged'
        QtMocHelpers::SignalData<void()>(23, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'specularColorChanged'
        QtMocHelpers::SignalData<void()>(24, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'specularMapChanged'
        QtMocHelpers::SignalData<void()>(25, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'normalStrengthChanged'
        QtMocHelpers::SignalData<void()>(26, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'occlusionMapChanged'
        QtMocHelpers::SignalData<void()>(27, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'occlusionAmountChanged'
        QtMocHelpers::SignalData<void()>(28, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'alphaModeChanged'
        QtMocHelpers::SignalData<void()>(29, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'alphaCutoffChanged'
        QtMocHelpers::SignalData<void()>(30, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'glossinessChannelChanged'
        QtMocHelpers::SignalData<void()>(31, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'opacityChannelChanged'
        QtMocHelpers::SignalData<void()>(32, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'occlusionChannelChanged'
        QtMocHelpers::SignalData<void()>(33, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pointSizeChanged'
        QtMocHelpers::SignalData<void()>(34, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lineWidthChanged'
        QtMocHelpers::SignalData<void()>(35, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'heightMapChanged'
        QtMocHelpers::SignalData<void()>(36, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'heightChannelChanged'
        QtMocHelpers::SignalData<void()>(37, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'heightAmountChanged'
        QtMocHelpers::SignalData<void()>(38, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'minHeightMapSamplesChanged'
        QtMocHelpers::SignalData<void()>(39, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'maxHeightMapSamplesChanged'
        QtMocHelpers::SignalData<void()>(40, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'clearcoatAmountChanged'
        QtMocHelpers::SignalData<void()>(41, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'clearcoatMapChanged'
        QtMocHelpers::SignalData<void()>(42, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'clearcoatChannelChanged'
        QtMocHelpers::SignalData<void()>(43, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'clearcoatRoughnessAmountChanged'
        QtMocHelpers::SignalData<void()>(44, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'clearcoatRoughnessChannelChanged'
        QtMocHelpers::SignalData<void()>(45, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'clearcoatRoughnessMapChanged'
        QtMocHelpers::SignalData<void()>(46, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'clearcoatNormalMapChanged'
        QtMocHelpers::SignalData<void()>(47, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'clearcoatNormalStrengthChanged'
        QtMocHelpers::SignalData<void()>(48, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'transmissionFactorChanged'
        QtMocHelpers::SignalData<void()>(49, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'transmissionMapChanged'
        QtMocHelpers::SignalData<void()>(50, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'transmissionChannelChanged'
        QtMocHelpers::SignalData<void()>(51, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'thicknessFactorChanged'
        QtMocHelpers::SignalData<void()>(52, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'thicknessMapChanged'
        QtMocHelpers::SignalData<void()>(53, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'thicknessChannelChanged'
        QtMocHelpers::SignalData<void()>(54, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'attenuationDistanceChanged'
        QtMocHelpers::SignalData<void()>(55, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'attenuationColorChanged'
        QtMocHelpers::SignalData<void()>(56, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'vertexColorsEnabledChanged'
        QtMocHelpers::RevisionedSignalData<void(bool)>(57, 6, QMC::AccessPublic, 0x605, QMetaType::Void, {{
            { QMetaType::Bool, 58 },
        }}),
        // Signal 'fresnelScaleBiasEnabledChanged'
        QtMocHelpers::RevisionedSignalData<void(bool)>(59, 6, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { QMetaType::Bool, 60 },
        }}),
        // Signal 'fresnelScaleChanged'
        QtMocHelpers::RevisionedSignalData<void(float)>(61, 6, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { QMetaType::Float, 62 },
        }}),
        // Signal 'fresnelBiasChanged'
        QtMocHelpers::RevisionedSignalData<void(float)>(63, 6, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { QMetaType::Float, 64 },
        }}),
        // Signal 'fresnelPowerChanged'
        QtMocHelpers::RevisionedSignalData<void(float)>(65, 6, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { QMetaType::Float, 66 },
        }}),
        // Signal 'clearcoatFresnelScaleBiasEnabledChanged'
        QtMocHelpers::RevisionedSignalData<void(bool)>(67, 6, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { QMetaType::Bool, 68 },
        }}),
        // Signal 'clearcoatFresnelScaleChanged'
        QtMocHelpers::RevisionedSignalData<void(float)>(69, 6, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { QMetaType::Float, 70 },
        }}),
        // Signal 'clearcoatFresnelBiasChanged'
        QtMocHelpers::RevisionedSignalData<void(float)>(71, 6, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { QMetaType::Float, 72 },
        }}),
        // Signal 'clearcoatFresnelPowerChanged'
        QtMocHelpers::RevisionedSignalData<void(float)>(73, 6, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { QMetaType::Float, 74 },
        }}),
        // Signal 'vertexColorsMaskEnabledChanged'
        QtMocHelpers::RevisionedSignalData<void()>(75, 6, QMC::AccessPublic, 0x608, QMetaType::Void),
        // Signal 'vertexColorRedMaskChanged'
        QtMocHelpers::RevisionedSignalData<void()>(76, 6, QMC::AccessPublic, 0x608, QMetaType::Void),
        // Signal 'vertexColorGreenMaskChanged'
        QtMocHelpers::RevisionedSignalData<void()>(77, 6, QMC::AccessPublic, 0x608, QMetaType::Void),
        // Signal 'vertexColorBlueMaskChanged'
        QtMocHelpers::RevisionedSignalData<void()>(78, 6, QMC::AccessPublic, 0x608, QMetaType::Void),
        // Signal 'vertexColorAlphaMaskChanged'
        QtMocHelpers::RevisionedSignalData<void()>(79, 6, QMC::AccessPublic, 0x608, QMetaType::Void),
        // Slot 'setLighting'
        QtMocHelpers::SlotData<void(QQuick3DSpecularGlossyMaterial::Lighting)>(80, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 81, 82 },
        }}),
        // Slot 'setBlendMode'
        QtMocHelpers::SlotData<void(QQuick3DSpecularGlossyMaterial::BlendMode)>(83, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 84, 85 },
        }}),
        // Slot 'setAlbedoColor'
        QtMocHelpers::SlotData<void(const QColor &)>(86, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 87, 88 },
        }}),
        // Slot 'setAlbedoMap'
        QtMocHelpers::SlotData<void(QQuick3DTexture *)>(89, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 90, 91 },
        }}),
        // Slot 'setAlbedoSingleChannelEnabled'
        QtMocHelpers::RevisionedSlotData<void(bool)>(92, 6, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { QMetaType::Bool, 93 },
        }}),
        // Slot 'setAlbedoChannel'
        QtMocHelpers::RevisionedSlotData<void(QQuick3DMaterial::TextureChannelMapping)>(94, 6, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { 0x80000000 | 95, 96 },
        }}),
        // Slot 'setSpecularSingleChannelEnabled'
        QtMocHelpers::RevisionedSlotData<void(bool)>(97, 6, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { QMetaType::Bool, 98 },
        }}),
        // Slot 'setSpecularChannel'
        QtMocHelpers::RevisionedSlotData<void(QQuick3DMaterial::TextureChannelMapping)>(99, 6, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { 0x80000000 | 95, 96 },
        }}),
        // Slot 'setEmissiveSingleChannelEnabled'
        QtMocHelpers::RevisionedSlotData<void(bool)>(100, 6, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { QMetaType::Bool, 101 },
        }}),
        // Slot 'setEmissiveChannel'
        QtMocHelpers::RevisionedSlotData<void(QQuick3DMaterial::TextureChannelMapping)>(102, 6, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { 0x80000000 | 95, 96 },
        }}),
        // Slot 'setEmissiveMap'
        QtMocHelpers::SlotData<void(QQuick3DTexture *)>(103, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 90, 104 },
        }}),
        // Slot 'setEmissiveFactor'
        QtMocHelpers::SlotData<void(const QVector3D &)>(105, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 106, 107 },
        }}),
        // Slot 'setGlossiness'
        QtMocHelpers::SlotData<void(float)>(108, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 109 },
        }}),
        // Slot 'setGlossinessMap'
        QtMocHelpers::SlotData<void(QQuick3DTexture *)>(110, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 90, 111 },
        }}),
        // Slot 'setInvertOpacityMapValue'
        QtMocHelpers::RevisionedSlotData<void(bool)>(112, 6, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { QMetaType::Bool, 113 },
        }}),
        // Slot 'setOpacity'
        QtMocHelpers::SlotData<void(float)>(114, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 115 },
        }}),
        // Slot 'setOpacityMap'
        QtMocHelpers::SlotData<void(QQuick3DTexture *)>(116, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 90, 117 },
        }}),
        // Slot 'setNormalMap'
        QtMocHelpers::SlotData<void(QQuick3DTexture *)>(118, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 90, 119 },
        }}),
        // Slot 'setSpecularColor'
        QtMocHelpers::SlotData<void(const QColor &)>(120, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 87, 121 },
        }}),
        // Slot 'setSpecularMap'
        QtMocHelpers::SlotData<void(QQuick3DTexture *)>(122, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 90, 123 },
        }}),
        // Slot 'setNormalStrength'
        QtMocHelpers::SlotData<void(float)>(124, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 125 },
        }}),
        // Slot 'setOcclusionMap'
        QtMocHelpers::SlotData<void(QQuick3DTexture *)>(126, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 90, 127 },
        }}),
        // Slot 'setOcclusionAmount'
        QtMocHelpers::SlotData<void(float)>(128, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 129 },
        }}),
        // Slot 'setAlphaMode'
        QtMocHelpers::SlotData<void(QQuick3DSpecularGlossyMaterial::AlphaMode)>(130, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 131, 132 },
        }}),
        // Slot 'setAlphaCutoff'
        QtMocHelpers::SlotData<void(float)>(133, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 134 },
        }}),
        // Slot 'setGlossinessChannel'
        QtMocHelpers::SlotData<void(QQuick3DMaterial::TextureChannelMapping)>(135, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 95, 96 },
        }}),
        // Slot 'setOpacityChannel'
        QtMocHelpers::SlotData<void(QQuick3DMaterial::TextureChannelMapping)>(136, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 95, 96 },
        }}),
        // Slot 'setOcclusionChannel'
        QtMocHelpers::SlotData<void(QQuick3DMaterial::TextureChannelMapping)>(137, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 95, 96 },
        }}),
        // Slot 'setPointSize'
        QtMocHelpers::SlotData<void(float)>(138, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 139 },
        }}),
        // Slot 'setLineWidth'
        QtMocHelpers::SlotData<void(float)>(140, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 141 },
        }}),
        // Slot 'setHeightMap'
        QtMocHelpers::SlotData<void(QQuick3DTexture *)>(142, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 90, 143 },
        }}),
        // Slot 'setHeightChannel'
        QtMocHelpers::SlotData<void(QQuick3DMaterial::TextureChannelMapping)>(144, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 95, 96 },
        }}),
        // Slot 'setHeightAmount'
        QtMocHelpers::SlotData<void(float)>(145, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 146 },
        }}),
        // Slot 'setMinHeightMapSamples'
        QtMocHelpers::SlotData<void(int)>(147, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 148 },
        }}),
        // Slot 'setMaxHeightMapSamples'
        QtMocHelpers::SlotData<void(int)>(149, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 148 },
        }}),
        // Slot 'setClearcoatAmount'
        QtMocHelpers::SlotData<void(float)>(150, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 151 },
        }}),
        // Slot 'setClearcoatMap'
        QtMocHelpers::SlotData<void(QQuick3DTexture *)>(152, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 90, 153 },
        }}),
        // Slot 'setClearcoatChannel'
        QtMocHelpers::SlotData<void(QQuick3DMaterial::TextureChannelMapping)>(154, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 95, 155 },
        }}),
        // Slot 'setClearcoatRoughnessAmount'
        QtMocHelpers::SlotData<void(float)>(156, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 157 },
        }}),
        // Slot 'setClearcoatRoughnessChannel'
        QtMocHelpers::SlotData<void(QQuick3DMaterial::TextureChannelMapping)>(158, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 95, 159 },
        }}),
        // Slot 'setClearcoatRoughnessMap'
        QtMocHelpers::SlotData<void(QQuick3DTexture *)>(160, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 90, 161 },
        }}),
        // Slot 'setClearcoatNormalMap'
        QtMocHelpers::SlotData<void(QQuick3DTexture *)>(162, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 90, 163 },
        }}),
        // Slot 'setClearcoatNormalStrength'
        QtMocHelpers::RevisionedSlotData<void(float)>(164, 6, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { QMetaType::Float, 165 },
        }}),
        // Slot 'setTransmissionFactor'
        QtMocHelpers::SlotData<void(float)>(166, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 167 },
        }}),
        // Slot 'setTransmissionMap'
        QtMocHelpers::SlotData<void(QQuick3DTexture *)>(168, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 90, 169 },
        }}),
        // Slot 'setTransmissionChannel'
        QtMocHelpers::SlotData<void(QQuick3DMaterial::TextureChannelMapping)>(170, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 95, 171 },
        }}),
        // Slot 'setThicknessFactor'
        QtMocHelpers::SlotData<void(float)>(172, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 173 },
        }}),
        // Slot 'setThicknessMap'
        QtMocHelpers::SlotData<void(QQuick3DTexture *)>(174, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 90, 175 },
        }}),
        // Slot 'setThicknessChannel'
        QtMocHelpers::SlotData<void(QQuick3DMaterial::TextureChannelMapping)>(176, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 95, 177 },
        }}),
        // Slot 'setAttenuationDistance'
        QtMocHelpers::SlotData<void(float)>(178, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 179 },
        }}),
        // Slot 'setAttenuationColor'
        QtMocHelpers::SlotData<void(const QColor &)>(180, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 87, 181 },
        }}),
        // Slot 'setFresnelScaleBiasEnabled'
        QtMocHelpers::RevisionedSlotData<void(bool)>(182, 6, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { QMetaType::Bool, 183 },
        }}),
        // Slot 'setFresnelScale'
        QtMocHelpers::RevisionedSlotData<void(float)>(184, 6, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { QMetaType::Float, 62 },
        }}),
        // Slot 'setFresnelBias'
        QtMocHelpers::RevisionedSlotData<void(float)>(185, 6, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { QMetaType::Float, 64 },
        }}),
        // Slot 'setFresnelPower'
        QtMocHelpers::RevisionedSlotData<void(float)>(186, 6, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { QMetaType::Float, 66 },
        }}),
        // Slot 'setClearcoatFresnelScaleBiasEnabled'
        QtMocHelpers::RevisionedSlotData<void(bool)>(187, 6, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { QMetaType::Bool, 188 },
        }}),
        // Slot 'setClearcoatFresnelScale'
        QtMocHelpers::RevisionedSlotData<void(float)>(189, 6, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { QMetaType::Float, 70 },
        }}),
        // Slot 'setClearcoatFresnelBias'
        QtMocHelpers::RevisionedSlotData<void(float)>(190, 6, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { QMetaType::Float, 72 },
        }}),
        // Slot 'setClearcoatFresnelPower'
        QtMocHelpers::RevisionedSlotData<void(float)>(191, 6, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { QMetaType::Float, 74 },
        }}),
        // Slot 'setVertexColorsEnabled'
        QtMocHelpers::RevisionedSlotData<void(bool)>(192, 6, QMC::AccessPublic, 0x605, QMetaType::Void, {{
            { QMetaType::Bool, 58 },
        }}),
        // Slot 'setVertexColorsMaskEnabled'
        QtMocHelpers::RevisionedSlotData<void(bool)>(193, 6, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { QMetaType::Bool, 194 },
        }}),
        // Slot 'setVertexColorRedMask'
        QtMocHelpers::RevisionedSlotData<void(VertexColorMaskFlags)>(195, 6, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { 0x80000000 | 196, 197 },
        }}),
        // Slot 'setVertexColorGreenMask'
        QtMocHelpers::RevisionedSlotData<void(VertexColorMaskFlags)>(198, 6, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { 0x80000000 | 196, 199 },
        }}),
        // Slot 'setVertexColorBlueMask'
        QtMocHelpers::RevisionedSlotData<void(VertexColorMaskFlags)>(200, 6, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { 0x80000000 | 196, 201 },
        }}),
        // Slot 'setVertexColorAlphaMask'
        QtMocHelpers::RevisionedSlotData<void(VertexColorMaskFlags)>(202, 6, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { 0x80000000 | 196, 203 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'lighting'
        QtMocHelpers::PropertyData<enum Lighting>(82, 0x80000000 | 204, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'blendMode'
        QtMocHelpers::PropertyData<enum BlendMode>(85, 0x80000000 | 205, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'albedoColor'
        QtMocHelpers::PropertyData<QColor>(206, 0x80000000 | 87, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'albedoMap'
        QtMocHelpers::PropertyData<QQuick3DTexture*>(91, 0x80000000 | 90, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'albedoSingleChannelEnabled'
        QtMocHelpers::PropertyData<bool>(93, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4, 0x608),
        // property 'albedoChannel'
        QtMocHelpers::PropertyData<QQuick3DMaterial::TextureChannelMapping>(207, 0x80000000 | 95, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5, 0x608),
        // property 'specularColor'
        QtMocHelpers::PropertyData<QColor>(208, 0x80000000 | 87, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 18),
        // property 'specularMap'
        QtMocHelpers::PropertyData<QQuick3DTexture*>(123, 0x80000000 | 90, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 19),
        // property 'specularSingleChannelEnabled'
        QtMocHelpers::PropertyData<bool>(98, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6, 0x608),
        // property 'specularChannel'
        QtMocHelpers::PropertyData<QQuick3DMaterial::TextureChannelMapping>(209, 0x80000000 | 95, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 7, 0x608),
        // property 'glossiness'
        QtMocHelpers::PropertyData<float>(109, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'glossinessMap'
        QtMocHelpers::PropertyData<QQuick3DTexture*>(111, 0x80000000 | 90, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 13),
        // property 'glossinessChannel'
        QtMocHelpers::PropertyData<QQuick3DMaterial::TextureChannelMapping>(210, 0x80000000 | 95, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 25),
        // property 'emissiveFactor'
        QtMocHelpers::PropertyData<QVector3D>(107, 0x80000000 | 106, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 11),
        // property 'emissiveMap'
        QtMocHelpers::PropertyData<QQuick3DTexture*>(104, 0x80000000 | 90, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 10),
        // property 'emissiveSingleChannelEnabled'
        QtMocHelpers::PropertyData<bool>(101, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8, 0x608),
        // property 'emissiveChannel'
        QtMocHelpers::PropertyData<QQuick3DMaterial::TextureChannelMapping>(211, 0x80000000 | 95, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 9, 0x608),
        // property 'invertOpacityMapValue'
        QtMocHelpers::PropertyData<bool>(113, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 14, 0x608),
        // property 'opacity'
        QtMocHelpers::PropertyData<float>(115, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 15),
        // property 'opacityMap'
        QtMocHelpers::PropertyData<QQuick3DTexture*>(117, 0x80000000 | 90, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 16),
        // property 'opacityChannel'
        QtMocHelpers::PropertyData<QQuick3DMaterial::TextureChannelMapping>(212, 0x80000000 | 95, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 26),
        // property 'normalMap'
        QtMocHelpers::PropertyData<QQuick3DTexture*>(119, 0x80000000 | 90, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 17),
        // property 'normalStrength'
        QtMocHelpers::PropertyData<float>(125, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 20),
        // property 'occlusionMap'
        QtMocHelpers::PropertyData<QQuick3DTexture*>(127, 0x80000000 | 90, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 21),
        // property 'occlusionChannel'
        QtMocHelpers::PropertyData<QQuick3DMaterial::TextureChannelMapping>(213, 0x80000000 | 95, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 27),
        // property 'occlusionAmount'
        QtMocHelpers::PropertyData<float>(129, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 22),
        // property 'alphaMode'
        QtMocHelpers::PropertyData<enum AlphaMode>(132, 0x80000000 | 214, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 23),
        // property 'alphaCutoff'
        QtMocHelpers::PropertyData<float>(134, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 24),
        // property 'pointSize'
        QtMocHelpers::PropertyData<float>(215, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 28),
        // property 'lineWidth'
        QtMocHelpers::PropertyData<float>(216, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 29),
        // property 'heightMap'
        QtMocHelpers::PropertyData<QQuick3DTexture*>(143, 0x80000000 | 90, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 30),
        // property 'heightChannel'
        QtMocHelpers::PropertyData<QQuick3DMaterial::TextureChannelMapping>(217, 0x80000000 | 95, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 31),
        // property 'heightAmount'
        QtMocHelpers::PropertyData<float>(146, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 32),
        // property 'minHeightMapSamples'
        QtMocHelpers::PropertyData<int>(218, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 33),
        // property 'maxHeightMapSamples'
        QtMocHelpers::PropertyData<int>(219, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 34),
        // property 'clearcoatAmount'
        QtMocHelpers::PropertyData<float>(220, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 35),
        // property 'clearcoatMap'
        QtMocHelpers::PropertyData<QQuick3DTexture*>(221, 0x80000000 | 90, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 36),
        // property 'clearcoatChannel'
        QtMocHelpers::PropertyData<QQuick3DMaterial::TextureChannelMapping>(222, 0x80000000 | 95, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 37),
        // property 'clearcoatRoughnessAmount'
        QtMocHelpers::PropertyData<float>(223, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 38),
        // property 'clearcoatRoughnessChannel'
        QtMocHelpers::PropertyData<QQuick3DMaterial::TextureChannelMapping>(224, 0x80000000 | 95, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 39),
        // property 'clearcoatRoughnessMap'
        QtMocHelpers::PropertyData<QQuick3DTexture*>(225, 0x80000000 | 90, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 40),
        // property 'clearcoatNormalMap'
        QtMocHelpers::PropertyData<QQuick3DTexture*>(226, 0x80000000 | 90, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 41),
        // property 'clearcoatNormalStrength'
        QtMocHelpers::PropertyData<float>(227, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 42, 0x608),
        // property 'transmissionFactor'
        QtMocHelpers::PropertyData<float>(228, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 43),
        // property 'transmissionMap'
        QtMocHelpers::PropertyData<QQuick3DTexture*>(229, 0x80000000 | 90, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 44),
        // property 'transmissionChannel'
        QtMocHelpers::PropertyData<QQuick3DMaterial::TextureChannelMapping>(230, 0x80000000 | 95, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 45),
        // property 'thicknessFactor'
        QtMocHelpers::PropertyData<float>(231, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 46),
        // property 'thicknessMap'
        QtMocHelpers::PropertyData<QQuick3DTexture*>(232, 0x80000000 | 90, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 47),
        // property 'thicknessChannel'
        QtMocHelpers::PropertyData<QQuick3DMaterial::TextureChannelMapping>(233, 0x80000000 | 95, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 48),
        // property 'attenuationDistance'
        QtMocHelpers::PropertyData<float>(234, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 49),
        // property 'attenuationColor'
        QtMocHelpers::PropertyData<QColor>(235, 0x80000000 | 87, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 50),
        // property 'vertexColorsEnabled'
        QtMocHelpers::PropertyData<bool>(58, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 51, 0x605),
        // property 'fresnelScaleBiasEnabled'
        QtMocHelpers::PropertyData<bool>(60, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 52, 0x608),
        // property 'fresnelScale'
        QtMocHelpers::PropertyData<float>(62, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 53, 0x608),
        // property 'fresnelBias'
        QtMocHelpers::PropertyData<float>(64, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 54, 0x608),
        // property 'fresnelPower'
        QtMocHelpers::PropertyData<float>(66, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 55, 0x608),
        // property 'clearcoatFresnelScaleBiasEnabled'
        QtMocHelpers::PropertyData<bool>(68, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 56, 0x608),
        // property 'clearcoatFresnelScale'
        QtMocHelpers::PropertyData<float>(70, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 57, 0x608),
        // property 'clearcoatFresnelBias'
        QtMocHelpers::PropertyData<float>(72, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 58, 0x608),
        // property 'clearcoatFresnelPower'
        QtMocHelpers::PropertyData<float>(74, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 59, 0x608),
        // property 'vertexColorsMaskEnabled'
        QtMocHelpers::PropertyData<bool>(194, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 60, 0x608),
        // property 'vertexColorRedMask'
        QtMocHelpers::PropertyData<VertexColorMaskFlags>(197, 0x80000000 | 196, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 61, 0x608),
        // property 'vertexColorGreenMask'
        QtMocHelpers::PropertyData<VertexColorMaskFlags>(199, 0x80000000 | 196, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 62, 0x608),
        // property 'vertexColorBlueMask'
        QtMocHelpers::PropertyData<VertexColorMaskFlags>(201, 0x80000000 | 196, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 63, 0x608),
        // property 'vertexColorAlphaMask'
        QtMocHelpers::PropertyData<VertexColorMaskFlags>(203, 0x80000000 | 196, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 64, 0x608),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Lighting'
        QtMocHelpers::EnumData<enum Lighting>(204, 204, QMC::EnumFlags{}).add({
            {  236, Lighting::NoLighting },
            {  237, Lighting::FragmentLighting },
        }),
        // enum 'BlendMode'
        QtMocHelpers::EnumData<enum BlendMode>(205, 205, QMC::EnumFlags{}).add({
            {  238, BlendMode::SourceOver },
            {  239, BlendMode::Screen },
            {  240, BlendMode::Multiply },
        }),
        // enum 'AlphaMode'
        QtMocHelpers::EnumData<enum AlphaMode>(214, 214, QMC::EnumFlags{}).add({
            {  241, AlphaMode::Default },
            {  242, AlphaMode::Mask },
            {  243, AlphaMode::Blend },
            {  244, AlphaMode::Opaque },
        }),
        // enum 'VertexColorMask'
        QtMocHelpers::EnumData<enum VertexColorMask>(245, 245, QMC::EnumFlags{}).add({
            {  246, VertexColorMask::NoMask },
            {  247, VertexColorMask::GlossinessMask },
            {  248, VertexColorMask::NormalStrengthMask },
            {  249, VertexColorMask::ClearcoatAmountMask },
            {  250, VertexColorMask::ClearcoatRoughnessAmountMask },
            {  251, VertexColorMask::ClearcoatNormalStrengthMask },
            {  252, VertexColorMask::HeightAmountMask },
            {  253, VertexColorMask::OcclusionAmountMask },
            {  254, VertexColorMask::ThicknessFactorMask },
            {  255, VertexColorMask::TransmissionFactorMask },
        }),
        // flag 'VertexColorMaskFlags'
        QtMocHelpers::EnumData<VertexColorMaskFlags>(196, 245, QMC::EnumIsFlag).add({
            {  246, VertexColorMask::NoMask },
            {  247, VertexColorMask::GlossinessMask },
            {  248, VertexColorMask::NormalStrengthMask },
            {  249, VertexColorMask::ClearcoatAmountMask },
            {  250, VertexColorMask::ClearcoatRoughnessAmountMask },
            {  251, VertexColorMask::ClearcoatNormalStrengthMask },
            {  252, VertexColorMask::HeightAmountMask },
            {  253, VertexColorMask::OcclusionAmountMask },
            {  254, VertexColorMask::ThicknessFactorMask },
            {  255, VertexColorMask::TransmissionFactorMask },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DSpecularGlossyMaterial, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN30QQuick3DSpecularGlossyMaterialE[] = {
    QMetaObject::SuperData::link<QQuick3DMaterial::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject QQuick3DSpecularGlossyMaterial::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuick3DMaterial::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN30QQuick3DSpecularGlossyMaterialE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN30QQuick3DSpecularGlossyMaterialE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN30QQuick3DSpecularGlossyMaterialE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN30QQuick3DSpecularGlossyMaterialE_t>.metaTypes,
    nullptr
} };

void QQuick3DSpecularGlossyMaterial::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DSpecularGlossyMaterial *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->lightingChanged(); break;
        case 1: _t->blendModeChanged(); break;
        case 2: _t->albedoColorChanged(); break;
        case 3: _t->albedoMapChanged(); break;
        case 4: _t->albedoSingleChannelEnabledChanged(); break;
        case 5: _t->albedoChannelChanged(); break;
        case 6: _t->specularSingleChannelEnabledChanged(); break;
        case 7: _t->specularChannelChanged(); break;
        case 8: _t->emissiveSingleChannelEnabledChanged(); break;
        case 9: _t->emissiveChannelChanged(); break;
        case 10: _t->emissiveMapChanged(); break;
        case 11: _t->emissiveFactorChanged(); break;
        case 12: _t->glossinessChanged(); break;
        case 13: _t->glossinessMapChanged(); break;
        case 14: _t->invertOpacityMapValueChanged(); break;
        case 15: _t->opacityChanged(); break;
        case 16: _t->opacityMapChanged(); break;
        case 17: _t->normalMapChanged(); break;
        case 18: _t->specularColorChanged(); break;
        case 19: _t->specularMapChanged(); break;
        case 20: _t->normalStrengthChanged(); break;
        case 21: _t->occlusionMapChanged(); break;
        case 22: _t->occlusionAmountChanged(); break;
        case 23: _t->alphaModeChanged(); break;
        case 24: _t->alphaCutoffChanged(); break;
        case 25: _t->glossinessChannelChanged(); break;
        case 26: _t->opacityChannelChanged(); break;
        case 27: _t->occlusionChannelChanged(); break;
        case 28: _t->pointSizeChanged(); break;
        case 29: _t->lineWidthChanged(); break;
        case 30: _t->heightMapChanged(); break;
        case 31: _t->heightChannelChanged(); break;
        case 32: _t->heightAmountChanged(); break;
        case 33: _t->minHeightMapSamplesChanged(); break;
        case 34: _t->maxHeightMapSamplesChanged(); break;
        case 35: _t->clearcoatAmountChanged(); break;
        case 36: _t->clearcoatMapChanged(); break;
        case 37: _t->clearcoatChannelChanged(); break;
        case 38: _t->clearcoatRoughnessAmountChanged(); break;
        case 39: _t->clearcoatRoughnessChannelChanged(); break;
        case 40: _t->clearcoatRoughnessMapChanged(); break;
        case 41: _t->clearcoatNormalMapChanged(); break;
        case 42: _t->clearcoatNormalStrengthChanged(); break;
        case 43: _t->transmissionFactorChanged(); break;
        case 44: _t->transmissionMapChanged(); break;
        case 45: _t->transmissionChannelChanged(); break;
        case 46: _t->thicknessFactorChanged(); break;
        case 47: _t->thicknessMapChanged(); break;
        case 48: _t->thicknessChannelChanged(); break;
        case 49: _t->attenuationDistanceChanged(); break;
        case 50: _t->attenuationColorChanged(); break;
        case 51: _t->vertexColorsEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 52: _t->fresnelScaleBiasEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 53: _t->fresnelScaleChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 54: _t->fresnelBiasChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 55: _t->fresnelPowerChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 56: _t->clearcoatFresnelScaleBiasEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 57: _t->clearcoatFresnelScaleChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 58: _t->clearcoatFresnelBiasChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 59: _t->clearcoatFresnelPowerChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 60: _t->vertexColorsMaskEnabledChanged(); break;
        case 61: _t->vertexColorRedMaskChanged(); break;
        case 62: _t->vertexColorGreenMaskChanged(); break;
        case 63: _t->vertexColorBlueMaskChanged(); break;
        case 64: _t->vertexColorAlphaMaskChanged(); break;
        case 65: _t->setLighting((*reinterpret_cast<std::add_pointer_t<QQuick3DSpecularGlossyMaterial::Lighting>>(_a[1]))); break;
        case 66: _t->setBlendMode((*reinterpret_cast<std::add_pointer_t<QQuick3DSpecularGlossyMaterial::BlendMode>>(_a[1]))); break;
        case 67: _t->setAlbedoColor((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 68: _t->setAlbedoMap((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 69: _t->setAlbedoSingleChannelEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 70: _t->setAlbedoChannel((*reinterpret_cast<std::add_pointer_t<QQuick3DMaterial::TextureChannelMapping>>(_a[1]))); break;
        case 71: _t->setSpecularSingleChannelEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 72: _t->setSpecularChannel((*reinterpret_cast<std::add_pointer_t<QQuick3DMaterial::TextureChannelMapping>>(_a[1]))); break;
        case 73: _t->setEmissiveSingleChannelEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 74: _t->setEmissiveChannel((*reinterpret_cast<std::add_pointer_t<QQuick3DMaterial::TextureChannelMapping>>(_a[1]))); break;
        case 75: _t->setEmissiveMap((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 76: _t->setEmissiveFactor((*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[1]))); break;
        case 77: _t->setGlossiness((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 78: _t->setGlossinessMap((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 79: _t->setInvertOpacityMapValue((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 80: _t->setOpacity((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 81: _t->setOpacityMap((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 82: _t->setNormalMap((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 83: _t->setSpecularColor((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 84: _t->setSpecularMap((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 85: _t->setNormalStrength((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 86: _t->setOcclusionMap((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 87: _t->setOcclusionAmount((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 88: _t->setAlphaMode((*reinterpret_cast<std::add_pointer_t<QQuick3DSpecularGlossyMaterial::AlphaMode>>(_a[1]))); break;
        case 89: _t->setAlphaCutoff((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 90: _t->setGlossinessChannel((*reinterpret_cast<std::add_pointer_t<QQuick3DMaterial::TextureChannelMapping>>(_a[1]))); break;
        case 91: _t->setOpacityChannel((*reinterpret_cast<std::add_pointer_t<QQuick3DMaterial::TextureChannelMapping>>(_a[1]))); break;
        case 92: _t->setOcclusionChannel((*reinterpret_cast<std::add_pointer_t<QQuick3DMaterial::TextureChannelMapping>>(_a[1]))); break;
        case 93: _t->setPointSize((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 94: _t->setLineWidth((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 95: _t->setHeightMap((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 96: _t->setHeightChannel((*reinterpret_cast<std::add_pointer_t<QQuick3DMaterial::TextureChannelMapping>>(_a[1]))); break;
        case 97: _t->setHeightAmount((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 98: _t->setMinHeightMapSamples((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 99: _t->setMaxHeightMapSamples((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 100: _t->setClearcoatAmount((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 101: _t->setClearcoatMap((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 102: _t->setClearcoatChannel((*reinterpret_cast<std::add_pointer_t<QQuick3DMaterial::TextureChannelMapping>>(_a[1]))); break;
        case 103: _t->setClearcoatRoughnessAmount((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 104: _t->setClearcoatRoughnessChannel((*reinterpret_cast<std::add_pointer_t<QQuick3DMaterial::TextureChannelMapping>>(_a[1]))); break;
        case 105: _t->setClearcoatRoughnessMap((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 106: _t->setClearcoatNormalMap((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 107: _t->setClearcoatNormalStrength((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 108: _t->setTransmissionFactor((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 109: _t->setTransmissionMap((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 110: _t->setTransmissionChannel((*reinterpret_cast<std::add_pointer_t<QQuick3DMaterial::TextureChannelMapping>>(_a[1]))); break;
        case 111: _t->setThicknessFactor((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 112: _t->setThicknessMap((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 113: _t->setThicknessChannel((*reinterpret_cast<std::add_pointer_t<QQuick3DMaterial::TextureChannelMapping>>(_a[1]))); break;
        case 114: _t->setAttenuationDistance((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 115: _t->setAttenuationColor((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 116: _t->setFresnelScaleBiasEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 117: _t->setFresnelScale((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 118: _t->setFresnelBias((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 119: _t->setFresnelPower((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 120: _t->setClearcoatFresnelScaleBiasEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 121: _t->setClearcoatFresnelScale((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 122: _t->setClearcoatFresnelBias((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 123: _t->setClearcoatFresnelPower((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 124: _t->setVertexColorsEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 125: _t->setVertexColorsMaskEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 126: _t->setVertexColorRedMask((*reinterpret_cast<std::add_pointer_t<VertexColorMaskFlags>>(_a[1]))); break;
        case 127: _t->setVertexColorGreenMask((*reinterpret_cast<std::add_pointer_t<VertexColorMaskFlags>>(_a[1]))); break;
        case 128: _t->setVertexColorBlueMask((*reinterpret_cast<std::add_pointer_t<VertexColorMaskFlags>>(_a[1]))); break;
        case 129: _t->setVertexColorAlphaMask((*reinterpret_cast<std::add_pointer_t<VertexColorMaskFlags>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 68:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        case 75:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        case 78:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        case 81:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        case 82:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        case 84:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        case 86:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        case 95:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        case 101:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        case 105:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        case 106:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        case 109:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        case 112:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)()>(_a, &QQuick3DSpecularGlossyMaterial::lightingChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)()>(_a, &QQuick3DSpecularGlossyMaterial::blendModeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)()>(_a, &QQuick3DSpecularGlossyMaterial::albedoColorChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)()>(_a, &QQuick3DSpecularGlossyMaterial::albedoMapChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)()>(_a, &QQuick3DSpecularGlossyMaterial::albedoSingleChannelEnabledChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)()>(_a, &QQuick3DSpecularGlossyMaterial::albedoChannelChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)()>(_a, &QQuick3DSpecularGlossyMaterial::specularSingleChannelEnabledChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)()>(_a, &QQuick3DSpecularGlossyMaterial::specularChannelChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)()>(_a, &QQuick3DSpecularGlossyMaterial::emissiveSingleChannelEnabledChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)()>(_a, &QQuick3DSpecularGlossyMaterial::emissiveChannelChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)()>(_a, &QQuick3DSpecularGlossyMaterial::emissiveMapChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)()>(_a, &QQuick3DSpecularGlossyMaterial::emissiveFactorChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)()>(_a, &QQuick3DSpecularGlossyMaterial::glossinessChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)()>(_a, &QQuick3DSpecularGlossyMaterial::glossinessMapChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)()>(_a, &QQuick3DSpecularGlossyMaterial::invertOpacityMapValueChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)()>(_a, &QQuick3DSpecularGlossyMaterial::opacityChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)()>(_a, &QQuick3DSpecularGlossyMaterial::opacityMapChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)()>(_a, &QQuick3DSpecularGlossyMaterial::normalMapChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)()>(_a, &QQuick3DSpecularGlossyMaterial::specularColorChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)()>(_a, &QQuick3DSpecularGlossyMaterial::specularMapChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)()>(_a, &QQuick3DSpecularGlossyMaterial::normalStrengthChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)()>(_a, &QQuick3DSpecularGlossyMaterial::occlusionMapChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)()>(_a, &QQuick3DSpecularGlossyMaterial::occlusionAmountChanged, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)()>(_a, &QQuick3DSpecularGlossyMaterial::alphaModeChanged, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)()>(_a, &QQuick3DSpecularGlossyMaterial::alphaCutoffChanged, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)()>(_a, &QQuick3DSpecularGlossyMaterial::glossinessChannelChanged, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)()>(_a, &QQuick3DSpecularGlossyMaterial::opacityChannelChanged, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)()>(_a, &QQuick3DSpecularGlossyMaterial::occlusionChannelChanged, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)()>(_a, &QQuick3DSpecularGlossyMaterial::pointSizeChanged, 28))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)()>(_a, &QQuick3DSpecularGlossyMaterial::lineWidthChanged, 29))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)()>(_a, &QQuick3DSpecularGlossyMaterial::heightMapChanged, 30))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)()>(_a, &QQuick3DSpecularGlossyMaterial::heightChannelChanged, 31))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)()>(_a, &QQuick3DSpecularGlossyMaterial::heightAmountChanged, 32))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)()>(_a, &QQuick3DSpecularGlossyMaterial::minHeightMapSamplesChanged, 33))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)()>(_a, &QQuick3DSpecularGlossyMaterial::maxHeightMapSamplesChanged, 34))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)()>(_a, &QQuick3DSpecularGlossyMaterial::clearcoatAmountChanged, 35))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)()>(_a, &QQuick3DSpecularGlossyMaterial::clearcoatMapChanged, 36))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)()>(_a, &QQuick3DSpecularGlossyMaterial::clearcoatChannelChanged, 37))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)()>(_a, &QQuick3DSpecularGlossyMaterial::clearcoatRoughnessAmountChanged, 38))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)()>(_a, &QQuick3DSpecularGlossyMaterial::clearcoatRoughnessChannelChanged, 39))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)()>(_a, &QQuick3DSpecularGlossyMaterial::clearcoatRoughnessMapChanged, 40))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)()>(_a, &QQuick3DSpecularGlossyMaterial::clearcoatNormalMapChanged, 41))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)()>(_a, &QQuick3DSpecularGlossyMaterial::clearcoatNormalStrengthChanged, 42))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)()>(_a, &QQuick3DSpecularGlossyMaterial::transmissionFactorChanged, 43))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)()>(_a, &QQuick3DSpecularGlossyMaterial::transmissionMapChanged, 44))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)()>(_a, &QQuick3DSpecularGlossyMaterial::transmissionChannelChanged, 45))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)()>(_a, &QQuick3DSpecularGlossyMaterial::thicknessFactorChanged, 46))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)()>(_a, &QQuick3DSpecularGlossyMaterial::thicknessMapChanged, 47))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)()>(_a, &QQuick3DSpecularGlossyMaterial::thicknessChannelChanged, 48))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)()>(_a, &QQuick3DSpecularGlossyMaterial::attenuationDistanceChanged, 49))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)()>(_a, &QQuick3DSpecularGlossyMaterial::attenuationColorChanged, 50))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)(bool )>(_a, &QQuick3DSpecularGlossyMaterial::vertexColorsEnabledChanged, 51))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)(bool )>(_a, &QQuick3DSpecularGlossyMaterial::fresnelScaleBiasEnabledChanged, 52))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)(float )>(_a, &QQuick3DSpecularGlossyMaterial::fresnelScaleChanged, 53))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)(float )>(_a, &QQuick3DSpecularGlossyMaterial::fresnelBiasChanged, 54))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)(float )>(_a, &QQuick3DSpecularGlossyMaterial::fresnelPowerChanged, 55))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)(bool )>(_a, &QQuick3DSpecularGlossyMaterial::clearcoatFresnelScaleBiasEnabledChanged, 56))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)(float )>(_a, &QQuick3DSpecularGlossyMaterial::clearcoatFresnelScaleChanged, 57))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)(float )>(_a, &QQuick3DSpecularGlossyMaterial::clearcoatFresnelBiasChanged, 58))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)(float )>(_a, &QQuick3DSpecularGlossyMaterial::clearcoatFresnelPowerChanged, 59))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)()>(_a, &QQuick3DSpecularGlossyMaterial::vertexColorsMaskEnabledChanged, 60))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)()>(_a, &QQuick3DSpecularGlossyMaterial::vertexColorRedMaskChanged, 61))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)()>(_a, &QQuick3DSpecularGlossyMaterial::vertexColorGreenMaskChanged, 62))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)()>(_a, &QQuick3DSpecularGlossyMaterial::vertexColorBlueMaskChanged, 63))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSpecularGlossyMaterial::*)()>(_a, &QQuick3DSpecularGlossyMaterial::vertexColorAlphaMaskChanged, 64))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 47:
        case 44:
        case 41:
        case 40:
        case 36:
        case 30:
        case 23:
        case 21:
        case 19:
        case 14:
        case 11:
        case 7:
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuick3DTexture* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<enum Lighting*>(_v) = _t->lighting(); break;
        case 1: *reinterpret_cast<enum BlendMode*>(_v) = _t->blendMode(); break;
        case 2: *reinterpret_cast<QColor*>(_v) = _t->albedoColor(); break;
        case 3: *reinterpret_cast<QQuick3DTexture**>(_v) = _t->albedoMap(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->albedoSingleChannelEnabled(); break;
        case 5: *reinterpret_cast<QQuick3DMaterial::TextureChannelMapping*>(_v) = _t->albedoChannel(); break;
        case 6: *reinterpret_cast<QColor*>(_v) = _t->specularColor(); break;
        case 7: *reinterpret_cast<QQuick3DTexture**>(_v) = _t->specularMap(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->specularSingleChannelEnabled(); break;
        case 9: *reinterpret_cast<QQuick3DMaterial::TextureChannelMapping*>(_v) = _t->specularChannel(); break;
        case 10: *reinterpret_cast<float*>(_v) = _t->glossiness(); break;
        case 11: *reinterpret_cast<QQuick3DTexture**>(_v) = _t->glossinessMap(); break;
        case 12: *reinterpret_cast<QQuick3DMaterial::TextureChannelMapping*>(_v) = _t->glossinessChannel(); break;
        case 13: *reinterpret_cast<QVector3D*>(_v) = _t->emissiveFactor(); break;
        case 14: *reinterpret_cast<QQuick3DTexture**>(_v) = _t->emissiveMap(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->emissiveSingleChannelEnabled(); break;
        case 16: *reinterpret_cast<QQuick3DMaterial::TextureChannelMapping*>(_v) = _t->emissiveChannel(); break;
        case 17: *reinterpret_cast<bool*>(_v) = _t->invertOpacityMapValue(); break;
        case 18: *reinterpret_cast<float*>(_v) = _t->opacity(); break;
        case 19: *reinterpret_cast<QQuick3DTexture**>(_v) = _t->opacityMap(); break;
        case 20: *reinterpret_cast<QQuick3DMaterial::TextureChannelMapping*>(_v) = _t->opacityChannel(); break;
        case 21: *reinterpret_cast<QQuick3DTexture**>(_v) = _t->normalMap(); break;
        case 22: *reinterpret_cast<float*>(_v) = _t->normalStrength(); break;
        case 23: *reinterpret_cast<QQuick3DTexture**>(_v) = _t->occlusionMap(); break;
        case 24: *reinterpret_cast<QQuick3DMaterial::TextureChannelMapping*>(_v) = _t->occlusionChannel(); break;
        case 25: *reinterpret_cast<float*>(_v) = _t->occlusionAmount(); break;
        case 26: *reinterpret_cast<enum AlphaMode*>(_v) = _t->alphaMode(); break;
        case 27: *reinterpret_cast<float*>(_v) = _t->alphaCutoff(); break;
        case 28: *reinterpret_cast<float*>(_v) = _t->pointSize(); break;
        case 29: *reinterpret_cast<float*>(_v) = _t->lineWidth(); break;
        case 30: *reinterpret_cast<QQuick3DTexture**>(_v) = _t->heightMap(); break;
        case 31: *reinterpret_cast<QQuick3DMaterial::TextureChannelMapping*>(_v) = _t->heightChannel(); break;
        case 32: *reinterpret_cast<float*>(_v) = _t->heightAmount(); break;
        case 33: *reinterpret_cast<int*>(_v) = _t->minHeightMapSamples(); break;
        case 34: *reinterpret_cast<int*>(_v) = _t->maxHeightMapSamples(); break;
        case 35: *reinterpret_cast<float*>(_v) = _t->clearcoatAmount(); break;
        case 36: *reinterpret_cast<QQuick3DTexture**>(_v) = _t->clearcoatMap(); break;
        case 37: *reinterpret_cast<QQuick3DMaterial::TextureChannelMapping*>(_v) = _t->clearcoatChannel(); break;
        case 38: *reinterpret_cast<float*>(_v) = _t->clearcoatRoughnessAmount(); break;
        case 39: *reinterpret_cast<QQuick3DMaterial::TextureChannelMapping*>(_v) = _t->clearcoatRoughnessChannel(); break;
        case 40: *reinterpret_cast<QQuick3DTexture**>(_v) = _t->clearcoatRoughnessMap(); break;
        case 41: *reinterpret_cast<QQuick3DTexture**>(_v) = _t->clearcoatNormalMap(); break;
        case 42: *reinterpret_cast<float*>(_v) = _t->clearcoatNormalStrength(); break;
        case 43: *reinterpret_cast<float*>(_v) = _t->transmissionFactor(); break;
        case 44: *reinterpret_cast<QQuick3DTexture**>(_v) = _t->transmissionMap(); break;
        case 45: *reinterpret_cast<QQuick3DMaterial::TextureChannelMapping*>(_v) = _t->transmissionChannel(); break;
        case 46: *reinterpret_cast<float*>(_v) = _t->thicknessFactor(); break;
        case 47: *reinterpret_cast<QQuick3DTexture**>(_v) = _t->thicknessMap(); break;
        case 48: *reinterpret_cast<QQuick3DMaterial::TextureChannelMapping*>(_v) = _t->thicknessChannel(); break;
        case 49: *reinterpret_cast<float*>(_v) = _t->attenuationDistance(); break;
        case 50: *reinterpret_cast<QColor*>(_v) = _t->attenuationColor(); break;
        case 51: *reinterpret_cast<bool*>(_v) = _t->vertexColorsEnabled(); break;
        case 52: *reinterpret_cast<bool*>(_v) = _t->fresnelScaleBiasEnabled(); break;
        case 53: *reinterpret_cast<float*>(_v) = _t->fresnelScale(); break;
        case 54: *reinterpret_cast<float*>(_v) = _t->fresnelBias(); break;
        case 55: *reinterpret_cast<float*>(_v) = _t->fresnelPower(); break;
        case 56: *reinterpret_cast<bool*>(_v) = _t->clearcoatFresnelScaleBiasEnabled(); break;
        case 57: *reinterpret_cast<float*>(_v) = _t->clearcoatFresnelScale(); break;
        case 58: *reinterpret_cast<float*>(_v) = _t->clearcoatFresnelBias(); break;
        case 59: *reinterpret_cast<float*>(_v) = _t->clearcoatFresnelPower(); break;
        case 60: *reinterpret_cast<bool*>(_v) = _t->vertexColorsMaskEnabled(); break;
        case 61: QtMocHelpers::assignFlags<VertexColorMaskFlags>(_v, _t->vertexColorRedMask()); break;
        case 62: QtMocHelpers::assignFlags<VertexColorMaskFlags>(_v, _t->vertexColorGreenMask()); break;
        case 63: QtMocHelpers::assignFlags<VertexColorMaskFlags>(_v, _t->vertexColorBlueMask()); break;
        case 64: QtMocHelpers::assignFlags<VertexColorMaskFlags>(_v, _t->vertexColorAlphaMask()); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setLighting(*reinterpret_cast<enum Lighting*>(_v)); break;
        case 1: _t->setBlendMode(*reinterpret_cast<enum BlendMode*>(_v)); break;
        case 2: _t->setAlbedoColor(*reinterpret_cast<QColor*>(_v)); break;
        case 3: _t->setAlbedoMap(*reinterpret_cast<QQuick3DTexture**>(_v)); break;
        case 4: _t->setAlbedoSingleChannelEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setAlbedoChannel(*reinterpret_cast<QQuick3DMaterial::TextureChannelMapping*>(_v)); break;
        case 6: _t->setSpecularColor(*reinterpret_cast<QColor*>(_v)); break;
        case 7: _t->setSpecularMap(*reinterpret_cast<QQuick3DTexture**>(_v)); break;
        case 8: _t->setSpecularSingleChannelEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 9: _t->setSpecularChannel(*reinterpret_cast<QQuick3DMaterial::TextureChannelMapping*>(_v)); break;
        case 10: _t->setGlossiness(*reinterpret_cast<float*>(_v)); break;
        case 11: _t->setGlossinessMap(*reinterpret_cast<QQuick3DTexture**>(_v)); break;
        case 12: _t->setGlossinessChannel(*reinterpret_cast<QQuick3DMaterial::TextureChannelMapping*>(_v)); break;
        case 13: _t->setEmissiveFactor(*reinterpret_cast<QVector3D*>(_v)); break;
        case 14: _t->setEmissiveMap(*reinterpret_cast<QQuick3DTexture**>(_v)); break;
        case 15: _t->setEmissiveSingleChannelEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 16: _t->setEmissiveChannel(*reinterpret_cast<QQuick3DMaterial::TextureChannelMapping*>(_v)); break;
        case 17: _t->setInvertOpacityMapValue(*reinterpret_cast<bool*>(_v)); break;
        case 18: _t->setOpacity(*reinterpret_cast<float*>(_v)); break;
        case 19: _t->setOpacityMap(*reinterpret_cast<QQuick3DTexture**>(_v)); break;
        case 20: _t->setOpacityChannel(*reinterpret_cast<QQuick3DMaterial::TextureChannelMapping*>(_v)); break;
        case 21: _t->setNormalMap(*reinterpret_cast<QQuick3DTexture**>(_v)); break;
        case 22: _t->setNormalStrength(*reinterpret_cast<float*>(_v)); break;
        case 23: _t->setOcclusionMap(*reinterpret_cast<QQuick3DTexture**>(_v)); break;
        case 24: _t->setOcclusionChannel(*reinterpret_cast<QQuick3DMaterial::TextureChannelMapping*>(_v)); break;
        case 25: _t->setOcclusionAmount(*reinterpret_cast<float*>(_v)); break;
        case 26: _t->setAlphaMode(*reinterpret_cast<enum AlphaMode*>(_v)); break;
        case 27: _t->setAlphaCutoff(*reinterpret_cast<float*>(_v)); break;
        case 28: _t->setPointSize(*reinterpret_cast<float*>(_v)); break;
        case 29: _t->setLineWidth(*reinterpret_cast<float*>(_v)); break;
        case 30: _t->setHeightMap(*reinterpret_cast<QQuick3DTexture**>(_v)); break;
        case 31: _t->setHeightChannel(*reinterpret_cast<QQuick3DMaterial::TextureChannelMapping*>(_v)); break;
        case 32: _t->setHeightAmount(*reinterpret_cast<float*>(_v)); break;
        case 33: _t->setMinHeightMapSamples(*reinterpret_cast<int*>(_v)); break;
        case 34: _t->setMaxHeightMapSamples(*reinterpret_cast<int*>(_v)); break;
        case 35: _t->setClearcoatAmount(*reinterpret_cast<float*>(_v)); break;
        case 36: _t->setClearcoatMap(*reinterpret_cast<QQuick3DTexture**>(_v)); break;
        case 37: _t->setClearcoatChannel(*reinterpret_cast<QQuick3DMaterial::TextureChannelMapping*>(_v)); break;
        case 38: _t->setClearcoatRoughnessAmount(*reinterpret_cast<float*>(_v)); break;
        case 39: _t->setClearcoatRoughnessChannel(*reinterpret_cast<QQuick3DMaterial::TextureChannelMapping*>(_v)); break;
        case 40: _t->setClearcoatRoughnessMap(*reinterpret_cast<QQuick3DTexture**>(_v)); break;
        case 41: _t->setClearcoatNormalMap(*reinterpret_cast<QQuick3DTexture**>(_v)); break;
        case 42: _t->setClearcoatNormalStrength(*reinterpret_cast<float*>(_v)); break;
        case 43: _t->setTransmissionFactor(*reinterpret_cast<float*>(_v)); break;
        case 44: _t->setTransmissionMap(*reinterpret_cast<QQuick3DTexture**>(_v)); break;
        case 45: _t->setTransmissionChannel(*reinterpret_cast<QQuick3DMaterial::TextureChannelMapping*>(_v)); break;
        case 46: _t->setThicknessFactor(*reinterpret_cast<float*>(_v)); break;
        case 47: _t->setThicknessMap(*reinterpret_cast<QQuick3DTexture**>(_v)); break;
        case 48: _t->setThicknessChannel(*reinterpret_cast<QQuick3DMaterial::TextureChannelMapping*>(_v)); break;
        case 49: _t->setAttenuationDistance(*reinterpret_cast<float*>(_v)); break;
        case 50: _t->setAttenuationColor(*reinterpret_cast<QColor*>(_v)); break;
        case 51: _t->setVertexColorsEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 52: _t->setFresnelScaleBiasEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 53: _t->setFresnelScale(*reinterpret_cast<float*>(_v)); break;
        case 54: _t->setFresnelBias(*reinterpret_cast<float*>(_v)); break;
        case 55: _t->setFresnelPower(*reinterpret_cast<float*>(_v)); break;
        case 56: _t->setClearcoatFresnelScaleBiasEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 57: _t->setClearcoatFresnelScale(*reinterpret_cast<float*>(_v)); break;
        case 58: _t->setClearcoatFresnelBias(*reinterpret_cast<float*>(_v)); break;
        case 59: _t->setClearcoatFresnelPower(*reinterpret_cast<float*>(_v)); break;
        case 60: _t->setVertexColorsMaskEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 61: _t->setVertexColorRedMask(*reinterpret_cast<VertexColorMaskFlags*>(_v)); break;
        case 62: _t->setVertexColorGreenMask(*reinterpret_cast<VertexColorMaskFlags*>(_v)); break;
        case 63: _t->setVertexColorBlueMask(*reinterpret_cast<VertexColorMaskFlags*>(_v)); break;
        case 64: _t->setVertexColorAlphaMask(*reinterpret_cast<VertexColorMaskFlags*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DSpecularGlossyMaterial::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DSpecularGlossyMaterial::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN30QQuick3DSpecularGlossyMaterialE_t>.strings))
        return static_cast<void*>(this);
    return QQuick3DMaterial::qt_metacast(_clname);
}

int QQuick3DSpecularGlossyMaterial::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuick3DMaterial::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 130)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 130;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 130)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 130;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 65;
    }
    return _id;
}

// SIGNAL 0
void QQuick3DSpecularGlossyMaterial::lightingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QQuick3DSpecularGlossyMaterial::blendModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QQuick3DSpecularGlossyMaterial::albedoColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QQuick3DSpecularGlossyMaterial::albedoMapChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QQuick3DSpecularGlossyMaterial::albedoSingleChannelEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QQuick3DSpecularGlossyMaterial::albedoChannelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QQuick3DSpecularGlossyMaterial::specularSingleChannelEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void QQuick3DSpecularGlossyMaterial::specularChannelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void QQuick3DSpecularGlossyMaterial::emissiveSingleChannelEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void QQuick3DSpecularGlossyMaterial::emissiveChannelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void QQuick3DSpecularGlossyMaterial::emissiveMapChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void QQuick3DSpecularGlossyMaterial::emissiveFactorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void QQuick3DSpecularGlossyMaterial::glossinessChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void QQuick3DSpecularGlossyMaterial::glossinessMapChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void QQuick3DSpecularGlossyMaterial::invertOpacityMapValueChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void QQuick3DSpecularGlossyMaterial::opacityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void QQuick3DSpecularGlossyMaterial::opacityMapChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void QQuick3DSpecularGlossyMaterial::normalMapChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void QQuick3DSpecularGlossyMaterial::specularColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void QQuick3DSpecularGlossyMaterial::specularMapChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void QQuick3DSpecularGlossyMaterial::normalStrengthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void QQuick3DSpecularGlossyMaterial::occlusionMapChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void QQuick3DSpecularGlossyMaterial::occlusionAmountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 22, nullptr);
}

// SIGNAL 23
void QQuick3DSpecularGlossyMaterial::alphaModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 23, nullptr);
}

// SIGNAL 24
void QQuick3DSpecularGlossyMaterial::alphaCutoffChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 24, nullptr);
}

// SIGNAL 25
void QQuick3DSpecularGlossyMaterial::glossinessChannelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 25, nullptr);
}

// SIGNAL 26
void QQuick3DSpecularGlossyMaterial::opacityChannelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 26, nullptr);
}

// SIGNAL 27
void QQuick3DSpecularGlossyMaterial::occlusionChannelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 27, nullptr);
}

// SIGNAL 28
void QQuick3DSpecularGlossyMaterial::pointSizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 28, nullptr);
}

// SIGNAL 29
void QQuick3DSpecularGlossyMaterial::lineWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 29, nullptr);
}

// SIGNAL 30
void QQuick3DSpecularGlossyMaterial::heightMapChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 30, nullptr);
}

// SIGNAL 31
void QQuick3DSpecularGlossyMaterial::heightChannelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 31, nullptr);
}

// SIGNAL 32
void QQuick3DSpecularGlossyMaterial::heightAmountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 32, nullptr);
}

// SIGNAL 33
void QQuick3DSpecularGlossyMaterial::minHeightMapSamplesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 33, nullptr);
}

// SIGNAL 34
void QQuick3DSpecularGlossyMaterial::maxHeightMapSamplesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 34, nullptr);
}

// SIGNAL 35
void QQuick3DSpecularGlossyMaterial::clearcoatAmountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 35, nullptr);
}

// SIGNAL 36
void QQuick3DSpecularGlossyMaterial::clearcoatMapChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 36, nullptr);
}

// SIGNAL 37
void QQuick3DSpecularGlossyMaterial::clearcoatChannelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 37, nullptr);
}

// SIGNAL 38
void QQuick3DSpecularGlossyMaterial::clearcoatRoughnessAmountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 38, nullptr);
}

// SIGNAL 39
void QQuick3DSpecularGlossyMaterial::clearcoatRoughnessChannelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 39, nullptr);
}

// SIGNAL 40
void QQuick3DSpecularGlossyMaterial::clearcoatRoughnessMapChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 40, nullptr);
}

// SIGNAL 41
void QQuick3DSpecularGlossyMaterial::clearcoatNormalMapChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 41, nullptr);
}

// SIGNAL 42
void QQuick3DSpecularGlossyMaterial::clearcoatNormalStrengthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 42, nullptr);
}

// SIGNAL 43
void QQuick3DSpecularGlossyMaterial::transmissionFactorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 43, nullptr);
}

// SIGNAL 44
void QQuick3DSpecularGlossyMaterial::transmissionMapChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 44, nullptr);
}

// SIGNAL 45
void QQuick3DSpecularGlossyMaterial::transmissionChannelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 45, nullptr);
}

// SIGNAL 46
void QQuick3DSpecularGlossyMaterial::thicknessFactorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 46, nullptr);
}

// SIGNAL 47
void QQuick3DSpecularGlossyMaterial::thicknessMapChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 47, nullptr);
}

// SIGNAL 48
void QQuick3DSpecularGlossyMaterial::thicknessChannelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 48, nullptr);
}

// SIGNAL 49
void QQuick3DSpecularGlossyMaterial::attenuationDistanceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 49, nullptr);
}

// SIGNAL 50
void QQuick3DSpecularGlossyMaterial::attenuationColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 50, nullptr);
}

// SIGNAL 51
void QQuick3DSpecularGlossyMaterial::vertexColorsEnabledChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 51, nullptr, _t1);
}

// SIGNAL 52
void QQuick3DSpecularGlossyMaterial::fresnelScaleBiasEnabledChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 52, nullptr, _t1);
}

// SIGNAL 53
void QQuick3DSpecularGlossyMaterial::fresnelScaleChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 53, nullptr, _t1);
}

// SIGNAL 54
void QQuick3DSpecularGlossyMaterial::fresnelBiasChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 54, nullptr, _t1);
}

// SIGNAL 55
void QQuick3DSpecularGlossyMaterial::fresnelPowerChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 55, nullptr, _t1);
}

// SIGNAL 56
void QQuick3DSpecularGlossyMaterial::clearcoatFresnelScaleBiasEnabledChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 56, nullptr, _t1);
}

// SIGNAL 57
void QQuick3DSpecularGlossyMaterial::clearcoatFresnelScaleChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 57, nullptr, _t1);
}

// SIGNAL 58
void QQuick3DSpecularGlossyMaterial::clearcoatFresnelBiasChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 58, nullptr, _t1);
}

// SIGNAL 59
void QQuick3DSpecularGlossyMaterial::clearcoatFresnelPowerChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 59, nullptr, _t1);
}

// SIGNAL 60
void QQuick3DSpecularGlossyMaterial::vertexColorsMaskEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 60, nullptr);
}

// SIGNAL 61
void QQuick3DSpecularGlossyMaterial::vertexColorRedMaskChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 61, nullptr);
}

// SIGNAL 62
void QQuick3DSpecularGlossyMaterial::vertexColorGreenMaskChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 62, nullptr);
}

// SIGNAL 63
void QQuick3DSpecularGlossyMaterial::vertexColorBlueMaskChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 63, nullptr);
}

// SIGNAL 64
void QQuick3DSpecularGlossyMaterial::vertexColorAlphaMaskChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 64, nullptr);
}
QT_WARNING_POP
