/****************************************************************************
** Meta object code from reading C++ file 'qquick3dfog_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtquick3d/src/quick3d/qquick3dfog_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquick3dfog_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11QQuick3DFogE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DFog::qt_create_metaobjectdata<qt_meta_tag_ZN11QQuick3DFogE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DFog",
        "QML.Element",
        "Fog",
        "changed",
        "",
        "enabledChanged",
        "colorChanged",
        "densityChanged",
        "depthEnabledChanged",
        "depthNearChanged",
        "depthFarChanged",
        "depthCurveChanged",
        "heightEnabledChanged",
        "leastIntenseYChanged",
        "mostIntenseYChanged",
        "heightCurveChanged",
        "transmitEnabledChanged",
        "transmitCurveChanged",
        "setEnabled",
        "newEnabled",
        "setColor",
        "QColor",
        "newColor",
        "setDensity",
        "newDensity",
        "setDepthEnabled",
        "newDepthEnabled",
        "setDepthNear",
        "newDepthNear",
        "setDepthFar",
        "newDepthFar",
        "setDepthCurve",
        "newDepthCurve",
        "setHeightEnabled",
        "newHeightEnabled",
        "setLeastIntenseY",
        "newleastIntenseY",
        "setMostIntenseY",
        "newmostIntenseY",
        "setHeightCurve",
        "newHeightCurve",
        "setTransmitEnabled",
        "newTransmitEnabled",
        "setTransmitCurve",
        "newTransmitCurve",
        "enabled",
        "color",
        "density",
        "depthEnabled",
        "depthNear",
        "depthFar",
        "depthCurve",
        "heightEnabled",
        "leastIntenseY",
        "mostIntenseY",
        "heightCurve",
        "transmitEnabled",
        "transmitCurve"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'changed'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enabledChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'colorChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'densityChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'depthEnabledChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'depthNearChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'depthFarChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'depthCurveChanged'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'heightEnabledChanged'
        QtMocHelpers::SignalData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'leastIntenseYChanged'
        QtMocHelpers::SignalData<void()>(13, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mostIntenseYChanged'
        QtMocHelpers::SignalData<void()>(14, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'heightCurveChanged'
        QtMocHelpers::SignalData<void()>(15, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'transmitEnabledChanged'
        QtMocHelpers::SignalData<void()>(16, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'transmitCurveChanged'
        QtMocHelpers::SignalData<void()>(17, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setEnabled'
        QtMocHelpers::SlotData<void(bool)>(18, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 19 },
        }}),
        // Slot 'setColor'
        QtMocHelpers::SlotData<void(const QColor &)>(20, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 22 },
        }}),
        // Slot 'setDensity'
        QtMocHelpers::SlotData<void(float)>(23, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 24 },
        }}),
        // Slot 'setDepthEnabled'
        QtMocHelpers::SlotData<void(bool)>(25, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 26 },
        }}),
        // Slot 'setDepthNear'
        QtMocHelpers::SlotData<void(float)>(27, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 28 },
        }}),
        // Slot 'setDepthFar'
        QtMocHelpers::SlotData<void(float)>(29, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 30 },
        }}),
        // Slot 'setDepthCurve'
        QtMocHelpers::SlotData<void(float)>(31, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 32 },
        }}),
        // Slot 'setHeightEnabled'
        QtMocHelpers::SlotData<void(bool)>(33, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 34 },
        }}),
        // Slot 'setLeastIntenseY'
        QtMocHelpers::SlotData<void(float)>(35, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 36 },
        }}),
        // Slot 'setMostIntenseY'
        QtMocHelpers::SlotData<void(float)>(37, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 38 },
        }}),
        // Slot 'setHeightCurve'
        QtMocHelpers::SlotData<void(float)>(39, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 40 },
        }}),
        // Slot 'setTransmitEnabled'
        QtMocHelpers::SlotData<void(bool)>(41, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 42 },
        }}),
        // Slot 'setTransmitCurve'
        QtMocHelpers::SlotData<void(float)>(43, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 44 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'enabled'
        QtMocHelpers::PropertyData<bool>(45, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'color'
        QtMocHelpers::PropertyData<QColor>(46, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'density'
        QtMocHelpers::PropertyData<float>(47, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'depthEnabled'
        QtMocHelpers::PropertyData<bool>(48, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'depthNear'
        QtMocHelpers::PropertyData<float>(49, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'depthFar'
        QtMocHelpers::PropertyData<float>(50, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'depthCurve'
        QtMocHelpers::PropertyData<float>(51, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'heightEnabled'
        QtMocHelpers::PropertyData<bool>(52, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'leastIntenseY'
        QtMocHelpers::PropertyData<float>(53, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'mostIntenseY'
        QtMocHelpers::PropertyData<float>(54, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'heightCurve'
        QtMocHelpers::PropertyData<float>(55, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'transmitEnabled'
        QtMocHelpers::PropertyData<bool>(56, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'transmitCurve'
        QtMocHelpers::PropertyData<float>(57, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DFog, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DFog::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11QQuick3DFogE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11QQuick3DFogE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11QQuick3DFogE_t>.metaTypes,
    nullptr
} };

void QQuick3DFog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DFog *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->changed(); break;
        case 1: _t->enabledChanged(); break;
        case 2: _t->colorChanged(); break;
        case 3: _t->densityChanged(); break;
        case 4: _t->depthEnabledChanged(); break;
        case 5: _t->depthNearChanged(); break;
        case 6: _t->depthFarChanged(); break;
        case 7: _t->depthCurveChanged(); break;
        case 8: _t->heightEnabledChanged(); break;
        case 9: _t->leastIntenseYChanged(); break;
        case 10: _t->mostIntenseYChanged(); break;
        case 11: _t->heightCurveChanged(); break;
        case 12: _t->transmitEnabledChanged(); break;
        case 13: _t->transmitCurveChanged(); break;
        case 14: _t->setEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 15: _t->setColor((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 16: _t->setDensity((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 17: _t->setDepthEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 18: _t->setDepthNear((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 19: _t->setDepthFar((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 20: _t->setDepthCurve((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 21: _t->setHeightEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 22: _t->setLeastIntenseY((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 23: _t->setMostIntenseY((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 24: _t->setHeightCurve((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 25: _t->setTransmitEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 26: _t->setTransmitCurve((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuick3DFog::*)()>(_a, &QQuick3DFog::changed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DFog::*)()>(_a, &QQuick3DFog::enabledChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DFog::*)()>(_a, &QQuick3DFog::colorChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DFog::*)()>(_a, &QQuick3DFog::densityChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DFog::*)()>(_a, &QQuick3DFog::depthEnabledChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DFog::*)()>(_a, &QQuick3DFog::depthNearChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DFog::*)()>(_a, &QQuick3DFog::depthFarChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DFog::*)()>(_a, &QQuick3DFog::depthCurveChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DFog::*)()>(_a, &QQuick3DFog::heightEnabledChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DFog::*)()>(_a, &QQuick3DFog::leastIntenseYChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DFog::*)()>(_a, &QQuick3DFog::mostIntenseYChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DFog::*)()>(_a, &QQuick3DFog::heightCurveChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DFog::*)()>(_a, &QQuick3DFog::transmitEnabledChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DFog::*)()>(_a, &QQuick3DFog::transmitCurveChanged, 13))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->isEnabled(); break;
        case 1: *reinterpret_cast<QColor*>(_v) = _t->color(); break;
        case 2: *reinterpret_cast<float*>(_v) = _t->density(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isDepthEnabled(); break;
        case 4: *reinterpret_cast<float*>(_v) = _t->depthNear(); break;
        case 5: *reinterpret_cast<float*>(_v) = _t->depthFar(); break;
        case 6: *reinterpret_cast<float*>(_v) = _t->depthCurve(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isHeightEnabled(); break;
        case 8: *reinterpret_cast<float*>(_v) = _t->leastIntenseY(); break;
        case 9: *reinterpret_cast<float*>(_v) = _t->mostIntenseY(); break;
        case 10: *reinterpret_cast<float*>(_v) = _t->heightCurve(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->isTransmitEnabled(); break;
        case 12: *reinterpret_cast<float*>(_v) = _t->transmitCurve(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 1: _t->setColor(*reinterpret_cast<QColor*>(_v)); break;
        case 2: _t->setDensity(*reinterpret_cast<float*>(_v)); break;
        case 3: _t->setDepthEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 4: _t->setDepthNear(*reinterpret_cast<float*>(_v)); break;
        case 5: _t->setDepthFar(*reinterpret_cast<float*>(_v)); break;
        case 6: _t->setDepthCurve(*reinterpret_cast<float*>(_v)); break;
        case 7: _t->setHeightEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 8: _t->setLeastIntenseY(*reinterpret_cast<float*>(_v)); break;
        case 9: _t->setMostIntenseY(*reinterpret_cast<float*>(_v)); break;
        case 10: _t->setHeightCurve(*reinterpret_cast<float*>(_v)); break;
        case 11: _t->setTransmitEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 12: _t->setTransmitCurve(*reinterpret_cast<float*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DFog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DFog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11QQuick3DFogE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QQuick3DFog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 27)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 27;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 27)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 27;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void QQuick3DFog::changed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QQuick3DFog::enabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QQuick3DFog::colorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QQuick3DFog::densityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QQuick3DFog::depthEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QQuick3DFog::depthNearChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QQuick3DFog::depthFarChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void QQuick3DFog::depthCurveChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void QQuick3DFog::heightEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void QQuick3DFog::leastIntenseYChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void QQuick3DFog::mostIntenseYChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void QQuick3DFog::heightCurveChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void QQuick3DFog::transmitEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void QQuick3DFog::transmitCurveChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}
QT_WARNING_POP
