/****************************************************************************
** Meta object code from reading C++ file 'qquick3dparticlesceneshape_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtquick3d/src/quick3dparticles/qquick3dparticlesceneshape_p.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquick3dparticlesceneshape_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN26QQuick3DParticleSceneShapeE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DParticleSceneShape::qt_create_metaobjectdata<qt_meta_tag_ZN26QQuick3DParticleSceneShapeE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DParticleSceneShape",
        "QML.Element",
        "ParticleSceneShape3D",
        "QML.AddedInVersion",
        "1547",
        "sceneChanged",
        "",
        "sceneCenterChanged",
        "sceneExtentsChanged",
        "shapeResolutionChanged",
        "geometryChanged",
        "excludedNodesChanged",
        "setScene",
        "QQuick3DNode*",
        "scene",
        "setSceneCenter",
        "QVector3D",
        "extents",
        "setSceneExtents",
        "setShapeResolution",
        "resolution",
        "setExcludedNodes",
        "QList<QQuick3DNode*>",
        "nodes",
        "getPosition",
        "particleIndex",
        "getSurfaceNormal",
        "sceneCenter",
        "sceneExtents",
        "shapeResolution",
        "excludedNodes",
        "geometry",
        "QQuick3DGeometry*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sceneChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sceneCenterChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sceneExtentsChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'shapeResolutionChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'geometryChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'excludedNodesChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setScene'
        QtMocHelpers::SlotData<void(QQuick3DNode *)>(12, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'setSceneCenter'
        QtMocHelpers::SlotData<void(const QVector3D &)>(15, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Slot 'setSceneExtents'
        QtMocHelpers::SlotData<void(const QVector3D &)>(18, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Slot 'setShapeResolution'
        QtMocHelpers::SlotData<void(float)>(19, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 20 },
        }}),
        // Slot 'setExcludedNodes'
        QtMocHelpers::SlotData<void(const QList<QQuick3DNode*> &)>(21, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Slot 'getPosition'
        QtMocHelpers::SlotData<QVector3D(int)>(24, 6, QMC::AccessPublic, 0x80000000 | 16, {{
            { QMetaType::Int, 25 },
        }}),
        // Slot 'getSurfaceNormal'
        QtMocHelpers::SlotData<QVector3D(int)>(26, 6, QMC::AccessPublic, 0x80000000 | 16, {{
            { QMetaType::Int, 25 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'scene'
        QtMocHelpers::PropertyData<QQuick3DNode*>(14, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'sceneCenter'
        QtMocHelpers::PropertyData<QVector3D>(27, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'sceneExtents'
        QtMocHelpers::PropertyData<QVector3D>(28, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'shapeResolution'
        QtMocHelpers::PropertyData<float>(29, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'excludedNodes'
        QtMocHelpers::PropertyData<QList<QQuick3DNode*>>(30, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5),
        // property 'geometry'
        QtMocHelpers::PropertyData<QQuick3DGeometry*>(31, 0x80000000 | 32, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 4),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DParticleSceneShape, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DParticleSceneShape::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuick3DParticleAbstractShape::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26QQuick3DParticleSceneShapeE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26QQuick3DParticleSceneShapeE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN26QQuick3DParticleSceneShapeE_t>.metaTypes,
    nullptr
} };

void QQuick3DParticleSceneShape::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DParticleSceneShape *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sceneChanged(); break;
        case 1: _t->sceneCenterChanged(); break;
        case 2: _t->sceneExtentsChanged(); break;
        case 3: _t->shapeResolutionChanged(); break;
        case 4: _t->geometryChanged(); break;
        case 5: _t->excludedNodesChanged(); break;
        case 6: _t->setScene((*reinterpret_cast<std::add_pointer_t<QQuick3DNode*>>(_a[1]))); break;
        case 7: _t->setSceneCenter((*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[1]))); break;
        case 8: _t->setSceneExtents((*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[1]))); break;
        case 9: _t->setShapeResolution((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 10: _t->setExcludedNodes((*reinterpret_cast<std::add_pointer_t<QList<QQuick3DNode*>>>(_a[1]))); break;
        case 11: { QVector3D _r = _t->getPosition((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVector3D*>(_a[0]) = std::move(_r); }  break;
        case 12: { QVector3D _r = _t->getSurfaceNormal((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVector3D*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleSceneShape::*)()>(_a, &QQuick3DParticleSceneShape::sceneChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleSceneShape::*)()>(_a, &QQuick3DParticleSceneShape::sceneCenterChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleSceneShape::*)()>(_a, &QQuick3DParticleSceneShape::sceneExtentsChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleSceneShape::*)()>(_a, &QQuick3DParticleSceneShape::shapeResolutionChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleSceneShape::*)()>(_a, &QQuick3DParticleSceneShape::geometryChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleSceneShape::*)()>(_a, &QQuick3DParticleSceneShape::excludedNodesChanged, 5))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QQuick3DNode**>(_v) = _t->scene(); break;
        case 1: *reinterpret_cast<QVector3D*>(_v) = _t->sceneCenter(); break;
        case 2: *reinterpret_cast<QVector3D*>(_v) = _t->sceneExtents(); break;
        case 3: *reinterpret_cast<float*>(_v) = _t->shapeResolution(); break;
        case 4: *reinterpret_cast<QList<QQuick3DNode*>*>(_v) = _t->excludedNodes(); break;
        case 5: *reinterpret_cast<QQuick3DGeometry**>(_v) = _t->geometry(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setScene(*reinterpret_cast<QQuick3DNode**>(_v)); break;
        case 1: _t->setSceneCenter(*reinterpret_cast<QVector3D*>(_v)); break;
        case 2: _t->setSceneExtents(*reinterpret_cast<QVector3D*>(_v)); break;
        case 3: _t->setShapeResolution(*reinterpret_cast<float*>(_v)); break;
        case 4: _t->setExcludedNodes(*reinterpret_cast<QList<QQuick3DNode*>*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DParticleSceneShape::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DParticleSceneShape::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26QQuick3DParticleSceneShapeE_t>.strings))
        return static_cast<void*>(this);
    return QQuick3DParticleAbstractShape::qt_metacast(_clname);
}

int QQuick3DParticleSceneShape::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuick3DParticleAbstractShape::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 13;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void QQuick3DParticleSceneShape::sceneChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QQuick3DParticleSceneShape::sceneCenterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QQuick3DParticleSceneShape::sceneExtentsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QQuick3DParticleSceneShape::shapeResolutionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QQuick3DParticleSceneShape::geometryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QQuick3DParticleSceneShape::excludedNodesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
