/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<private/qquick3drenderstatsmeshesmodel_p.h>)
#  include <private/qquick3drenderstatsmeshesmodel_p.h>
#endif
#if __has_include(<private/qquick3drenderstatspassesmodel_p.h>)
#  include <private/qquick3drenderstatspassesmodel_p.h>
#endif
#if __has_include(<private/qquick3drenderstatstexturesmodel_p.h>)
#  include <private/qquick3drenderstatstexturesmodel_p.h>
#endif
#if __has_include(<private/sceneeffects_p.h>)
#  include <private/sceneeffects_p.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_QtQuick3D_Helpers_impl()
{
    qmlRegisterModule("QtQuick3D.Helpers.impl", 6, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<DepthOfFieldEffect>("QtQuick3D.Helpers.impl", 6);
    qmlRegisterTypesAndRevisions<MainSceneEffect>("QtQuick3D.Helpers.impl", 6);
    QMetaType::fromType<QAbstractTableModel *>().id();
    qmlRegisterTypesAndRevisions<QQuick3DRenderStatsMeshesModel>("QtQuick3D.Helpers.impl", 6);
    qmlRegisterAnonymousTypesAndRevisions<QAbstractItemModel>("QtQuick3D.Helpers.impl", 6);
    qmlRegisterTypesAndRevisions<QQuick3DRenderStatsPassesModel>("QtQuick3D.Helpers.impl", 6);
    qmlRegisterTypesAndRevisions<QQuick3DRenderStatsTexturesModel>("QtQuick3D.Helpers.impl", 6);
    qmlRegisterTypesAndRevisions<SceneEffectBase>("QtQuick3D.Helpers.impl", 6);
    qmlRegisterTypesAndRevisions<SceneEffectEnvironment>("QtQuick3D.Helpers.impl", 6);
    qmlRegisterAnonymousTypesAndRevisions<QQuick3DSceneEnvironment>("QtQuick3D.Helpers.impl", 6);
    qmlRegisterTypesAndRevisions<SsgiEnvEffect>("QtQuick3D.Helpers.impl", 6);
    qmlRegisterTypesAndRevisions<SsrEnvEffect>("QtQuick3D.Helpers.impl", 6);
    QT_WARNING_POP
    qmlRegisterModule("QtQuick3D.Helpers.impl", 6, 11);
}

static const QQmlModuleRegistration qtQuick3DHelpersimplRegistration("QtQuick3D.Helpers.impl", qml_register_types_QtQuick3D_Helpers_impl);
