/****************************************************************************
** Meta object code from reading C++ file 'qquick3dcamera_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtquick3d/src/quick3d/qquick3dcamera_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquick3dcamera_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14QQuick3DCameraE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DCamera::qt_create_metaobjectdata<qt_meta_tag_ZN14QQuick3DCameraE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DCamera",
        "QML.Element",
        "Camera",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Camera is Abstract",
        "frustumCullingEnabledChanged",
        "",
        "lookAtNodeChanged",
        "levelOfDetailBiasChanged",
        "setFrustumCullingEnabled",
        "frustumCullingEnabled",
        "setLookAtNode",
        "QQuick3DNode*",
        "node",
        "setLevelOfDetailBias",
        "newLevelOFDetailBias",
        "updateLookAt",
        "mapToViewport",
        "QVector3D",
        "scenePos",
        "mapFromViewport",
        "viewportPos",
        "lookAt",
        "lookAtNode",
        "levelOfDetailBias"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'frustumCullingEnabledChanged'
        QtMocHelpers::SignalData<void()>(7, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lookAtNodeChanged'
        QtMocHelpers::RevisionedSignalData<void()>(9, 8, QMC::AccessPublic, 0x604, QMetaType::Void),
        // Signal 'levelOfDetailBiasChanged'
        QtMocHelpers::RevisionedSignalData<void()>(10, 8, QMC::AccessPublic, 0x605, QMetaType::Void),
        // Slot 'setFrustumCullingEnabled'
        QtMocHelpers::SlotData<void(bool)>(11, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 12 },
        }}),
        // Slot 'setLookAtNode'
        QtMocHelpers::SlotData<void(QQuick3DNode *)>(13, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Slot 'setLevelOfDetailBias'
        QtMocHelpers::RevisionedSlotData<void(float)>(16, 8, QMC::AccessPublic, 0x605, QMetaType::Void, {{
            { QMetaType::Float, 17 },
        }}),
        // Slot 'updateLookAt'
        QtMocHelpers::SlotData<void()>(18, 8, QMC::AccessPrivate, QMetaType::Void),
        // Method 'mapToViewport'
        QtMocHelpers::MethodData<QVector3D(const QVector3D &) const>(19, 8, QMC::AccessPublic, 0x80000000 | 20, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Method 'mapFromViewport'
        QtMocHelpers::MethodData<QVector3D(const QVector3D &) const>(22, 8, QMC::AccessPublic, 0x80000000 | 20, {{
            { 0x80000000 | 20, 23 },
        }}),
        // Method 'lookAt'
        QtMocHelpers::MethodData<void(const QVector3D &)>(24, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Method 'lookAt'
        QtMocHelpers::MethodData<void(QQuick3DNode *)>(24, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'frustumCullingEnabled'
        QtMocHelpers::PropertyData<bool>(12, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'lookAtNode'
        QtMocHelpers::PropertyData<QQuick3DNode*>(25, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1, 0x604),
        // property 'levelOfDetailBias'
        QtMocHelpers::PropertyData<float>(26, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2, 0x605),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DCamera, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DCamera::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuick3DNode::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14QQuick3DCameraE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14QQuick3DCameraE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14QQuick3DCameraE_t>.metaTypes,
    nullptr
} };

void QQuick3DCamera::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DCamera *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->frustumCullingEnabledChanged(); break;
        case 1: _t->lookAtNodeChanged(); break;
        case 2: _t->levelOfDetailBiasChanged(); break;
        case 3: _t->setFrustumCullingEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->setLookAtNode((*reinterpret_cast<std::add_pointer_t<QQuick3DNode*>>(_a[1]))); break;
        case 5: _t->setLevelOfDetailBias((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 6: _t->updateLookAt(); break;
        case 7: { QVector3D _r = _t->mapToViewport((*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVector3D*>(_a[0]) = std::move(_r); }  break;
        case 8: { QVector3D _r = _t->mapFromViewport((*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVector3D*>(_a[0]) = std::move(_r); }  break;
        case 9: _t->lookAt((*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[1]))); break;
        case 10: _t->lookAt((*reinterpret_cast<std::add_pointer_t<QQuick3DNode*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DNode* >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DNode* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuick3DCamera::*)()>(_a, &QQuick3DCamera::frustumCullingEnabledChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DCamera::*)()>(_a, &QQuick3DCamera::lookAtNodeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DCamera::*)()>(_a, &QQuick3DCamera::levelOfDetailBiasChanged, 2))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuick3DNode* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->frustumCullingEnabled(); break;
        case 1: *reinterpret_cast<QQuick3DNode**>(_v) = _t->lookAtNode(); break;
        case 2: *reinterpret_cast<float*>(_v) = _t->levelOfDetailBias(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setFrustumCullingEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 1: _t->setLookAtNode(*reinterpret_cast<QQuick3DNode**>(_v)); break;
        case 2: _t->setLevelOfDetailBias(*reinterpret_cast<float*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DCamera::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DCamera::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14QQuick3DCameraE_t>.strings))
        return static_cast<void*>(this);
    return QQuick3DNode::qt_metacast(_clname);
}

int QQuick3DCamera::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuick3DNode::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void QQuick3DCamera::frustumCullingEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QQuick3DCamera::lookAtNodeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QQuick3DCamera::levelOfDetailBiasChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
