/****************************************************************************
** Meta object code from reading C++ file 'qquick3dparticlesystemlogging_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtquick3d/src/quick3dparticles/qquick3dparticlesystemlogging_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquick3dparticlesystemlogging_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN29QQuick3DParticleSystemLoggingE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DParticleSystemLogging::qt_create_metaobjectdata<qt_meta_tag_ZN29QQuick3DParticleSystemLoggingE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DParticleSystemLogging",
        "QML.Element",
        "anonymous",
        "QML.AddedInVersion",
        "1538",
        "loggingIntervalChanged",
        "",
        "updatesChanged",
        "particlesMaxChanged",
        "particlesUsedChanged",
        "timeChanged",
        "timeAverageChanged",
        "timeDeviationChanged",
        "setLoggingInterval",
        "interval",
        "loggingInterval",
        "updates",
        "particlesMax",
        "particlesUsed",
        "time",
        "timeAverage",
        "timeDeviation"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'loggingIntervalChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'updatesChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'particlesMaxChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'particlesUsedChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'timeChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'timeAverageChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'timeDeviationChanged'
        QtMocHelpers::RevisionedSignalData<void()>(12, 6, QMC::AccessPublic, 0x603, QMetaType::Void),
        // Slot 'setLoggingInterval'
        QtMocHelpers::SlotData<void(int)>(13, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 14 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'loggingInterval'
        QtMocHelpers::PropertyData<int>(15, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'updates'
        QtMocHelpers::PropertyData<int>(16, QMetaType::Int, QMC::DefaultPropertyFlags, 1),
        // property 'particlesMax'
        QtMocHelpers::PropertyData<int>(17, QMetaType::Int, QMC::DefaultPropertyFlags, 2),
        // property 'particlesUsed'
        QtMocHelpers::PropertyData<int>(18, QMetaType::Int, QMC::DefaultPropertyFlags, 3),
        // property 'time'
        QtMocHelpers::PropertyData<float>(19, QMetaType::Float, QMC::DefaultPropertyFlags, 4),
        // property 'timeAverage'
        QtMocHelpers::PropertyData<float>(20, QMetaType::Float, QMC::DefaultPropertyFlags, 5),
        // property 'timeDeviation'
        QtMocHelpers::PropertyData<float>(21, QMetaType::Float, QMC::DefaultPropertyFlags, 6, 0x603),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DParticleSystemLogging, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DParticleSystemLogging::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29QQuick3DParticleSystemLoggingE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29QQuick3DParticleSystemLoggingE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN29QQuick3DParticleSystemLoggingE_t>.metaTypes,
    nullptr
} };

void QQuick3DParticleSystemLogging::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DParticleSystemLogging *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->loggingIntervalChanged(); break;
        case 1: _t->updatesChanged(); break;
        case 2: _t->particlesMaxChanged(); break;
        case 3: _t->particlesUsedChanged(); break;
        case 4: _t->timeChanged(); break;
        case 5: _t->timeAverageChanged(); break;
        case 6: _t->timeDeviationChanged(); break;
        case 7: _t->setLoggingInterval((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleSystemLogging::*)()>(_a, &QQuick3DParticleSystemLogging::loggingIntervalChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleSystemLogging::*)()>(_a, &QQuick3DParticleSystemLogging::updatesChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleSystemLogging::*)()>(_a, &QQuick3DParticleSystemLogging::particlesMaxChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleSystemLogging::*)()>(_a, &QQuick3DParticleSystemLogging::particlesUsedChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleSystemLogging::*)()>(_a, &QQuick3DParticleSystemLogging::timeChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleSystemLogging::*)()>(_a, &QQuick3DParticleSystemLogging::timeAverageChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleSystemLogging::*)()>(_a, &QQuick3DParticleSystemLogging::timeDeviationChanged, 6))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->loggingInterval(); break;
        case 1: *reinterpret_cast<int*>(_v) = _t->updates(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->particlesMax(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->particlesUsed(); break;
        case 4: *reinterpret_cast<float*>(_v) = _t->time(); break;
        case 5: *reinterpret_cast<float*>(_v) = _t->timeAverage(); break;
        case 6: *reinterpret_cast<float*>(_v) = _t->timeDeviation(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setLoggingInterval(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DParticleSystemLogging::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DParticleSystemLogging::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29QQuick3DParticleSystemLoggingE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QQuick3DParticleSystemLogging::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void QQuick3DParticleSystemLogging::loggingIntervalChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QQuick3DParticleSystemLogging::updatesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QQuick3DParticleSystemLogging::particlesMaxChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QQuick3DParticleSystemLogging::particlesUsedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QQuick3DParticleSystemLogging::timeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QQuick3DParticleSystemLogging::timeAverageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QQuick3DParticleSystemLogging::timeDeviationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
