/****************************************************************************
** Meta object code from reading C++ file 'qquick3dparticlewander_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtquick3d/src/quick3dparticles/qquick3dparticlewander_p.h"
#include <QtGui/qtextcursor.h>
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquick3dparticlewander_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN22QQuick3DParticleWanderE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DParticleWander::qt_create_metaobjectdata<qt_meta_tag_ZN22QQuick3DParticleWanderE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DParticleWander",
        "QML.Element",
        "Wander3D",
        "QML.AddedInVersion",
        "1538",
        "globalAmountChanged",
        "",
        "globalPaceChanged",
        "globalPaceStartChanged",
        "uniqueAmountChanged",
        "uniquePaceChanged",
        "uniqueAmountVariationChanged",
        "uniquePaceVariationChanged",
        "fadeInDurationChanged",
        "fadeOutDurationChanged",
        "setGlobalAmount",
        "QVector3D",
        "globalAmount",
        "setGlobalPace",
        "globalPace",
        "setGlobalPaceStart",
        "globalPaceStart",
        "setUniqueAmount",
        "uniqueAmount",
        "setUniquePace",
        "uniquePace",
        "setUniqueAmountVariation",
        "uniqueAmountVariation",
        "setUniquePaceVariation",
        "uniquePaceVariation",
        "setFadeInDuration",
        "fadeInDuration",
        "setFadeOutDuration",
        "fadeOutDuration"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'globalAmountChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'globalPaceChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'globalPaceStartChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'uniqueAmountChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'uniquePaceChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'uniqueAmountVariationChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'uniquePaceVariationChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fadeInDurationChanged'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fadeOutDurationChanged'
        QtMocHelpers::SignalData<void()>(14, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setGlobalAmount'
        QtMocHelpers::SlotData<void(const QVector3D &)>(15, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Slot 'setGlobalPace'
        QtMocHelpers::SlotData<void(const QVector3D &)>(18, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 19 },
        }}),
        // Slot 'setGlobalPaceStart'
        QtMocHelpers::SlotData<void(const QVector3D &)>(20, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 21 },
        }}),
        // Slot 'setUniqueAmount'
        QtMocHelpers::SlotData<void(const QVector3D &)>(22, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 23 },
        }}),
        // Slot 'setUniquePace'
        QtMocHelpers::SlotData<void(const QVector3D &)>(24, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 25 },
        }}),
        // Slot 'setUniqueAmountVariation'
        QtMocHelpers::SlotData<void(float)>(26, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 27 },
        }}),
        // Slot 'setUniquePaceVariation'
        QtMocHelpers::SlotData<void(float)>(28, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 29 },
        }}),
        // Slot 'setFadeInDuration'
        QtMocHelpers::SlotData<void(int)>(30, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 31 },
        }}),
        // Slot 'setFadeOutDuration'
        QtMocHelpers::SlotData<void(int)>(32, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 33 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'globalAmount'
        QtMocHelpers::PropertyData<QVector3D>(17, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'globalPace'
        QtMocHelpers::PropertyData<QVector3D>(19, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'globalPaceStart'
        QtMocHelpers::PropertyData<QVector3D>(21, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'uniqueAmount'
        QtMocHelpers::PropertyData<QVector3D>(23, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'uniquePace'
        QtMocHelpers::PropertyData<QVector3D>(25, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 4),
        // property 'uniqueAmountVariation'
        QtMocHelpers::PropertyData<float>(27, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'uniquePaceVariation'
        QtMocHelpers::PropertyData<float>(29, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'fadeInDuration'
        QtMocHelpers::PropertyData<int>(31, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'fadeOutDuration'
        QtMocHelpers::PropertyData<int>(33, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DParticleWander, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DParticleWander::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuick3DParticleAffector::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22QQuick3DParticleWanderE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22QQuick3DParticleWanderE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22QQuick3DParticleWanderE_t>.metaTypes,
    nullptr
} };

void QQuick3DParticleWander::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DParticleWander *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->globalAmountChanged(); break;
        case 1: _t->globalPaceChanged(); break;
        case 2: _t->globalPaceStartChanged(); break;
        case 3: _t->uniqueAmountChanged(); break;
        case 4: _t->uniquePaceChanged(); break;
        case 5: _t->uniqueAmountVariationChanged(); break;
        case 6: _t->uniquePaceVariationChanged(); break;
        case 7: _t->fadeInDurationChanged(); break;
        case 8: _t->fadeOutDurationChanged(); break;
        case 9: _t->setGlobalAmount((*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[1]))); break;
        case 10: _t->setGlobalPace((*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[1]))); break;
        case 11: _t->setGlobalPaceStart((*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[1]))); break;
        case 12: _t->setUniqueAmount((*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[1]))); break;
        case 13: _t->setUniquePace((*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[1]))); break;
        case 14: _t->setUniqueAmountVariation((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 15: _t->setUniquePaceVariation((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 16: _t->setFadeInDuration((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 17: _t->setFadeOutDuration((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleWander::*)()>(_a, &QQuick3DParticleWander::globalAmountChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleWander::*)()>(_a, &QQuick3DParticleWander::globalPaceChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleWander::*)()>(_a, &QQuick3DParticleWander::globalPaceStartChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleWander::*)()>(_a, &QQuick3DParticleWander::uniqueAmountChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleWander::*)()>(_a, &QQuick3DParticleWander::uniquePaceChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleWander::*)()>(_a, &QQuick3DParticleWander::uniqueAmountVariationChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleWander::*)()>(_a, &QQuick3DParticleWander::uniquePaceVariationChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleWander::*)()>(_a, &QQuick3DParticleWander::fadeInDurationChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleWander::*)()>(_a, &QQuick3DParticleWander::fadeOutDurationChanged, 8))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QVector3D*>(_v) = _t->globalAmount(); break;
        case 1: *reinterpret_cast<QVector3D*>(_v) = _t->globalPace(); break;
        case 2: *reinterpret_cast<QVector3D*>(_v) = _t->globalPaceStart(); break;
        case 3: *reinterpret_cast<QVector3D*>(_v) = _t->uniqueAmount(); break;
        case 4: *reinterpret_cast<QVector3D*>(_v) = _t->uniquePace(); break;
        case 5: *reinterpret_cast<float*>(_v) = _t->uniqueAmountVariation(); break;
        case 6: *reinterpret_cast<float*>(_v) = _t->uniquePaceVariation(); break;
        case 7: *reinterpret_cast<int*>(_v) = _t->fadeInDuration(); break;
        case 8: *reinterpret_cast<int*>(_v) = _t->fadeOutDuration(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setGlobalAmount(*reinterpret_cast<QVector3D*>(_v)); break;
        case 1: _t->setGlobalPace(*reinterpret_cast<QVector3D*>(_v)); break;
        case 2: _t->setGlobalPaceStart(*reinterpret_cast<QVector3D*>(_v)); break;
        case 3: _t->setUniqueAmount(*reinterpret_cast<QVector3D*>(_v)); break;
        case 4: _t->setUniquePace(*reinterpret_cast<QVector3D*>(_v)); break;
        case 5: _t->setUniqueAmountVariation(*reinterpret_cast<float*>(_v)); break;
        case 6: _t->setUniquePaceVariation(*reinterpret_cast<float*>(_v)); break;
        case 7: _t->setFadeInDuration(*reinterpret_cast<int*>(_v)); break;
        case 8: _t->setFadeOutDuration(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DParticleWander::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DParticleWander::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22QQuick3DParticleWanderE_t>.strings))
        return static_cast<void*>(this);
    return QQuick3DParticleAffector::qt_metacast(_clname);
}

int QQuick3DParticleWander::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuick3DParticleAffector::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 18;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void QQuick3DParticleWander::globalAmountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QQuick3DParticleWander::globalPaceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QQuick3DParticleWander::globalPaceStartChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QQuick3DParticleWander::uniqueAmountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QQuick3DParticleWander::uniquePaceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QQuick3DParticleWander::uniqueAmountVariationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QQuick3DParticleWander::uniquePaceVariationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void QQuick3DParticleWander::fadeInDurationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void QQuick3DParticleWander::fadeOutDurationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
QT_WARNING_POP
