/****************************************************************************
** Meta object code from reading C++ file 'qquick3dxractionmapper_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../qtquick3d/src/xr/quick3dxr/qquick3dxractionmapper_p.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquick3dxractionmapper_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN21QQuick3DXrInputActionE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DXrInputAction::qt_create_metaobjectdata<qt_meta_tag_ZN21QQuick3DXrInputActionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DXrInputAction",
        "QML.Element",
        "XrInputAction",
        "QML.AddedInVersion",
        "1544",
        "valueChanged",
        "",
        "pressedChanged",
        "triggered",
        "actionNameChanged",
        "actionIdChanged",
        "handChanged",
        "enabledChanged",
        "controllerChanged",
        "value",
        "pressed",
        "actionName",
        "actionId",
        "QList<Action>",
        "enabled",
        "hand",
        "Controller",
        "controller",
        "LeftHand",
        "RightHand",
        "Unknown",
        "LeftController",
        "RightController",
        "UnknownController",
        "Action",
        "CustomAction",
        "Button1Pressed",
        "Button1Touched",
        "Button2Pressed",
        "Button2Touched",
        "ButtonMenuPressed",
        "ButtonMenuTouched",
        "ButtonSystemPressed",
        "ButtonSystemTouched",
        "SqueezeValue",
        "SqueezeForce",
        "SqueezePressed",
        "TriggerValue",
        "TriggerPressed",
        "TriggerTouched",
        "ThumbstickX",
        "ThumbstickY",
        "ThumbstickPressed",
        "ThumbstickTouched",
        "ThumbrestTouched",
        "TrackpadX",
        "TrackpadY",
        "TrackpadForce",
        "TrackpadTouched",
        "TrackpadPressed",
        "IndexFingerPinch",
        "MiddleFingerPinch",
        "RingFingerPinch",
        "LittleFingerPinch",
        "HandTrackingMenuPress",
        "NumHandActions",
        "NumActions"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'valueChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pressedChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'triggered'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'actionNameChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'actionIdChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'handChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enabledChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'controllerChanged'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'value'
        QtMocHelpers::PropertyData<float>(14, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Final, 0),
        // property 'pressed'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Final, 1),
        // property 'actionName'
        QtMocHelpers::PropertyData<QString>(16, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 3),
        // property 'actionId'
        QtMocHelpers::PropertyData<QList<Action>>(17, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 4),
        // property 'enabled'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 6, 0x609),
        // property 'hand'
        QtMocHelpers::PropertyData<enum Controller>(20, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 5),
        // property 'controller'
        QtMocHelpers::PropertyData<enum Controller>(22, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 7, 0x60a),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Controller'
        QtMocHelpers::EnumData<enum Controller>(21, 21, QMC::EnumFlags{}).add({
            {   23, Controller::LeftHand },
            {   24, Controller::RightHand },
            {   25, Controller::Unknown },
            {   26, Controller::LeftController },
            {   27, Controller::RightController },
            {   28, Controller::UnknownController },
        }),
        // enum 'Action'
        QtMocHelpers::EnumData<enum Action>(29, 29, QMC::EnumFlags{}).add({
            {   30, Action::CustomAction },
            {   31, Action::Button1Pressed },
            {   32, Action::Button1Touched },
            {   33, Action::Button2Pressed },
            {   34, Action::Button2Touched },
            {   35, Action::ButtonMenuPressed },
            {   36, Action::ButtonMenuTouched },
            {   37, Action::ButtonSystemPressed },
            {   38, Action::ButtonSystemTouched },
            {   39, Action::SqueezeValue },
            {   40, Action::SqueezeForce },
            {   41, Action::SqueezePressed },
            {   42, Action::TriggerValue },
            {   43, Action::TriggerPressed },
            {   44, Action::TriggerTouched },
            {   45, Action::ThumbstickX },
            {   46, Action::ThumbstickY },
            {   47, Action::ThumbstickPressed },
            {   48, Action::ThumbstickTouched },
            {   49, Action::ThumbrestTouched },
            {   50, Action::TrackpadX },
            {   51, Action::TrackpadY },
            {   52, Action::TrackpadForce },
            {   53, Action::TrackpadTouched },
            {   54, Action::TrackpadPressed },
            {   55, Action::IndexFingerPinch },
            {   56, Action::MiddleFingerPinch },
            {   57, Action::RingFingerPinch },
            {   58, Action::LittleFingerPinch },
            {   59, Action::HandTrackingMenuPress },
            {   60, Action::NumHandActions },
            {   61, Action::NumActions },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DXrInputAction, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DXrInputAction::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21QQuick3DXrInputActionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21QQuick3DXrInputActionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21QQuick3DXrInputActionE_t>.metaTypes,
    nullptr
} };

void QQuick3DXrInputAction::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DXrInputAction *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->valueChanged(); break;
        case 1: _t->pressedChanged(); break;
        case 2: _t->triggered(); break;
        case 3: _t->actionNameChanged(); break;
        case 4: _t->actionIdChanged(); break;
        case 5: _t->handChanged(); break;
        case 6: _t->enabledChanged(); break;
        case 7: _t->controllerChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuick3DXrInputAction::*)()>(_a, &QQuick3DXrInputAction::valueChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DXrInputAction::*)()>(_a, &QQuick3DXrInputAction::pressedChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DXrInputAction::*)()>(_a, &QQuick3DXrInputAction::triggered, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DXrInputAction::*)()>(_a, &QQuick3DXrInputAction::actionNameChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DXrInputAction::*)()>(_a, &QQuick3DXrInputAction::actionIdChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DXrInputAction::*)()>(_a, &QQuick3DXrInputAction::handChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DXrInputAction::*)()>(_a, &QQuick3DXrInputAction::enabledChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DXrInputAction::*)()>(_a, &QQuick3DXrInputAction::controllerChanged, 7))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<float*>(_v) = _t->value(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->pressed(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->actionName(); break;
        case 3: *reinterpret_cast<QList<Action>*>(_v) = _t->actionId(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->enabled(); break;
        case 5: *reinterpret_cast<enum Controller*>(_v) = _t->hand(); break;
        case 6: *reinterpret_cast<enum Controller*>(_v) = _t->controller(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 2: _t->setActionName(*reinterpret_cast<QString*>(_v)); break;
        case 3: _t->setActionId(*reinterpret_cast<QList<Action>*>(_v)); break;
        case 4: _t->setEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setHand(*reinterpret_cast<enum Controller*>(_v)); break;
        case 6: _t->setController(*reinterpret_cast<enum Controller*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DXrInputAction::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DXrInputAction::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21QQuick3DXrInputActionE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return QObject::qt_metacast(_clname);
}

int QQuick3DXrInputAction::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void QQuick3DXrInputAction::valueChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QQuick3DXrInputAction::pressedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QQuick3DXrInputAction::triggered()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QQuick3DXrInputAction::actionNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QQuick3DXrInputAction::actionIdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QQuick3DXrInputAction::handChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QQuick3DXrInputAction::enabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void QQuick3DXrInputAction::controllerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
namespace {
struct qt_meta_tag_ZN24QQuick3DXrHapticFeedbackE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DXrHapticFeedback::qt_create_metaobjectdata<qt_meta_tag_ZN24QQuick3DXrHapticFeedbackE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DXrHapticFeedback",
        "QML.Element",
        "XrHapticFeedback",
        "QML.AddedInVersion",
        "1545",
        "controllerChanged",
        "",
        "hapticEffectChanged",
        "triggerChanged",
        "conditionChanged",
        "start",
        "stop",
        "controller",
        "Controller",
        "hapticEffect",
        "QQuick3DXrAbstractHapticEffect*",
        "trigger",
        "condition",
        "Condition",
        "LeftController",
        "RightController",
        "UnknownController",
        "RisingEdge",
        "TrailingEdge"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'controllerChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hapticEffectChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'triggerChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'conditionChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'start'
        QtMocHelpers::SlotData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'stop'
        QtMocHelpers::SlotData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'controller'
        QtMocHelpers::PropertyData<enum Controller>(12, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 0),
        // property 'hapticEffect'
        QtMocHelpers::PropertyData<QQuick3DXrAbstractHapticEffect*>(14, 0x80000000 | 15, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 1),
        // property 'trigger'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 2),
        // property 'condition'
        QtMocHelpers::PropertyData<enum Condition>(17, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 3),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Controller'
        QtMocHelpers::EnumData<enum Controller>(13, 13, QMC::EnumIsScoped).add({
            {   19, Controller::LeftController },
            {   20, Controller::RightController },
            {   21, Controller::UnknownController },
        }),
        // enum 'Condition'
        QtMocHelpers::EnumData<enum Condition>(18, 18, QMC::EnumIsScoped).add({
            {   22, Condition::RisingEdge },
            {   23, Condition::TrailingEdge },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DXrHapticFeedback, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DXrHapticFeedback::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24QQuick3DXrHapticFeedbackE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24QQuick3DXrHapticFeedbackE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN24QQuick3DXrHapticFeedbackE_t>.metaTypes,
    nullptr
} };

void QQuick3DXrHapticFeedback::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DXrHapticFeedback *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->controllerChanged(); break;
        case 1: _t->hapticEffectChanged(); break;
        case 2: _t->triggerChanged(); break;
        case 3: _t->conditionChanged(); break;
        case 4: _t->start(); break;
        case 5: _t->stop(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuick3DXrHapticFeedback::*)()>(_a, &QQuick3DXrHapticFeedback::controllerChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DXrHapticFeedback::*)()>(_a, &QQuick3DXrHapticFeedback::hapticEffectChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DXrHapticFeedback::*)()>(_a, &QQuick3DXrHapticFeedback::triggerChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DXrHapticFeedback::*)()>(_a, &QQuick3DXrHapticFeedback::conditionChanged, 3))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuick3DXrAbstractHapticEffect* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<enum Controller*>(_v) = _t->controller(); break;
        case 1: *reinterpret_cast<QQuick3DXrAbstractHapticEffect**>(_v) = _t->hapticEffect(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->trigger(); break;
        case 3: *reinterpret_cast<enum Condition*>(_v) = _t->condition(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setController(*reinterpret_cast<enum Controller*>(_v)); break;
        case 1: _t->setHapticEffect(*reinterpret_cast<QQuick3DXrAbstractHapticEffect**>(_v)); break;
        case 2: _t->setTrigger(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setCondition(*reinterpret_cast<enum Condition*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DXrHapticFeedback::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DXrHapticFeedback::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24QQuick3DXrHapticFeedbackE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return QObject::qt_metacast(_clname);
}

int QQuick3DXrHapticFeedback::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void QQuick3DXrHapticFeedback::controllerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QQuick3DXrHapticFeedback::hapticEffectChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QQuick3DXrHapticFeedback::triggerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QQuick3DXrHapticFeedback::conditionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
namespace {
struct qt_meta_tag_ZN22QQuick3DXrActionMapperE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DXrActionMapper::qt_create_metaobjectdata<qt_meta_tag_ZN22QQuick3DXrActionMapperE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DXrActionMapper"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QQuick3DXrActionMapper, qt_meta_tag_ZN22QQuick3DXrActionMapperE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QQuick3DXrActionMapper::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22QQuick3DXrActionMapperE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22QQuick3DXrActionMapperE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22QQuick3DXrActionMapperE_t>.metaTypes,
    nullptr
} };

void QQuick3DXrActionMapper::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DXrActionMapper *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *QQuick3DXrActionMapper::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DXrActionMapper::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22QQuick3DXrActionMapperE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QQuick3DXrActionMapper::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
