/****************************************************************************
** Meta object code from reading C++ file 'proceduralskytexturedata_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtquick3d/src/helpers/proceduralskytexturedata_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'proceduralskytexturedata_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN24ProceduralSkyTextureDataE_t {};
} // unnamed namespace

template <> constexpr inline auto ProceduralSkyTextureData::qt_create_metaobjectdata<qt_meta_tag_ZN24ProceduralSkyTextureDataE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ProceduralSkyTextureData",
        "QML.Element",
        "auto",
        "skyTopColorChanged",
        "",
        "QColor",
        "skyTopColor",
        "skyHorizonColorChanged",
        "skyHorizonColor",
        "skyCurveChanged",
        "skyCurve",
        "skyEnergyChanged",
        "skyEnergy",
        "groundBottomColorChanged",
        "groundBottomColor",
        "groundHorizonColorChanged",
        "groundHorizonColor",
        "groundCurveChanged",
        "groundCurve",
        "groundEnergyChanged",
        "groundEnergy",
        "sunColorChanged",
        "sunColor",
        "sunLatitudeChanged",
        "sunLatitude",
        "sunLongitudeChanged",
        "sunLongitude",
        "sunAngleMinChanged",
        "sunAngleMin",
        "sunAngleMaxChanged",
        "sunAngleMax",
        "sunCurveChanged",
        "sunCurve",
        "sunEnergyChanged",
        "sunEnergy",
        "textureQualityChanged",
        "SkyTextureQuality",
        "textureQuality",
        "setSkyTopColor",
        "setSkyHorizonColor",
        "setSkyCurve",
        "setSkyEnergy",
        "setGroundBottomColor",
        "setGroundHorizonColor",
        "setGroundCurve",
        "setGroundEnergy",
        "setSunColor",
        "setSunLatitude",
        "setSunLongitude",
        "setSunAngleMin",
        "setSunAngleMax",
        "setSunCurve",
        "setSunEnergy",
        "setTextureQuality",
        "generateRGBA16FTexture",
        "SkyTextureQualityLow",
        "SkyTextureQualityMedium",
        "SkyTextureQualityHigh",
        "SkyTextureQualityVeryHigh"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'skyTopColorChanged'
        QtMocHelpers::SignalData<void(QColor)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'skyHorizonColorChanged'
        QtMocHelpers::SignalData<void(QColor)>(7, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 8 },
        }}),
        // Signal 'skyCurveChanged'
        QtMocHelpers::SignalData<void(float)>(9, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 10 },
        }}),
        // Signal 'skyEnergyChanged'
        QtMocHelpers::SignalData<void(float)>(11, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 12 },
        }}),
        // Signal 'groundBottomColorChanged'
        QtMocHelpers::SignalData<void(QColor)>(13, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 14 },
        }}),
        // Signal 'groundHorizonColorChanged'
        QtMocHelpers::SignalData<void(QColor)>(15, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 16 },
        }}),
        // Signal 'groundCurveChanged'
        QtMocHelpers::SignalData<void(float)>(17, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 18 },
        }}),
        // Signal 'groundEnergyChanged'
        QtMocHelpers::SignalData<void(float)>(19, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 20 },
        }}),
        // Signal 'sunColorChanged'
        QtMocHelpers::SignalData<void(QColor)>(21, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 22 },
        }}),
        // Signal 'sunLatitudeChanged'
        QtMocHelpers::SignalData<void(float)>(23, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 24 },
        }}),
        // Signal 'sunLongitudeChanged'
        QtMocHelpers::SignalData<void(float)>(25, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 26 },
        }}),
        // Signal 'sunAngleMinChanged'
        QtMocHelpers::SignalData<void(float)>(27, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 28 },
        }}),
        // Signal 'sunAngleMaxChanged'
        QtMocHelpers::SignalData<void(float)>(29, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 30 },
        }}),
        // Signal 'sunCurveChanged'
        QtMocHelpers::SignalData<void(float)>(31, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 32 },
        }}),
        // Signal 'sunEnergyChanged'
        QtMocHelpers::SignalData<void(float)>(33, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 34 },
        }}),
        // Signal 'textureQualityChanged'
        QtMocHelpers::SignalData<void(enum SkyTextureQuality)>(35, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 36, 37 },
        }}),
        // Slot 'setSkyTopColor'
        QtMocHelpers::SlotData<void(QColor)>(38, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'setSkyHorizonColor'
        QtMocHelpers::SlotData<void(QColor)>(39, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 8 },
        }}),
        // Slot 'setSkyCurve'
        QtMocHelpers::SlotData<void(float)>(40, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 10 },
        }}),
        // Slot 'setSkyEnergy'
        QtMocHelpers::SlotData<void(float)>(41, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 12 },
        }}),
        // Slot 'setGroundBottomColor'
        QtMocHelpers::SlotData<void(QColor)>(42, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 14 },
        }}),
        // Slot 'setGroundHorizonColor'
        QtMocHelpers::SlotData<void(QColor)>(43, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 16 },
        }}),
        // Slot 'setGroundCurve'
        QtMocHelpers::SlotData<void(float)>(44, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 18 },
        }}),
        // Slot 'setGroundEnergy'
        QtMocHelpers::SlotData<void(float)>(45, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 20 },
        }}),
        // Slot 'setSunColor'
        QtMocHelpers::SlotData<void(QColor)>(46, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 22 },
        }}),
        // Slot 'setSunLatitude'
        QtMocHelpers::SlotData<void(float)>(47, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 24 },
        }}),
        // Slot 'setSunLongitude'
        QtMocHelpers::SlotData<void(float)>(48, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 26 },
        }}),
        // Slot 'setSunAngleMin'
        QtMocHelpers::SlotData<void(float)>(49, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 28 },
        }}),
        // Slot 'setSunAngleMax'
        QtMocHelpers::SlotData<void(float)>(50, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 30 },
        }}),
        // Slot 'setSunCurve'
        QtMocHelpers::SlotData<void(float)>(51, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 32 },
        }}),
        // Slot 'setSunEnergy'
        QtMocHelpers::SlotData<void(float)>(52, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 34 },
        }}),
        // Slot 'setTextureQuality'
        QtMocHelpers::SlotData<void(enum SkyTextureQuality)>(53, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 36, 37 },
        }}),
        // Slot 'generateRGBA16FTexture'
        QtMocHelpers::SlotData<void()>(54, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'skyTopColor'
        QtMocHelpers::PropertyData<QColor>(6, 0x80000000 | 5, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'skyHorizonColor'
        QtMocHelpers::PropertyData<QColor>(8, 0x80000000 | 5, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'skyCurve'
        QtMocHelpers::PropertyData<float>(10, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'skyEnergy'
        QtMocHelpers::PropertyData<float>(12, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'groundBottomColor'
        QtMocHelpers::PropertyData<QColor>(14, 0x80000000 | 5, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 4),
        // property 'groundHorizonColor'
        QtMocHelpers::PropertyData<QColor>(16, 0x80000000 | 5, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5),
        // property 'groundCurve'
        QtMocHelpers::PropertyData<float>(18, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'groundEnergy'
        QtMocHelpers::PropertyData<float>(20, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'sunColor'
        QtMocHelpers::PropertyData<QColor>(22, 0x80000000 | 5, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 8),
        // property 'sunLatitude'
        QtMocHelpers::PropertyData<float>(24, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'sunLongitude'
        QtMocHelpers::PropertyData<float>(26, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'sunAngleMin'
        QtMocHelpers::PropertyData<float>(28, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'sunAngleMax'
        QtMocHelpers::PropertyData<float>(30, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'sunCurve'
        QtMocHelpers::PropertyData<float>(32, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13),
        // property 'sunEnergy'
        QtMocHelpers::PropertyData<float>(34, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 14),
        // property 'textureQuality'
        QtMocHelpers::PropertyData<enum SkyTextureQuality>(37, 0x80000000 | 36, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 15),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'SkyTextureQuality'
        QtMocHelpers::EnumData<enum SkyTextureQuality>(36, 36, QMC::EnumIsScoped).add({
            {   55, SkyTextureQuality::SkyTextureQualityLow },
            {   56, SkyTextureQuality::SkyTextureQualityMedium },
            {   57, SkyTextureQuality::SkyTextureQualityHigh },
            {   58, SkyTextureQuality::SkyTextureQualityVeryHigh },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<ProceduralSkyTextureData, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject ProceduralSkyTextureData::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuick3DTextureData::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24ProceduralSkyTextureDataE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24ProceduralSkyTextureDataE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN24ProceduralSkyTextureDataE_t>.metaTypes,
    nullptr
} };

void ProceduralSkyTextureData::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ProceduralSkyTextureData *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->skyTopColorChanged((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 1: _t->skyHorizonColorChanged((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 2: _t->skyCurveChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 3: _t->skyEnergyChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 4: _t->groundBottomColorChanged((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 5: _t->groundHorizonColorChanged((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 6: _t->groundCurveChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 7: _t->groundEnergyChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 8: _t->sunColorChanged((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 9: _t->sunLatitudeChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 10: _t->sunLongitudeChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 11: _t->sunAngleMinChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 12: _t->sunAngleMaxChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 13: _t->sunCurveChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 14: _t->sunEnergyChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 15: _t->textureQualityChanged((*reinterpret_cast<std::add_pointer_t<enum SkyTextureQuality>>(_a[1]))); break;
        case 16: _t->setSkyTopColor((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 17: _t->setSkyHorizonColor((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 18: _t->setSkyCurve((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 19: _t->setSkyEnergy((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 20: _t->setGroundBottomColor((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 21: _t->setGroundHorizonColor((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 22: _t->setGroundCurve((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 23: _t->setGroundEnergy((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 24: _t->setSunColor((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 25: _t->setSunLatitude((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 26: _t->setSunLongitude((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 27: _t->setSunAngleMin((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 28: _t->setSunAngleMax((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 29: _t->setSunCurve((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 30: _t->setSunEnergy((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 31: _t->setTextureQuality((*reinterpret_cast<std::add_pointer_t<enum SkyTextureQuality>>(_a[1]))); break;
        case 32: _t->generateRGBA16FTexture(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ProceduralSkyTextureData::*)(QColor )>(_a, &ProceduralSkyTextureData::skyTopColorChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProceduralSkyTextureData::*)(QColor )>(_a, &ProceduralSkyTextureData::skyHorizonColorChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProceduralSkyTextureData::*)(float )>(_a, &ProceduralSkyTextureData::skyCurveChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProceduralSkyTextureData::*)(float )>(_a, &ProceduralSkyTextureData::skyEnergyChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProceduralSkyTextureData::*)(QColor )>(_a, &ProceduralSkyTextureData::groundBottomColorChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProceduralSkyTextureData::*)(QColor )>(_a, &ProceduralSkyTextureData::groundHorizonColorChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProceduralSkyTextureData::*)(float )>(_a, &ProceduralSkyTextureData::groundCurveChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProceduralSkyTextureData::*)(float )>(_a, &ProceduralSkyTextureData::groundEnergyChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProceduralSkyTextureData::*)(QColor )>(_a, &ProceduralSkyTextureData::sunColorChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProceduralSkyTextureData::*)(float )>(_a, &ProceduralSkyTextureData::sunLatitudeChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProceduralSkyTextureData::*)(float )>(_a, &ProceduralSkyTextureData::sunLongitudeChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProceduralSkyTextureData::*)(float )>(_a, &ProceduralSkyTextureData::sunAngleMinChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProceduralSkyTextureData::*)(float )>(_a, &ProceduralSkyTextureData::sunAngleMaxChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProceduralSkyTextureData::*)(float )>(_a, &ProceduralSkyTextureData::sunCurveChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProceduralSkyTextureData::*)(float )>(_a, &ProceduralSkyTextureData::sunEnergyChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProceduralSkyTextureData::*)(SkyTextureQuality )>(_a, &ProceduralSkyTextureData::textureQualityChanged, 15))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QColor*>(_v) = _t->skyTopColor(); break;
        case 1: *reinterpret_cast<QColor*>(_v) = _t->skyHorizonColor(); break;
        case 2: *reinterpret_cast<float*>(_v) = _t->skyCurve(); break;
        case 3: *reinterpret_cast<float*>(_v) = _t->skyEnergy(); break;
        case 4: *reinterpret_cast<QColor*>(_v) = _t->groundBottomColor(); break;
        case 5: *reinterpret_cast<QColor*>(_v) = _t->groundHorizonColor(); break;
        case 6: *reinterpret_cast<float*>(_v) = _t->groundCurve(); break;
        case 7: *reinterpret_cast<float*>(_v) = _t->groundEnergy(); break;
        case 8: *reinterpret_cast<QColor*>(_v) = _t->sunColor(); break;
        case 9: *reinterpret_cast<float*>(_v) = _t->sunLatitude(); break;
        case 10: *reinterpret_cast<float*>(_v) = _t->sunLongitude(); break;
        case 11: *reinterpret_cast<float*>(_v) = _t->sunAngleMin(); break;
        case 12: *reinterpret_cast<float*>(_v) = _t->sunAngleMax(); break;
        case 13: *reinterpret_cast<float*>(_v) = _t->sunCurve(); break;
        case 14: *reinterpret_cast<float*>(_v) = _t->sunEnergy(); break;
        case 15: *reinterpret_cast<enum SkyTextureQuality*>(_v) = _t->textureQuality(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setSkyTopColor(*reinterpret_cast<QColor*>(_v)); break;
        case 1: _t->setSkyHorizonColor(*reinterpret_cast<QColor*>(_v)); break;
        case 2: _t->setSkyCurve(*reinterpret_cast<float*>(_v)); break;
        case 3: _t->setSkyEnergy(*reinterpret_cast<float*>(_v)); break;
        case 4: _t->setGroundBottomColor(*reinterpret_cast<QColor*>(_v)); break;
        case 5: _t->setGroundHorizonColor(*reinterpret_cast<QColor*>(_v)); break;
        case 6: _t->setGroundCurve(*reinterpret_cast<float*>(_v)); break;
        case 7: _t->setGroundEnergy(*reinterpret_cast<float*>(_v)); break;
        case 8: _t->setSunColor(*reinterpret_cast<QColor*>(_v)); break;
        case 9: _t->setSunLatitude(*reinterpret_cast<float*>(_v)); break;
        case 10: _t->setSunLongitude(*reinterpret_cast<float*>(_v)); break;
        case 11: _t->setSunAngleMin(*reinterpret_cast<float*>(_v)); break;
        case 12: _t->setSunAngleMax(*reinterpret_cast<float*>(_v)); break;
        case 13: _t->setSunCurve(*reinterpret_cast<float*>(_v)); break;
        case 14: _t->setSunEnergy(*reinterpret_cast<float*>(_v)); break;
        case 15: _t->setTextureQuality(*reinterpret_cast<enum SkyTextureQuality*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *ProceduralSkyTextureData::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ProceduralSkyTextureData::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24ProceduralSkyTextureDataE_t>.strings))
        return static_cast<void*>(this);
    return QQuick3DTextureData::qt_metacast(_clname);
}

int ProceduralSkyTextureData::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuick3DTextureData::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 33)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 33;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 33)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 33;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    return _id;
}

// SIGNAL 0
void ProceduralSkyTextureData::skyTopColorChanged(QColor _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void ProceduralSkyTextureData::skyHorizonColorChanged(QColor _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void ProceduralSkyTextureData::skyCurveChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void ProceduralSkyTextureData::skyEnergyChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void ProceduralSkyTextureData::groundBottomColorChanged(QColor _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void ProceduralSkyTextureData::groundHorizonColorChanged(QColor _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void ProceduralSkyTextureData::groundCurveChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void ProceduralSkyTextureData::groundEnergyChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void ProceduralSkyTextureData::sunColorChanged(QColor _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void ProceduralSkyTextureData::sunLatitudeChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void ProceduralSkyTextureData::sunLongitudeChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void ProceduralSkyTextureData::sunAngleMinChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void ProceduralSkyTextureData::sunAngleMaxChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void ProceduralSkyTextureData::sunCurveChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void ProceduralSkyTextureData::sunEnergyChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void ProceduralSkyTextureData::textureQualityChanged(SkyTextureQuality _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}
QT_WARNING_POP
