/****************************************************************************
** Meta object code from reading C++ file 'qquick3ddebugsettings_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtquick3d/src/quick3d/qquick3ddebugsettings_p.h"
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquick3ddebugsettings_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN21QQuick3DDebugSettingsE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DDebugSettings::qt_create_metaobjectdata<qt_meta_tag_ZN21QQuick3DDebugSettingsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DDebugSettings",
        "QML.Element",
        "DebugSettings",
        "materialOverrideChanged",
        "",
        "wireframeEnabledChanged",
        "drawDirectionalLightShadowBoxesChanged",
        "drawPointLightShadowBoxesChanged",
        "drawShadowCastingBoundsChanged",
        "drawShadowReceivingBoundsChanged",
        "drawCascadesChanged",
        "drawSceneCascadeIntersectionChanged",
        "disableShadowCameraUpdateChanged",
        "drawCulledObjectsChanged",
        "changed",
        "materialOverride",
        "QQuick3DMaterialOverrides",
        "wireframeEnabled",
        "drawDirectionalLightShadowBoxes",
        "drawPointLightShadowBoxes",
        "drawShadowCastingBounds",
        "drawShadowReceivingBounds",
        "drawCascades",
        "drawSceneCascadeIntersection",
        "disableShadowCameraUpdate",
        "drawCulledObjects",
        "None",
        "BaseColor",
        "Roughness",
        "Metalness",
        "Diffuse",
        "Specular",
        "ShadowOcclusion",
        "Emission",
        "AmbientOcclusion",
        "Normals",
        "Tangents",
        "Binormals",
        "F0"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'materialOverrideChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'wireframeEnabledChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'drawDirectionalLightShadowBoxesChanged'
        QtMocHelpers::RevisionedSignalData<void()>(6, 4, QMC::AccessPublic, 0x608, QMetaType::Void),
        // Signal 'drawPointLightShadowBoxesChanged'
        QtMocHelpers::RevisionedSignalData<void()>(7, 4, QMC::AccessPublic, 0x609, QMetaType::Void),
        // Signal 'drawShadowCastingBoundsChanged'
        QtMocHelpers::RevisionedSignalData<void()>(8, 4, QMC::AccessPublic, 0x608, QMetaType::Void),
        // Signal 'drawShadowReceivingBoundsChanged'
        QtMocHelpers::RevisionedSignalData<void()>(9, 4, QMC::AccessPublic, 0x608, QMetaType::Void),
        // Signal 'drawCascadesChanged'
        QtMocHelpers::RevisionedSignalData<void()>(10, 4, QMC::AccessPublic, 0x608, QMetaType::Void),
        // Signal 'drawSceneCascadeIntersectionChanged'
        QtMocHelpers::RevisionedSignalData<void()>(11, 4, QMC::AccessPublic, 0x608, QMetaType::Void),
        // Signal 'disableShadowCameraUpdateChanged'
        QtMocHelpers::RevisionedSignalData<void()>(12, 4, QMC::AccessPublic, 0x608, QMetaType::Void),
        // Signal 'drawCulledObjectsChanged'
        QtMocHelpers::RevisionedSignalData<void()>(13, 4, QMC::AccessPublic, 0x60b, QMetaType::Void),
        // Signal 'changed'
        QtMocHelpers::SignalData<void()>(14, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'materialOverride'
        QtMocHelpers::PropertyData<enum QQuick3DMaterialOverrides>(15, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'wireframeEnabled'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'drawDirectionalLightShadowBoxes'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 2, 0x608),
        // property 'drawPointLightShadowBoxes'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 3, 0x609),
        // property 'drawShadowCastingBounds'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 4, 0x608),
        // property 'drawShadowReceivingBounds'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 5, 0x608),
        // property 'drawCascades'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 6, 0x608),
        // property 'drawSceneCascadeIntersection'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 7, 0x608),
        // property 'disableShadowCameraUpdate'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 8, 0x608),
        // property 'drawCulledObjects'
        QtMocHelpers::PropertyData<bool>(25, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 9, 0x60b),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'QQuick3DMaterialOverrides'
        QtMocHelpers::EnumData<enum QQuick3DMaterialOverrides>(16, 16, QMC::EnumFlags{}).add({
            {   26, QQuick3DMaterialOverrides::None },
            {   27, QQuick3DMaterialOverrides::BaseColor },
            {   28, QQuick3DMaterialOverrides::Roughness },
            {   29, QQuick3DMaterialOverrides::Metalness },
            {   30, QQuick3DMaterialOverrides::Diffuse },
            {   31, QQuick3DMaterialOverrides::Specular },
            {   32, QQuick3DMaterialOverrides::ShadowOcclusion },
            {   33, QQuick3DMaterialOverrides::Emission },
            {   34, QQuick3DMaterialOverrides::AmbientOcclusion },
            {   35, QQuick3DMaterialOverrides::Normals },
            {   36, QQuick3DMaterialOverrides::Tangents },
            {   37, QQuick3DMaterialOverrides::Binormals },
            {   38, QQuick3DMaterialOverrides::F0 },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DDebugSettings, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DDebugSettings::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21QQuick3DDebugSettingsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21QQuick3DDebugSettingsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21QQuick3DDebugSettingsE_t>.metaTypes,
    nullptr
} };

void QQuick3DDebugSettings::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DDebugSettings *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->materialOverrideChanged(); break;
        case 1: _t->wireframeEnabledChanged(); break;
        case 2: _t->drawDirectionalLightShadowBoxesChanged(); break;
        case 3: _t->drawPointLightShadowBoxesChanged(); break;
        case 4: _t->drawShadowCastingBoundsChanged(); break;
        case 5: _t->drawShadowReceivingBoundsChanged(); break;
        case 6: _t->drawCascadesChanged(); break;
        case 7: _t->drawSceneCascadeIntersectionChanged(); break;
        case 8: _t->disableShadowCameraUpdateChanged(); break;
        case 9: _t->drawCulledObjectsChanged(); break;
        case 10: _t->changed(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuick3DDebugSettings::*)()>(_a, &QQuick3DDebugSettings::materialOverrideChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DDebugSettings::*)()>(_a, &QQuick3DDebugSettings::wireframeEnabledChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DDebugSettings::*)()>(_a, &QQuick3DDebugSettings::drawDirectionalLightShadowBoxesChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DDebugSettings::*)()>(_a, &QQuick3DDebugSettings::drawPointLightShadowBoxesChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DDebugSettings::*)()>(_a, &QQuick3DDebugSettings::drawShadowCastingBoundsChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DDebugSettings::*)()>(_a, &QQuick3DDebugSettings::drawShadowReceivingBoundsChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DDebugSettings::*)()>(_a, &QQuick3DDebugSettings::drawCascadesChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DDebugSettings::*)()>(_a, &QQuick3DDebugSettings::drawSceneCascadeIntersectionChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DDebugSettings::*)()>(_a, &QQuick3DDebugSettings::disableShadowCameraUpdateChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DDebugSettings::*)()>(_a, &QQuick3DDebugSettings::drawCulledObjectsChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DDebugSettings::*)()>(_a, &QQuick3DDebugSettings::changed, 10))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<enum QQuick3DMaterialOverrides*>(_v) = _t->materialOverride(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->wireframeEnabled(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->drawDirectionalLightShadowBoxes(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->drawPointLightShadowBoxes(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->drawShadowCastingBounds(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->drawShadowReceivingBounds(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->drawCascades(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->drawSceneCascadeIntersection(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->disableShadowCameraUpdate(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->drawCulledObjects(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setMaterialOverride(*reinterpret_cast<enum QQuick3DMaterialOverrides*>(_v)); break;
        case 1: _t->setWireframeEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 2: _t->setDrawDirectionalLightShadowBoxes(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setDrawPointLightShadowBoxes(*reinterpret_cast<bool*>(_v)); break;
        case 4: _t->setDrawShadowCastingBounds(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setDrawShadowReceivingBounds(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setDrawCascades(*reinterpret_cast<bool*>(_v)); break;
        case 7: _t->setDrawSceneCascadeIntersection(*reinterpret_cast<bool*>(_v)); break;
        case 8: _t->setDisableShadowCameraUpdate(*reinterpret_cast<bool*>(_v)); break;
        case 9: _t->setDrawCulledObjects(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DDebugSettings::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DDebugSettings::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21QQuick3DDebugSettingsE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QQuick3DDebugSettings::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void QQuick3DDebugSettings::materialOverrideChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QQuick3DDebugSettings::wireframeEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QQuick3DDebugSettings::drawDirectionalLightShadowBoxesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QQuick3DDebugSettings::drawPointLightShadowBoxesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QQuick3DDebugSettings::drawShadowCastingBoundsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QQuick3DDebugSettings::drawShadowReceivingBoundsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QQuick3DDebugSettings::drawCascadesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void QQuick3DDebugSettings::drawSceneCascadeIntersectionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void QQuick3DDebugSettings::disableShadowCameraUpdateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void QQuick3DDebugSettings::drawCulledObjectsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void QQuick3DDebugSettings::changed()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}
QT_WARNING_POP
