/****************************************************************************
** Meta object code from reading C++ file 'qquick3dparticlelineparticle_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtquick3d/src/quick3dparticles/qquick3dparticlelineparticle_p.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquick3dparticlelineparticle_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN28QQuick3DParticleLineParticleE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DParticleLineParticle::qt_create_metaobjectdata<qt_meta_tag_ZN28QQuick3DParticleLineParticleE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DParticleLineParticle",
        "QML.Element",
        "LineParticle3D",
        "QML.AddedInVersion",
        "1540",
        "segmentCountChanged",
        "",
        "alphaFadeChanged",
        "scaleMultiplierChanged",
        "texcoordMultiplierChanged",
        "lengthChanged",
        "lengthVariationChanged",
        "lengthDeltaMinChanged",
        "eolFadeOutDurationChanged",
        "texcoordModeChanged",
        "setSegmentCount",
        "count",
        "setAlphaFade",
        "fade",
        "setScaleMultiplier",
        "multiplier",
        "setTexcoordMultiplier",
        "setLength",
        "length",
        "setLengthVariation",
        "setLengthDeltaMin",
        "min",
        "setEolFadeOutDuration",
        "duration",
        "setTexcoordMode",
        "QQuick3DParticleLineParticle::TexcoordMode",
        "mode",
        "segmentCount",
        "alphaFade",
        "scaleMultiplier",
        "texcoordMultiplier",
        "lengthVariation",
        "lengthDeltaMin",
        "eolFadeOutDuration",
        "texcoordMode",
        "TexcoordMode",
        "Absolute",
        "Relative",
        "Fill"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'segmentCountChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'alphaFadeChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scaleMultiplierChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'texcoordMultiplierChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lengthChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lengthVariationChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lengthDeltaMinChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'eolFadeOutDurationChanged'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'texcoordModeChanged'
        QtMocHelpers::SignalData<void()>(14, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setSegmentCount'
        QtMocHelpers::SlotData<void(int)>(15, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 16 },
        }}),
        // Slot 'setAlphaFade'
        QtMocHelpers::SlotData<void(float)>(17, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 18 },
        }}),
        // Slot 'setScaleMultiplier'
        QtMocHelpers::SlotData<void(float)>(19, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 20 },
        }}),
        // Slot 'setTexcoordMultiplier'
        QtMocHelpers::SlotData<void(float)>(21, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 20 },
        }}),
        // Slot 'setLength'
        QtMocHelpers::SlotData<void(float)>(22, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 23 },
        }}),
        // Slot 'setLengthVariation'
        QtMocHelpers::SlotData<void(float)>(24, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 23 },
        }}),
        // Slot 'setLengthDeltaMin'
        QtMocHelpers::SlotData<void(float)>(25, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 26 },
        }}),
        // Slot 'setEolFadeOutDuration'
        QtMocHelpers::SlotData<void(int)>(27, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 28 },
        }}),
        // Slot 'setTexcoordMode'
        QtMocHelpers::SlotData<void(QQuick3DParticleLineParticle::TexcoordMode)>(29, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 30, 31 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'segmentCount'
        QtMocHelpers::PropertyData<int>(32, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'alphaFade'
        QtMocHelpers::PropertyData<float>(33, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'scaleMultiplier'
        QtMocHelpers::PropertyData<float>(34, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'texcoordMultiplier'
        QtMocHelpers::PropertyData<float>(35, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'length'
        QtMocHelpers::PropertyData<float>(23, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'lengthVariation'
        QtMocHelpers::PropertyData<float>(36, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'lengthDeltaMin'
        QtMocHelpers::PropertyData<float>(37, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'eolFadeOutDuration'
        QtMocHelpers::PropertyData<int>(38, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'texcoordMode'
        QtMocHelpers::PropertyData<enum TexcoordMode>(39, 0x80000000 | 40, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 8),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'TexcoordMode'
        QtMocHelpers::EnumData<enum TexcoordMode>(40, 40, QMC::EnumFlags{}).add({
            {   41, TexcoordMode::Absolute },
            {   42, TexcoordMode::Relative },
            {   43, TexcoordMode::Fill },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DParticleLineParticle, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DParticleLineParticle::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuick3DParticleSpriteParticle::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN28QQuick3DParticleLineParticleE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN28QQuick3DParticleLineParticleE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN28QQuick3DParticleLineParticleE_t>.metaTypes,
    nullptr
} };

void QQuick3DParticleLineParticle::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DParticleLineParticle *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->segmentCountChanged(); break;
        case 1: _t->alphaFadeChanged(); break;
        case 2: _t->scaleMultiplierChanged(); break;
        case 3: _t->texcoordMultiplierChanged(); break;
        case 4: _t->lengthChanged(); break;
        case 5: _t->lengthVariationChanged(); break;
        case 6: _t->lengthDeltaMinChanged(); break;
        case 7: _t->eolFadeOutDurationChanged(); break;
        case 8: _t->texcoordModeChanged(); break;
        case 9: _t->setSegmentCount((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->setAlphaFade((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 11: _t->setScaleMultiplier((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 12: _t->setTexcoordMultiplier((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 13: _t->setLength((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 14: _t->setLengthVariation((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 15: _t->setLengthDeltaMin((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 16: _t->setEolFadeOutDuration((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 17: _t->setTexcoordMode((*reinterpret_cast<std::add_pointer_t<QQuick3DParticleLineParticle::TexcoordMode>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleLineParticle::*)()>(_a, &QQuick3DParticleLineParticle::segmentCountChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleLineParticle::*)()>(_a, &QQuick3DParticleLineParticle::alphaFadeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleLineParticle::*)()>(_a, &QQuick3DParticleLineParticle::scaleMultiplierChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleLineParticle::*)()>(_a, &QQuick3DParticleLineParticle::texcoordMultiplierChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleLineParticle::*)()>(_a, &QQuick3DParticleLineParticle::lengthChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleLineParticle::*)()>(_a, &QQuick3DParticleLineParticle::lengthVariationChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleLineParticle::*)()>(_a, &QQuick3DParticleLineParticle::lengthDeltaMinChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleLineParticle::*)()>(_a, &QQuick3DParticleLineParticle::eolFadeOutDurationChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleLineParticle::*)()>(_a, &QQuick3DParticleLineParticle::texcoordModeChanged, 8))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->segmentCount(); break;
        case 1: *reinterpret_cast<float*>(_v) = _t->alphaFade(); break;
        case 2: *reinterpret_cast<float*>(_v) = _t->scaleMultiplier(); break;
        case 3: *reinterpret_cast<float*>(_v) = _t->texcoordMultiplier(); break;
        case 4: *reinterpret_cast<float*>(_v) = _t->length(); break;
        case 5: *reinterpret_cast<float*>(_v) = _t->lengthVariation(); break;
        case 6: *reinterpret_cast<float*>(_v) = _t->lengthDeltaMin(); break;
        case 7: *reinterpret_cast<int*>(_v) = _t->eolFadeOutDuration(); break;
        case 8: *reinterpret_cast<enum TexcoordMode*>(_v) = _t->texcoordMode(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setSegmentCount(*reinterpret_cast<int*>(_v)); break;
        case 1: _t->setAlphaFade(*reinterpret_cast<float*>(_v)); break;
        case 2: _t->setScaleMultiplier(*reinterpret_cast<float*>(_v)); break;
        case 3: _t->setTexcoordMultiplier(*reinterpret_cast<float*>(_v)); break;
        case 4: _t->setLength(*reinterpret_cast<float*>(_v)); break;
        case 5: _t->setLengthVariation(*reinterpret_cast<float*>(_v)); break;
        case 6: _t->setLengthDeltaMin(*reinterpret_cast<float*>(_v)); break;
        case 7: _t->setEolFadeOutDuration(*reinterpret_cast<int*>(_v)); break;
        case 8: _t->setTexcoordMode(*reinterpret_cast<enum TexcoordMode*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DParticleLineParticle::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DParticleLineParticle::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN28QQuick3DParticleLineParticleE_t>.strings))
        return static_cast<void*>(this);
    return QQuick3DParticleSpriteParticle::qt_metacast(_clname);
}

int QQuick3DParticleLineParticle::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuick3DParticleSpriteParticle::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 18;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void QQuick3DParticleLineParticle::segmentCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QQuick3DParticleLineParticle::alphaFadeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QQuick3DParticleLineParticle::scaleMultiplierChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QQuick3DParticleLineParticle::texcoordMultiplierChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QQuick3DParticleLineParticle::lengthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QQuick3DParticleLineParticle::lengthVariationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QQuick3DParticleLineParticle::lengthDeltaMinChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void QQuick3DParticleLineParticle::eolFadeOutDurationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void QQuick3DParticleLineParticle::texcoordModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
QT_WARNING_POP
