/****************************************************************************
** Meta object code from reading C++ file 'buildmessage.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtquick3d/tools/materialeditor/buildmessage.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'buildmessage.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18ShaderBuildMessageE_t {};
} // unnamed namespace

template <> constexpr inline auto ShaderBuildMessage::qt_create_metaobjectdata<qt_meta_tag_ZN18ShaderBuildMessageE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ShaderBuildMessage",
        "QML.Element",
        "shaderStatus",
        "filename",
        "message",
        "identifier",
        "line",
        "status",
        "Status",
        "stage",
        "Stage",
        "Success",
        "Error",
        "Vertex",
        "Fragment"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'filename'
        QtMocHelpers::PropertyData<QString>(3, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'message'
        QtMocHelpers::PropertyData<QString>(4, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'identifier'
        QtMocHelpers::PropertyData<QString>(5, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'line'
        QtMocHelpers::PropertyData<qint64>(6, QMetaType::LongLong, QMC::DefaultPropertyFlags),
        // property 'status'
        QtMocHelpers::PropertyData<enum Status>(7, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'stage'
        QtMocHelpers::PropertyData<enum Stage>(9, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Status'
        QtMocHelpers::EnumData<enum Status>(8, 8, QMC::EnumIsScoped).add({
            {   11, Status::Success },
            {   12, Status::Error },
        }),
        // enum 'Stage'
        QtMocHelpers::EnumData<enum Stage>(10, 10, QMC::EnumIsScoped).add({
            {   13, Stage::Vertex },
            {   14, Stage::Fragment },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<ShaderBuildMessage, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject ShaderBuildMessage::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ShaderBuildMessageE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ShaderBuildMessageE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18ShaderBuildMessageE_t>.metaTypes,
    nullptr
} };

void ShaderBuildMessage::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<ShaderBuildMessage *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->filename(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->message(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->identifier(); break;
        case 3: *reinterpret_cast<qint64*>(_v) = _t->line(); break;
        case 4: *reinterpret_cast<enum Status*>(_v) = _t->status(); break;
        case 5: *reinterpret_cast<enum Stage*>(_v) = _t->stage(); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN25ShaderBuildMessageDerivedE_t {};
} // unnamed namespace

template <> constexpr inline auto ShaderBuildMessageDerived::qt_create_metaobjectdata<qt_meta_tag_ZN25ShaderBuildMessageDerivedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ShaderBuildMessageDerived"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ShaderBuildMessageDerived, qt_meta_tag_ZN25ShaderBuildMessageDerivedE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ShaderBuildMessageDerived::staticMetaObject = { {
    QtPrivate::MetaObjectForType<ShaderBuildMessage>::value,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25ShaderBuildMessageDerivedE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25ShaderBuildMessageDerivedE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN25ShaderBuildMessageDerivedE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN11ShaderEnumsE_t {};
} // unnamed namespace

template <> constexpr inline auto ShaderEnums::qt_create_metaobjectdata<qt_meta_tag_ZN11ShaderEnumsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ShaderEnums",
        "QML.Foreign",
        "ShaderBuildMessageDerived",
        "QML.ForeignIsNamespace",
        "true",
        "QML.Element",
        "ShaderConstants"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN11ShaderEnumsE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}

static constexpr auto qt_staticMetaObjectContent_ZN11ShaderEnumsE =
    ShaderEnums::qt_create_metaobjectdata<qt_meta_tag_ZN11ShaderEnumsE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN11ShaderEnumsE =
    qt_staticMetaObjectContent_ZN11ShaderEnumsE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN11ShaderEnumsE =
    qt_staticMetaObjectContent_ZN11ShaderEnumsE.relocatingData;

Q_CONSTINIT const QMetaObject ShaderEnums::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN11ShaderEnumsE.stringdata,
    qt_staticMetaObjectStaticContent_ZN11ShaderEnumsE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN11ShaderEnumsE.metaTypes,
    nullptr
} };

QT_WARNING_POP
