/****************************************************************************
** Meta object code from reading C++ file 'qquick3drepeater_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtquick3d/src/quick3d/qquick3drepeater_p.h"
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquick3drepeater_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16QQuick3DRepeaterE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DRepeater::qt_create_metaobjectdata<qt_meta_tag_ZN16QQuick3DRepeaterE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DRepeater",
        "DefaultProperty",
        "delegate",
        "QML.Element",
        "Repeater3D",
        "modelChanged",
        "",
        "delegateChanged",
        "countChanged",
        "objectAdded",
        "index",
        "QQuick3DObject*",
        "object",
        "objectRemoved",
        "delegateModelAccessChanged",
        "createdObject",
        "item",
        "initObject",
        "modelUpdated",
        "QQmlChangeSet",
        "changeSet",
        "reset",
        "objectAt",
        "model",
        "QVariant",
        "QQmlComponent*",
        "count",
        "delegateModelAccess",
        "QQmlDelegateModel::DelegateModelAccess"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'modelChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'delegateChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'countChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'objectAdded'
        QtMocHelpers::SignalData<void(int, QQuick3DObject *)>(9, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 10 }, { 0x80000000 | 11, 12 },
        }}),
        // Signal 'objectRemoved'
        QtMocHelpers::SignalData<void(int, QQuick3DObject *)>(13, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 10 }, { 0x80000000 | 11, 12 },
        }}),
        // Signal 'delegateModelAccessChanged'
        QtMocHelpers::RevisionedSignalData<void()>(14, 6, QMC::AccessPublic, 0x60a, QMetaType::Void),
        // Slot 'createdObject'
        QtMocHelpers::SlotData<void(int, QObject *)>(15, 6, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 10 }, { QMetaType::QObjectStar, 16 },
        }}),
        // Slot 'initObject'
        QtMocHelpers::SlotData<void(int, QObject *)>(17, 6, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 6 }, { QMetaType::QObjectStar, 16 },
        }}),
        // Slot 'modelUpdated'
        QtMocHelpers::SlotData<void(const QQmlChangeSet &, bool)>(18, 6, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 19, 20 }, { QMetaType::Bool, 21 },
        }}),
        // Method 'objectAt'
        QtMocHelpers::MethodData<QQuick3DObject *(int) const>(22, 6, QMC::AccessPublic, 0x80000000 | 11, {{
            { QMetaType::Int, 10 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'model'
        QtMocHelpers::PropertyData<QVariant>(23, 0x80000000 | 24, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'delegate'
        QtMocHelpers::PropertyData<QQmlComponent*>(2, 0x80000000 | 25, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'count'
        QtMocHelpers::PropertyData<int>(26, QMetaType::Int, QMC::DefaultPropertyFlags, 2),
        // property 'delegateModelAccess'
        QtMocHelpers::PropertyData<QQmlDelegateModel::DelegateModelAccess>(27, 0x80000000 | 28, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 5, 0x60a),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DRepeater, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN16QQuick3DRepeaterE[] = {
    QMetaObject::SuperData::link<QQmlDelegateModel::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject QQuick3DRepeater::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuick3DNode::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16QQuick3DRepeaterE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16QQuick3DRepeaterE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN16QQuick3DRepeaterE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16QQuick3DRepeaterE_t>.metaTypes,
    nullptr
} };

void QQuick3DRepeater::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DRepeater *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->modelChanged(); break;
        case 1: _t->delegateChanged(); break;
        case 2: _t->countChanged(); break;
        case 3: _t->objectAdded((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QQuick3DObject*>>(_a[2]))); break;
        case 4: _t->objectRemoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QQuick3DObject*>>(_a[2]))); break;
        case 5: _t->delegateModelAccessChanged(); break;
        case 6: _t->createdObject((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[2]))); break;
        case 7: _t->initObject((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[2]))); break;
        case 8: _t->modelUpdated((*reinterpret_cast<std::add_pointer_t<QQmlChangeSet>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 9: { QQuick3DObject* _r = _t->objectAt((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QQuick3DObject**>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DObject* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DObject* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuick3DRepeater::*)()>(_a, &QQuick3DRepeater::modelChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DRepeater::*)()>(_a, &QQuick3DRepeater::delegateChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DRepeater::*)()>(_a, &QQuick3DRepeater::countChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DRepeater::*)(int , QQuick3DObject * )>(_a, &QQuick3DRepeater::objectAdded, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DRepeater::*)(int , QQuick3DObject * )>(_a, &QQuick3DRepeater::objectRemoved, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DRepeater::*)()>(_a, &QQuick3DRepeater::delegateModelAccessChanged, 5))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQmlComponent* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QVariant*>(_v) = _t->model(); break;
        case 1: *reinterpret_cast<QQmlComponent**>(_v) = _t->delegate(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->count(); break;
        case 3: *reinterpret_cast<QQmlDelegateModel::DelegateModelAccess*>(_v) = _t->delegateModelAccess(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setModel(*reinterpret_cast<QVariant*>(_v)); break;
        case 1: _t->setDelegate(*reinterpret_cast<QQmlComponent**>(_v)); break;
        case 3: _t->setDelegateModelAccess(*reinterpret_cast<QQmlDelegateModel::DelegateModelAccess*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DRepeater::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DRepeater::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16QQuick3DRepeaterE_t>.strings))
        return static_cast<void*>(this);
    return QQuick3DNode::qt_metacast(_clname);
}

int QQuick3DRepeater::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuick3DNode::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void QQuick3DRepeater::modelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QQuick3DRepeater::delegateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QQuick3DRepeater::countChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QQuick3DRepeater::objectAdded(int _t1, QQuick3DObject * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void QQuick3DRepeater::objectRemoved(int _t1, QQuick3DObject * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void QQuick3DRepeater::delegateModelAccessChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
