/****************************************************************************
** Meta object code from reading C++ file 'qquick3dparticleemitter_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtquick3d/src/quick3dparticles/qquick3dparticleemitter_p.h"
#include <QtGui/qtextcursor.h>
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquick3dparticleemitter_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN23QQuick3DParticleEmitterE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DParticleEmitter::qt_create_metaobjectdata<qt_meta_tag_ZN23QQuick3DParticleEmitterE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DParticleEmitter",
        "QML.Element",
        "ParticleEmitter3D",
        "QML.AddedInVersion",
        "1538",
        "velocityChanged",
        "",
        "systemChanged",
        "emitRateChanged",
        "particleScaleChanged",
        "particleEndScaleChanged",
        "particleScaleVariationChanged",
        "particleEndScaleVariationChanged",
        "lifeSpanChanged",
        "lifeSpanVariationChanged",
        "particleChanged",
        "shapeChanged",
        "particleRotationChanged",
        "particleRotationVariationChanged",
        "particleRotationVelocityChanged",
        "particleRotationVariationVelocityChanged",
        "enabledChanged",
        "depthBiasChanged",
        "reversedChanged",
        "emitModeChanged",
        "setEnabled",
        "enabled",
        "setVelocity",
        "QQuick3DParticleDirection*",
        "velocity",
        "setSystem",
        "QQuick3DParticleSystem*",
        "system",
        "setEmitRate",
        "emitRate",
        "setParticleScale",
        "particleScale",
        "setParticleEndScale",
        "particleEndScale",
        "setParticleScaleVariation",
        "particleScaleVariation",
        "setParticleEndScaleVariation",
        "particleEndScaleVariation",
        "setLifeSpan",
        "lifeSpan",
        "setLifeSpanVariation",
        "lifeSpanVariation",
        "setParticle",
        "QQuick3DParticle*",
        "particle",
        "setShape",
        "QQuick3DParticleAbstractShape*",
        "shape",
        "setParticleRotation",
        "QVector3D",
        "particleRotation",
        "setParticleRotationVariation",
        "particleRotationVariation",
        "setParticleRotationVelocity",
        "particleRotationVelocity",
        "setParticleRotationVelocityVariation",
        "particleRotationVelocityVariation",
        "setDepthBias",
        "bias",
        "setReversed",
        "reversed",
        "setEmitMode",
        "EmitMode",
        "mode",
        "burst",
        "count",
        "duration",
        "position",
        "emitBursts",
        "QQmlListProperty<QQuick3DParticleEmitBurst>",
        "depthBias",
        "emitMode",
        "Default",
        "SurfaceNormal",
        "SurfaceReflected"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'velocityChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'systemChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'emitRateChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'particleScaleChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'particleEndScaleChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'particleScaleVariationChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'particleEndScaleVariationChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lifeSpanChanged'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lifeSpanVariationChanged'
        QtMocHelpers::SignalData<void()>(14, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'particleChanged'
        QtMocHelpers::SignalData<void()>(15, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'shapeChanged'
        QtMocHelpers::SignalData<void()>(16, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'particleRotationChanged'
        QtMocHelpers::SignalData<void()>(17, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'particleRotationVariationChanged'
        QtMocHelpers::SignalData<void()>(18, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'particleRotationVelocityChanged'
        QtMocHelpers::SignalData<void()>(19, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'particleRotationVariationVelocityChanged'
        QtMocHelpers::SignalData<void()>(20, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enabledChanged'
        QtMocHelpers::SignalData<void()>(21, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'depthBiasChanged'
        QtMocHelpers::SignalData<void()>(22, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'reversedChanged'
        QtMocHelpers::RevisionedSignalData<void()>(23, 6, QMC::AccessPublic, 0x60a, QMetaType::Void),
        // Signal 'emitModeChanged'
        QtMocHelpers::RevisionedSignalData<void()>(24, 6, QMC::AccessPublic, 0x60a, QMetaType::Void),
        // Slot 'setEnabled'
        QtMocHelpers::SlotData<void(bool)>(25, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 26 },
        }}),
        // Slot 'setVelocity'
        QtMocHelpers::SlotData<void(QQuick3DParticleDirection *)>(27, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 28, 29 },
        }}),
        // Slot 'setSystem'
        QtMocHelpers::SlotData<void(QQuick3DParticleSystem *)>(30, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 31, 32 },
        }}),
        // Slot 'setEmitRate'
        QtMocHelpers::SlotData<void(float)>(33, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 34 },
        }}),
        // Slot 'setParticleScale'
        QtMocHelpers::SlotData<void(float)>(35, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 36 },
        }}),
        // Slot 'setParticleEndScale'
        QtMocHelpers::SlotData<void(float)>(37, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 38 },
        }}),
        // Slot 'setParticleScaleVariation'
        QtMocHelpers::SlotData<void(float)>(39, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 40 },
        }}),
        // Slot 'setParticleEndScaleVariation'
        QtMocHelpers::SlotData<void(float)>(41, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 42 },
        }}),
        // Slot 'setLifeSpan'
        QtMocHelpers::SlotData<void(int)>(43, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 44 },
        }}),
        // Slot 'setLifeSpanVariation'
        QtMocHelpers::SlotData<void(int)>(45, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 46 },
        }}),
        // Slot 'setParticle'
        QtMocHelpers::SlotData<void(QQuick3DParticle *)>(47, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 48, 49 },
        }}),
        // Slot 'setShape'
        QtMocHelpers::SlotData<void(QQuick3DParticleAbstractShape *)>(50, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 51, 52 },
        }}),
        // Slot 'setParticleRotation'
        QtMocHelpers::SlotData<void(const QVector3D &)>(53, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 54, 55 },
        }}),
        // Slot 'setParticleRotationVariation'
        QtMocHelpers::SlotData<void(const QVector3D &)>(56, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 54, 57 },
        }}),
        // Slot 'setParticleRotationVelocity'
        QtMocHelpers::SlotData<void(const QVector3D &)>(58, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 54, 59 },
        }}),
        // Slot 'setParticleRotationVelocityVariation'
        QtMocHelpers::SlotData<void(const QVector3D &)>(60, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 54, 61 },
        }}),
        // Slot 'setDepthBias'
        QtMocHelpers::SlotData<void(float)>(62, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 63 },
        }}),
        // Slot 'setReversed'
        QtMocHelpers::RevisionedSlotData<void(bool)>(64, 6, QMC::AccessPublic, 0x60a, QMetaType::Void, {{
            { QMetaType::Bool, 65 },
        }}),
        // Slot 'setEmitMode'
        QtMocHelpers::RevisionedSlotData<void(enum EmitMode)>(66, 6, QMC::AccessPublic, 0x60a, QMetaType::Void, {{
            { 0x80000000 | 67, 68 },
        }}),
        // Method 'burst'
        QtMocHelpers::MethodData<void(int)>(69, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 70 },
        }}),
        // Method 'burst'
        QtMocHelpers::MethodData<void(int, int)>(69, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 70 }, { QMetaType::Int, 71 },
        }}),
        // Method 'burst'
        QtMocHelpers::MethodData<void(int, int, const QVector3D &)>(69, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 70 }, { QMetaType::Int, 71 }, { 0x80000000 | 54, 72 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'system'
        QtMocHelpers::PropertyData<QQuick3DParticleSystem*>(32, 0x80000000 | 31, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'emitBursts'
        QtMocHelpers::PropertyData<QQmlListProperty<QQuick3DParticleEmitBurst>>(73, 0x80000000 | 74, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'velocity'
        QtMocHelpers::PropertyData<QQuick3DParticleDirection*>(29, 0x80000000 | 28, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'particle'
        QtMocHelpers::PropertyData<QQuick3DParticle*>(49, 0x80000000 | 48, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 9),
        // property 'enabled'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 15),
        // property 'shape'
        QtMocHelpers::PropertyData<QQuick3DParticleAbstractShape*>(52, 0x80000000 | 51, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 10),
        // property 'emitRate'
        QtMocHelpers::PropertyData<float>(34, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'lifeSpan'
        QtMocHelpers::PropertyData<int>(44, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'lifeSpanVariation'
        QtMocHelpers::PropertyData<int>(46, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'particleScale'
        QtMocHelpers::PropertyData<float>(36, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'particleEndScale'
        QtMocHelpers::PropertyData<float>(38, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'particleScaleVariation'
        QtMocHelpers::PropertyData<float>(40, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'particleEndScaleVariation'
        QtMocHelpers::PropertyData<float>(42, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'particleRotation'
        QtMocHelpers::PropertyData<QVector3D>(55, 0x80000000 | 54, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 11),
        // property 'particleRotationVariation'
        QtMocHelpers::PropertyData<QVector3D>(57, 0x80000000 | 54, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 12),
        // property 'particleRotationVelocity'
        QtMocHelpers::PropertyData<QVector3D>(59, 0x80000000 | 54, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 13),
        // property 'particleRotationVelocityVariation'
        QtMocHelpers::PropertyData<QVector3D>(61, 0x80000000 | 54, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 14),
        // property 'depthBias'
        QtMocHelpers::PropertyData<float>(75, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 16),
        // property 'reversed'
        QtMocHelpers::PropertyData<bool>(65, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 17, 0x60a),
        // property 'emitMode'
        QtMocHelpers::PropertyData<enum EmitMode>(76, 0x80000000 | 67, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 18, 0x60a),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'EmitMode'
        QtMocHelpers::EnumData<enum EmitMode>(67, 67, QMC::EnumFlags{}).add({
            {   77, EmitMode::Default },
            {   78, EmitMode::SurfaceNormal },
            {   79, EmitMode::SurfaceReflected },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DParticleEmitter, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DParticleEmitter::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuick3DNode::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23QQuick3DParticleEmitterE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23QQuick3DParticleEmitterE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23QQuick3DParticleEmitterE_t>.metaTypes,
    nullptr
} };

void QQuick3DParticleEmitter::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DParticleEmitter *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->velocityChanged(); break;
        case 1: _t->systemChanged(); break;
        case 2: _t->emitRateChanged(); break;
        case 3: _t->particleScaleChanged(); break;
        case 4: _t->particleEndScaleChanged(); break;
        case 5: _t->particleScaleVariationChanged(); break;
        case 6: _t->particleEndScaleVariationChanged(); break;
        case 7: _t->lifeSpanChanged(); break;
        case 8: _t->lifeSpanVariationChanged(); break;
        case 9: _t->particleChanged(); break;
        case 10: _t->shapeChanged(); break;
        case 11: _t->particleRotationChanged(); break;
        case 12: _t->particleRotationVariationChanged(); break;
        case 13: _t->particleRotationVelocityChanged(); break;
        case 14: _t->particleRotationVariationVelocityChanged(); break;
        case 15: _t->enabledChanged(); break;
        case 16: _t->depthBiasChanged(); break;
        case 17: _t->reversedChanged(); break;
        case 18: _t->emitModeChanged(); break;
        case 19: _t->setEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 20: _t->setVelocity((*reinterpret_cast<std::add_pointer_t<QQuick3DParticleDirection*>>(_a[1]))); break;
        case 21: _t->setSystem((*reinterpret_cast<std::add_pointer_t<QQuick3DParticleSystem*>>(_a[1]))); break;
        case 22: _t->setEmitRate((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 23: _t->setParticleScale((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 24: _t->setParticleEndScale((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 25: _t->setParticleScaleVariation((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 26: _t->setParticleEndScaleVariation((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 27: _t->setLifeSpan((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 28: _t->setLifeSpanVariation((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 29: _t->setParticle((*reinterpret_cast<std::add_pointer_t<QQuick3DParticle*>>(_a[1]))); break;
        case 30: _t->setShape((*reinterpret_cast<std::add_pointer_t<QQuick3DParticleAbstractShape*>>(_a[1]))); break;
        case 31: _t->setParticleRotation((*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[1]))); break;
        case 32: _t->setParticleRotationVariation((*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[1]))); break;
        case 33: _t->setParticleRotationVelocity((*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[1]))); break;
        case 34: _t->setParticleRotationVelocityVariation((*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[1]))); break;
        case 35: _t->setDepthBias((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 36: _t->setReversed((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 37: _t->setEmitMode((*reinterpret_cast<std::add_pointer_t<enum EmitMode>>(_a[1]))); break;
        case 38: _t->burst((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 39: _t->burst((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 40: _t->burst((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[3]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 20:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DParticleDirection* >(); break;
            }
            break;
        case 21:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DParticleSystem* >(); break;
            }
            break;
        case 29:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DParticle* >(); break;
            }
            break;
        case 30:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DParticleAbstractShape* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleEmitter::*)()>(_a, &QQuick3DParticleEmitter::velocityChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleEmitter::*)()>(_a, &QQuick3DParticleEmitter::systemChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleEmitter::*)()>(_a, &QQuick3DParticleEmitter::emitRateChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleEmitter::*)()>(_a, &QQuick3DParticleEmitter::particleScaleChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleEmitter::*)()>(_a, &QQuick3DParticleEmitter::particleEndScaleChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleEmitter::*)()>(_a, &QQuick3DParticleEmitter::particleScaleVariationChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleEmitter::*)()>(_a, &QQuick3DParticleEmitter::particleEndScaleVariationChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleEmitter::*)()>(_a, &QQuick3DParticleEmitter::lifeSpanChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleEmitter::*)()>(_a, &QQuick3DParticleEmitter::lifeSpanVariationChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleEmitter::*)()>(_a, &QQuick3DParticleEmitter::particleChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleEmitter::*)()>(_a, &QQuick3DParticleEmitter::shapeChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleEmitter::*)()>(_a, &QQuick3DParticleEmitter::particleRotationChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleEmitter::*)()>(_a, &QQuick3DParticleEmitter::particleRotationVariationChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleEmitter::*)()>(_a, &QQuick3DParticleEmitter::particleRotationVelocityChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleEmitter::*)()>(_a, &QQuick3DParticleEmitter::particleRotationVariationVelocityChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleEmitter::*)()>(_a, &QQuick3DParticleEmitter::enabledChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleEmitter::*)()>(_a, &QQuick3DParticleEmitter::depthBiasChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleEmitter::*)()>(_a, &QQuick3DParticleEmitter::reversedChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleEmitter::*)()>(_a, &QQuick3DParticleEmitter::emitModeChanged, 18))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuick3DParticle* >(); break;
        case 5:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuick3DParticleAbstractShape* >(); break;
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuick3DParticleDirection* >(); break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuick3DParticleSystem* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QQuick3DParticleSystem**>(_v) = _t->system(); break;
        case 1: *reinterpret_cast<QQmlListProperty<QQuick3DParticleEmitBurst>*>(_v) = _t->emitBursts(); break;
        case 2: *reinterpret_cast<QQuick3DParticleDirection**>(_v) = _t->velocity(); break;
        case 3: *reinterpret_cast<QQuick3DParticle**>(_v) = _t->particle(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->enabled(); break;
        case 5: *reinterpret_cast<QQuick3DParticleAbstractShape**>(_v) = _t->shape(); break;
        case 6: *reinterpret_cast<float*>(_v) = _t->emitRate(); break;
        case 7: *reinterpret_cast<int*>(_v) = _t->lifeSpan(); break;
        case 8: *reinterpret_cast<int*>(_v) = _t->lifeSpanVariation(); break;
        case 9: *reinterpret_cast<float*>(_v) = _t->particleScale(); break;
        case 10: *reinterpret_cast<float*>(_v) = _t->particleEndScale(); break;
        case 11: *reinterpret_cast<float*>(_v) = _t->particleScaleVariation(); break;
        case 12: *reinterpret_cast<float*>(_v) = _t->particleEndScaleVariation(); break;
        case 13: *reinterpret_cast<QVector3D*>(_v) = _t->particleRotation(); break;
        case 14: *reinterpret_cast<QVector3D*>(_v) = _t->particleRotationVariation(); break;
        case 15: *reinterpret_cast<QVector3D*>(_v) = _t->particleRotationVelocity(); break;
        case 16: *reinterpret_cast<QVector3D*>(_v) = _t->particleRotationVelocityVariation(); break;
        case 17: *reinterpret_cast<float*>(_v) = _t->depthBias(); break;
        case 18: *reinterpret_cast<bool*>(_v) = _t->reversed(); break;
        case 19: *reinterpret_cast<enum EmitMode*>(_v) = _t->emitMode(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setSystem(*reinterpret_cast<QQuick3DParticleSystem**>(_v)); break;
        case 2: _t->setVelocity(*reinterpret_cast<QQuick3DParticleDirection**>(_v)); break;
        case 3: _t->setParticle(*reinterpret_cast<QQuick3DParticle**>(_v)); break;
        case 4: _t->setEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setShape(*reinterpret_cast<QQuick3DParticleAbstractShape**>(_v)); break;
        case 6: _t->setEmitRate(*reinterpret_cast<float*>(_v)); break;
        case 7: _t->setLifeSpan(*reinterpret_cast<int*>(_v)); break;
        case 8: _t->setLifeSpanVariation(*reinterpret_cast<int*>(_v)); break;
        case 9: _t->setParticleScale(*reinterpret_cast<float*>(_v)); break;
        case 10: _t->setParticleEndScale(*reinterpret_cast<float*>(_v)); break;
        case 11: _t->setParticleScaleVariation(*reinterpret_cast<float*>(_v)); break;
        case 12: _t->setParticleEndScaleVariation(*reinterpret_cast<float*>(_v)); break;
        case 13: _t->setParticleRotation(*reinterpret_cast<QVector3D*>(_v)); break;
        case 14: _t->setParticleRotationVariation(*reinterpret_cast<QVector3D*>(_v)); break;
        case 15: _t->setParticleRotationVelocity(*reinterpret_cast<QVector3D*>(_v)); break;
        case 16: _t->setParticleRotationVelocityVariation(*reinterpret_cast<QVector3D*>(_v)); break;
        case 17: _t->setDepthBias(*reinterpret_cast<float*>(_v)); break;
        case 18: _t->setReversed(*reinterpret_cast<bool*>(_v)); break;
        case 19: _t->setEmitMode(*reinterpret_cast<enum EmitMode*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DParticleEmitter::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DParticleEmitter::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23QQuick3DParticleEmitterE_t>.strings))
        return static_cast<void*>(this);
    return QQuick3DNode::qt_metacast(_clname);
}

int QQuick3DParticleEmitter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuick3DNode::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 41)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 41;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 41)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 41;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    return _id;
}

// SIGNAL 0
void QQuick3DParticleEmitter::velocityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QQuick3DParticleEmitter::systemChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QQuick3DParticleEmitter::emitRateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QQuick3DParticleEmitter::particleScaleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QQuick3DParticleEmitter::particleEndScaleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QQuick3DParticleEmitter::particleScaleVariationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QQuick3DParticleEmitter::particleEndScaleVariationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void QQuick3DParticleEmitter::lifeSpanChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void QQuick3DParticleEmitter::lifeSpanVariationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void QQuick3DParticleEmitter::particleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void QQuick3DParticleEmitter::shapeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void QQuick3DParticleEmitter::particleRotationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void QQuick3DParticleEmitter::particleRotationVariationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void QQuick3DParticleEmitter::particleRotationVelocityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void QQuick3DParticleEmitter::particleRotationVariationVelocityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void QQuick3DParticleEmitter::enabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void QQuick3DParticleEmitter::depthBiasChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void QQuick3DParticleEmitter::reversedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void QQuick3DParticleEmitter::emitModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}
QT_WARNING_POP
