/****************************************************************************
** Meta object code from reading C++ file 'qquick3dviewport_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtquick3d/src/quick3d/qquick3dviewport_p.h"
#include <QtGui/qtextcursor.h>
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquick3dviewport_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16QQuick3DViewportE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DViewport::qt_create_metaobjectdata<qt_meta_tag_ZN16QQuick3DViewportE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DViewport",
        "DefaultProperty",
        "data",
        "QML.Element",
        "View3D",
        "cameraChanged",
        "",
        "environmentChanged",
        "sceneChanged",
        "importSceneChanged",
        "renderModeChanged",
        "renderFormatChanged",
        "explicitTextureWidthChanged",
        "explicitTextureHeightChanged",
        "effectiveTextureSizeChanged",
        "renderOverridesChanged",
        "setCamera",
        "QQuick3DCamera*",
        "camera",
        "setEnvironment",
        "QQuick3DSceneEnvironment*",
        "environment",
        "setImportScene",
        "QQuick3DNode*",
        "inScene",
        "setRenderMode",
        "QQuick3DViewport::RenderMode",
        "renderMode",
        "setRenderFormat",
        "QQuickShaderEffectSource::Format",
        "format",
        "setExplicitTextureWidth",
        "width",
        "setExplicitTextureHeight",
        "height",
        "cleanupDirectRenderer",
        "setGlobalPickingEnabled",
        "isEnabled",
        "invalidateSceneGraph",
        "updateInputProcessing",
        "onReleaseCachedResources",
        "mapFrom3DScene",
        "QVector3D",
        "scenePos",
        "mapTo3DScene",
        "viewPos",
        "pick",
        "QQuick3DPickResult",
        "x",
        "y",
        "QQuick3DModel*",
        "model",
        "pickSubset",
        "QList<QQuick3DPickResult>",
        "QJSValue",
        "models",
        "pickAll",
        "rayPick",
        "origin",
        "direction",
        "rayPickAll",
        "closestPointPick",
        "radius",
        "pickInRect",
        "QList<QQuick3DObject*>",
        "QPointF",
        "start",
        "end",
        "setTouchpoint",
        "QQuickItem*",
        "target",
        "position",
        "pointId",
        "active",
        "bakeLightmap",
        "denoiseLightmap",
        "rebuildExtensionList",
        "QQmlListProperty<QObject>",
        "scene",
        "importScene",
        "RenderMode",
        "renderFormat",
        "renderStats",
        "QQuick3DRenderStats*",
        "extensions",
        "QQmlListProperty<QQuick3DObject>",
        "explicitTextureWidth",
        "explicitTextureHeight",
        "effectiveTextureSize",
        "QSize",
        "renderOverrides",
        "RenderOverrides",
        "Offscreen",
        "Underlay",
        "Overlay",
        "Inline",
        "RenderOverride",
        "None",
        "DisableInternalPasses"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'cameraChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'environmentChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sceneChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'importSceneChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'renderModeChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'renderFormatChanged'
        QtMocHelpers::RevisionedSignalData<void()>(11, 6, QMC::AccessPublic, 0x604, QMetaType::Void),
        // Signal 'explicitTextureWidthChanged'
        QtMocHelpers::RevisionedSignalData<void()>(12, 6, QMC::AccessPublic, 0x607, QMetaType::Void),
        // Signal 'explicitTextureHeightChanged'
        QtMocHelpers::RevisionedSignalData<void()>(13, 6, QMC::AccessPublic, 0x607, QMetaType::Void),
        // Signal 'effectiveTextureSizeChanged'
        QtMocHelpers::RevisionedSignalData<void()>(14, 6, QMC::AccessPublic, 0x607, QMetaType::Void),
        // Signal 'renderOverridesChanged'
        QtMocHelpers::SignalData<void()>(15, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setCamera'
        QtMocHelpers::SlotData<void(QQuick3DCamera *)>(16, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'setEnvironment'
        QtMocHelpers::SlotData<void(QQuick3DSceneEnvironment *)>(19, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Slot 'setImportScene'
        QtMocHelpers::SlotData<void(QQuick3DNode *)>(22, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 23, 24 },
        }}),
        // Slot 'setRenderMode'
        QtMocHelpers::SlotData<void(QQuick3DViewport::RenderMode)>(25, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 26, 27 },
        }}),
        // Slot 'setRenderFormat'
        QtMocHelpers::RevisionedSlotData<void(QQuickShaderEffectSource::Format)>(28, 6, QMC::AccessPublic, 0x604, QMetaType::Void, {{
            { 0x80000000 | 29, 30 },
        }}),
        // Slot 'setExplicitTextureWidth'
        QtMocHelpers::RevisionedSlotData<void(int)>(31, 6, QMC::AccessPublic, 0x607, QMetaType::Void, {{
            { QMetaType::Int, 32 },
        }}),
        // Slot 'setExplicitTextureHeight'
        QtMocHelpers::RevisionedSlotData<void(int)>(33, 6, QMC::AccessPublic, 0x607, QMetaType::Void, {{
            { QMetaType::Int, 34 },
        }}),
        // Slot 'cleanupDirectRenderer'
        QtMocHelpers::SlotData<void()>(35, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setGlobalPickingEnabled'
        QtMocHelpers::SlotData<void(bool)>(36, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 37 },
        }}),
        // Slot 'invalidateSceneGraph'
        QtMocHelpers::SlotData<void()>(38, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateInputProcessing'
        QtMocHelpers::SlotData<void()>(39, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onReleaseCachedResources'
        QtMocHelpers::SlotData<void()>(40, 6, QMC::AccessPrivate, QMetaType::Void),
        // Method 'mapFrom3DScene'
        QtMocHelpers::MethodData<QVector3D(const QVector3D &) const>(41, 6, QMC::AccessPublic, 0x80000000 | 42, {{
            { 0x80000000 | 42, 43 },
        }}),
        // Method 'mapTo3DScene'
        QtMocHelpers::MethodData<QVector3D(const QVector3D &) const>(44, 6, QMC::AccessPublic, 0x80000000 | 42, {{
            { 0x80000000 | 42, 45 },
        }}),
        // Method 'pick'
        QtMocHelpers::MethodData<QQuick3DPickResult(float, float) const>(46, 6, QMC::AccessPublic, 0x80000000 | 47, {{
            { QMetaType::Float, 48 }, { QMetaType::Float, 49 },
        }}),
        // Method 'pick'
        QtMocHelpers::RevisionedMethodData<QQuick3DPickResult(float, float, QQuick3DModel *) const>(46, 6, QMC::AccessPublic, 0x608, 0x80000000 | 47, {{
            { QMetaType::Float, 48 }, { QMetaType::Float, 49 }, { 0x80000000 | 50, 51 },
        }}),
        // Method 'pickSubset'
        QtMocHelpers::RevisionedMethodData<QList<QQuick3DPickResult>(float, float, const QJSValue &) const>(52, 6, QMC::AccessPublic, 0x608, 0x80000000 | 53, {{
            { QMetaType::Float, 48 }, { QMetaType::Float, 49 }, { 0x80000000 | 54, 55 },
        }}),
        // Method 'pickAll'
        QtMocHelpers::RevisionedMethodData<QList<QQuick3DPickResult>(float, float) const>(56, 6, QMC::AccessPublic, 0x602, 0x80000000 | 53, {{
            { QMetaType::Float, 48 }, { QMetaType::Float, 49 },
        }}),
        // Method 'rayPick'
        QtMocHelpers::RevisionedMethodData<QQuick3DPickResult(const QVector3D &, const QVector3D &) const>(57, 6, QMC::AccessPublic, 0x602, 0x80000000 | 47, {{
            { 0x80000000 | 42, 58 }, { 0x80000000 | 42, 59 },
        }}),
        // Method 'rayPickAll'
        QtMocHelpers::RevisionedMethodData<QList<QQuick3DPickResult>(const QVector3D &, const QVector3D &) const>(60, 6, QMC::AccessPublic, 0x602, 0x80000000 | 53, {{
            { 0x80000000 | 42, 58 }, { 0x80000000 | 42, 59 },
        }}),
        // Method 'rayPick'
        QtMocHelpers::RevisionedMethodData<QQuick3DPickResult(const QVector3D &, const QVector3D &, QQuick3DModel *) const>(57, 6, QMC::AccessPublic, 0x60b, 0x80000000 | 47, {{
            { 0x80000000 | 42, 58 }, { 0x80000000 | 42, 59 }, { 0x80000000 | 50, 51 },
        }}),
        // Method 'closestPointPick'
        QtMocHelpers::RevisionedMethodData<QQuick3DPickResult(const QVector3D &, float, QQuick3DModel *) const>(61, 6, QMC::AccessPublic, 0x60b, 0x80000000 | 47, {{
            { 0x80000000 | 42, 58 }, { QMetaType::Float, 62 }, { 0x80000000 | 50, 51 },
        }}),
        // Method 'closestPointPick'
        QtMocHelpers::RevisionedMethodData<QQuick3DPickResult(const QVector3D &, float) const>(61, 6, QMC::AccessPublic | QMC::MethodCloned, 0x60b, 0x80000000 | 47, {{
            { 0x80000000 | 42, 58 }, { QMetaType::Float, 62 },
        }}),
        // Method 'pickInRect'
        QtMocHelpers::RevisionedMethodData<QList<QQuick3DObject*>(const QPointF &, const QPointF &) const>(63, 6, QMC::AccessPublic, 0x60b, 0x80000000 | 64, {{
            { 0x80000000 | 65, 66 }, { 0x80000000 | 65, 67 },
        }}),
        // Method 'setTouchpoint'
        QtMocHelpers::RevisionedMethodData<void(QQuickItem *, const QPointF &, int, bool)>(68, 6, QMC::AccessPublic, 0x608, QMetaType::Void, {{
            { 0x80000000 | 69, 70 }, { 0x80000000 | 65, 71 }, { QMetaType::Int, 72 }, { QMetaType::Bool, 73 },
        }}),
        // Method 'bakeLightmap'
        QtMocHelpers::MethodData<void()>(74, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'denoiseLightmap'
        QtMocHelpers::RevisionedMethodData<void()>(75, 6, QMC::AccessPublic, 0x60a, QMetaType::Void),
        // Method 'rebuildExtensionList'
        QtMocHelpers::RevisionedMethodData<void()>(76, 6, QMC::AccessPublic, 0x607, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'data'
        QtMocHelpers::PropertyData<QQmlListProperty<QObject>>(2, 0x80000000 | 77, QMC::Readable | QMC::Scriptable | QMC::Stored | QMC::EnumOrFlag | QMC::Final),
        // property 'camera'
        QtMocHelpers::PropertyData<QQuick3DCamera*>(18, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 0),
        // property 'environment'
        QtMocHelpers::PropertyData<QQuick3DSceneEnvironment*>(21, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 1),
        // property 'scene'
        QtMocHelpers::PropertyData<QQuick3DNode*>(78, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'importScene'
        QtMocHelpers::PropertyData<QQuick3DNode*>(79, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 3),
        // property 'renderMode'
        QtMocHelpers::PropertyData<enum RenderMode>(27, 0x80000000 | 80, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 4),
        // property 'renderFormat'
        QtMocHelpers::PropertyData<QQuickShaderEffectSource::Format>(81, 0x80000000 | 29, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 5, 0x604),
        // property 'renderStats'
        QtMocHelpers::PropertyData<QQuick3DRenderStats*>(82, 0x80000000 | 83, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'extensions'
        QtMocHelpers::PropertyData<QQmlListProperty<QQuick3DObject>>(84, 0x80000000 | 85, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, -1, 0x606),
        // property 'explicitTextureWidth'
        QtMocHelpers::PropertyData<int>(86, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 6, 0x607),
        // property 'explicitTextureHeight'
        QtMocHelpers::PropertyData<int>(87, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 7, 0x607),
        // property 'effectiveTextureSize'
        QtMocHelpers::PropertyData<QSize>(88, 0x80000000 | 89, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 8, 0x607),
        // property 'renderOverrides'
        QtMocHelpers::PropertyData<RenderOverrides>(90, 0x80000000 | 91, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 9, 0x60b),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'RenderMode'
        QtMocHelpers::EnumData<enum RenderMode>(80, 80, QMC::EnumFlags{}).add({
            {   92, RenderMode::Offscreen },
            {   93, RenderMode::Underlay },
            {   94, RenderMode::Overlay },
            {   95, RenderMode::Inline },
        }),
        // enum 'RenderOverride'
        QtMocHelpers::EnumData<enum RenderOverride>(96, 96, QMC::EnumIsScoped).add({
            {   97, RenderOverride::None },
            {   98, RenderOverride::DisableInternalPasses },
        }),
        // flag 'RenderOverrides'
        QtMocHelpers::EnumData<RenderOverrides>(91, 96, QMC::EnumIsFlag | QMC::EnumIsScoped).add({
            {   97, RenderOverride::None },
            {   98, RenderOverride::DisableInternalPasses },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DViewport, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN16QQuick3DViewportE[] = {
    QMetaObject::SuperData::link<QQuickShaderEffectSource::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject QQuick3DViewport::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16QQuick3DViewportE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16QQuick3DViewportE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN16QQuick3DViewportE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16QQuick3DViewportE_t>.metaTypes,
    nullptr
} };

void QQuick3DViewport::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DViewport *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->cameraChanged(); break;
        case 1: _t->environmentChanged(); break;
        case 2: _t->sceneChanged(); break;
        case 3: _t->importSceneChanged(); break;
        case 4: _t->renderModeChanged(); break;
        case 5: _t->renderFormatChanged(); break;
        case 6: _t->explicitTextureWidthChanged(); break;
        case 7: _t->explicitTextureHeightChanged(); break;
        case 8: _t->effectiveTextureSizeChanged(); break;
        case 9: _t->renderOverridesChanged(); break;
        case 10: _t->setCamera((*reinterpret_cast<std::add_pointer_t<QQuick3DCamera*>>(_a[1]))); break;
        case 11: _t->setEnvironment((*reinterpret_cast<std::add_pointer_t<QQuick3DSceneEnvironment*>>(_a[1]))); break;
        case 12: _t->setImportScene((*reinterpret_cast<std::add_pointer_t<QQuick3DNode*>>(_a[1]))); break;
        case 13: _t->setRenderMode((*reinterpret_cast<std::add_pointer_t<QQuick3DViewport::RenderMode>>(_a[1]))); break;
        case 14: _t->setRenderFormat((*reinterpret_cast<std::add_pointer_t<QQuickShaderEffectSource::Format>>(_a[1]))); break;
        case 15: _t->setExplicitTextureWidth((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 16: _t->setExplicitTextureHeight((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 17: _t->cleanupDirectRenderer(); break;
        case 18: _t->setGlobalPickingEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 19: _t->invalidateSceneGraph(); break;
        case 20: _t->updateInputProcessing(); break;
        case 21: _t->onReleaseCachedResources(); break;
        case 22: { QVector3D _r = _t->mapFrom3DScene((*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVector3D*>(_a[0]) = std::move(_r); }  break;
        case 23: { QVector3D _r = _t->mapTo3DScene((*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVector3D*>(_a[0]) = std::move(_r); }  break;
        case 24: { QQuick3DPickResult _r = _t->pick((*reinterpret_cast<std::add_pointer_t<float>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<float>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QQuick3DPickResult*>(_a[0]) = std::move(_r); }  break;
        case 25: { QQuick3DPickResult _r = _t->pick((*reinterpret_cast<std::add_pointer_t<float>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<float>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QQuick3DModel*>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QQuick3DPickResult*>(_a[0]) = std::move(_r); }  break;
        case 26: { QList<QQuick3DPickResult> _r = _t->pickSubset((*reinterpret_cast<std::add_pointer_t<float>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<float>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QList<QQuick3DPickResult>*>(_a[0]) = std::move(_r); }  break;
        case 27: { QList<QQuick3DPickResult> _r = _t->pickAll((*reinterpret_cast<std::add_pointer_t<float>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<float>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QList<QQuick3DPickResult>*>(_a[0]) = std::move(_r); }  break;
        case 28: { QQuick3DPickResult _r = _t->rayPick((*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QQuick3DPickResult*>(_a[0]) = std::move(_r); }  break;
        case 29: { QList<QQuick3DPickResult> _r = _t->rayPickAll((*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QList<QQuick3DPickResult>*>(_a[0]) = std::move(_r); }  break;
        case 30: { QQuick3DPickResult _r = _t->rayPick((*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QQuick3DModel*>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QQuick3DPickResult*>(_a[0]) = std::move(_r); }  break;
        case 31: { QQuick3DPickResult _r = _t->closestPointPick((*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<float>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QQuick3DModel*>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QQuick3DPickResult*>(_a[0]) = std::move(_r); }  break;
        case 32: { QQuick3DPickResult _r = _t->closestPointPick((*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<float>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QQuick3DPickResult*>(_a[0]) = std::move(_r); }  break;
        case 33: { QList<QQuick3DObject*> _r = _t->pickInRect((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QList<QQuick3DObject*>*>(_a[0]) = std::move(_r); }  break;
        case 34: _t->setTouchpoint((*reinterpret_cast<std::add_pointer_t<QQuickItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 35: _t->bakeLightmap(); break;
        case 36: _t->denoiseLightmap(); break;
        case 37: _t->rebuildExtensionList(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DSceneEnvironment* >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DNode* >(); break;
            }
            break;
        case 25:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DModel* >(); break;
            }
            break;
        case 26:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 30:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DModel* >(); break;
            }
            break;
        case 31:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DModel* >(); break;
            }
            break;
        case 34:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuickItem* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuick3DViewport::*)()>(_a, &QQuick3DViewport::cameraChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DViewport::*)()>(_a, &QQuick3DViewport::environmentChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DViewport::*)()>(_a, &QQuick3DViewport::sceneChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DViewport::*)()>(_a, &QQuick3DViewport::importSceneChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DViewport::*)()>(_a, &QQuick3DViewport::renderModeChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DViewport::*)()>(_a, &QQuick3DViewport::renderFormatChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DViewport::*)()>(_a, &QQuick3DViewport::explicitTextureWidthChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DViewport::*)()>(_a, &QQuick3DViewport::explicitTextureHeightChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DViewport::*)()>(_a, &QQuick3DViewport::effectiveTextureSizeChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DViewport::*)()>(_a, &QQuick3DViewport::renderOverridesChanged, 9))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 8:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQmlListProperty<QQuick3DObject> >(); break;
        case 4:
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuick3DNode* >(); break;
        case 7:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuick3DRenderStats* >(); break;
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuick3DSceneEnvironment* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QQmlListProperty<QObject>*>(_v) = _t->data(); break;
        case 1: *reinterpret_cast<QQuick3DCamera**>(_v) = _t->camera(); break;
        case 2: *reinterpret_cast<QQuick3DSceneEnvironment**>(_v) = _t->environment(); break;
        case 3: *reinterpret_cast<QQuick3DNode**>(_v) = _t->scene(); break;
        case 4: *reinterpret_cast<QQuick3DNode**>(_v) = _t->importScene(); break;
        case 5: *reinterpret_cast<enum RenderMode*>(_v) = _t->renderMode(); break;
        case 6: *reinterpret_cast<QQuickShaderEffectSource::Format*>(_v) = _t->renderFormat(); break;
        case 7: *reinterpret_cast<QQuick3DRenderStats**>(_v) = _t->renderStats(); break;
        case 8: *reinterpret_cast<QQmlListProperty<QQuick3DObject>*>(_v) = _t->extensions(); break;
        case 9: *reinterpret_cast<int*>(_v) = _t->explicitTextureWidth(); break;
        case 10: *reinterpret_cast<int*>(_v) = _t->explicitTextureHeight(); break;
        case 11: *reinterpret_cast<QSize*>(_v) = _t->effectiveTextureSize(); break;
        case 12: QtMocHelpers::assignFlags<RenderOverrides>(_v, _t->renderOverrides()); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setCamera(*reinterpret_cast<QQuick3DCamera**>(_v)); break;
        case 2: _t->setEnvironment(*reinterpret_cast<QQuick3DSceneEnvironment**>(_v)); break;
        case 4: _t->setImportScene(*reinterpret_cast<QQuick3DNode**>(_v)); break;
        case 5: _t->setRenderMode(*reinterpret_cast<enum RenderMode*>(_v)); break;
        case 6: _t->setRenderFormat(*reinterpret_cast<QQuickShaderEffectSource::Format*>(_v)); break;
        case 9: _t->setExplicitTextureWidth(*reinterpret_cast<int*>(_v)); break;
        case 10: _t->setExplicitTextureHeight(*reinterpret_cast<int*>(_v)); break;
        case 12: _t->setRenderOverrides(*reinterpret_cast<RenderOverrides*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DViewport::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DViewport::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16QQuick3DViewportE_t>.strings))
        return static_cast<void*>(this);
    return QQuickItem::qt_metacast(_clname);
}

int QQuick3DViewport::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 38)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 38;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 38)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 38;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void QQuick3DViewport::cameraChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QQuick3DViewport::environmentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QQuick3DViewport::sceneChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QQuick3DViewport::importSceneChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QQuick3DViewport::renderModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QQuick3DViewport::renderFormatChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QQuick3DViewport::explicitTextureWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void QQuick3DViewport::explicitTextureHeightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void QQuick3DViewport::effectiveTextureSizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void QQuick3DViewport::renderOverridesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}
QT_WARNING_POP
