/****************************************************************************
** Meta object code from reading C++ file 'qquick3dparticleattractor_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtquick3d/src/quick3dparticles/qquick3dparticleattractor_p.h"
#include <QtGui/qtextcursor.h>
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquick3dparticleattractor_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN25QQuick3DParticleAttractorE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DParticleAttractor::qt_create_metaobjectdata<qt_meta_tag_ZN25QQuick3DParticleAttractorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DParticleAttractor",
        "QML.Element",
        "Attractor3D",
        "QML.AddedInVersion",
        "1538",
        "positionVariationChanged",
        "",
        "shapeChanged",
        "durationChanged",
        "durationVariationChanged",
        "hideAtEndChanged",
        "useCachedPositionsChanged",
        "positionsAmountChanged",
        "setPositionVariation",
        "QVector3D",
        "positionVariation",
        "setShape",
        "QQuick3DParticleAbstractShape*",
        "shape",
        "setDuration",
        "duration",
        "setDurationVariation",
        "durationVariation",
        "setHideAtEnd",
        "hideAtEnd",
        "setUseCachedPositions",
        "useCachedPositions",
        "setPositionsAmount",
        "positionsAmount"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'positionVariationChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'shapeChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'durationChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'durationVariationChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hideAtEndChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'useCachedPositionsChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'positionsAmountChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setPositionVariation'
        QtMocHelpers::SlotData<void(const QVector3D &)>(13, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Slot 'setShape'
        QtMocHelpers::SlotData<void(QQuick3DParticleAbstractShape *)>(16, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'setDuration'
        QtMocHelpers::SlotData<void(int)>(19, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 20 },
        }}),
        // Slot 'setDurationVariation'
        QtMocHelpers::SlotData<void(int)>(21, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 22 },
        }}),
        // Slot 'setHideAtEnd'
        QtMocHelpers::SlotData<void(bool)>(23, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 24 },
        }}),
        // Slot 'setUseCachedPositions'
        QtMocHelpers::SlotData<void(bool)>(25, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 26 },
        }}),
        // Slot 'setPositionsAmount'
        QtMocHelpers::SlotData<void(int)>(27, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 28 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'positionVariation'
        QtMocHelpers::PropertyData<QVector3D>(15, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'shape'
        QtMocHelpers::PropertyData<QQuick3DParticleAbstractShape*>(18, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'duration'
        QtMocHelpers::PropertyData<int>(20, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'durationVariation'
        QtMocHelpers::PropertyData<int>(22, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'hideAtEnd'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'useCachedPositions'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'positionsAmount'
        QtMocHelpers::PropertyData<int>(28, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DParticleAttractor, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DParticleAttractor::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuick3DParticleAffector::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25QQuick3DParticleAttractorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25QQuick3DParticleAttractorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN25QQuick3DParticleAttractorE_t>.metaTypes,
    nullptr
} };

void QQuick3DParticleAttractor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DParticleAttractor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->positionVariationChanged(); break;
        case 1: _t->shapeChanged(); break;
        case 2: _t->durationChanged(); break;
        case 3: _t->durationVariationChanged(); break;
        case 4: _t->hideAtEndChanged(); break;
        case 5: _t->useCachedPositionsChanged(); break;
        case 6: _t->positionsAmountChanged(); break;
        case 7: _t->setPositionVariation((*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[1]))); break;
        case 8: _t->setShape((*reinterpret_cast<std::add_pointer_t<QQuick3DParticleAbstractShape*>>(_a[1]))); break;
        case 9: _t->setDuration((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->setDurationVariation((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->setHideAtEnd((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->setUseCachedPositions((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->setPositionsAmount((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DParticleAbstractShape* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleAttractor::*)()>(_a, &QQuick3DParticleAttractor::positionVariationChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleAttractor::*)()>(_a, &QQuick3DParticleAttractor::shapeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleAttractor::*)()>(_a, &QQuick3DParticleAttractor::durationChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleAttractor::*)()>(_a, &QQuick3DParticleAttractor::durationVariationChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleAttractor::*)()>(_a, &QQuick3DParticleAttractor::hideAtEndChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleAttractor::*)()>(_a, &QQuick3DParticleAttractor::useCachedPositionsChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleAttractor::*)()>(_a, &QQuick3DParticleAttractor::positionsAmountChanged, 6))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuick3DParticleAbstractShape* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QVector3D*>(_v) = _t->positionVariation(); break;
        case 1: *reinterpret_cast<QQuick3DParticleAbstractShape**>(_v) = _t->shape(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->duration(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->durationVariation(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->hideAtEnd(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->useCachedPositions(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->positionsAmount(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setPositionVariation(*reinterpret_cast<QVector3D*>(_v)); break;
        case 1: _t->setShape(*reinterpret_cast<QQuick3DParticleAbstractShape**>(_v)); break;
        case 2: _t->setDuration(*reinterpret_cast<int*>(_v)); break;
        case 3: _t->setDurationVariation(*reinterpret_cast<int*>(_v)); break;
        case 4: _t->setHideAtEnd(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setUseCachedPositions(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setPositionsAmount(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DParticleAttractor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DParticleAttractor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25QQuick3DParticleAttractorE_t>.strings))
        return static_cast<void*>(this);
    return QQuick3DParticleAffector::qt_metacast(_clname);
}

int QQuick3DParticleAttractor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuick3DParticleAffector::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void QQuick3DParticleAttractor::positionVariationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QQuick3DParticleAttractor::shapeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QQuick3DParticleAttractor::durationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QQuick3DParticleAttractor::durationVariationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QQuick3DParticleAttractor::hideAtEndChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QQuick3DParticleAttractor::useCachedPositionsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QQuick3DParticleAttractor::positionsAmountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
