/****************************************************************************
** Meta object code from reading C++ file 'qquick3dtexture_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtquick3d/src/quick3d/qquick3dtexture_p.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquick3dtexture_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15QQuick3DTextureE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DTexture::qt_create_metaobjectdata<qt_meta_tag_ZN15QQuick3DTextureE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DTexture",
        "QML.Element",
        "Texture",
        "sourceChanged",
        "",
        "sourceItemChanged",
        "scaleUChanged",
        "scaleVChanged",
        "mappingModeChanged",
        "horizontalTilingChanged",
        "verticalTilingChanged",
        "depthTilingChanged",
        "rotationUVChanged",
        "positionUChanged",
        "positionVChanged",
        "pivotUChanged",
        "pivotVChanged",
        "flipUChanged",
        "flipVChanged",
        "indexUVChanged",
        "magFilterChanged",
        "minFilterChanged",
        "mipFilterChanged",
        "textureDataChanged",
        "generateMipmapsChanged",
        "autoOrientationChanged",
        "textureProviderChanged",
        "setSource",
        "QUrl",
        "source",
        "setSourceItem",
        "QQuickItem*",
        "sourceItem",
        "setScaleU",
        "scaleU",
        "setScaleV",
        "scaleV",
        "setMappingMode",
        "QQuick3DTexture::MappingMode",
        "mappingMode",
        "setHorizontalTiling",
        "QQuick3DTexture::TilingMode",
        "tilingModeHorizontal",
        "setVerticalTiling",
        "tilingModeVertical",
        "setDepthTiling",
        "tilingModeDepth",
        "setRotationUV",
        "rotationUV",
        "setPositionU",
        "positionU",
        "setPositionV",
        "positionV",
        "setPivotU",
        "pivotU",
        "setPivotV",
        "pivotV",
        "setFlipU",
        "flipU",
        "setFlipV",
        "flipV",
        "setIndexUV",
        "indexUV",
        "setMagFilter",
        "QQuick3DTexture::Filter",
        "magFilter",
        "setMinFilter",
        "minFilter",
        "setMipFilter",
        "mipFilter",
        "setTextureData",
        "QQuick3DTextureData*",
        "textureData",
        "setGenerateMipmaps",
        "generateMipmaps",
        "setAutoOrientation",
        "autoOrientation",
        "sourceItemDestroyed",
        "item",
        "sourceItemWindowChanged",
        "QQuickWindow*",
        "window",
        "textureProvider",
        "QQuick3DRenderExtension*",
        "MappingMode",
        "TilingMode",
        "Filter",
        "UV",
        "Environment",
        "LightProbe",
        "ClampToEdge",
        "MirroredRepeat",
        "Repeat",
        "None",
        "Nearest",
        "Linear"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sourceChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sourceItemChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scaleUChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scaleVChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mappingModeChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'horizontalTilingChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'verticalTilingChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'depthTilingChanged'
        QtMocHelpers::RevisionedSignalData<void()>(11, 4, QMC::AccessPublic, 0x607, QMetaType::Void),
        // Signal 'rotationUVChanged'
        QtMocHelpers::SignalData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'positionUChanged'
        QtMocHelpers::SignalData<void()>(13, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'positionVChanged'
        QtMocHelpers::SignalData<void()>(14, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pivotUChanged'
        QtMocHelpers::SignalData<void()>(15, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pivotVChanged'
        QtMocHelpers::SignalData<void()>(16, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'flipUChanged'
        QtMocHelpers::SignalData<void()>(17, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'flipVChanged'
        QtMocHelpers::SignalData<void()>(18, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'indexUVChanged'
        QtMocHelpers::SignalData<void()>(19, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'magFilterChanged'
        QtMocHelpers::SignalData<void()>(20, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'minFilterChanged'
        QtMocHelpers::SignalData<void()>(21, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mipFilterChanged'
        QtMocHelpers::SignalData<void()>(22, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'textureDataChanged'
        QtMocHelpers::SignalData<void()>(23, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'generateMipmapsChanged'
        QtMocHelpers::SignalData<void()>(24, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'autoOrientationChanged'
        QtMocHelpers::SignalData<void()>(25, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'textureProviderChanged'
        QtMocHelpers::RevisionedSignalData<void()>(26, 4, QMC::AccessPublic, 0x607, QMetaType::Void),
        // Slot 'setSource'
        QtMocHelpers::SlotData<void(const QUrl &)>(27, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 28, 29 },
        }}),
        // Slot 'setSourceItem'
        QtMocHelpers::SlotData<void(QQuickItem *)>(30, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 31, 32 },
        }}),
        // Slot 'setScaleU'
        QtMocHelpers::SlotData<void(float)>(33, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 34 },
        }}),
        // Slot 'setScaleV'
        QtMocHelpers::SlotData<void(float)>(35, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 36 },
        }}),
        // Slot 'setMappingMode'
        QtMocHelpers::SlotData<void(QQuick3DTexture::MappingMode)>(37, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 38, 39 },
        }}),
        // Slot 'setHorizontalTiling'
        QtMocHelpers::SlotData<void(QQuick3DTexture::TilingMode)>(40, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 41, 42 },
        }}),
        // Slot 'setVerticalTiling'
        QtMocHelpers::SlotData<void(QQuick3DTexture::TilingMode)>(43, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 41, 44 },
        }}),
        // Slot 'setDepthTiling'
        QtMocHelpers::RevisionedSlotData<void(QQuick3DTexture::TilingMode)>(45, 4, QMC::AccessPublic, 0x607, QMetaType::Void, {{
            { 0x80000000 | 41, 46 },
        }}),
        // Slot 'setRotationUV'
        QtMocHelpers::SlotData<void(float)>(47, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 48 },
        }}),
        // Slot 'setPositionU'
        QtMocHelpers::SlotData<void(float)>(49, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 50 },
        }}),
        // Slot 'setPositionV'
        QtMocHelpers::SlotData<void(float)>(51, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 52 },
        }}),
        // Slot 'setPivotU'
        QtMocHelpers::SlotData<void(float)>(53, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 54 },
        }}),
        // Slot 'setPivotV'
        QtMocHelpers::SlotData<void(float)>(55, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 56 },
        }}),
        // Slot 'setFlipU'
        QtMocHelpers::SlotData<void(bool)>(57, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 58 },
        }}),
        // Slot 'setFlipV'
        QtMocHelpers::SlotData<void(bool)>(59, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 60 },
        }}),
        // Slot 'setIndexUV'
        QtMocHelpers::SlotData<void(int)>(61, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 62 },
        }}),
        // Slot 'setMagFilter'
        QtMocHelpers::SlotData<void(QQuick3DTexture::Filter)>(63, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 64, 65 },
        }}),
        // Slot 'setMinFilter'
        QtMocHelpers::SlotData<void(QQuick3DTexture::Filter)>(66, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 64, 67 },
        }}),
        // Slot 'setMipFilter'
        QtMocHelpers::SlotData<void(QQuick3DTexture::Filter)>(68, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 64, 69 },
        }}),
        // Slot 'setTextureData'
        QtMocHelpers::SlotData<void(QQuick3DTextureData *)>(70, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 71, 72 },
        }}),
        // Slot 'setGenerateMipmaps'
        QtMocHelpers::SlotData<void(bool)>(73, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 74 },
        }}),
        // Slot 'setAutoOrientation'
        QtMocHelpers::SlotData<void(bool)>(75, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 76 },
        }}),
        // Slot 'sourceItemDestroyed'
        QtMocHelpers::SlotData<void(QObject *)>(77, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QObjectStar, 78 },
        }}),
        // Slot 'sourceItemWindowChanged'
        QtMocHelpers::SlotData<void(QQuickWindow *)>(79, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 80, 81 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'source'
        QtMocHelpers::PropertyData<QUrl>(29, 0x80000000 | 28, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'sourceItem'
        QtMocHelpers::PropertyData<QQuickItem*>(32, 0x80000000 | 31, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'textureData'
        QtMocHelpers::PropertyData<QQuick3DTextureData*>(72, 0x80000000 | 71, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 19),
        // property 'textureProvider'
        QtMocHelpers::PropertyData<QQuick3DRenderExtension*>(82, 0x80000000 | 83, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 22, 0x607),
        // property 'scaleU'
        QtMocHelpers::PropertyData<float>(34, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'scaleV'
        QtMocHelpers::PropertyData<float>(36, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'mappingMode'
        QtMocHelpers::PropertyData<enum MappingMode>(39, 0x80000000 | 84, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 4),
        // property 'tilingModeHorizontal'
        QtMocHelpers::PropertyData<enum TilingMode>(42, 0x80000000 | 85, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 5),
        // property 'tilingModeVertical'
        QtMocHelpers::PropertyData<enum TilingMode>(44, 0x80000000 | 85, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 6),
        // property 'tilingModeDepth'
        QtMocHelpers::PropertyData<enum TilingMode>(46, 0x80000000 | 85, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 7, 0x607),
        // property 'rotationUV'
        QtMocHelpers::PropertyData<float>(48, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'positionU'
        QtMocHelpers::PropertyData<float>(50, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'positionV'
        QtMocHelpers::PropertyData<float>(52, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'pivotU'
        QtMocHelpers::PropertyData<float>(54, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'pivotV'
        QtMocHelpers::PropertyData<float>(56, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'flipU'
        QtMocHelpers::PropertyData<bool>(58, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13),
        // property 'flipV'
        QtMocHelpers::PropertyData<bool>(60, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 14),
        // property 'indexUV'
        QtMocHelpers::PropertyData<int>(62, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 15),
        // property 'magFilter'
        QtMocHelpers::PropertyData<enum Filter>(65, 0x80000000 | 86, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 16),
        // property 'minFilter'
        QtMocHelpers::PropertyData<enum Filter>(67, 0x80000000 | 86, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 17),
        // property 'mipFilter'
        QtMocHelpers::PropertyData<enum Filter>(69, 0x80000000 | 86, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 18),
        // property 'generateMipmaps'
        QtMocHelpers::PropertyData<bool>(74, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 20),
        // property 'autoOrientation'
        QtMocHelpers::PropertyData<bool>(76, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 21, 0x602),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'MappingMode'
        QtMocHelpers::EnumData<enum MappingMode>(84, 84, QMC::EnumFlags{}).add({
            {   87, MappingMode::UV },
            {   88, MappingMode::Environment },
            {   89, MappingMode::LightProbe },
        }),
        // enum 'TilingMode'
        QtMocHelpers::EnumData<enum TilingMode>(85, 85, QMC::EnumFlags{}).add({
            {   90, TilingMode::ClampToEdge },
            {   91, TilingMode::MirroredRepeat },
            {   92, TilingMode::Repeat },
        }),
        // enum 'Filter'
        QtMocHelpers::EnumData<enum Filter>(86, 86, QMC::EnumFlags{}).add({
            {   93, Filter::None },
            {   94, Filter::Nearest },
            {   95, Filter::Linear },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DTexture, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DTexture::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuick3DObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15QQuick3DTextureE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15QQuick3DTextureE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15QQuick3DTextureE_t>.metaTypes,
    nullptr
} };

void QQuick3DTexture::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DTexture *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sourceChanged(); break;
        case 1: _t->sourceItemChanged(); break;
        case 2: _t->scaleUChanged(); break;
        case 3: _t->scaleVChanged(); break;
        case 4: _t->mappingModeChanged(); break;
        case 5: _t->horizontalTilingChanged(); break;
        case 6: _t->verticalTilingChanged(); break;
        case 7: _t->depthTilingChanged(); break;
        case 8: _t->rotationUVChanged(); break;
        case 9: _t->positionUChanged(); break;
        case 10: _t->positionVChanged(); break;
        case 11: _t->pivotUChanged(); break;
        case 12: _t->pivotVChanged(); break;
        case 13: _t->flipUChanged(); break;
        case 14: _t->flipVChanged(); break;
        case 15: _t->indexUVChanged(); break;
        case 16: _t->magFilterChanged(); break;
        case 17: _t->minFilterChanged(); break;
        case 18: _t->mipFilterChanged(); break;
        case 19: _t->textureDataChanged(); break;
        case 20: _t->generateMipmapsChanged(); break;
        case 21: _t->autoOrientationChanged(); break;
        case 22: _t->textureProviderChanged(); break;
        case 23: _t->setSource((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 24: _t->setSourceItem((*reinterpret_cast<std::add_pointer_t<QQuickItem*>>(_a[1]))); break;
        case 25: _t->setScaleU((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 26: _t->setScaleV((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 27: _t->setMappingMode((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture::MappingMode>>(_a[1]))); break;
        case 28: _t->setHorizontalTiling((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture::TilingMode>>(_a[1]))); break;
        case 29: _t->setVerticalTiling((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture::TilingMode>>(_a[1]))); break;
        case 30: _t->setDepthTiling((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture::TilingMode>>(_a[1]))); break;
        case 31: _t->setRotationUV((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 32: _t->setPositionU((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 33: _t->setPositionV((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 34: _t->setPivotU((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 35: _t->setPivotV((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 36: _t->setFlipU((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 37: _t->setFlipV((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 38: _t->setIndexUV((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 39: _t->setMagFilter((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture::Filter>>(_a[1]))); break;
        case 40: _t->setMinFilter((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture::Filter>>(_a[1]))); break;
        case 41: _t->setMipFilter((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture::Filter>>(_a[1]))); break;
        case 42: _t->setTextureData((*reinterpret_cast<std::add_pointer_t<QQuick3DTextureData*>>(_a[1]))); break;
        case 43: _t->setGenerateMipmaps((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 44: _t->setAutoOrientation((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 45: _t->sourceItemDestroyed((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        case 46: _t->sourceItemWindowChanged((*reinterpret_cast<std::add_pointer_t<QQuickWindow*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 24:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuickItem* >(); break;
            }
            break;
        case 42:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTextureData* >(); break;
            }
            break;
        case 46:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuickWindow* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuick3DTexture::*)()>(_a, &QQuick3DTexture::sourceChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DTexture::*)()>(_a, &QQuick3DTexture::sourceItemChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DTexture::*)()>(_a, &QQuick3DTexture::scaleUChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DTexture::*)()>(_a, &QQuick3DTexture::scaleVChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DTexture::*)()>(_a, &QQuick3DTexture::mappingModeChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DTexture::*)()>(_a, &QQuick3DTexture::horizontalTilingChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DTexture::*)()>(_a, &QQuick3DTexture::verticalTilingChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DTexture::*)()>(_a, &QQuick3DTexture::depthTilingChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DTexture::*)()>(_a, &QQuick3DTexture::rotationUVChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DTexture::*)()>(_a, &QQuick3DTexture::positionUChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DTexture::*)()>(_a, &QQuick3DTexture::positionVChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DTexture::*)()>(_a, &QQuick3DTexture::pivotUChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DTexture::*)()>(_a, &QQuick3DTexture::pivotVChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DTexture::*)()>(_a, &QQuick3DTexture::flipUChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DTexture::*)()>(_a, &QQuick3DTexture::flipVChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DTexture::*)()>(_a, &QQuick3DTexture::indexUVChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DTexture::*)()>(_a, &QQuick3DTexture::magFilterChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DTexture::*)()>(_a, &QQuick3DTexture::minFilterChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DTexture::*)()>(_a, &QQuick3DTexture::mipFilterChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DTexture::*)()>(_a, &QQuick3DTexture::textureDataChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DTexture::*)()>(_a, &QQuick3DTexture::generateMipmapsChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DTexture::*)()>(_a, &QQuick3DTexture::autoOrientationChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DTexture::*)()>(_a, &QQuick3DTexture::textureProviderChanged, 22))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuick3DTextureData* >(); break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuickItem* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QUrl*>(_v) = _t->source(); break;
        case 1: *reinterpret_cast<QQuickItem**>(_v) = _t->sourceItem(); break;
        case 2: *reinterpret_cast<QQuick3DTextureData**>(_v) = _t->textureData(); break;
        case 3: *reinterpret_cast<QQuick3DRenderExtension**>(_v) = _t->textureProvider(); break;
        case 4: *reinterpret_cast<float*>(_v) = _t->scaleU(); break;
        case 5: *reinterpret_cast<float*>(_v) = _t->scaleV(); break;
        case 6: *reinterpret_cast<enum MappingMode*>(_v) = _t->mappingMode(); break;
        case 7: *reinterpret_cast<enum TilingMode*>(_v) = _t->horizontalTiling(); break;
        case 8: *reinterpret_cast<enum TilingMode*>(_v) = _t->verticalTiling(); break;
        case 9: *reinterpret_cast<enum TilingMode*>(_v) = _t->depthTiling(); break;
        case 10: *reinterpret_cast<float*>(_v) = _t->rotationUV(); break;
        case 11: *reinterpret_cast<float*>(_v) = _t->positionU(); break;
        case 12: *reinterpret_cast<float*>(_v) = _t->positionV(); break;
        case 13: *reinterpret_cast<float*>(_v) = _t->pivotU(); break;
        case 14: *reinterpret_cast<float*>(_v) = _t->pivotV(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->flipU(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->flipV(); break;
        case 17: *reinterpret_cast<int*>(_v) = _t->indexUV(); break;
        case 18: *reinterpret_cast<enum Filter*>(_v) = _t->magFilter(); break;
        case 19: *reinterpret_cast<enum Filter*>(_v) = _t->minFilter(); break;
        case 20: *reinterpret_cast<enum Filter*>(_v) = _t->mipFilter(); break;
        case 21: *reinterpret_cast<bool*>(_v) = _t->generateMipmaps(); break;
        case 22: *reinterpret_cast<bool*>(_v) = _t->autoOrientation(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setSource(*reinterpret_cast<QUrl*>(_v)); break;
        case 1: _t->setSourceItem(*reinterpret_cast<QQuickItem**>(_v)); break;
        case 2: _t->setTextureData(*reinterpret_cast<QQuick3DTextureData**>(_v)); break;
        case 3: _t->setTextureProvider(*reinterpret_cast<QQuick3DRenderExtension**>(_v)); break;
        case 4: _t->setScaleU(*reinterpret_cast<float*>(_v)); break;
        case 5: _t->setScaleV(*reinterpret_cast<float*>(_v)); break;
        case 6: _t->setMappingMode(*reinterpret_cast<enum MappingMode*>(_v)); break;
        case 7: _t->setHorizontalTiling(*reinterpret_cast<enum TilingMode*>(_v)); break;
        case 8: _t->setVerticalTiling(*reinterpret_cast<enum TilingMode*>(_v)); break;
        case 9: _t->setDepthTiling(*reinterpret_cast<enum TilingMode*>(_v)); break;
        case 10: _t->setRotationUV(*reinterpret_cast<float*>(_v)); break;
        case 11: _t->setPositionU(*reinterpret_cast<float*>(_v)); break;
        case 12: _t->setPositionV(*reinterpret_cast<float*>(_v)); break;
        case 13: _t->setPivotU(*reinterpret_cast<float*>(_v)); break;
        case 14: _t->setPivotV(*reinterpret_cast<float*>(_v)); break;
        case 15: _t->setFlipU(*reinterpret_cast<bool*>(_v)); break;
        case 16: _t->setFlipV(*reinterpret_cast<bool*>(_v)); break;
        case 17: _t->setIndexUV(*reinterpret_cast<int*>(_v)); break;
        case 18: _t->setMagFilter(*reinterpret_cast<enum Filter*>(_v)); break;
        case 19: _t->setMinFilter(*reinterpret_cast<enum Filter*>(_v)); break;
        case 20: _t->setMipFilter(*reinterpret_cast<enum Filter*>(_v)); break;
        case 21: _t->setGenerateMipmaps(*reinterpret_cast<bool*>(_v)); break;
        case 22: _t->setAutoOrientation(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DTexture::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DTexture::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15QQuick3DTextureE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQuickItemChangeListener"))
        return static_cast< QQuickItemChangeListener*>(this);
    return QQuick3DObject::qt_metacast(_clname);
}

int QQuick3DTexture::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuick3DObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 47)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 47;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 47)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 47;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    }
    return _id;
}

// SIGNAL 0
void QQuick3DTexture::sourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QQuick3DTexture::sourceItemChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QQuick3DTexture::scaleUChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QQuick3DTexture::scaleVChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QQuick3DTexture::mappingModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QQuick3DTexture::horizontalTilingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QQuick3DTexture::verticalTilingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void QQuick3DTexture::depthTilingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void QQuick3DTexture::rotationUVChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void QQuick3DTexture::positionUChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void QQuick3DTexture::positionVChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void QQuick3DTexture::pivotUChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void QQuick3DTexture::pivotVChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void QQuick3DTexture::flipUChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void QQuick3DTexture::flipVChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void QQuick3DTexture::indexUVChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void QQuick3DTexture::magFilterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void QQuick3DTexture::minFilterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void QQuick3DTexture::mipFilterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void QQuick3DTexture::textureDataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void QQuick3DTexture::generateMipmapsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void QQuick3DTexture::autoOrientationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void QQuick3DTexture::textureProviderChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 22, nullptr);
}
QT_WARNING_POP
