/****************************************************************************
** Meta object code from reading C++ file 'qquick3dparticlespriteparticle_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtquick3d/src/quick3dparticles/qquick3dparticlespriteparticle_p.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquick3dparticlespriteparticle_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN30QQuick3DParticleSpriteParticleE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DParticleSpriteParticle::qt_create_metaobjectdata<qt_meta_tag_ZN30QQuick3DParticleSpriteParticleE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DParticleSpriteParticle",
        "QML.Element",
        "SpriteParticle3D",
        "QML.AddedInVersion",
        "1538",
        "blendModeChanged",
        "",
        "spriteChanged",
        "spriteSequenceChanged",
        "billboardChanged",
        "particleScaleChanged",
        "colorTableChanged",
        "lightsChanged",
        "offsetXChanged",
        "offsetYChanged",
        "castsReflectionsChanged",
        "setBlendMode",
        "QQuick3DParticleSpriteParticle::BlendMode",
        "blendMode",
        "setSprite",
        "QQuick3DTexture*",
        "sprite",
        "setSpriteSequence",
        "QQuick3DParticleSpriteSequence*",
        "spriteSequence",
        "setBillboard",
        "billboard",
        "setParticleScale",
        "scale",
        "setColorTable",
        "colorTable",
        "setOffsetX",
        "value",
        "setOffsetY",
        "setCastsReflections",
        "castsReflections",
        "onLightDestroyed",
        "object",
        "BlendMode",
        "particleScale",
        "lights",
        "QQmlListProperty<QQuick3DAbstractLight>",
        "offsetX",
        "offsetY",
        "SourceOver",
        "Screen",
        "Multiply"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'blendModeChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'spriteChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'spriteSequenceChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'billboardChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'particleScaleChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'colorTableChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lightsChanged'
        QtMocHelpers::RevisionedSignalData<void()>(12, 6, QMC::AccessPublic, 0x603, QMetaType::Void),
        // Signal 'offsetXChanged'
        QtMocHelpers::RevisionedSignalData<void()>(13, 6, QMC::AccessPublic, 0x603, QMetaType::Void),
        // Signal 'offsetYChanged'
        QtMocHelpers::RevisionedSignalData<void()>(14, 6, QMC::AccessPublic, 0x603, QMetaType::Void),
        // Signal 'castsReflectionsChanged'
        QtMocHelpers::RevisionedSignalData<void()>(15, 6, QMC::AccessPublic, 0x604, QMetaType::Void),
        // Slot 'setBlendMode'
        QtMocHelpers::SlotData<void(QQuick3DParticleSpriteParticle::BlendMode)>(16, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'setSprite'
        QtMocHelpers::SlotData<void(QQuick3DTexture *)>(19, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Slot 'setSpriteSequence'
        QtMocHelpers::SlotData<void(QQuick3DParticleSpriteSequence *)>(22, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 23, 24 },
        }}),
        // Slot 'setBillboard'
        QtMocHelpers::SlotData<void(bool)>(25, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 26 },
        }}),
        // Slot 'setParticleScale'
        QtMocHelpers::SlotData<void(float)>(27, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 28 },
        }}),
        // Slot 'setColorTable'
        QtMocHelpers::SlotData<void(QQuick3DTexture *)>(29, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 30 },
        }}),
        // Slot 'setOffsetX'
        QtMocHelpers::SlotData<void(float)>(31, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 32 },
        }}),
        // Slot 'setOffsetY'
        QtMocHelpers::SlotData<void(float)>(33, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 32 },
        }}),
        // Slot 'setCastsReflections'
        QtMocHelpers::RevisionedSlotData<void(bool)>(34, 6, QMC::AccessPublic, 0x604, QMetaType::Void, {{
            { QMetaType::Bool, 35 },
        }}),
        // Slot 'onLightDestroyed'
        QtMocHelpers::SlotData<void(QObject *)>(36, 6, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QObjectStar, 37 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'blendMode'
        QtMocHelpers::PropertyData<enum BlendMode>(18, 0x80000000 | 38, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'sprite'
        QtMocHelpers::PropertyData<QQuick3DTexture*>(21, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'spriteSequence'
        QtMocHelpers::PropertyData<QQuick3DParticleSpriteSequence*>(24, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'billboard'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'particleScale'
        QtMocHelpers::PropertyData<float>(39, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'colorTable'
        QtMocHelpers::PropertyData<QQuick3DTexture*>(30, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5),
        // property 'lights'
        QtMocHelpers::PropertyData<QQmlListProperty<QQuick3DAbstractLight>>(40, 0x80000000 | 41, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 6, 0x603),
        // property 'offsetX'
        QtMocHelpers::PropertyData<float>(42, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7, 0x603),
        // property 'offsetY'
        QtMocHelpers::PropertyData<float>(43, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8, 0x603),
        // property 'castsReflections'
        QtMocHelpers::PropertyData<bool>(35, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9, 0x604),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'BlendMode'
        QtMocHelpers::EnumData<enum BlendMode>(38, 38, QMC::EnumFlags{}).add({
            {   44, BlendMode::SourceOver },
            {   45, BlendMode::Screen },
            {   46, BlendMode::Multiply },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DParticleSpriteParticle, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DParticleSpriteParticle::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuick3DParticle::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN30QQuick3DParticleSpriteParticleE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN30QQuick3DParticleSpriteParticleE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN30QQuick3DParticleSpriteParticleE_t>.metaTypes,
    nullptr
} };

void QQuick3DParticleSpriteParticle::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DParticleSpriteParticle *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->blendModeChanged(); break;
        case 1: _t->spriteChanged(); break;
        case 2: _t->spriteSequenceChanged(); break;
        case 3: _t->billboardChanged(); break;
        case 4: _t->particleScaleChanged(); break;
        case 5: _t->colorTableChanged(); break;
        case 6: _t->lightsChanged(); break;
        case 7: _t->offsetXChanged(); break;
        case 8: _t->offsetYChanged(); break;
        case 9: _t->castsReflectionsChanged(); break;
        case 10: _t->setBlendMode((*reinterpret_cast<std::add_pointer_t<QQuick3DParticleSpriteParticle::BlendMode>>(_a[1]))); break;
        case 11: _t->setSprite((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 12: _t->setSpriteSequence((*reinterpret_cast<std::add_pointer_t<QQuick3DParticleSpriteSequence*>>(_a[1]))); break;
        case 13: _t->setBillboard((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 14: _t->setParticleScale((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 15: _t->setColorTable((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 16: _t->setOffsetX((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 17: _t->setOffsetY((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 18: _t->setCastsReflections((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 19: _t->onLightDestroyed((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DParticleSpriteSequence* >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleSpriteParticle::*)()>(_a, &QQuick3DParticleSpriteParticle::blendModeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleSpriteParticle::*)()>(_a, &QQuick3DParticleSpriteParticle::spriteChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleSpriteParticle::*)()>(_a, &QQuick3DParticleSpriteParticle::spriteSequenceChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleSpriteParticle::*)()>(_a, &QQuick3DParticleSpriteParticle::billboardChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleSpriteParticle::*)()>(_a, &QQuick3DParticleSpriteParticle::particleScaleChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleSpriteParticle::*)()>(_a, &QQuick3DParticleSpriteParticle::colorTableChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleSpriteParticle::*)()>(_a, &QQuick3DParticleSpriteParticle::lightsChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleSpriteParticle::*)()>(_a, &QQuick3DParticleSpriteParticle::offsetXChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleSpriteParticle::*)()>(_a, &QQuick3DParticleSpriteParticle::offsetYChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DParticleSpriteParticle::*)()>(_a, &QQuick3DParticleSpriteParticle::castsReflectionsChanged, 9))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuick3DParticleSpriteSequence* >(); break;
        case 5:
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuick3DTexture* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<enum BlendMode*>(_v) = _t->blendMode(); break;
        case 1: *reinterpret_cast<QQuick3DTexture**>(_v) = _t->sprite(); break;
        case 2: *reinterpret_cast<QQuick3DParticleSpriteSequence**>(_v) = _t->spriteSequence(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->billboard(); break;
        case 4: *reinterpret_cast<float*>(_v) = _t->particleScale(); break;
        case 5: *reinterpret_cast<QQuick3DTexture**>(_v) = _t->colorTable(); break;
        case 6: *reinterpret_cast<QQmlListProperty<QQuick3DAbstractLight>*>(_v) = _t->lights(); break;
        case 7: *reinterpret_cast<float*>(_v) = _t->offsetX(); break;
        case 8: *reinterpret_cast<float*>(_v) = _t->offsetY(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->castsReflections(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setBlendMode(*reinterpret_cast<enum BlendMode*>(_v)); break;
        case 1: _t->setSprite(*reinterpret_cast<QQuick3DTexture**>(_v)); break;
        case 2: _t->setSpriteSequence(*reinterpret_cast<QQuick3DParticleSpriteSequence**>(_v)); break;
        case 3: _t->setBillboard(*reinterpret_cast<bool*>(_v)); break;
        case 4: _t->setParticleScale(*reinterpret_cast<float*>(_v)); break;
        case 5: _t->setColorTable(*reinterpret_cast<QQuick3DTexture**>(_v)); break;
        case 7: _t->setOffsetX(*reinterpret_cast<float*>(_v)); break;
        case 8: _t->setOffsetY(*reinterpret_cast<float*>(_v)); break;
        case 9: _t->setCastsReflections(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DParticleSpriteParticle::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DParticleSpriteParticle::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN30QQuick3DParticleSpriteParticleE_t>.strings))
        return static_cast<void*>(this);
    return QQuick3DParticle::qt_metacast(_clname);
}

int QQuick3DParticleSpriteParticle::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuick3DParticle::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void QQuick3DParticleSpriteParticle::blendModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QQuick3DParticleSpriteParticle::spriteChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QQuick3DParticleSpriteParticle::spriteSequenceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QQuick3DParticleSpriteParticle::billboardChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QQuick3DParticleSpriteParticle::particleScaleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QQuick3DParticleSpriteParticle::colorTableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QQuick3DParticleSpriteParticle::lightsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void QQuick3DParticleSpriteParticle::offsetXChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void QQuick3DParticleSpriteParticle::offsetYChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void QQuick3DParticleSpriteParticle::castsReflectionsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}
QT_WARNING_POP
