/****************************************************************************
** Meta object code from reading C++ file 'qquick3druntimeloader_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtquick3d/src/assetutils/qquick3druntimeloader_p.h"
#include <QtGui/qtextcursor.h>
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquick3druntimeloader_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN21QQuick3DRuntimeLoaderE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DRuntimeLoader::qt_create_metaobjectdata<qt_meta_tag_ZN21QQuick3DRuntimeLoaderE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DRuntimeLoader",
        "QML.Element",
        "RuntimeLoader",
        "QML.AddedInVersion",
        "1538",
        "sourceChanged",
        "",
        "statusChanged",
        "errorStringChanged",
        "boundsChanged",
        "instancingChanged",
        "source",
        "QUrl",
        "status",
        "Status",
        "errorString",
        "bounds",
        "QQuick3DBounds3",
        "instancing",
        "QQuick3DInstancing*",
        "supportedExtensions",
        "supportedMimeTypes",
        "QList<QMimeType>",
        "Empty",
        "Success",
        "Error"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sourceChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'statusChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'errorStringChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'boundsChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'instancingChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'source'
        QtMocHelpers::PropertyData<QUrl>(11, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'status'
        QtMocHelpers::PropertyData<enum Status>(13, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'errorString'
        QtMocHelpers::PropertyData<QString>(15, QMetaType::QString, QMC::DefaultPropertyFlags, 2),
        // property 'bounds'
        QtMocHelpers::PropertyData<QQuick3DBounds3>(16, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 3),
        // property 'instancing'
        QtMocHelpers::PropertyData<QQuick3DInstancing*>(18, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 4),
        // property 'supportedExtensions'
        QtMocHelpers::PropertyData<QStringList>(20, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant, -1, 0x607),
        // property 'supportedMimeTypes'
        QtMocHelpers::PropertyData<QList<QMimeType>>(21, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant, -1, 0x607),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Status'
        QtMocHelpers::EnumData<enum Status>(14, 14, QMC::EnumIsScoped).add({
            {   23, Status::Empty },
            {   24, Status::Success },
            {   25, Status::Error },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DRuntimeLoader, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DRuntimeLoader::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuick3DNode::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21QQuick3DRuntimeLoaderE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21QQuick3DRuntimeLoaderE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21QQuick3DRuntimeLoaderE_t>.metaTypes,
    nullptr
} };

void QQuick3DRuntimeLoader::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DRuntimeLoader *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sourceChanged(); break;
        case 1: _t->statusChanged(); break;
        case 2: _t->errorStringChanged(); break;
        case 3: _t->boundsChanged(); break;
        case 4: _t->instancingChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuick3DRuntimeLoader::*)()>(_a, &QQuick3DRuntimeLoader::sourceChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DRuntimeLoader::*)()>(_a, &QQuick3DRuntimeLoader::statusChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DRuntimeLoader::*)()>(_a, &QQuick3DRuntimeLoader::errorStringChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DRuntimeLoader::*)()>(_a, &QQuick3DRuntimeLoader::boundsChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DRuntimeLoader::*)()>(_a, &QQuick3DRuntimeLoader::instancingChanged, 4))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuick3DBounds3 >(); break;
        case 4:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuick3DInstancing* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QUrl*>(_v) = _t->source(); break;
        case 1: *reinterpret_cast<enum Status*>(_v) = _t->status(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->errorString(); break;
        case 3: *reinterpret_cast<QQuick3DBounds3*>(_v) = _t->bounds(); break;
        case 4: *reinterpret_cast<QQuick3DInstancing**>(_v) = _t->instancing(); break;
        case 5: *reinterpret_cast<QStringList*>(_v) = _t->supportedExtensions(); break;
        case 6: *reinterpret_cast<QList<QMimeType>*>(_v) = _t->supportedMimeTypes(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setSource(*reinterpret_cast<QUrl*>(_v)); break;
        case 4: _t->setInstancing(*reinterpret_cast<QQuick3DInstancing**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DRuntimeLoader::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DRuntimeLoader::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21QQuick3DRuntimeLoaderE_t>.strings))
        return static_cast<void*>(this);
    return QQuick3DNode::qt_metacast(_clname);
}

int QQuick3DRuntimeLoader::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuick3DNode::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void QQuick3DRuntimeLoader::sourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QQuick3DRuntimeLoader::statusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QQuick3DRuntimeLoader::errorStringChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QQuick3DRuntimeLoader::boundsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QQuick3DRuntimeLoader::instancingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
