/****************************************************************************
** Meta object code from reading C++ file 'qquick3dmodel_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtquick3d/src/quick3d/qquick3dmodel_p.h"
#include <QtGui/qtextcursor.h>
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquick3dmodel_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15QQuick3DBounds3E_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DBounds3::qt_create_metaobjectdata<qt_meta_tag_ZN15QQuick3DBounds3E_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DBounds3",
        "QML.Element",
        "bounds",
        "minimum",
        "QVector3D",
        "maximum"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'minimum'
        QtMocHelpers::PropertyData<QVector3D>(3, 0x80000000 | 4, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'maximum'
        QtMocHelpers::PropertyData<QVector3D>(5, 0x80000000 | 4, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DBounds3, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DBounds3::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15QQuick3DBounds3E_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15QQuick3DBounds3E_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15QQuick3DBounds3E_t>.metaTypes,
    nullptr
} };

void QQuick3DBounds3::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<QQuick3DBounds3 *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QVector3D*>(_v) = _t->minimum(); break;
        case 1: *reinterpret_cast<QVector3D*>(_v) = _t->maximum(); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN13QQuick3DModelE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DModel::qt_create_metaobjectdata<qt_meta_tag_ZN13QQuick3DModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DModel",
        "QML.Element",
        "Model",
        "sourceChanged",
        "",
        "castsShadowsChanged",
        "receivesShadowsChanged",
        "pickableChanged",
        "geometryChanged",
        "skeletonChanged",
        "inverseBindPosesChanged",
        "boundsChanged",
        "instancingChanged",
        "instanceRootChanged",
        "morphTargetsChanged",
        "depthBiasChanged",
        "receivesReflectionsChanged",
        "castsReflectionsChanged",
        "skinChanged",
        "usedInBakedLightingChanged",
        "lightmapBaseResolutionChanged",
        "bakedLightmapChanged",
        "instancingLodMinChanged",
        "instancingLodMaxChanged",
        "levelOfDetailBiasChanged",
        "texelsPerUnitChanged",
        "motionVectorEnabledChanged",
        "motionVectorScaleChanged",
        "setSource",
        "QUrl",
        "source",
        "setCastsShadows",
        "castsShadows",
        "setReceivesShadows",
        "receivesShadows",
        "setPickable",
        "pickable",
        "setGeometry",
        "QQuick3DGeometry*",
        "geometry",
        "setSkeleton",
        "QQuick3DSkeleton*",
        "skeleton",
        "setInverseBindPoses",
        "QList<QMatrix4x4>",
        "poses",
        "setBounds",
        "QVector3D",
        "min",
        "max",
        "setInstancing",
        "QQuick3DInstancing*",
        "instancing",
        "setInstanceRoot",
        "QQuick3DNode*",
        "instanceRoot",
        "setDepthBias",
        "bias",
        "setReceivesReflections",
        "receivesReflections",
        "setCastsReflections",
        "castsReflections",
        "setSkin",
        "QQuick3DSkin*",
        "skin",
        "setUsedInBakedLighting",
        "enable",
        "setLightmapBaseResolution",
        "resolution",
        "setBakedLightmap",
        "QQuick3DBakedLightmap*",
        "bakedLightmap",
        "setInstancingLodMin",
        "minDistance",
        "setInstancingLodMax",
        "maxDistance",
        "setLevelOfDetailBias",
        "newLevelOfDetailBias",
        "setMotionVectorScale",
        "newMotionVectorScale",
        "setMotionVectorEnabled",
        "newMotionVectorEnabled",
        "onMaterialDestroyed",
        "object",
        "onMorphTargetDestroyed",
        "materials",
        "QQmlListProperty<QQuick3DMaterial>",
        "morphTargets",
        "QQmlListProperty<QQuick3DMorphTarget>",
        "inverseBindPoses",
        "bounds",
        "QQuick3DBounds3",
        "depthBias",
        "usedInBakedLighting",
        "lightmapBaseResolution",
        "instancingLodMin",
        "instancingLodMax",
        "levelOfDetailBias",
        "texelsPerUnit",
        "motionVectorEnabled",
        "motionVectorScale"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sourceChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'castsShadowsChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'receivesShadowsChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pickableChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'geometryChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'skeletonChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'inverseBindPosesChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'boundsChanged'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'instancingChanged'
        QtMocHelpers::SignalData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'instanceRootChanged'
        QtMocHelpers::SignalData<void()>(13, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'morphTargetsChanged'
        QtMocHelpers::SignalData<void()>(14, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'depthBiasChanged'
        QtMocHelpers::SignalData<void()>(15, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'receivesReflectionsChanged'
        QtMocHelpers::RevisionedSignalData<void()>(16, 4, QMC::AccessPublic, 0x603, QMetaType::Void),
        // Signal 'castsReflectionsChanged'
        QtMocHelpers::RevisionedSignalData<void()>(17, 4, QMC::AccessPublic, 0x604, QMetaType::Void),
        // Signal 'skinChanged'
        QtMocHelpers::RevisionedSignalData<void()>(18, 4, QMC::AccessPublic, 0x604, QMetaType::Void),
        // Signal 'usedInBakedLightingChanged'
        QtMocHelpers::RevisionedSignalData<void()>(19, 4, QMC::AccessPublic, 0x604, QMetaType::Void),
        // Signal 'lightmapBaseResolutionChanged'
        QtMocHelpers::RevisionedSignalData<void()>(20, 4, QMC::AccessPublic, 0x604, QMetaType::Void),
        // Signal 'bakedLightmapChanged'
        QtMocHelpers::RevisionedSignalData<void()>(21, 4, QMC::AccessPublic, 0x604, QMetaType::Void),
        // Signal 'instancingLodMinChanged'
        QtMocHelpers::RevisionedSignalData<void()>(22, 4, QMC::AccessPublic, 0x605, QMetaType::Void),
        // Signal 'instancingLodMaxChanged'
        QtMocHelpers::RevisionedSignalData<void()>(23, 4, QMC::AccessPublic, 0x605, QMetaType::Void),
        // Signal 'levelOfDetailBiasChanged'
        QtMocHelpers::RevisionedSignalData<void()>(24, 4, QMC::AccessPublic, 0x605, QMetaType::Void),
        // Signal 'texelsPerUnitChanged'
        QtMocHelpers::RevisionedSignalData<void()>(25, 4, QMC::AccessPublic, 0x60a, QMetaType::Void),
        // Signal 'motionVectorEnabledChanged'
        QtMocHelpers::RevisionedSignalData<void()>(26, 4, QMC::AccessPublic, 0x60b, QMetaType::Void),
        // Signal 'motionVectorScaleChanged'
        QtMocHelpers::RevisionedSignalData<void()>(27, 4, QMC::AccessPublic, 0x60b, QMetaType::Void),
        // Slot 'setSource'
        QtMocHelpers::SlotData<void(const QUrl &)>(28, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 29, 30 },
        }}),
        // Slot 'setCastsShadows'
        QtMocHelpers::SlotData<void(bool)>(31, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 32 },
        }}),
        // Slot 'setReceivesShadows'
        QtMocHelpers::SlotData<void(bool)>(33, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 34 },
        }}),
        // Slot 'setPickable'
        QtMocHelpers::SlotData<void(bool)>(35, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 36 },
        }}),
        // Slot 'setGeometry'
        QtMocHelpers::SlotData<void(QQuick3DGeometry *)>(37, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 38, 39 },
        }}),
        // Slot 'setSkeleton'
        QtMocHelpers::SlotData<void(QQuick3DSkeleton *)>(40, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 41, 42 },
        }}),
        // Slot 'setInverseBindPoses'
        QtMocHelpers::SlotData<void(const QList<QMatrix4x4> &)>(43, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 44, 45 },
        }}),
        // Slot 'setBounds'
        QtMocHelpers::SlotData<void(const QVector3D &, const QVector3D &)>(46, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 47, 48 }, { 0x80000000 | 47, 49 },
        }}),
        // Slot 'setInstancing'
        QtMocHelpers::SlotData<void(QQuick3DInstancing *)>(50, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 51, 52 },
        }}),
        // Slot 'setInstanceRoot'
        QtMocHelpers::SlotData<void(QQuick3DNode *)>(53, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 54, 55 },
        }}),
        // Slot 'setDepthBias'
        QtMocHelpers::SlotData<void(float)>(56, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 57 },
        }}),
        // Slot 'setReceivesReflections'
        QtMocHelpers::RevisionedSlotData<void(bool)>(58, 4, QMC::AccessPublic, 0x603, QMetaType::Void, {{
            { QMetaType::Bool, 59 },
        }}),
        // Slot 'setCastsReflections'
        QtMocHelpers::RevisionedSlotData<void(bool)>(60, 4, QMC::AccessPublic, 0x604, QMetaType::Void, {{
            { QMetaType::Bool, 61 },
        }}),
        // Slot 'setSkin'
        QtMocHelpers::RevisionedSlotData<void(QQuick3DSkin *)>(62, 4, QMC::AccessPublic, 0x604, QMetaType::Void, {{
            { 0x80000000 | 63, 64 },
        }}),
        // Slot 'setUsedInBakedLighting'
        QtMocHelpers::RevisionedSlotData<void(bool)>(65, 4, QMC::AccessPublic, 0x604, QMetaType::Void, {{
            { QMetaType::Bool, 66 },
        }}),
        // Slot 'setLightmapBaseResolution'
        QtMocHelpers::RevisionedSlotData<void(int)>(67, 4, QMC::AccessPublic, 0x604, QMetaType::Void, {{
            { QMetaType::Int, 68 },
        }}),
        // Slot 'setBakedLightmap'
        QtMocHelpers::RevisionedSlotData<void(QQuick3DBakedLightmap *)>(69, 4, QMC::AccessPublic, 0x604, QMetaType::Void, {{
            { 0x80000000 | 70, 71 },
        }}),
        // Slot 'setInstancingLodMin'
        QtMocHelpers::RevisionedSlotData<void(float)>(72, 4, QMC::AccessPublic, 0x605, QMetaType::Void, {{
            { QMetaType::Float, 73 },
        }}),
        // Slot 'setInstancingLodMax'
        QtMocHelpers::RevisionedSlotData<void(float)>(74, 4, QMC::AccessPublic, 0x605, QMetaType::Void, {{
            { QMetaType::Float, 75 },
        }}),
        // Slot 'setLevelOfDetailBias'
        QtMocHelpers::RevisionedSlotData<void(float)>(76, 4, QMC::AccessPublic, 0x605, QMetaType::Void, {{
            { QMetaType::Float, 77 },
        }}),
        // Slot 'setMotionVectorScale'
        QtMocHelpers::RevisionedSlotData<void(float)>(78, 4, QMC::AccessPublic, 0x60b, QMetaType::Void, {{
            { QMetaType::Float, 79 },
        }}),
        // Slot 'setMotionVectorEnabled'
        QtMocHelpers::RevisionedSlotData<void(bool)>(80, 4, QMC::AccessPublic, 0x60b, QMetaType::Void, {{
            { QMetaType::Bool, 81 },
        }}),
        // Slot 'onMaterialDestroyed'
        QtMocHelpers::SlotData<void(QObject *)>(82, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QObjectStar, 83 },
        }}),
        // Slot 'onMorphTargetDestroyed'
        QtMocHelpers::SlotData<void(QObject *)>(84, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QObjectStar, 83 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'source'
        QtMocHelpers::PropertyData<QUrl>(30, 0x80000000 | 29, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'castsShadows'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'receivesShadows'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'materials'
        QtMocHelpers::PropertyData<QQmlListProperty<QQuick3DMaterial>>(85, 0x80000000 | 86, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'morphTargets'
        QtMocHelpers::PropertyData<QQmlListProperty<QQuick3DMorphTarget>>(87, 0x80000000 | 88, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 10),
        // property 'pickable'
        QtMocHelpers::PropertyData<bool>(36, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'geometry'
        QtMocHelpers::PropertyData<QQuick3DGeometry*>(39, 0x80000000 | 38, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 4),
        // property 'instancing'
        QtMocHelpers::PropertyData<QQuick3DInstancing*>(52, 0x80000000 | 51, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 8),
        // property 'instanceRoot'
        QtMocHelpers::PropertyData<QQuick3DNode*>(55, 0x80000000 | 54, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 9),
        // property 'skeleton'
        QtMocHelpers::PropertyData<QQuick3DSkeleton*>(42, 0x80000000 | 41, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5),
        // property 'skin'
        QtMocHelpers::PropertyData<QQuick3DSkin*>(64, 0x80000000 | 63, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 14, 0x604),
        // property 'inverseBindPoses'
        QtMocHelpers::PropertyData<QList<QMatrix4x4>>(89, 0x80000000 | 44, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 6),
        // property 'bounds'
        QtMocHelpers::PropertyData<QQuick3DBounds3>(90, 0x80000000 | 91, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 7),
        // property 'depthBias'
        QtMocHelpers::PropertyData<float>(92, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'receivesReflections'
        QtMocHelpers::PropertyData<bool>(59, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12, 0x603),
        // property 'castsReflections'
        QtMocHelpers::PropertyData<bool>(61, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13, 0x604),
        // property 'usedInBakedLighting'
        QtMocHelpers::PropertyData<bool>(93, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 15, 0x604),
        // property 'lightmapBaseResolution'
        QtMocHelpers::PropertyData<int>(94, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 16, 0x604),
        // property 'bakedLightmap'
        QtMocHelpers::PropertyData<QQuick3DBakedLightmap*>(71, 0x80000000 | 70, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 17, 0x604),
        // property 'instancingLodMin'
        QtMocHelpers::PropertyData<float>(95, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 18, 0x605),
        // property 'instancingLodMax'
        QtMocHelpers::PropertyData<float>(96, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 19, 0x605),
        // property 'levelOfDetailBias'
        QtMocHelpers::PropertyData<float>(97, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 20, 0x605),
        // property 'texelsPerUnit'
        QtMocHelpers::PropertyData<float>(98, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 21, 0x60a),
        // property 'motionVectorEnabled'
        QtMocHelpers::PropertyData<bool>(99, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 22, 0x60b),
        // property 'motionVectorScale'
        QtMocHelpers::PropertyData<float>(100, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 23, 0x60b),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuick3DNode::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13QQuick3DModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13QQuick3DModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13QQuick3DModelE_t>.metaTypes,
    nullptr
} };

void QQuick3DModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sourceChanged(); break;
        case 1: _t->castsShadowsChanged(); break;
        case 2: _t->receivesShadowsChanged(); break;
        case 3: _t->pickableChanged(); break;
        case 4: _t->geometryChanged(); break;
        case 5: _t->skeletonChanged(); break;
        case 6: _t->inverseBindPosesChanged(); break;
        case 7: _t->boundsChanged(); break;
        case 8: _t->instancingChanged(); break;
        case 9: _t->instanceRootChanged(); break;
        case 10: _t->morphTargetsChanged(); break;
        case 11: _t->depthBiasChanged(); break;
        case 12: _t->receivesReflectionsChanged(); break;
        case 13: _t->castsReflectionsChanged(); break;
        case 14: _t->skinChanged(); break;
        case 15: _t->usedInBakedLightingChanged(); break;
        case 16: _t->lightmapBaseResolutionChanged(); break;
        case 17: _t->bakedLightmapChanged(); break;
        case 18: _t->instancingLodMinChanged(); break;
        case 19: _t->instancingLodMaxChanged(); break;
        case 20: _t->levelOfDetailBiasChanged(); break;
        case 21: _t->texelsPerUnitChanged(); break;
        case 22: _t->motionVectorEnabledChanged(); break;
        case 23: _t->motionVectorScaleChanged(); break;
        case 24: _t->setSource((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 25: _t->setCastsShadows((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 26: _t->setReceivesShadows((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 27: _t->setPickable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 28: _t->setGeometry((*reinterpret_cast<std::add_pointer_t<QQuick3DGeometry*>>(_a[1]))); break;
        case 29: _t->setSkeleton((*reinterpret_cast<std::add_pointer_t<QQuick3DSkeleton*>>(_a[1]))); break;
        case 30: _t->setInverseBindPoses((*reinterpret_cast<std::add_pointer_t<QList<QMatrix4x4>>>(_a[1]))); break;
        case 31: _t->setBounds((*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[2]))); break;
        case 32: _t->setInstancing((*reinterpret_cast<std::add_pointer_t<QQuick3DInstancing*>>(_a[1]))); break;
        case 33: _t->setInstanceRoot((*reinterpret_cast<std::add_pointer_t<QQuick3DNode*>>(_a[1]))); break;
        case 34: _t->setDepthBias((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 35: _t->setReceivesReflections((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 36: _t->setCastsReflections((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 37: _t->setSkin((*reinterpret_cast<std::add_pointer_t<QQuick3DSkin*>>(_a[1]))); break;
        case 38: _t->setUsedInBakedLighting((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 39: _t->setLightmapBaseResolution((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 40: _t->setBakedLightmap((*reinterpret_cast<std::add_pointer_t<QQuick3DBakedLightmap*>>(_a[1]))); break;
        case 41: _t->setInstancingLodMin((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 42: _t->setInstancingLodMax((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 43: _t->setLevelOfDetailBias((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 44: _t->setMotionVectorScale((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 45: _t->setMotionVectorEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 46: _t->onMaterialDestroyed((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        case 47: _t->onMorphTargetDestroyed((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 28:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DGeometry* >(); break;
            }
            break;
        case 29:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DSkeleton* >(); break;
            }
            break;
        case 32:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DInstancing* >(); break;
            }
            break;
        case 33:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DNode* >(); break;
            }
            break;
        case 37:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DSkin* >(); break;
            }
            break;
        case 40:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DBakedLightmap* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuick3DModel::*)()>(_a, &QQuick3DModel::sourceChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DModel::*)()>(_a, &QQuick3DModel::castsShadowsChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DModel::*)()>(_a, &QQuick3DModel::receivesShadowsChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DModel::*)()>(_a, &QQuick3DModel::pickableChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DModel::*)()>(_a, &QQuick3DModel::geometryChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DModel::*)()>(_a, &QQuick3DModel::skeletonChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DModel::*)()>(_a, &QQuick3DModel::inverseBindPosesChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DModel::*)()>(_a, &QQuick3DModel::boundsChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DModel::*)()>(_a, &QQuick3DModel::instancingChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DModel::*)()>(_a, &QQuick3DModel::instanceRootChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DModel::*)()>(_a, &QQuick3DModel::morphTargetsChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DModel::*)()>(_a, &QQuick3DModel::depthBiasChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DModel::*)()>(_a, &QQuick3DModel::receivesReflectionsChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DModel::*)()>(_a, &QQuick3DModel::castsReflectionsChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DModel::*)()>(_a, &QQuick3DModel::skinChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DModel::*)()>(_a, &QQuick3DModel::usedInBakedLightingChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DModel::*)()>(_a, &QQuick3DModel::lightmapBaseResolutionChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DModel::*)()>(_a, &QQuick3DModel::bakedLightmapChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DModel::*)()>(_a, &QQuick3DModel::instancingLodMinChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DModel::*)()>(_a, &QQuick3DModel::instancingLodMaxChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DModel::*)()>(_a, &QQuick3DModel::levelOfDetailBiasChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DModel::*)()>(_a, &QQuick3DModel::texelsPerUnitChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DModel::*)()>(_a, &QQuick3DModel::motionVectorEnabledChanged, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DModel::*)()>(_a, &QQuick3DModel::motionVectorScaleChanged, 23))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 18:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuick3DBakedLightmap* >(); break;
        case 12:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuick3DBounds3 >(); break;
        case 6:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuick3DGeometry* >(); break;
        case 7:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuick3DInstancing* >(); break;
        case 8:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuick3DNode* >(); break;
        case 9:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuick3DSkeleton* >(); break;
        case 10:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuick3DSkin* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QUrl*>(_v) = _t->source(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->castsShadows(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->receivesShadows(); break;
        case 3: *reinterpret_cast<QQmlListProperty<QQuick3DMaterial>*>(_v) = _t->materials(); break;
        case 4: *reinterpret_cast<QQmlListProperty<QQuick3DMorphTarget>*>(_v) = _t->morphTargets(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->pickable(); break;
        case 6: *reinterpret_cast<QQuick3DGeometry**>(_v) = _t->geometry(); break;
        case 7: *reinterpret_cast<QQuick3DInstancing**>(_v) = _t->instancing(); break;
        case 8: *reinterpret_cast<QQuick3DNode**>(_v) = _t->instanceRoot(); break;
        case 9: *reinterpret_cast<QQuick3DSkeleton**>(_v) = _t->skeleton(); break;
        case 10: *reinterpret_cast<QQuick3DSkin**>(_v) = _t->skin(); break;
        case 11: *reinterpret_cast<QList<QMatrix4x4>*>(_v) = _t->inverseBindPoses(); break;
        case 12: *reinterpret_cast<QQuick3DBounds3*>(_v) = _t->bounds(); break;
        case 13: *reinterpret_cast<float*>(_v) = _t->depthBias(); break;
        case 14: *reinterpret_cast<bool*>(_v) = _t->receivesReflections(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->castsReflections(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->isUsedInBakedLighting(); break;
        case 17: *reinterpret_cast<int*>(_v) = _t->lightmapBaseResolution(); break;
        case 18: *reinterpret_cast<QQuick3DBakedLightmap**>(_v) = _t->bakedLightmap(); break;
        case 19: *reinterpret_cast<float*>(_v) = _t->instancingLodMin(); break;
        case 20: *reinterpret_cast<float*>(_v) = _t->instancingLodMax(); break;
        case 21: *reinterpret_cast<float*>(_v) = _t->levelOfDetailBias(); break;
        case 22: *reinterpret_cast<float*>(_v) = _t->texelsPerUnit(); break;
        case 23: *reinterpret_cast<bool*>(_v) = _t->motionVectorEnabled(); break;
        case 24: *reinterpret_cast<float*>(_v) = _t->motionVectorScale(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setSource(*reinterpret_cast<QUrl*>(_v)); break;
        case 1: _t->setCastsShadows(*reinterpret_cast<bool*>(_v)); break;
        case 2: _t->setReceivesShadows(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setPickable(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setGeometry(*reinterpret_cast<QQuick3DGeometry**>(_v)); break;
        case 7: _t->setInstancing(*reinterpret_cast<QQuick3DInstancing**>(_v)); break;
        case 8: _t->setInstanceRoot(*reinterpret_cast<QQuick3DNode**>(_v)); break;
        case 9: _t->setSkeleton(*reinterpret_cast<QQuick3DSkeleton**>(_v)); break;
        case 10: _t->setSkin(*reinterpret_cast<QQuick3DSkin**>(_v)); break;
        case 11: _t->setInverseBindPoses(*reinterpret_cast<QList<QMatrix4x4>*>(_v)); break;
        case 13: _t->setDepthBias(*reinterpret_cast<float*>(_v)); break;
        case 14: _t->setReceivesReflections(*reinterpret_cast<bool*>(_v)); break;
        case 15: _t->setCastsReflections(*reinterpret_cast<bool*>(_v)); break;
        case 16: _t->setUsedInBakedLighting(*reinterpret_cast<bool*>(_v)); break;
        case 17: _t->setLightmapBaseResolution(*reinterpret_cast<int*>(_v)); break;
        case 18: _t->setBakedLightmap(*reinterpret_cast<QQuick3DBakedLightmap**>(_v)); break;
        case 19: _t->setInstancingLodMin(*reinterpret_cast<float*>(_v)); break;
        case 20: _t->setInstancingLodMax(*reinterpret_cast<float*>(_v)); break;
        case 21: _t->setLevelOfDetailBias(*reinterpret_cast<float*>(_v)); break;
        case 22: _t->setTexelsPerUnit(*reinterpret_cast<float*>(_v)); break;
        case 23: _t->setMotionVectorEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 24: _t->setMotionVectorScale(*reinterpret_cast<float*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13QQuick3DModelE_t>.strings))
        return static_cast<void*>(this);
    return QQuick3DNode::qt_metacast(_clname);
}

int QQuick3DModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuick3DNode::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 48)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 48;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 48)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 48;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 25;
    }
    return _id;
}

// SIGNAL 0
void QQuick3DModel::sourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QQuick3DModel::castsShadowsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QQuick3DModel::receivesShadowsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QQuick3DModel::pickableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QQuick3DModel::geometryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QQuick3DModel::skeletonChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QQuick3DModel::inverseBindPosesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void QQuick3DModel::boundsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void QQuick3DModel::instancingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void QQuick3DModel::instanceRootChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void QQuick3DModel::morphTargetsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void QQuick3DModel::depthBiasChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void QQuick3DModel::receivesReflectionsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void QQuick3DModel::castsReflectionsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void QQuick3DModel::skinChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void QQuick3DModel::usedInBakedLightingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void QQuick3DModel::lightmapBaseResolutionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void QQuick3DModel::bakedLightmapChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void QQuick3DModel::instancingLodMinChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void QQuick3DModel::instancingLodMaxChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void QQuick3DModel::levelOfDetailBiasChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void QQuick3DModel::texelsPerUnitChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void QQuick3DModel::motionVectorEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 22, nullptr);
}

// SIGNAL 23
void QQuick3DModel::motionVectorScaleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 23, nullptr);
}
QT_WARNING_POP
