/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<private/qquick3dabstractlight_p.h>)
#  include <private/qquick3dabstractlight_p.h>
#endif
#if __has_include(<private/qquick3dbakedlightmap_p.h>)
#  include <private/qquick3dbakedlightmap_p.h>
#endif
#if __has_include(<private/qquick3dcamera_p.h>)
#  include <private/qquick3dcamera_p.h>
#endif
#if __has_include(<private/qquick3dcontentlayer_p.h>)
#  include <private/qquick3dcontentlayer_p.h>
#endif
#if __has_include(<private/qquick3dcubemaptexture_p.h>)
#  include <private/qquick3dcubemaptexture_p.h>
#endif
#if __has_include(<private/qquick3dcustomcamera_p.h>)
#  include <private/qquick3dcustomcamera_p.h>
#endif
#if __has_include(<private/qquick3dcustommaterial_p.h>)
#  include <private/qquick3dcustommaterial_p.h>
#endif
#if __has_include(<private/qquick3ddebugsettings_p.h>)
#  include <private/qquick3ddebugsettings_p.h>
#endif
#if __has_include(<private/qquick3ddefaultmaterial_p.h>)
#  include <private/qquick3ddefaultmaterial_p.h>
#endif
#if __has_include(<private/qquick3ddirectionallight_p.h>)
#  include <private/qquick3ddirectionallight_p.h>
#endif
#if __has_include(<private/qquick3deffect_p.h>)
#  include <private/qquick3deffect_p.h>
#endif
#if __has_include(<private/qquick3dfog_p.h>)
#  include <private/qquick3dfog_p.h>
#endif
#if __has_include(<private/qquick3dfrustumcamera_p.h>)
#  include <private/qquick3dfrustumcamera_p.h>
#endif
#if __has_include(<private/qquick3dinstancing_p.h>)
#  include <private/qquick3dinstancing_p.h>
#endif
#if __has_include(<private/qquick3djoint_p.h>)
#  include <private/qquick3djoint_p.h>
#endif
#if __has_include(<private/qquick3dlightmapper_p.h>)
#  include <private/qquick3dlightmapper_p.h>
#endif
#if __has_include(<private/qquick3dloader_p.h>)
#  include <private/qquick3dloader_p.h>
#endif
#if __has_include(<private/qquick3dmaterial_p.h>)
#  include <private/qquick3dmaterial_p.h>
#endif
#if __has_include(<private/qquick3dmodel_p.h>)
#  include <private/qquick3dmodel_p.h>
#endif
#if __has_include(<private/qquick3dmorphtarget_p.h>)
#  include <private/qquick3dmorphtarget_p.h>
#endif
#if __has_include(<private/qquick3dnode_p.h>)
#  include <private/qquick3dnode_p.h>
#endif
#if __has_include(<private/qquick3dorthographiccamera_p.h>)
#  include <private/qquick3dorthographiccamera_p.h>
#endif
#if __has_include(<private/qquick3dperspectivecamera_p.h>)
#  include <private/qquick3dperspectivecamera_p.h>
#endif
#if __has_include(<private/qquick3dpickresult_p.h>)
#  include <private/qquick3dpickresult_p.h>
#endif
#if __has_include(<private/qquick3dpointlight_p.h>)
#  include <private/qquick3dpointlight_p.h>
#endif
#if __has_include(<private/qquick3dprincipledmaterial_p.h>)
#  include <private/qquick3dprincipledmaterial_p.h>
#endif
#if __has_include(<private/qquick3dquaternionanimation_p.h>)
#  include <private/qquick3dquaternionanimation_p.h>
#endif
#if __has_include(<private/qquick3dquaternionutils_p.h>)
#  include <private/qquick3dquaternionutils_p.h>
#endif
#if __has_include(<private/qquick3dreflectionprobe_p.h>)
#  include <private/qquick3dreflectionprobe_p.h>
#endif
#if __has_include(<private/qquick3drenderpass_p.h>)
#  include <private/qquick3drenderpass_p.h>
#endif
#if __has_include(<private/qquick3drenderstats_p.h>)
#  include <private/qquick3drenderstats_p.h>
#endif
#if __has_include(<private/qquick3drepeater_p.h>)
#  include <private/qquick3drepeater_p.h>
#endif
#if __has_include(<private/qquick3dresourceloader_p.h>)
#  include <private/qquick3dresourceloader_p.h>
#endif
#if __has_include(<private/qquick3dsceneenvironment_p.h>)
#  include <private/qquick3dsceneenvironment_p.h>
#endif
#if __has_include(<private/qquick3dshaderutils_p.h>)
#  include <private/qquick3dshaderutils_p.h>
#endif
#if __has_include(<private/qquick3dskeleton_p.h>)
#  include <private/qquick3dskeleton_p.h>
#endif
#if __has_include(<private/qquick3dskin_p.h>)
#  include <private/qquick3dskin_p.h>
#endif
#if __has_include(<private/qquick3dspecularglossymaterial_p.h>)
#  include <private/qquick3dspecularglossymaterial_p.h>
#endif
#if __has_include(<private/qquick3dspotlight_p.h>)
#  include <private/qquick3dspotlight_p.h>
#endif
#if __has_include(<private/qquick3dtexture_p.h>)
#  include <private/qquick3dtexture_p.h>
#endif
#if __has_include(<private/qquick3dviewport_p.h>)
#  include <private/qquick3dviewport_p.h>
#endif
#if __has_include(<qquick3dgeometry.h>)
#  include <qquick3dgeometry.h>
#endif
#if __has_include(<qquick3dinstancing.h>)
#  include <qquick3dinstancing.h>
#endif
#if __has_include(<qquick3dobject.h>)
#  include <qquick3dobject.h>
#endif
#if __has_include(<qquick3drenderextensions.h>)
#  include <qquick3drenderextensions.h>
#endif
#if __has_include(<qquick3dtexturedata.h>)
#  include <qquick3dtexturedata.h>
#endif
#if __has_include(<qquick3dtextureproviderextension.h>)
#  include <qquick3dtextureproviderextension.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_QtQuick3D()
{
    qmlRegisterModule("QtQuick3D", 6, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<QQuick3DAbstractLight>("QtQuick3D", 6);
    qmlRegisterEnum<QQuick3DAbstractLight::QSSGShadowMapQuality>("QQuick3DAbstractLight::QSSGShadowMapQuality");
    qmlRegisterEnum<QQuick3DAbstractLight::QSSGSoftShadowQuality>("QQuick3DAbstractLight::QSSGSoftShadowQuality");
    qmlRegisterEnum<QQuick3DAbstractLight::QSSGBakeMode>("QQuick3DAbstractLight::QSSGBakeMode");
    qmlRegisterTypesAndRevisions<QQuick3DBakedLightmap>("QtQuick3D", 6);
    qmlRegisterTypesAndRevisions<QQuick3DBounds3>("QtQuick3D", 6);
    qmlRegisterTypesAndRevisions<QQuick3DCamera>("QtQuick3D", 6);
    qmlRegisterTypesAndRevisions<QQuick3DContentLayer>("QtQuick3D", 6);
    qmlRegisterEnum<QQuick3DContentLayer::LayerFlags>("QQuick3DContentLayer::LayerFlags");
    qmlRegisterEnum<QQuick3DContentLayer::LayerFlag>("QQuick3DContentLayer::LayerFlag");
    qmlRegisterTypesAndRevisions<QQuick3DCubeMapTexture>("QtQuick3D", 6);
    qmlRegisterTypesAndRevisions<QQuick3DCustomCamera>("QtQuick3D", 6);
    qmlRegisterTypesAndRevisions<QQuick3DCustomMaterial>("QtQuick3D", 6);
    qmlRegisterEnum<QQuick3DCustomMaterial::ShadingMode>("QQuick3DCustomMaterial::ShadingMode");
    qmlRegisterEnum<QQuick3DCustomMaterial::BlendMode>("QQuick3DCustomMaterial::BlendMode");
    qmlRegisterTypesAndRevisions<QQuick3DDebugSettings>("QtQuick3D", 6);
    qmlRegisterEnum<QQuick3DDebugSettings::QQuick3DMaterialOverrides>("QQuick3DDebugSettings::QQuick3DMaterialOverrides");
    qmlRegisterTypesAndRevisions<QQuick3DDefaultMaterial>("QtQuick3D", 6);
    qmlRegisterEnum<QQuick3DDefaultMaterial::Lighting>("QQuick3DDefaultMaterial::Lighting");
    qmlRegisterEnum<QQuick3DDefaultMaterial::BlendMode>("QQuick3DDefaultMaterial::BlendMode");
    qmlRegisterEnum<QQuick3DDefaultMaterial::SpecularModel>("QQuick3DDefaultMaterial::SpecularModel");
    qmlRegisterTypesAndRevisions<QQuick3DDirectionalLight>("QtQuick3D", 6);
    qmlRegisterTypesAndRevisions<QQuick3DEffect>("QtQuick3D", 6);
    qmlRegisterTypesAndRevisions<QQuick3DFileInstancing>("QtQuick3D", 6);
    qmlRegisterTypesAndRevisions<QQuick3DFog>("QtQuick3D", 6);
    qmlRegisterTypesAndRevisions<QQuick3DFrustumCamera>("QtQuick3D", 6);
    qmlRegisterTypesAndRevisions<QQuick3DGeometry>("QtQuick3D", 6);
    qmlRegisterTypesAndRevisions<QQuick3DInstanceList>("QtQuick3D", 6);
    qmlRegisterTypesAndRevisions<QQuick3DInstanceListEntry>("QtQuick3D", 6);
    qmlRegisterTypesAndRevisions<QQuick3DInstancing>("QtQuick3D", 6);
    qmlRegisterTypesAndRevisions<QQuick3DJoint>("QtQuick3D", 6);
    qmlRegisterTypesAndRevisions<QQuick3DLightmapper>("QtQuick3D", 6);
    qmlRegisterTypesAndRevisions<QQuick3DLoader>("QtQuick3D", 6);
    qmlRegisterEnum<QQuick3DLoader::Status>("QQuick3DLoader::Status");
    qmlRegisterTypesAndRevisions<QQuick3DMaterial>("QtQuick3D", 6);
    qmlRegisterEnum<QQuick3DMaterial::CullMode>("QQuick3DMaterial::CullMode");
    qmlRegisterEnum<QQuick3DMaterial::TextureChannelMapping>("QQuick3DMaterial::TextureChannelMapping");
    qmlRegisterEnum<QQuick3DMaterial::DepthDrawMode>("QQuick3DMaterial::DepthDrawMode");
    qmlRegisterEnum<QQuick3DMaterial::VertexColorMask>("QQuick3DMaterial::VertexColorMask");
    qmlRegisterEnum<QQuick3DMaterial::VertexColorMaskFlags>("QQuick3DMaterial::VertexColorMaskFlags");
    qmlRegisterEnum<QQuick3DMaterial::VertexColorMask>("QQuick3DMaterial::VertexColorMask");
    qmlRegisterTypesAndRevisions<QQuick3DModel>("QtQuick3D", 6);
    qmlRegisterTypesAndRevisions<QQuick3DMorphTarget>("QtQuick3D", 6);
    qmlRegisterEnum<QQuick3DMorphTarget::MorphTargetAttribute>("QQuick3DMorphTarget::MorphTargetAttribute");
    qmlRegisterEnum<QQuick3DMorphTarget::MorphTargetAttributes>("QQuick3DMorphTarget::MorphTargetAttributes");
    qmlRegisterEnum<QQuick3DMorphTarget::MorphTargetAttribute>("QQuick3DMorphTarget::MorphTargetAttribute");
    qmlRegisterTypesAndRevisions<QQuick3DNode>("QtQuick3D", 6);
    qmlRegisterEnum<QQuick3DNode::TransformSpace>("QQuick3DNode::TransformSpace");
    qmlRegisterEnum<QQuick3DNode::StaticFlags>("QQuick3DNode::StaticFlags");
    qmlRegisterTypesAndRevisions<QQuick3DObject>("QtQuick3D", 6);
    qmlRegisterTypesAndRevisions<QQuick3DOrthographicCamera>("QtQuick3D", 6);
    qmlRegisterTypesAndRevisions<QQuick3DPerspectiveCamera>("QtQuick3D", 6);
    qmlRegisterEnum<QQuick3DPerspectiveCamera::FieldOfViewOrientation>("QQuick3DPerspectiveCamera::FieldOfViewOrientation");
    qmlRegisterTypesAndRevisions<QQuick3DPickResult>("QtQuick3D", 6);
    {
        Q_CONSTINIT static auto metaType = QQmlPrivate::metaTypeForNamespace(
            [](const QtPrivate::QMetaTypeInterface *) {return &QQuick3DPickResultEnums::staticMetaObject;},
            "QQuick3DPickResultEnums");
        QMetaType(&metaType).id();
    }
    qmlRegisterNamespaceAndRevisions(&QQuick3DPickResultEnums::staticMetaObject, "QtQuick3D", 6, nullptr, &QQuick3DPickResultEnums::staticMetaObject, nullptr);
    qmlRegisterEnum<QQuick3DPickResultEnums::HitType>("QQuick3DPickResultEnums::HitType");
    qmlRegisterTypesAndRevisions<QQuick3DPointLight>("QtQuick3D", 6);
    qmlRegisterTypesAndRevisions<QQuick3DPrincipledMaterial>("QtQuick3D", 6);
    qmlRegisterEnum<QQuick3DPrincipledMaterial::Lighting>("QQuick3DPrincipledMaterial::Lighting");
    qmlRegisterEnum<QQuick3DPrincipledMaterial::BlendMode>("QQuick3DPrincipledMaterial::BlendMode");
    qmlRegisterEnum<QQuick3DPrincipledMaterial::AlphaMode>("QQuick3DPrincipledMaterial::AlphaMode");
    qmlRegisterEnum<QQuick3DPrincipledMaterial::VertexColorMask>("QQuick3DPrincipledMaterial::VertexColorMask");
    qmlRegisterEnum<QQuick3DPrincipledMaterial::VertexColorMaskFlags>("QQuick3DPrincipledMaterial::VertexColorMaskFlags");
    qmlRegisterEnum<QQuick3DPrincipledMaterial::VertexColorMask>("QQuick3DPrincipledMaterial::VertexColorMask");
    qmlRegisterTypesAndRevisions<QQuick3DQuaternionAnimation>("QtQuick3D", 6);
    qmlRegisterAnonymousTypesAndRevisions<QQuickAbstractAnimation>("QtQuick3D", 6);
    qmlRegisterEnum<QQuick3DQuaternionAnimation::Type>("QQuick3DQuaternionAnimation::Type");
    qmlRegisterTypesAndRevisions<QQuick3DQuaternionUtils>("QtQuick3D", 6);
    qmlRegisterTypesAndRevisions<QQuick3DReflectionProbe>("QtQuick3D", 6);
    qmlRegisterEnum<QQuick3DReflectionProbe::ReflectionQuality>("QQuick3DReflectionProbe::ReflectionQuality");
    qmlRegisterEnum<QQuick3DReflectionProbe::ReflectionRefreshMode>("QQuick3DReflectionProbe::ReflectionRefreshMode");
    qmlRegisterEnum<QQuick3DReflectionProbe::ReflectionTimeSlicing>("QQuick3DReflectionProbe::ReflectionTimeSlicing");
    qmlRegisterTypesAndRevisions<QQuick3DRenderExtension>("QtQuick3D", 6);
    qmlRegisterTypesAndRevisions<QQuick3DRenderPass>("QtQuick3D", 6);
    qmlRegisterEnum<QQuick3DRenderPass::MaterialModes>("QQuick3DRenderPass::MaterialModes");
    qmlRegisterEnum<QQuick3DRenderPass::PassMode>("QQuick3DRenderPass::PassMode");
    qmlRegisterEnum<QQuick3DRenderPass::RenderTargetFlags>("QQuick3DRenderPass::RenderTargetFlags");
    qmlRegisterEnum<QQuick3DRenderPass::RenderTargetFlag>("QQuick3DRenderPass::RenderTargetFlag");
    qmlRegisterTypesAndRevisions<QQuick3DRenderPassTargetBlend>("QtQuick3D", 6);
    qmlRegisterEnum<QQuick3DRenderPassTargetBlend::BlendFactor>("QQuick3DRenderPassTargetBlend::BlendFactor");
    qmlRegisterEnum<QQuick3DRenderPassTargetBlend::BlendOperation>("QQuick3DRenderPassTargetBlend::BlendOperation");
    qmlRegisterTypesAndRevisions<QQuick3DRenderStats>("QtQuick3D", 6);
    QMetaType::fromType<QQuick3DRenderPassTargetBlend>().id();
    qmlRegisterNamespaceAndRevisions(&QQuick3DRenderPassTargetBlend::staticMetaObject, "QtQuick3D", 6, nullptr, &QQuick3DRenderTargetBlendForeign::staticMetaObject, nullptr);
    qmlRegisterEnum<QQuick3DRenderPassTargetBlend::BlendFactor>("QQuick3DRenderPassTargetBlend::BlendFactor");
    qmlRegisterEnum<QQuick3DRenderPassTargetBlend::BlendOperation>("QQuick3DRenderPassTargetBlend::BlendOperation");
    qmlRegisterTypesAndRevisions<QQuick3DRepeater>("QtQuick3D", 6);
    qmlRegisterTypesAndRevisions<QQuick3DResourceLoader>("QtQuick3D", 6);
    qmlRegisterTypesAndRevisions<QQuick3DSceneEnvironment>("QtQuick3D", 6);
    qmlRegisterEnum<QQuick3DSceneEnvironment::QQuick3DEnvironmentAAModeValues>("QQuick3DSceneEnvironment::QQuick3DEnvironmentAAModeValues");
    qmlRegisterEnum<QQuick3DSceneEnvironment::QQuick3DEnvironmentAAQualityValues>("QQuick3DSceneEnvironment::QQuick3DEnvironmentAAQualityValues");
    qmlRegisterEnum<QQuick3DSceneEnvironment::QQuick3DEnvironmentBackgroundTypes>("QQuick3DSceneEnvironment::QQuick3DEnvironmentBackgroundTypes");
    qmlRegisterEnum<QQuick3DSceneEnvironment::QQuick3DEnvironmentTonemapModes>("QQuick3DSceneEnvironment::QQuick3DEnvironmentTonemapModes");
    qmlRegisterEnum<QQuick3DSceneEnvironment::QQuick3DEnvironmentOITMethod>("QQuick3DSceneEnvironment::QQuick3DEnvironmentOITMethod");
    qmlRegisterEnum<QQuick3DSceneEnvironment::QQuick3DEnvironmentTemporalAAMode>("QQuick3DSceneEnvironment::QQuick3DEnvironmentTemporalAAMode");
    qmlRegisterTypesAndRevisions<QQuick3DShaderUtilsApplyValue>("QtQuick3D", 6);
    qmlRegisterTypesAndRevisions<QQuick3DShaderUtilsBuffer>("QtQuick3D", 6);
    qmlRegisterEnum<QQuick3DShaderUtilsBuffer::TextureFilterOperation>("QQuick3DShaderUtilsBuffer::TextureFilterOperation");
    qmlRegisterEnum<QQuick3DShaderUtilsBuffer::TextureCoordOperation>("QQuick3DShaderUtilsBuffer::TextureCoordOperation");
    qmlRegisterEnum<QQuick3DShaderUtilsBuffer::AllocateBufferFlagValues>("QQuick3DShaderUtilsBuffer::AllocateBufferFlagValues");
    qmlRegisterEnum<QQuick3DShaderUtilsBuffer::TextureFormat>("QQuick3DShaderUtilsBuffer::TextureFormat");
    qmlRegisterTypesAndRevisions<QQuick3DShaderUtilsBufferInput>("QtQuick3D", 6);
    qmlRegisterTypesAndRevisions<QQuick3DShaderUtilsPipelineStateOverride>("QtQuick3D", 6);
    qmlRegisterEnum<QQuick3DShaderUtilsPipelineStateOverride::CompareOperation>("QQuick3DShaderUtilsPipelineStateOverride::CompareOperation");
    qmlRegisterEnum<QQuick3DShaderUtilsPipelineStateOverride::CullMode>("QQuick3DShaderUtilsPipelineStateOverride::CullMode");
    qmlRegisterEnum<QQuick3DShaderUtilsPipelineStateOverride::PolygonMode>("QQuick3DShaderUtilsPipelineStateOverride::PolygonMode");
    qmlRegisterTypesAndRevisions<QQuick3DShaderUtilsRenderCommand>("QtQuick3D", 6);
    qmlRegisterTypesAndRevisions<QQuick3DShaderUtilsRenderPass>("QtQuick3D", 6);
    qmlRegisterTypesAndRevisions<QQuick3DShaderUtilsRenderPassAddDefine>("QtQuick3D", 6);
    qmlRegisterTypesAndRevisions<QQuick3DShaderUtilsRenderPassColorAttachment>("QtQuick3D", 6);
    qmlRegisterTypesAndRevisions<QQuick3DShaderUtilsRenderPassDepthStencilAttachment>("QtQuick3D", 6);
    qmlRegisterTypesAndRevisions<QQuick3DShaderUtilsRenderPassDepthTextureAttachment>("QtQuick3D", 6);
    qmlRegisterTypesAndRevisions<QQuick3DShaderUtilsRenderPassTexture>("QtQuick3D", 6);
    qmlRegisterEnum<QQuick3DShaderUtilsRenderPassTexture::TextureFormat>("QQuick3DShaderUtilsRenderPassTexture::TextureFormat");
    qmlRegisterTypesAndRevisions<QQuick3DShaderUtilsRenderablesFilter>("QtQuick3D", 6);
    qmlRegisterEnum<QQuick3DShaderUtilsRenderablesFilter::RenderableTypes>("QQuick3DShaderUtilsRenderablesFilter::RenderableTypes");
    qmlRegisterEnum<QQuick3DShaderUtilsRenderablesFilter::RenderableType>("QQuick3DShaderUtilsRenderablesFilter::RenderableType");
    qmlRegisterTypesAndRevisions<QQuick3DShaderUtilsShader>("QtQuick3D", 6);
    qmlRegisterEnum<QQuick3DShaderUtilsShader::Stage>("QQuick3DShaderUtilsShader::Stage");
    qmlRegisterTypesAndRevisions<QQuick3DShaderUtilsSubRenderPass>("QtQuick3D", 6);
    qmlRegisterTypesAndRevisions<QQuick3DShaderUtilsTextureInput>("QtQuick3D", 6);
    qmlRegisterTypesAndRevisions<QQuick3DSkeleton>("QtQuick3D", 6);
    qmlRegisterTypesAndRevisions<QQuick3DSkin>("QtQuick3D", 6);
    qmlRegisterTypesAndRevisions<QQuick3DSpecularGlossyMaterial>("QtQuick3D", 6);
    qmlRegisterEnum<QQuick3DSpecularGlossyMaterial::Lighting>("QQuick3DSpecularGlossyMaterial::Lighting");
    qmlRegisterEnum<QQuick3DSpecularGlossyMaterial::BlendMode>("QQuick3DSpecularGlossyMaterial::BlendMode");
    qmlRegisterEnum<QQuick3DSpecularGlossyMaterial::AlphaMode>("QQuick3DSpecularGlossyMaterial::AlphaMode");
    qmlRegisterEnum<QQuick3DSpecularGlossyMaterial::VertexColorMask>("QQuick3DSpecularGlossyMaterial::VertexColorMask");
    qmlRegisterEnum<QQuick3DSpecularGlossyMaterial::VertexColorMaskFlags>("QQuick3DSpecularGlossyMaterial::VertexColorMaskFlags");
    qmlRegisterEnum<QQuick3DSpecularGlossyMaterial::VertexColorMask>("QQuick3DSpecularGlossyMaterial::VertexColorMask");
    qmlRegisterTypesAndRevisions<QQuick3DSpotLight>("QtQuick3D", 6);
    qmlRegisterTypesAndRevisions<QQuick3DTexture>("QtQuick3D", 6);
    qmlRegisterEnum<QQuick3DTexture::MappingMode>("QQuick3DTexture::MappingMode");
    qmlRegisterEnum<QQuick3DTexture::TilingMode>("QQuick3DTexture::TilingMode");
    qmlRegisterEnum<QQuick3DTexture::Filter>("QQuick3DTexture::Filter");
    qmlRegisterTypesAndRevisions<QQuick3DTextureData>("QtQuick3D", 6);
    qmlRegisterEnum<QQuick3DTextureData::Format>("QQuick3DTextureData::Format");
    qmlRegisterTypesAndRevisions<QQuick3DTextureProviderExtension>("QtQuick3D", 6);
    qmlRegisterEnum<QQuick3DTextureProviderExtension::SamplerHint>("QQuick3DTextureProviderExtension::SamplerHint");
    qmlRegisterTypesAndRevisions<QQuick3DViewport>("QtQuick3D", 6);
    qmlRegisterAnonymousTypesAndRevisions<QQuickItem>("QtQuick3D", 6);
    qmlRegisterEnum<QQuick3DViewport::RenderMode>("QQuick3DViewport::RenderMode");
    qmlRegisterEnum<QQuick3DViewport::RenderOverride>("QQuick3DViewport::RenderOverride");
    qmlRegisterEnum<QQuick3DViewport::RenderOverrides>("QQuick3DViewport::RenderOverrides");
    qmlRegisterEnum<QQuick3DViewport::RenderOverride>("QQuick3DViewport::RenderOverride");
    QT_WARNING_POP
    qmlRegisterModule("QtQuick3D", 6, 11);
}

static const QQmlModuleRegistration qtQuick3DRegistration("QtQuick3D", qml_register_types_QtQuick3D);
