/****************************************************************************
** Meta object code from reading C++ file 'qquick3ddirectionallight_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtquick3d/src/quick3d/qquick3ddirectionallight_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquick3ddirectionallight_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN24QQuick3DDirectionalLightE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DDirectionalLight::qt_create_metaobjectdata<qt_meta_tag_ZN24QQuick3DDirectionalLightE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DDirectionalLight",
        "QML.Element",
        "DirectionalLight",
        "csmSplit1Changed",
        "",
        "csmSplit2Changed",
        "csmSplit3Changed",
        "csmNumSplitsChanged",
        "csmBlendRatioChanged",
        "lockShadowmapTexelsChanged",
        "csmSplit1",
        "csmSplit2",
        "csmSplit3",
        "csmNumSplits",
        "csmBlendRatio",
        "lockShadowmapTexels"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'csmSplit1Changed'
        QtMocHelpers::RevisionedSignalData<void()>(3, 4, QMC::AccessPublic, 0x608, QMetaType::Void),
        // Signal 'csmSplit2Changed'
        QtMocHelpers::RevisionedSignalData<void()>(5, 4, QMC::AccessPublic, 0x608, QMetaType::Void),
        // Signal 'csmSplit3Changed'
        QtMocHelpers::RevisionedSignalData<void()>(6, 4, QMC::AccessPublic, 0x608, QMetaType::Void),
        // Signal 'csmNumSplitsChanged'
        QtMocHelpers::RevisionedSignalData<void()>(7, 4, QMC::AccessPublic, 0x608, QMetaType::Void),
        // Signal 'csmBlendRatioChanged'
        QtMocHelpers::RevisionedSignalData<void()>(8, 4, QMC::AccessPublic, 0x608, QMetaType::Void),
        // Signal 'lockShadowmapTexelsChanged'
        QtMocHelpers::RevisionedSignalData<void()>(9, 4, QMC::AccessPublic, 0x609, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'csmSplit1'
        QtMocHelpers::PropertyData<float>(10, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 0, 0x608),
        // property 'csmSplit2'
        QtMocHelpers::PropertyData<float>(11, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 1, 0x608),
        // property 'csmSplit3'
        QtMocHelpers::PropertyData<float>(12, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 2, 0x608),
        // property 'csmNumSplits'
        QtMocHelpers::PropertyData<int>(13, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 3, 0x608),
        // property 'csmBlendRatio'
        QtMocHelpers::PropertyData<float>(14, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 4, 0x608),
        // property 'lockShadowmapTexels'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 5, 0x609),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DDirectionalLight, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DDirectionalLight::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuick3DAbstractLight::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24QQuick3DDirectionalLightE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24QQuick3DDirectionalLightE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN24QQuick3DDirectionalLightE_t>.metaTypes,
    nullptr
} };

void QQuick3DDirectionalLight::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DDirectionalLight *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->csmSplit1Changed(); break;
        case 1: _t->csmSplit2Changed(); break;
        case 2: _t->csmSplit3Changed(); break;
        case 3: _t->csmNumSplitsChanged(); break;
        case 4: _t->csmBlendRatioChanged(); break;
        case 5: _t->lockShadowmapTexelsChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuick3DDirectionalLight::*)()>(_a, &QQuick3DDirectionalLight::csmSplit1Changed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DDirectionalLight::*)()>(_a, &QQuick3DDirectionalLight::csmSplit2Changed, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DDirectionalLight::*)()>(_a, &QQuick3DDirectionalLight::csmSplit3Changed, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DDirectionalLight::*)()>(_a, &QQuick3DDirectionalLight::csmNumSplitsChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DDirectionalLight::*)()>(_a, &QQuick3DDirectionalLight::csmBlendRatioChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DDirectionalLight::*)()>(_a, &QQuick3DDirectionalLight::lockShadowmapTexelsChanged, 5))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<float*>(_v) = _t->csmSplit1(); break;
        case 1: *reinterpret_cast<float*>(_v) = _t->csmSplit2(); break;
        case 2: *reinterpret_cast<float*>(_v) = _t->csmSplit3(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->csmNumSplits(); break;
        case 4: *reinterpret_cast<float*>(_v) = _t->csmBlendRatio(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->lockShadowmapTexels(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setCsmSplit1(*reinterpret_cast<float*>(_v)); break;
        case 1: _t->setCsmSplit2(*reinterpret_cast<float*>(_v)); break;
        case 2: _t->setCsmSplit3(*reinterpret_cast<float*>(_v)); break;
        case 3: _t->setCsmNumSplits(*reinterpret_cast<int*>(_v)); break;
        case 4: _t->setCsmBlendRatio(*reinterpret_cast<float*>(_v)); break;
        case 5: _t->setLockShadowmapTexels(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DDirectionalLight::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DDirectionalLight::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24QQuick3DDirectionalLightE_t>.strings))
        return static_cast<void*>(this);
    return QQuick3DAbstractLight::qt_metacast(_clname);
}

int QQuick3DDirectionalLight::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuick3DAbstractLight::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void QQuick3DDirectionalLight::csmSplit1Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QQuick3DDirectionalLight::csmSplit2Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QQuick3DDirectionalLight::csmSplit3Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QQuick3DDirectionalLight::csmNumSplitsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QQuick3DDirectionalLight::csmBlendRatioChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QQuick3DDirectionalLight::lockShadowmapTexelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
