/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<buildmessage.h>)
#  include <buildmessage.h>
#endif
#if __has_include(<materialadapter.h>)
#  include <materialadapter.h>
#endif
#if __has_include(<syntaxhighlighter.h>)
#  include <syntaxhighlighter.h>
#endif
#if __has_include(<uniformmodel.h>)
#  include <uniformmodel.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_QtQuick3D_MaterialEditor()
{
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<MaterialAdapter>("QtQuick3D.MaterialEditor", 1);
    QMetaType::fromType<QSyntaxHighlighter *>().id();
    qmlRegisterTypesAndRevisions<ShaderBuildMessage>("QtQuick3D.MaterialEditor", 1);
    qmlRegisterEnum<ShaderBuildMessage::Status>("ShaderBuildMessage::Status");
    qmlRegisterEnum<ShaderBuildMessage::Stage>("ShaderBuildMessage::Stage");
    QMetaType::fromType<ShaderBuildMessageDerived>().id();
    qmlRegisterNamespaceAndRevisions(&ShaderBuildMessageDerived::staticMetaObject, "QtQuick3D.MaterialEditor", 1, nullptr, &ShaderEnums::staticMetaObject, nullptr);
    qmlRegisterTypesAndRevisions<SyntaxHighlighter>("QtQuick3D.MaterialEditor", 1);
    qmlRegisterTypesAndRevisions<UniformModel>("QtQuick3D.MaterialEditor", 1);
    qmlRegisterAnonymousTypesAndRevisions<QAbstractItemModel>("QtQuick3D.MaterialEditor", 1);
    qmlRegisterEnum<UniformModel::UniformType>("UniformModel::UniformType");
    QT_WARNING_POP
    qmlRegisterModule("QtQuick3D.MaterialEditor", 1, 0);
}

static const QQmlModuleRegistration qtQuick3DMaterialEditorRegistration("QtQuick3D.MaterialEditor", qml_register_types_QtQuick3D_MaterialEditor);
