/****************************************************************************
** Meta object code from reading C++ file 'randominstancing_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtquick3d/src/helpers/randominstancing_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'randominstancing_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN21QQuick3DInstanceRangeE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DInstanceRange::qt_create_metaobjectdata<qt_meta_tag_ZN21QQuick3DInstanceRangeE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DInstanceRange",
        "QML.AddedInVersion",
        "1538",
        "QML.Element",
        "InstanceRange",
        "fromChanged",
        "",
        "toChanged",
        "proportionalChanged",
        "changed",
        "setFrom",
        "QVariant",
        "from",
        "setTo",
        "to",
        "setProportional",
        "proportional"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'fromChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'toChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'proportionalChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'changed'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setFrom'
        QtMocHelpers::SlotData<void(QVariant)>(10, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'setTo'
        QtMocHelpers::SlotData<void(QVariant)>(13, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 14 },
        }}),
        // Slot 'setProportional'
        QtMocHelpers::SlotData<void(bool)>(15, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 16 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'from'
        QtMocHelpers::PropertyData<QVariant>(12, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'to'
        QtMocHelpers::PropertyData<QVariant>(14, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'proportional'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DInstanceRange, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DInstanceRange::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuick3DObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21QQuick3DInstanceRangeE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21QQuick3DInstanceRangeE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21QQuick3DInstanceRangeE_t>.metaTypes,
    nullptr
} };

void QQuick3DInstanceRange::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DInstanceRange *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->fromChanged(); break;
        case 1: _t->toChanged(); break;
        case 2: _t->proportionalChanged(); break;
        case 3: _t->changed(); break;
        case 4: _t->setFrom((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1]))); break;
        case 5: _t->setTo((*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[1]))); break;
        case 6: _t->setProportional((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuick3DInstanceRange::*)()>(_a, &QQuick3DInstanceRange::fromChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DInstanceRange::*)()>(_a, &QQuick3DInstanceRange::toChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DInstanceRange::*)()>(_a, &QQuick3DInstanceRange::proportionalChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DInstanceRange::*)()>(_a, &QQuick3DInstanceRange::changed, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QVariant*>(_v) = _t->from(); break;
        case 1: *reinterpret_cast<QVariant*>(_v) = _t->to(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->proportional(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setFrom(*reinterpret_cast<QVariant*>(_v)); break;
        case 1: _t->setTo(*reinterpret_cast<QVariant*>(_v)); break;
        case 2: _t->setProportional(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DInstanceRange::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DInstanceRange::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21QQuick3DInstanceRangeE_t>.strings))
        return static_cast<void*>(this);
    return QQuick3DObject::qt_metacast(_clname);
}

int QQuick3DInstanceRange::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuick3DObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void QQuick3DInstanceRange::fromChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QQuick3DInstanceRange::toChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QQuick3DInstanceRange::proportionalChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QQuick3DInstanceRange::changed()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
namespace {
struct qt_meta_tag_ZN24QQuick3DRandomInstancingE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DRandomInstancing::qt_create_metaobjectdata<qt_meta_tag_ZN24QQuick3DRandomInstancingE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DRandomInstancing",
        "QML.Element",
        "RandomInstancing",
        "QML.AddedInVersion",
        "1538",
        "instanceCountChanged",
        "",
        "randomSeedChanged",
        "positionChanged",
        "scaleChanged",
        "rotationChanged",
        "colorChanged",
        "customDataChanged",
        "colorModelChanged",
        "gridSpacingChanged",
        "setInstanceCount",
        "instanceCount",
        "setRandomSeed",
        "randomSeed",
        "setPosition",
        "QQuick3DInstanceRange*",
        "position",
        "setScale",
        "scale",
        "setRotation",
        "rotation",
        "setColor",
        "color",
        "setCustomData",
        "customData",
        "setColorModel",
        "ColorModel",
        "colorModel",
        "handleChange",
        "gridSpacing",
        "QVector3D",
        "RGB",
        "HSV",
        "HSL"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'instanceCountChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'randomSeedChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'positionChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scaleChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'rotationChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'colorChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'customDataChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'colorModelChanged'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'gridSpacingChanged'
        QtMocHelpers::SignalData<void()>(14, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setInstanceCount'
        QtMocHelpers::SlotData<void(int)>(15, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 16 },
        }}),
        // Slot 'setRandomSeed'
        QtMocHelpers::SlotData<void(int)>(17, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 18 },
        }}),
        // Slot 'setPosition'
        QtMocHelpers::SlotData<void(QQuick3DInstanceRange *)>(19, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Slot 'setScale'
        QtMocHelpers::SlotData<void(QQuick3DInstanceRange *)>(22, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 23 },
        }}),
        // Slot 'setRotation'
        QtMocHelpers::SlotData<void(QQuick3DInstanceRange *)>(24, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 25 },
        }}),
        // Slot 'setColor'
        QtMocHelpers::SlotData<void(QQuick3DInstanceRange *)>(26, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 27 },
        }}),
        // Slot 'setCustomData'
        QtMocHelpers::SlotData<void(QQuick3DInstanceRange *)>(28, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 29 },
        }}),
        // Slot 'setColorModel'
        QtMocHelpers::SlotData<void(enum ColorModel)>(30, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 31, 32 },
        }}),
        // Slot 'handleChange'
        QtMocHelpers::SlotData<void()>(33, 6, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'instanceCount'
        QtMocHelpers::PropertyData<int>(16, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'position'
        QtMocHelpers::PropertyData<QQuick3DInstanceRange*>(21, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'scale'
        QtMocHelpers::PropertyData<QQuick3DInstanceRange*>(23, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'rotation'
        QtMocHelpers::PropertyData<QQuick3DInstanceRange*>(25, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 4),
        // property 'color'
        QtMocHelpers::PropertyData<QQuick3DInstanceRange*>(27, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5),
        // property 'colorModel'
        QtMocHelpers::PropertyData<enum ColorModel>(32, 0x80000000 | 31, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 7),
        // property 'customData'
        QtMocHelpers::PropertyData<QQuick3DInstanceRange*>(29, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 6),
        // property 'gridSpacing'
        QtMocHelpers::PropertyData<QVector3D>(34, 0x80000000 | 35, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 8, 0x609),
        // property 'randomSeed'
        QtMocHelpers::PropertyData<int>(18, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'ColorModel'
        QtMocHelpers::EnumData<enum ColorModel>(31, 31, QMC::EnumIsScoped).add({
            {   36, ColorModel::RGB },
            {   37, ColorModel::HSV },
            {   38, ColorModel::HSL },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DRandomInstancing, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DRandomInstancing::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuick3DInstancing::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24QQuick3DRandomInstancingE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24QQuick3DRandomInstancingE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN24QQuick3DRandomInstancingE_t>.metaTypes,
    nullptr
} };

void QQuick3DRandomInstancing::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DRandomInstancing *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->instanceCountChanged(); break;
        case 1: _t->randomSeedChanged(); break;
        case 2: _t->positionChanged(); break;
        case 3: _t->scaleChanged(); break;
        case 4: _t->rotationChanged(); break;
        case 5: _t->colorChanged(); break;
        case 6: _t->customDataChanged(); break;
        case 7: _t->colorModelChanged(); break;
        case 8: _t->gridSpacingChanged(); break;
        case 9: _t->setInstanceCount((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->setRandomSeed((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->setPosition((*reinterpret_cast<std::add_pointer_t<QQuick3DInstanceRange*>>(_a[1]))); break;
        case 12: _t->setScale((*reinterpret_cast<std::add_pointer_t<QQuick3DInstanceRange*>>(_a[1]))); break;
        case 13: _t->setRotation((*reinterpret_cast<std::add_pointer_t<QQuick3DInstanceRange*>>(_a[1]))); break;
        case 14: _t->setColor((*reinterpret_cast<std::add_pointer_t<QQuick3DInstanceRange*>>(_a[1]))); break;
        case 15: _t->setCustomData((*reinterpret_cast<std::add_pointer_t<QQuick3DInstanceRange*>>(_a[1]))); break;
        case 16: _t->setColorModel((*reinterpret_cast<std::add_pointer_t<enum ColorModel>>(_a[1]))); break;
        case 17: _t->handleChange(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DInstanceRange* >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DInstanceRange* >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DInstanceRange* >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DInstanceRange* >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DInstanceRange* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuick3DRandomInstancing::*)()>(_a, &QQuick3DRandomInstancing::instanceCountChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DRandomInstancing::*)()>(_a, &QQuick3DRandomInstancing::randomSeedChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DRandomInstancing::*)()>(_a, &QQuick3DRandomInstancing::positionChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DRandomInstancing::*)()>(_a, &QQuick3DRandomInstancing::scaleChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DRandomInstancing::*)()>(_a, &QQuick3DRandomInstancing::rotationChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DRandomInstancing::*)()>(_a, &QQuick3DRandomInstancing::colorChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DRandomInstancing::*)()>(_a, &QQuick3DRandomInstancing::customDataChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DRandomInstancing::*)()>(_a, &QQuick3DRandomInstancing::colorModelChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DRandomInstancing::*)()>(_a, &QQuick3DRandomInstancing::gridSpacingChanged, 8))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 6:
        case 4:
        case 3:
        case 2:
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuick3DInstanceRange* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->instanceCount(); break;
        case 1: *reinterpret_cast<QQuick3DInstanceRange**>(_v) = _t->position(); break;
        case 2: *reinterpret_cast<QQuick3DInstanceRange**>(_v) = _t->scale(); break;
        case 3: *reinterpret_cast<QQuick3DInstanceRange**>(_v) = _t->rotation(); break;
        case 4: *reinterpret_cast<QQuick3DInstanceRange**>(_v) = _t->color(); break;
        case 5: *reinterpret_cast<enum ColorModel*>(_v) = _t->colorModel(); break;
        case 6: *reinterpret_cast<QQuick3DInstanceRange**>(_v) = _t->customData(); break;
        case 7: *reinterpret_cast<QVector3D*>(_v) = _t->gridSpacing(); break;
        case 8: *reinterpret_cast<int*>(_v) = _t->randomSeed(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setInstanceCount(*reinterpret_cast<int*>(_v)); break;
        case 1: _t->setPosition(*reinterpret_cast<QQuick3DInstanceRange**>(_v)); break;
        case 2: _t->setScale(*reinterpret_cast<QQuick3DInstanceRange**>(_v)); break;
        case 3: _t->setRotation(*reinterpret_cast<QQuick3DInstanceRange**>(_v)); break;
        case 4: _t->setColor(*reinterpret_cast<QQuick3DInstanceRange**>(_v)); break;
        case 5: _t->setColorModel(*reinterpret_cast<enum ColorModel*>(_v)); break;
        case 6: _t->setCustomData(*reinterpret_cast<QQuick3DInstanceRange**>(_v)); break;
        case 7: _t->setGridSpacing(*reinterpret_cast<QVector3D*>(_v)); break;
        case 8: _t->setRandomSeed(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DRandomInstancing::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DRandomInstancing::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24QQuick3DRandomInstancingE_t>.strings))
        return static_cast<void*>(this);
    return QQuick3DInstancing::qt_metacast(_clname);
}

int QQuick3DRandomInstancing::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuick3DInstancing::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void QQuick3DRandomInstancing::instanceCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QQuick3DRandomInstancing::randomSeedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QQuick3DRandomInstancing::positionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QQuick3DRandomInstancing::scaleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QQuick3DRandomInstancing::rotationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QQuick3DRandomInstancing::colorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QQuick3DRandomInstancing::customDataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void QQuick3DRandomInstancing::colorModelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void QQuick3DRandomInstancing::gridSpacingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
QT_WARNING_POP
