/****************************************************************************
** Meta object code from reading C++ file 'qquick3drenderoutputprovider_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtquick3d/src/helpers/qquick3drenderoutputprovider_p.h"
#include <QtNetwork/QSslError>
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquick3drenderoutputprovider_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN28QQuick3DRenderOutputProviderE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DRenderOutputProvider::qt_create_metaobjectdata<qt_meta_tag_ZN28QQuick3DRenderOutputProviderE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DRenderOutputProvider",
        "QML.Element",
        "RenderOutputProvider",
        "QML.AddedInVersion",
        "1547",
        "textureSourceChanged",
        "",
        "renderPassChanged",
        "attachmentSelectorChanged",
        "textureSource",
        "TextureSource",
        "renderPass",
        "QQuick3DRenderPass*",
        "attachmentSelector",
        "AttachmentSelector",
        "None",
        "UserPassTexture",
        "AoTexture",
        "DepthTexture",
        "ScreenTexture",
        "NormalTexture",
        "MotionVectorTexture",
        "Attachment0",
        "Attachment1",
        "Attachment2",
        "Attachment3"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'textureSourceChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'renderPassChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'attachmentSelectorChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'textureSource'
        QtMocHelpers::PropertyData<enum TextureSource>(9, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 0),
        // property 'renderPass'
        QtMocHelpers::PropertyData<QQuick3DRenderPass*>(11, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 1),
        // property 'attachmentSelector'
        QtMocHelpers::PropertyData<enum AttachmentSelector>(13, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 2),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'TextureSource'
        QtMocHelpers::EnumData<enum TextureSource>(10, 10, QMC::EnumIsScoped).add({
            {   15, TextureSource::None },
            {   16, TextureSource::UserPassTexture },
            {   17, TextureSource::AoTexture },
            {   18, TextureSource::DepthTexture },
            {   19, TextureSource::ScreenTexture },
            {   20, TextureSource::NormalTexture },
            {   21, TextureSource::MotionVectorTexture },
        }),
        // enum 'AttachmentSelector'
        QtMocHelpers::EnumData<enum AttachmentSelector>(14, 14, QMC::EnumIsScoped).add({
            {   22, AttachmentSelector::Attachment0 },
            {   23, AttachmentSelector::Attachment1 },
            {   24, AttachmentSelector::Attachment2 },
            {   25, AttachmentSelector::Attachment3 },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DRenderOutputProvider, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DRenderOutputProvider::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuick3DTextureProviderExtension::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN28QQuick3DRenderOutputProviderE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN28QQuick3DRenderOutputProviderE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN28QQuick3DRenderOutputProviderE_t>.metaTypes,
    nullptr
} };

void QQuick3DRenderOutputProvider::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DRenderOutputProvider *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->textureSourceChanged(); break;
        case 1: _t->renderPassChanged(); break;
        case 2: _t->attachmentSelectorChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuick3DRenderOutputProvider::*)()>(_a, &QQuick3DRenderOutputProvider::textureSourceChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DRenderOutputProvider::*)()>(_a, &QQuick3DRenderOutputProvider::renderPassChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DRenderOutputProvider::*)()>(_a, &QQuick3DRenderOutputProvider::attachmentSelectorChanged, 2))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuick3DRenderPass* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<enum TextureSource*>(_v) = _t->textureSource(); break;
        case 1: *reinterpret_cast<QQuick3DRenderPass**>(_v) = _t->renderPass(); break;
        case 2: *reinterpret_cast<enum AttachmentSelector*>(_v) = _t->attachmentSelector(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setTextureSource(*reinterpret_cast<enum TextureSource*>(_v)); break;
        case 1: _t->setRenderPass(*reinterpret_cast<QQuick3DRenderPass**>(_v)); break;
        case 2: _t->setAttachmentSelector(*reinterpret_cast<enum AttachmentSelector*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DRenderOutputProvider::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DRenderOutputProvider::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN28QQuick3DRenderOutputProviderE_t>.strings))
        return static_cast<void*>(this);
    return QQuick3DTextureProviderExtension::qt_metacast(_clname);
}

int QQuick3DRenderOutputProvider::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuick3DTextureProviderExtension::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void QQuick3DRenderOutputProvider::textureSourceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QQuick3DRenderOutputProvider::renderPassChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QQuick3DRenderOutputProvider::attachmentSelectorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
