/****************************************************************************
** Meta object code from reading C++ file 'qquick3ddefaultmaterial_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtquick3d/src/quick3d/qquick3ddefaultmaterial_p.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquick3ddefaultmaterial_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN23QQuick3DDefaultMaterialE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DDefaultMaterial::qt_create_metaobjectdata<qt_meta_tag_ZN23QQuick3DDefaultMaterialE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DDefaultMaterial",
        "QML.Element",
        "DefaultMaterial",
        "lightingChanged",
        "",
        "QQuick3DDefaultMaterial::Lighting",
        "lighting",
        "blendModeChanged",
        "QQuick3DDefaultMaterial::BlendMode",
        "blendMode",
        "diffuseColorChanged",
        "QColor",
        "diffuseColor",
        "diffuseMapChanged",
        "QQuick3DTexture*",
        "diffuseMap",
        "emissiveFactorChanged",
        "QVector3D",
        "emissiveFactor",
        "emissiveMapChanged",
        "emissiveMap",
        "specularReflectionMapChanged",
        "specularReflectionMap",
        "specularMapChanged",
        "specularMap",
        "specularModelChanged",
        "QQuick3DDefaultMaterial::SpecularModel",
        "specularModel",
        "specularTintChanged",
        "specularTint",
        "indexOfRefractionChanged",
        "indexOfRefraction",
        "fresnelPowerChanged",
        "fresnelPower",
        "specularAmountChanged",
        "specularAmount",
        "specularRoughnessChanged",
        "specularRoughness",
        "roughnessMapChanged",
        "roughnessMap",
        "opacityChanged",
        "opacity",
        "opacityMapChanged",
        "opacityMap",
        "bumpMapChanged",
        "bumpMap",
        "bumpAmountChanged",
        "bumpAmount",
        "normalMapChanged",
        "normalMap",
        "translucencyMapChanged",
        "translucencyMap",
        "translucentFalloffChanged",
        "translucentFalloff",
        "diffuseLightWrapChanged",
        "diffuseLightWrap",
        "vertexColorsEnabledChanged",
        "vertexColorsEnabled",
        "roughnessChannelChanged",
        "QQuick3DMaterial::TextureChannelMapping",
        "channel",
        "opacityChannelChanged",
        "translucencyChannelChanged",
        "pointSizeChanged",
        "lineWidthChanged",
        "setLighting",
        "setBlendMode",
        "setDiffuseColor",
        "setDiffuseMap",
        "setEmissiveFactor",
        "setEmissiveMap",
        "setSpecularReflectionMap",
        "setSpecularMap",
        "setSpecularModel",
        "setSpecularTint",
        "setIndexOfRefraction",
        "setFresnelPower",
        "setSpecularAmount",
        "setSpecularRoughness",
        "setRoughnessMap",
        "setOpacity",
        "setOpacityMap",
        "setBumpMap",
        "setBumpAmount",
        "setNormalMap",
        "setTranslucencyMap",
        "setTranslucentFalloff",
        "setDiffuseLightWrap",
        "setVertexColorsEnabled",
        "setRoughnessChannel",
        "setOpacityChannel",
        "setTranslucencyChannel",
        "setPointSize",
        "size",
        "setLineWidth",
        "width",
        "Lighting",
        "BlendMode",
        "SpecularModel",
        "roughnessChannel",
        "opacityChannel",
        "translucencyChannel",
        "pointSize",
        "lineWidth",
        "NoLighting",
        "FragmentLighting",
        "SourceOver",
        "Screen",
        "Multiply",
        "Default",
        "KGGX"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'lightingChanged'
        QtMocHelpers::SignalData<void(QQuick3DDefaultMaterial::Lighting)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'blendModeChanged'
        QtMocHelpers::SignalData<void(QQuick3DDefaultMaterial::BlendMode)>(7, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Signal 'diffuseColorChanged'
        QtMocHelpers::SignalData<void(QColor)>(10, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Signal 'diffuseMapChanged'
        QtMocHelpers::SignalData<void(QQuick3DTexture *)>(13, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Signal 'emissiveFactorChanged'
        QtMocHelpers::SignalData<void(QVector3D)>(16, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Signal 'emissiveMapChanged'
        QtMocHelpers::SignalData<void(QQuick3DTexture *)>(19, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 20 },
        }}),
        // Signal 'specularReflectionMapChanged'
        QtMocHelpers::SignalData<void(QQuick3DTexture *)>(21, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 22 },
        }}),
        // Signal 'specularMapChanged'
        QtMocHelpers::SignalData<void(QQuick3DTexture *)>(23, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 24 },
        }}),
        // Signal 'specularModelChanged'
        QtMocHelpers::SignalData<void(QQuick3DDefaultMaterial::SpecularModel)>(25, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 26, 27 },
        }}),
        // Signal 'specularTintChanged'
        QtMocHelpers::SignalData<void(QColor)>(28, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 29 },
        }}),
        // Signal 'indexOfRefractionChanged'
        QtMocHelpers::SignalData<void(float)>(30, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 31 },
        }}),
        // Signal 'fresnelPowerChanged'
        QtMocHelpers::SignalData<void(float)>(32, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 33 },
        }}),
        // Signal 'specularAmountChanged'
        QtMocHelpers::SignalData<void(float)>(34, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 35 },
        }}),
        // Signal 'specularRoughnessChanged'
        QtMocHelpers::SignalData<void(float)>(36, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 37 },
        }}),
        // Signal 'roughnessMapChanged'
        QtMocHelpers::SignalData<void(QQuick3DTexture *)>(38, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 39 },
        }}),
        // Signal 'opacityChanged'
        QtMocHelpers::SignalData<void(float)>(40, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 41 },
        }}),
        // Signal 'opacityMapChanged'
        QtMocHelpers::SignalData<void(QQuick3DTexture *)>(42, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 43 },
        }}),
        // Signal 'bumpMapChanged'
        QtMocHelpers::SignalData<void(QQuick3DTexture *)>(44, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 45 },
        }}),
        // Signal 'bumpAmountChanged'
        QtMocHelpers::SignalData<void(float)>(46, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 47 },
        }}),
        // Signal 'normalMapChanged'
        QtMocHelpers::SignalData<void(QQuick3DTexture *)>(48, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 49 },
        }}),
        // Signal 'translucencyMapChanged'
        QtMocHelpers::SignalData<void(QQuick3DTexture *)>(50, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 51 },
        }}),
        // Signal 'translucentFalloffChanged'
        QtMocHelpers::SignalData<void(float)>(52, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 53 },
        }}),
        // Signal 'diffuseLightWrapChanged'
        QtMocHelpers::SignalData<void(float)>(54, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 55 },
        }}),
        // Signal 'vertexColorsEnabledChanged'
        QtMocHelpers::SignalData<void(bool)>(56, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 57 },
        }}),
        // Signal 'roughnessChannelChanged'
        QtMocHelpers::SignalData<void(QQuick3DMaterial::TextureChannelMapping)>(58, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 59, 60 },
        }}),
        // Signal 'opacityChannelChanged'
        QtMocHelpers::SignalData<void(QQuick3DMaterial::TextureChannelMapping)>(61, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 59, 60 },
        }}),
        // Signal 'translucencyChannelChanged'
        QtMocHelpers::SignalData<void(QQuick3DMaterial::TextureChannelMapping)>(62, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 59, 60 },
        }}),
        // Signal 'pointSizeChanged'
        QtMocHelpers::SignalData<void()>(63, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lineWidthChanged'
        QtMocHelpers::SignalData<void()>(64, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setLighting'
        QtMocHelpers::SlotData<void(QQuick3DDefaultMaterial::Lighting)>(65, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'setBlendMode'
        QtMocHelpers::SlotData<void(QQuick3DDefaultMaterial::BlendMode)>(66, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'setDiffuseColor'
        QtMocHelpers::SlotData<void(QColor)>(67, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'setDiffuseMap'
        QtMocHelpers::SlotData<void(QQuick3DTexture *)>(68, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Slot 'setEmissiveFactor'
        QtMocHelpers::SlotData<void(QVector3D)>(69, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'setEmissiveMap'
        QtMocHelpers::SlotData<void(QQuick3DTexture *)>(70, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 20 },
        }}),
        // Slot 'setSpecularReflectionMap'
        QtMocHelpers::SlotData<void(QQuick3DTexture *)>(71, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 22 },
        }}),
        // Slot 'setSpecularMap'
        QtMocHelpers::SlotData<void(QQuick3DTexture *)>(72, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 24 },
        }}),
        // Slot 'setSpecularModel'
        QtMocHelpers::SlotData<void(QQuick3DDefaultMaterial::SpecularModel)>(73, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 26, 27 },
        }}),
        // Slot 'setSpecularTint'
        QtMocHelpers::SlotData<void(QColor)>(74, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 29 },
        }}),
        // Slot 'setIndexOfRefraction'
        QtMocHelpers::SlotData<void(float)>(75, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 31 },
        }}),
        // Slot 'setFresnelPower'
        QtMocHelpers::SlotData<void(float)>(76, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 33 },
        }}),
        // Slot 'setSpecularAmount'
        QtMocHelpers::SlotData<void(float)>(77, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 35 },
        }}),
        // Slot 'setSpecularRoughness'
        QtMocHelpers::SlotData<void(float)>(78, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 37 },
        }}),
        // Slot 'setRoughnessMap'
        QtMocHelpers::SlotData<void(QQuick3DTexture *)>(79, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 39 },
        }}),
        // Slot 'setOpacity'
        QtMocHelpers::SlotData<void(float)>(80, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 41 },
        }}),
        // Slot 'setOpacityMap'
        QtMocHelpers::SlotData<void(QQuick3DTexture *)>(81, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 43 },
        }}),
        // Slot 'setBumpMap'
        QtMocHelpers::SlotData<void(QQuick3DTexture *)>(82, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 45 },
        }}),
        // Slot 'setBumpAmount'
        QtMocHelpers::SlotData<void(float)>(83, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 47 },
        }}),
        // Slot 'setNormalMap'
        QtMocHelpers::SlotData<void(QQuick3DTexture *)>(84, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 49 },
        }}),
        // Slot 'setTranslucencyMap'
        QtMocHelpers::SlotData<void(QQuick3DTexture *)>(85, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 51 },
        }}),
        // Slot 'setTranslucentFalloff'
        QtMocHelpers::SlotData<void(float)>(86, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 53 },
        }}),
        // Slot 'setDiffuseLightWrap'
        QtMocHelpers::SlotData<void(float)>(87, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 55 },
        }}),
        // Slot 'setVertexColorsEnabled'
        QtMocHelpers::SlotData<void(bool)>(88, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 57 },
        }}),
        // Slot 'setRoughnessChannel'
        QtMocHelpers::SlotData<void(QQuick3DMaterial::TextureChannelMapping)>(89, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 59, 60 },
        }}),
        // Slot 'setOpacityChannel'
        QtMocHelpers::SlotData<void(QQuick3DMaterial::TextureChannelMapping)>(90, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 59, 60 },
        }}),
        // Slot 'setTranslucencyChannel'
        QtMocHelpers::SlotData<void(QQuick3DMaterial::TextureChannelMapping)>(91, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 59, 60 },
        }}),
        // Slot 'setPointSize'
        QtMocHelpers::SlotData<void(float)>(92, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 93 },
        }}),
        // Slot 'setLineWidth'
        QtMocHelpers::SlotData<void(float)>(94, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 95 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'lighting'
        QtMocHelpers::PropertyData<enum Lighting>(6, 0x80000000 | 96, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'blendMode'
        QtMocHelpers::PropertyData<enum BlendMode>(9, 0x80000000 | 97, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'diffuseColor'
        QtMocHelpers::PropertyData<QColor>(12, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'diffuseMap'
        QtMocHelpers::PropertyData<QQuick3DTexture*>(15, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'emissiveFactor'
        QtMocHelpers::PropertyData<QVector3D>(18, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 4),
        // property 'emissiveMap'
        QtMocHelpers::PropertyData<QQuick3DTexture*>(20, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5),
        // property 'specularReflectionMap'
        QtMocHelpers::PropertyData<QQuick3DTexture*>(22, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 6),
        // property 'specularMap'
        QtMocHelpers::PropertyData<QQuick3DTexture*>(24, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 7),
        // property 'specularModel'
        QtMocHelpers::PropertyData<enum SpecularModel>(27, 0x80000000 | 98, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 8),
        // property 'specularTint'
        QtMocHelpers::PropertyData<QColor>(29, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 9),
        // property 'indexOfRefraction'
        QtMocHelpers::PropertyData<float>(31, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'fresnelPower'
        QtMocHelpers::PropertyData<float>(33, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'specularAmount'
        QtMocHelpers::PropertyData<float>(35, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'specularRoughness'
        QtMocHelpers::PropertyData<float>(37, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13),
        // property 'roughnessMap'
        QtMocHelpers::PropertyData<QQuick3DTexture*>(39, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 14),
        // property 'roughnessChannel'
        QtMocHelpers::PropertyData<QQuick3DMaterial::TextureChannelMapping>(99, 0x80000000 | 59, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 24),
        // property 'opacity'
        QtMocHelpers::PropertyData<float>(41, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 15),
        // property 'opacityMap'
        QtMocHelpers::PropertyData<QQuick3DTexture*>(43, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 16),
        // property 'opacityChannel'
        QtMocHelpers::PropertyData<QQuick3DMaterial::TextureChannelMapping>(100, 0x80000000 | 59, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 25),
        // property 'bumpMap'
        QtMocHelpers::PropertyData<QQuick3DTexture*>(45, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 17),
        // property 'bumpAmount'
        QtMocHelpers::PropertyData<float>(47, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 18),
        // property 'normalMap'
        QtMocHelpers::PropertyData<QQuick3DTexture*>(49, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 19),
        // property 'translucencyMap'
        QtMocHelpers::PropertyData<QQuick3DTexture*>(51, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 20),
        // property 'translucencyChannel'
        QtMocHelpers::PropertyData<QQuick3DMaterial::TextureChannelMapping>(101, 0x80000000 | 59, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 26),
        // property 'translucentFalloff'
        QtMocHelpers::PropertyData<float>(53, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 21),
        // property 'diffuseLightWrap'
        QtMocHelpers::PropertyData<float>(55, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 22),
        // property 'vertexColorsEnabled'
        QtMocHelpers::PropertyData<bool>(57, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 23),
        // property 'pointSize'
        QtMocHelpers::PropertyData<float>(102, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 27),
        // property 'lineWidth'
        QtMocHelpers::PropertyData<float>(103, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 28),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Lighting'
        QtMocHelpers::EnumData<enum Lighting>(96, 96, QMC::EnumFlags{}).add({
            {  104, Lighting::NoLighting },
            {  105, Lighting::FragmentLighting },
        }),
        // enum 'BlendMode'
        QtMocHelpers::EnumData<enum BlendMode>(97, 97, QMC::EnumFlags{}).add({
            {  106, BlendMode::SourceOver },
            {  107, BlendMode::Screen },
            {  108, BlendMode::Multiply },
        }),
        // enum 'SpecularModel'
        QtMocHelpers::EnumData<enum SpecularModel>(98, 98, QMC::EnumFlags{}).add({
            {  109, SpecularModel::Default },
            {  110, SpecularModel::KGGX },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DDefaultMaterial, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN23QQuick3DDefaultMaterialE[] = {
    QMetaObject::SuperData::link<QQuick3DMaterial::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject QQuick3DDefaultMaterial::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuick3DMaterial::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23QQuick3DDefaultMaterialE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23QQuick3DDefaultMaterialE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN23QQuick3DDefaultMaterialE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23QQuick3DDefaultMaterialE_t>.metaTypes,
    nullptr
} };

void QQuick3DDefaultMaterial::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DDefaultMaterial *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->lightingChanged((*reinterpret_cast<std::add_pointer_t<QQuick3DDefaultMaterial::Lighting>>(_a[1]))); break;
        case 1: _t->blendModeChanged((*reinterpret_cast<std::add_pointer_t<QQuick3DDefaultMaterial::BlendMode>>(_a[1]))); break;
        case 2: _t->diffuseColorChanged((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 3: _t->diffuseMapChanged((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 4: _t->emissiveFactorChanged((*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[1]))); break;
        case 5: _t->emissiveMapChanged((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 6: _t->specularReflectionMapChanged((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 7: _t->specularMapChanged((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 8: _t->specularModelChanged((*reinterpret_cast<std::add_pointer_t<QQuick3DDefaultMaterial::SpecularModel>>(_a[1]))); break;
        case 9: _t->specularTintChanged((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 10: _t->indexOfRefractionChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 11: _t->fresnelPowerChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 12: _t->specularAmountChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 13: _t->specularRoughnessChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 14: _t->roughnessMapChanged((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 15: _t->opacityChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 16: _t->opacityMapChanged((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 17: _t->bumpMapChanged((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 18: _t->bumpAmountChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 19: _t->normalMapChanged((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 20: _t->translucencyMapChanged((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 21: _t->translucentFalloffChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 22: _t->diffuseLightWrapChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 23: _t->vertexColorsEnabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 24: _t->roughnessChannelChanged((*reinterpret_cast<std::add_pointer_t<QQuick3DMaterial::TextureChannelMapping>>(_a[1]))); break;
        case 25: _t->opacityChannelChanged((*reinterpret_cast<std::add_pointer_t<QQuick3DMaterial::TextureChannelMapping>>(_a[1]))); break;
        case 26: _t->translucencyChannelChanged((*reinterpret_cast<std::add_pointer_t<QQuick3DMaterial::TextureChannelMapping>>(_a[1]))); break;
        case 27: _t->pointSizeChanged(); break;
        case 28: _t->lineWidthChanged(); break;
        case 29: _t->setLighting((*reinterpret_cast<std::add_pointer_t<QQuick3DDefaultMaterial::Lighting>>(_a[1]))); break;
        case 30: _t->setBlendMode((*reinterpret_cast<std::add_pointer_t<QQuick3DDefaultMaterial::BlendMode>>(_a[1]))); break;
        case 31: _t->setDiffuseColor((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 32: _t->setDiffuseMap((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 33: _t->setEmissiveFactor((*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[1]))); break;
        case 34: _t->setEmissiveMap((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 35: _t->setSpecularReflectionMap((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 36: _t->setSpecularMap((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 37: _t->setSpecularModel((*reinterpret_cast<std::add_pointer_t<QQuick3DDefaultMaterial::SpecularModel>>(_a[1]))); break;
        case 38: _t->setSpecularTint((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 39: _t->setIndexOfRefraction((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 40: _t->setFresnelPower((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 41: _t->setSpecularAmount((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 42: _t->setSpecularRoughness((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 43: _t->setRoughnessMap((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 44: _t->setOpacity((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 45: _t->setOpacityMap((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 46: _t->setBumpMap((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 47: _t->setBumpAmount((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 48: _t->setNormalMap((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 49: _t->setTranslucencyMap((*reinterpret_cast<std::add_pointer_t<QQuick3DTexture*>>(_a[1]))); break;
        case 50: _t->setTranslucentFalloff((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 51: _t->setDiffuseLightWrap((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 52: _t->setVertexColorsEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 53: _t->setRoughnessChannel((*reinterpret_cast<std::add_pointer_t<QQuick3DMaterial::TextureChannelMapping>>(_a[1]))); break;
        case 54: _t->setOpacityChannel((*reinterpret_cast<std::add_pointer_t<QQuick3DMaterial::TextureChannelMapping>>(_a[1]))); break;
        case 55: _t->setTranslucencyChannel((*reinterpret_cast<std::add_pointer_t<QQuick3DMaterial::TextureChannelMapping>>(_a[1]))); break;
        case 56: _t->setPointSize((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 57: _t->setLineWidth((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        case 19:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        case 20:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        case 32:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        case 34:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        case 35:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        case 36:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        case 43:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        case 45:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        case 46:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        case 48:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        case 49:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DTexture* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuick3DDefaultMaterial::*)(QQuick3DDefaultMaterial::Lighting )>(_a, &QQuick3DDefaultMaterial::lightingChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DDefaultMaterial::*)(QQuick3DDefaultMaterial::BlendMode )>(_a, &QQuick3DDefaultMaterial::blendModeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DDefaultMaterial::*)(QColor )>(_a, &QQuick3DDefaultMaterial::diffuseColorChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DDefaultMaterial::*)(QQuick3DTexture * )>(_a, &QQuick3DDefaultMaterial::diffuseMapChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DDefaultMaterial::*)(QVector3D )>(_a, &QQuick3DDefaultMaterial::emissiveFactorChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DDefaultMaterial::*)(QQuick3DTexture * )>(_a, &QQuick3DDefaultMaterial::emissiveMapChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DDefaultMaterial::*)(QQuick3DTexture * )>(_a, &QQuick3DDefaultMaterial::specularReflectionMapChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DDefaultMaterial::*)(QQuick3DTexture * )>(_a, &QQuick3DDefaultMaterial::specularMapChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DDefaultMaterial::*)(QQuick3DDefaultMaterial::SpecularModel )>(_a, &QQuick3DDefaultMaterial::specularModelChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DDefaultMaterial::*)(QColor )>(_a, &QQuick3DDefaultMaterial::specularTintChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DDefaultMaterial::*)(float )>(_a, &QQuick3DDefaultMaterial::indexOfRefractionChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DDefaultMaterial::*)(float )>(_a, &QQuick3DDefaultMaterial::fresnelPowerChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DDefaultMaterial::*)(float )>(_a, &QQuick3DDefaultMaterial::specularAmountChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DDefaultMaterial::*)(float )>(_a, &QQuick3DDefaultMaterial::specularRoughnessChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DDefaultMaterial::*)(QQuick3DTexture * )>(_a, &QQuick3DDefaultMaterial::roughnessMapChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DDefaultMaterial::*)(float )>(_a, &QQuick3DDefaultMaterial::opacityChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DDefaultMaterial::*)(QQuick3DTexture * )>(_a, &QQuick3DDefaultMaterial::opacityMapChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DDefaultMaterial::*)(QQuick3DTexture * )>(_a, &QQuick3DDefaultMaterial::bumpMapChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DDefaultMaterial::*)(float )>(_a, &QQuick3DDefaultMaterial::bumpAmountChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DDefaultMaterial::*)(QQuick3DTexture * )>(_a, &QQuick3DDefaultMaterial::normalMapChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DDefaultMaterial::*)(QQuick3DTexture * )>(_a, &QQuick3DDefaultMaterial::translucencyMapChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DDefaultMaterial::*)(float )>(_a, &QQuick3DDefaultMaterial::translucentFalloffChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DDefaultMaterial::*)(float )>(_a, &QQuick3DDefaultMaterial::diffuseLightWrapChanged, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DDefaultMaterial::*)(bool )>(_a, &QQuick3DDefaultMaterial::vertexColorsEnabledChanged, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DDefaultMaterial::*)(QQuick3DMaterial::TextureChannelMapping )>(_a, &QQuick3DDefaultMaterial::roughnessChannelChanged, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DDefaultMaterial::*)(QQuick3DMaterial::TextureChannelMapping )>(_a, &QQuick3DDefaultMaterial::opacityChannelChanged, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DDefaultMaterial::*)(QQuick3DMaterial::TextureChannelMapping )>(_a, &QQuick3DDefaultMaterial::translucencyChannelChanged, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DDefaultMaterial::*)()>(_a, &QQuick3DDefaultMaterial::pointSizeChanged, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DDefaultMaterial::*)()>(_a, &QQuick3DDefaultMaterial::lineWidthChanged, 28))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 22:
        case 21:
        case 19:
        case 17:
        case 14:
        case 7:
        case 6:
        case 5:
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuick3DTexture* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<enum Lighting*>(_v) = _t->lighting(); break;
        case 1: *reinterpret_cast<enum BlendMode*>(_v) = _t->blendMode(); break;
        case 2: *reinterpret_cast<QColor*>(_v) = _t->diffuseColor(); break;
        case 3: *reinterpret_cast<QQuick3DTexture**>(_v) = _t->diffuseMap(); break;
        case 4: *reinterpret_cast<QVector3D*>(_v) = _t->emissiveFactor(); break;
        case 5: *reinterpret_cast<QQuick3DTexture**>(_v) = _t->emissiveMap(); break;
        case 6: *reinterpret_cast<QQuick3DTexture**>(_v) = _t->specularReflectionMap(); break;
        case 7: *reinterpret_cast<QQuick3DTexture**>(_v) = _t->specularMap(); break;
        case 8: *reinterpret_cast<enum SpecularModel*>(_v) = _t->specularModel(); break;
        case 9: *reinterpret_cast<QColor*>(_v) = _t->specularTint(); break;
        case 10: *reinterpret_cast<float*>(_v) = _t->indexOfRefraction(); break;
        case 11: *reinterpret_cast<float*>(_v) = _t->fresnelPower(); break;
        case 12: *reinterpret_cast<float*>(_v) = _t->specularAmount(); break;
        case 13: *reinterpret_cast<float*>(_v) = _t->specularRoughness(); break;
        case 14: *reinterpret_cast<QQuick3DTexture**>(_v) = _t->roughnessMap(); break;
        case 15: *reinterpret_cast<QQuick3DMaterial::TextureChannelMapping*>(_v) = _t->roughnessChannel(); break;
        case 16: *reinterpret_cast<float*>(_v) = _t->opacity(); break;
        case 17: *reinterpret_cast<QQuick3DTexture**>(_v) = _t->opacityMap(); break;
        case 18: *reinterpret_cast<QQuick3DMaterial::TextureChannelMapping*>(_v) = _t->opacityChannel(); break;
        case 19: *reinterpret_cast<QQuick3DTexture**>(_v) = _t->bumpMap(); break;
        case 20: *reinterpret_cast<float*>(_v) = _t->bumpAmount(); break;
        case 21: *reinterpret_cast<QQuick3DTexture**>(_v) = _t->normalMap(); break;
        case 22: *reinterpret_cast<QQuick3DTexture**>(_v) = _t->translucencyMap(); break;
        case 23: *reinterpret_cast<QQuick3DMaterial::TextureChannelMapping*>(_v) = _t->translucencyChannel(); break;
        case 24: *reinterpret_cast<float*>(_v) = _t->translucentFalloff(); break;
        case 25: *reinterpret_cast<float*>(_v) = _t->diffuseLightWrap(); break;
        case 26: *reinterpret_cast<bool*>(_v) = _t->vertexColorsEnabled(); break;
        case 27: *reinterpret_cast<float*>(_v) = _t->pointSize(); break;
        case 28: *reinterpret_cast<float*>(_v) = _t->lineWidth(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setLighting(*reinterpret_cast<enum Lighting*>(_v)); break;
        case 1: _t->setBlendMode(*reinterpret_cast<enum BlendMode*>(_v)); break;
        case 2: _t->setDiffuseColor(*reinterpret_cast<QColor*>(_v)); break;
        case 3: _t->setDiffuseMap(*reinterpret_cast<QQuick3DTexture**>(_v)); break;
        case 4: _t->setEmissiveFactor(*reinterpret_cast<QVector3D*>(_v)); break;
        case 5: _t->setEmissiveMap(*reinterpret_cast<QQuick3DTexture**>(_v)); break;
        case 6: _t->setSpecularReflectionMap(*reinterpret_cast<QQuick3DTexture**>(_v)); break;
        case 7: _t->setSpecularMap(*reinterpret_cast<QQuick3DTexture**>(_v)); break;
        case 8: _t->setSpecularModel(*reinterpret_cast<enum SpecularModel*>(_v)); break;
        case 9: _t->setSpecularTint(*reinterpret_cast<QColor*>(_v)); break;
        case 10: _t->setIndexOfRefraction(*reinterpret_cast<float*>(_v)); break;
        case 11: _t->setFresnelPower(*reinterpret_cast<float*>(_v)); break;
        case 12: _t->setSpecularAmount(*reinterpret_cast<float*>(_v)); break;
        case 13: _t->setSpecularRoughness(*reinterpret_cast<float*>(_v)); break;
        case 14: _t->setRoughnessMap(*reinterpret_cast<QQuick3DTexture**>(_v)); break;
        case 15: _t->setRoughnessChannel(*reinterpret_cast<QQuick3DMaterial::TextureChannelMapping*>(_v)); break;
        case 16: _t->setOpacity(*reinterpret_cast<float*>(_v)); break;
        case 17: _t->setOpacityMap(*reinterpret_cast<QQuick3DTexture**>(_v)); break;
        case 18: _t->setOpacityChannel(*reinterpret_cast<QQuick3DMaterial::TextureChannelMapping*>(_v)); break;
        case 19: _t->setBumpMap(*reinterpret_cast<QQuick3DTexture**>(_v)); break;
        case 20: _t->setBumpAmount(*reinterpret_cast<float*>(_v)); break;
        case 21: _t->setNormalMap(*reinterpret_cast<QQuick3DTexture**>(_v)); break;
        case 22: _t->setTranslucencyMap(*reinterpret_cast<QQuick3DTexture**>(_v)); break;
        case 23: _t->setTranslucencyChannel(*reinterpret_cast<QQuick3DMaterial::TextureChannelMapping*>(_v)); break;
        case 24: _t->setTranslucentFalloff(*reinterpret_cast<float*>(_v)); break;
        case 25: _t->setDiffuseLightWrap(*reinterpret_cast<float*>(_v)); break;
        case 26: _t->setVertexColorsEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 27: _t->setPointSize(*reinterpret_cast<float*>(_v)); break;
        case 28: _t->setLineWidth(*reinterpret_cast<float*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DDefaultMaterial::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DDefaultMaterial::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23QQuick3DDefaultMaterialE_t>.strings))
        return static_cast<void*>(this);
    return QQuick3DMaterial::qt_metacast(_clname);
}

int QQuick3DDefaultMaterial::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuick3DMaterial::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 58)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 58;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 58)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 58;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 29;
    }
    return _id;
}

// SIGNAL 0
void QQuick3DDefaultMaterial::lightingChanged(QQuick3DDefaultMaterial::Lighting _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void QQuick3DDefaultMaterial::blendModeChanged(QQuick3DDefaultMaterial::BlendMode _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void QQuick3DDefaultMaterial::diffuseColorChanged(QColor _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void QQuick3DDefaultMaterial::diffuseMapChanged(QQuick3DTexture * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void QQuick3DDefaultMaterial::emissiveFactorChanged(QVector3D _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void QQuick3DDefaultMaterial::emissiveMapChanged(QQuick3DTexture * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void QQuick3DDefaultMaterial::specularReflectionMapChanged(QQuick3DTexture * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void QQuick3DDefaultMaterial::specularMapChanged(QQuick3DTexture * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void QQuick3DDefaultMaterial::specularModelChanged(QQuick3DDefaultMaterial::SpecularModel _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void QQuick3DDefaultMaterial::specularTintChanged(QColor _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void QQuick3DDefaultMaterial::indexOfRefractionChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void QQuick3DDefaultMaterial::fresnelPowerChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void QQuick3DDefaultMaterial::specularAmountChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void QQuick3DDefaultMaterial::specularRoughnessChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}

// SIGNAL 14
void QQuick3DDefaultMaterial::roughnessMapChanged(QQuick3DTexture * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void QQuick3DDefaultMaterial::opacityChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void QQuick3DDefaultMaterial::opacityMapChanged(QQuick3DTexture * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void QQuick3DDefaultMaterial::bumpMapChanged(QQuick3DTexture * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void QQuick3DDefaultMaterial::bumpAmountChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void QQuick3DDefaultMaterial::normalMapChanged(QQuick3DTexture * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1);
}

// SIGNAL 20
void QQuick3DDefaultMaterial::translucencyMapChanged(QQuick3DTexture * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 20, nullptr, _t1);
}

// SIGNAL 21
void QQuick3DDefaultMaterial::translucentFalloffChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 21, nullptr, _t1);
}

// SIGNAL 22
void QQuick3DDefaultMaterial::diffuseLightWrapChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 22, nullptr, _t1);
}

// SIGNAL 23
void QQuick3DDefaultMaterial::vertexColorsEnabledChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 23, nullptr, _t1);
}

// SIGNAL 24
void QQuick3DDefaultMaterial::roughnessChannelChanged(QQuick3DMaterial::TextureChannelMapping _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 24, nullptr, _t1);
}

// SIGNAL 25
void QQuick3DDefaultMaterial::opacityChannelChanged(QQuick3DMaterial::TextureChannelMapping _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 25, nullptr, _t1);
}

// SIGNAL 26
void QQuick3DDefaultMaterial::translucencyChannelChanged(QQuick3DMaterial::TextureChannelMapping _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 26, nullptr, _t1);
}

// SIGNAL 27
void QQuick3DDefaultMaterial::pointSizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 27, nullptr);
}

// SIGNAL 28
void QQuick3DDefaultMaterial::lineWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 28, nullptr);
}
QT_WARNING_POP
