/****************************************************************************
** Meta object code from reading C++ file 'qquick3dxrview_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../qtquick3d/src/xr/quick3dxr/qquick3dxrview_p.h"
#include <QtGui/qtextcursor.h>
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquick3dxrview_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14QQuick3DXrViewE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DXrView::qt_create_metaobjectdata<qt_meta_tag_ZN14QQuick3DXrViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DXrView",
        "QML.Element",
        "XrView",
        "QML.AddedInVersion",
        "1544",
        "initializeFailed",
        "",
        "errorString",
        "sessionEnded",
        "xrOriginChanged",
        "environmentChanged",
        "QQuick3DSceneEnvironment*",
        "environment",
        "passthroughEnabledChanged",
        "quitOnSessionEndChanged",
        "fixedFoveationChanged",
        "frameReady",
        "referenceSpaceChanged",
        "depthSubmissionEnabledChanged",
        "multiViewRenderingEnabledChanged",
        "setEnvironment",
        "setPassthroughEnabled",
        "enable",
        "setQuitOnSessionEnd",
        "setDepthSubmissionEnabled",
        "setXROrigin",
        "QQuick3DXrOrigin*",
        "newXrOrigin",
        "updateViewportGeometry",
        "handleSessionEnded",
        "handleClearColorChanged",
        "handleAAChanged",
        "init",
        "rayPick",
        "QQuick3DPickResult",
        "QVector3D",
        "origin",
        "direction",
        "rayPickAll",
        "QList<QQuick3DPickResult>",
        "QQuick3DModel*",
        "model",
        "closestPointPick",
        "radius",
        "setTouchpoint",
        "QQuickItem*",
        "target",
        "QPointF",
        "position",
        "pointId",
        "active",
        "processTouch",
        "pos",
        "touchpointState",
        "QVariantMap",
        "xrOrigin",
        "passthroughSupported",
        "passthroughEnabled",
        "runtimeInfo",
        "QQuick3DXrRuntimeInfo*",
        "quitOnSessionEnd",
        "renderStats",
        "QQuick3DRenderStats*",
        "fixedFoveation",
        "FoveationLevel",
        "referenceSpace",
        "ReferenceSpace",
        "depthSubmissionEnabled",
        "multiViewRenderingSupported",
        "multiViewRenderingEnabled",
        "NoFoveation",
        "LowFoveation",
        "MediumFoveation",
        "HighFoveation",
        "ReferenceSpaceUnknown",
        "ReferenceSpaceLocal",
        "ReferenceSpaceStage",
        "ReferenceSpaceLocalFloor"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'initializeFailed'
        QtMocHelpers::SignalData<void(const QString &)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'sessionEnded'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'xrOriginChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'environmentChanged'
        QtMocHelpers::SignalData<void(QQuick3DSceneEnvironment *)>(10, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Signal 'passthroughEnabledChanged'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'quitOnSessionEndChanged'
        QtMocHelpers::SignalData<void()>(14, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fixedFoveationChanged'
        QtMocHelpers::SignalData<void()>(15, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'frameReady'
        QtMocHelpers::SignalData<void()>(16, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'referenceSpaceChanged'
        QtMocHelpers::SignalData<void()>(17, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'depthSubmissionEnabledChanged'
        QtMocHelpers::SignalData<void()>(18, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'multiViewRenderingEnabledChanged'
        QtMocHelpers::SignalData<void()>(19, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setEnvironment'
        QtMocHelpers::SlotData<void(QQuick3DSceneEnvironment *)>(20, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'setPassthroughEnabled'
        QtMocHelpers::SlotData<void(bool)>(21, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 22 },
        }}),
        // Slot 'setQuitOnSessionEnd'
        QtMocHelpers::SlotData<void(bool)>(23, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 22 },
        }}),
        // Slot 'setDepthSubmissionEnabled'
        QtMocHelpers::SlotData<void(bool)>(24, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 22 },
        }}),
        // Slot 'setXROrigin'
        QtMocHelpers::SlotData<void(QQuick3DXrOrigin *)>(25, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 26, 27 },
        }}),
        // Slot 'updateViewportGeometry'
        QtMocHelpers::SlotData<void()>(28, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'handleSessionEnded'
        QtMocHelpers::SlotData<void()>(29, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'handleClearColorChanged'
        QtMocHelpers::SlotData<void()>(30, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'handleAAChanged'
        QtMocHelpers::SlotData<void()>(31, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'init'
        QtMocHelpers::SlotData<bool()>(32, 6, QMC::AccessPrivate, QMetaType::Bool),
        // Method 'rayPick'
        QtMocHelpers::MethodData<QQuick3DPickResult(const QVector3D &, const QVector3D &) const>(33, 6, QMC::AccessPublic, 0x80000000 | 34, {{
            { 0x80000000 | 35, 36 }, { 0x80000000 | 35, 37 },
        }}),
        // Method 'rayPickAll'
        QtMocHelpers::MethodData<QList<QQuick3DPickResult>(const QVector3D &, const QVector3D &) const>(38, 6, QMC::AccessPublic, 0x80000000 | 39, {{
            { 0x80000000 | 35, 36 }, { 0x80000000 | 35, 37 },
        }}),
        // Method 'rayPick'
        QtMocHelpers::RevisionedMethodData<QQuick3DPickResult(const QVector3D &, const QVector3D &, QQuick3DModel *) const>(33, 6, QMC::AccessPublic, 0x60b, 0x80000000 | 34, {{
            { 0x80000000 | 35, 36 }, { 0x80000000 | 35, 37 }, { 0x80000000 | 40, 41 },
        }}),
        // Method 'closestPointPick'
        QtMocHelpers::RevisionedMethodData<QQuick3DPickResult(const QVector3D &, float, QQuick3DModel *) const>(42, 6, QMC::AccessPublic, 0x60b, 0x80000000 | 34, {{
            { 0x80000000 | 35, 36 }, { QMetaType::Float, 43 }, { 0x80000000 | 40, 41 },
        }}),
        // Method 'closestPointPick'
        QtMocHelpers::RevisionedMethodData<QQuick3DPickResult(const QVector3D &, float) const>(42, 6, QMC::AccessPublic | QMC::MethodCloned, 0x60b, 0x80000000 | 34, {{
            { 0x80000000 | 35, 36 }, { QMetaType::Float, 43 },
        }}),
        // Method 'setTouchpoint'
        QtMocHelpers::MethodData<void(QQuickItem *, const QPointF &, int, bool)>(44, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 45, 46 }, { 0x80000000 | 47, 48 }, { QMetaType::Int, 49 }, { QMetaType::Bool, 50 },
        }}),
        // Method 'processTouch'
        QtMocHelpers::MethodData<QVector3D(const QVector3D &, int)>(51, 6, QMC::AccessPublic, 0x80000000 | 35, {{
            { 0x80000000 | 35, 52 }, { QMetaType::Int, 49 },
        }}),
        // Method 'touchpointState'
        QtMocHelpers::MethodData<QVariantMap(int) const>(53, 6, QMC::AccessPublic, 0x80000000 | 54, {{
            { QMetaType::Int, 49 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'xrOrigin'
        QtMocHelpers::PropertyData<QQuick3DXrOrigin*>(55, 0x80000000 | 26, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 2),
        // property 'environment'
        QtMocHelpers::PropertyData<QQuick3DSceneEnvironment*>(12, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'passthroughSupported'
        QtMocHelpers::PropertyData<bool>(56, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'passthroughEnabled'
        QtMocHelpers::PropertyData<bool>(57, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 4),
        // property 'runtimeInfo'
        QtMocHelpers::PropertyData<QQuick3DXrRuntimeInfo*>(58, 0x80000000 | 59, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'quitOnSessionEnd'
        QtMocHelpers::PropertyData<bool>(60, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 5),
        // property 'renderStats'
        QtMocHelpers::PropertyData<QQuick3DRenderStats*>(61, 0x80000000 | 62, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'fixedFoveation'
        QtMocHelpers::PropertyData<enum FoveationLevel>(63, 0x80000000 | 64, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 6),
        // property 'referenceSpace'
        QtMocHelpers::PropertyData<enum ReferenceSpace>(65, 0x80000000 | 66, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 8),
        // property 'depthSubmissionEnabled'
        QtMocHelpers::PropertyData<bool>(67, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 9),
        // property 'multiViewRenderingSupported'
        QtMocHelpers::PropertyData<bool>(68, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'multiViewRenderingEnabled'
        QtMocHelpers::PropertyData<bool>(69, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Final, 10),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'FoveationLevel'
        QtMocHelpers::EnumData<enum FoveationLevel>(64, 64, QMC::EnumFlags{}).add({
            {   70, FoveationLevel::NoFoveation },
            {   71, FoveationLevel::LowFoveation },
            {   72, FoveationLevel::MediumFoveation },
            {   73, FoveationLevel::HighFoveation },
        }),
        // enum 'ReferenceSpace'
        QtMocHelpers::EnumData<enum ReferenceSpace>(66, 66, QMC::EnumIsScoped).add({
            {   74, ReferenceSpace::ReferenceSpaceUnknown },
            {   75, ReferenceSpace::ReferenceSpaceLocal },
            {   76, ReferenceSpace::ReferenceSpaceStage },
            {   77, ReferenceSpace::ReferenceSpaceLocalFloor },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DXrView, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DXrView::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuick3DNode::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14QQuick3DXrViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14QQuick3DXrViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14QQuick3DXrViewE_t>.metaTypes,
    nullptr
} };

void QQuick3DXrView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DXrView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->initializeFailed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->sessionEnded(); break;
        case 2: _t->xrOriginChanged(); break;
        case 3: _t->environmentChanged((*reinterpret_cast<std::add_pointer_t<QQuick3DSceneEnvironment*>>(_a[1]))); break;
        case 4: _t->passthroughEnabledChanged(); break;
        case 5: _t->quitOnSessionEndChanged(); break;
        case 6: _t->fixedFoveationChanged(); break;
        case 7: _t->frameReady(); break;
        case 8: _t->referenceSpaceChanged(); break;
        case 9: _t->depthSubmissionEnabledChanged(); break;
        case 10: _t->multiViewRenderingEnabledChanged(); break;
        case 11: _t->setEnvironment((*reinterpret_cast<std::add_pointer_t<QQuick3DSceneEnvironment*>>(_a[1]))); break;
        case 12: _t->setPassthroughEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->setQuitOnSessionEnd((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 14: _t->setDepthSubmissionEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 15: _t->setXROrigin((*reinterpret_cast<std::add_pointer_t<QQuick3DXrOrigin*>>(_a[1]))); break;
        case 16: _t->updateViewportGeometry(); break;
        case 17: _t->handleSessionEnded(); break;
        case 18: _t->handleClearColorChanged(); break;
        case 19: _t->handleAAChanged(); break;
        case 20: { bool _r = _t->init();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 21: { QQuick3DPickResult _r = _t->rayPick((*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QQuick3DPickResult*>(_a[0]) = std::move(_r); }  break;
        case 22: { QList<QQuick3DPickResult> _r = _t->rayPickAll((*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QList<QQuick3DPickResult>*>(_a[0]) = std::move(_r); }  break;
        case 23: { QQuick3DPickResult _r = _t->rayPick((*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QQuick3DModel*>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QQuick3DPickResult*>(_a[0]) = std::move(_r); }  break;
        case 24: { QQuick3DPickResult _r = _t->closestPointPick((*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<float>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QQuick3DModel*>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QQuick3DPickResult*>(_a[0]) = std::move(_r); }  break;
        case 25: { QQuick3DPickResult _r = _t->closestPointPick((*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<float>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QQuick3DPickResult*>(_a[0]) = std::move(_r); }  break;
        case 26: _t->setTouchpoint((*reinterpret_cast<std::add_pointer_t<QQuickItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 27: { QVector3D _r = _t->processTouch((*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QVector3D*>(_a[0]) = std::move(_r); }  break;
        case 28: { QVariantMap _r = _t->touchpointState((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DSceneEnvironment* >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DSceneEnvironment* >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DXrOrigin* >(); break;
            }
            break;
        case 23:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DModel* >(); break;
            }
            break;
        case 24:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuick3DModel* >(); break;
            }
            break;
        case 26:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuickItem* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuick3DXrView::*)(const QString & )>(_a, &QQuick3DXrView::initializeFailed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DXrView::*)()>(_a, &QQuick3DXrView::sessionEnded, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DXrView::*)()>(_a, &QQuick3DXrView::xrOriginChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DXrView::*)(QQuick3DSceneEnvironment * )>(_a, &QQuick3DXrView::environmentChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DXrView::*)()>(_a, &QQuick3DXrView::passthroughEnabledChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DXrView::*)()>(_a, &QQuick3DXrView::quitOnSessionEndChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DXrView::*)()>(_a, &QQuick3DXrView::fixedFoveationChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DXrView::*)()>(_a, &QQuick3DXrView::frameReady, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DXrView::*)()>(_a, &QQuick3DXrView::referenceSpaceChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DXrView::*)()>(_a, &QQuick3DXrView::depthSubmissionEnabledChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DXrView::*)()>(_a, &QQuick3DXrView::multiViewRenderingEnabledChanged, 10))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 6:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuick3DRenderStats* >(); break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuick3DSceneEnvironment* >(); break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuick3DXrOrigin* >(); break;
        case 4:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuick3DXrRuntimeInfo* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QQuick3DXrOrigin**>(_v) = _t->xrOrigin(); break;
        case 1: *reinterpret_cast<QQuick3DSceneEnvironment**>(_v) = _t->environment(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->passthroughSupported(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->passthroughEnabled(); break;
        case 4: *reinterpret_cast<QQuick3DXrRuntimeInfo**>(_v) = _t->runtimeInfo(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->isQuitOnSessionEndEnabled(); break;
        case 6: *reinterpret_cast<QQuick3DRenderStats**>(_v) = _t->renderStats(); break;
        case 7: *reinterpret_cast<enum FoveationLevel*>(_v) = _t->fixedFoveation(); break;
        case 8: *reinterpret_cast<enum ReferenceSpace*>(_v) = _t->referenceSpace(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->depthSubmissionEnabled(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isMultiViewRenderingSupported(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->multiViewRenderingEnabled(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setXROrigin(*reinterpret_cast<QQuick3DXrOrigin**>(_v)); break;
        case 1: _t->setEnvironment(*reinterpret_cast<QQuick3DSceneEnvironment**>(_v)); break;
        case 3: _t->setPassthroughEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setQuitOnSessionEnd(*reinterpret_cast<bool*>(_v)); break;
        case 7: _t->setFixedFoveation(*reinterpret_cast<enum FoveationLevel*>(_v)); break;
        case 8: _t->setReferenceSpace(*reinterpret_cast<enum ReferenceSpace*>(_v)); break;
        case 9: _t->setDepthSubmissionEnabled(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DXrView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DXrView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14QQuick3DXrViewE_t>.strings))
        return static_cast<void*>(this);
    return QQuick3DNode::qt_metacast(_clname);
}

int QQuick3DXrView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuick3DNode::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 29)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 29;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 29)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 29;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void QQuick3DXrView::initializeFailed(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void QQuick3DXrView::sessionEnded()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QQuick3DXrView::xrOriginChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QQuick3DXrView::environmentChanged(QQuick3DSceneEnvironment * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void QQuick3DXrView::passthroughEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QQuick3DXrView::quitOnSessionEndChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QQuick3DXrView::fixedFoveationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void QQuick3DXrView::frameReady()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void QQuick3DXrView::referenceSpaceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void QQuick3DXrView::depthSubmissionEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void QQuick3DXrView::multiViewRenderingEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}
QT_WARNING_POP
