// This file is autogenerated. Changes will be overwritten.
#include "EWIEGA46WW/moc_qquick3drenderstatsmeshesmodel_p.cpp"
#include "EWIEGA46WW/moc_qquick3drenderstatspassesmodel_p.cpp"
#include "EWIEGA46WW/moc_qquick3drenderstatstexturesmodel_p.cpp"
#include "EWIEGA46WW/moc_sceneeffects_p.cpp"
