/****************************************************************************
** Meta object code from reading C++ file 'qquick3dxrhandinput_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../qtquick3d/src/xr/quick3dxr/qquick3dxrhandinput_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquick3dxrhandinput_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19QQuick3DXrHandInputE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DXrHandInput::qt_create_metaobjectdata<qt_meta_tag_ZN19QQuick3DXrHandInputE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DXrHandInput",
        "isActiveChanged",
        "",
        "poseSpaceChanged",
        "posePositionChanged",
        "poseRotationChanged",
        "jointPositionsChanged",
        "jointRotationsChanged",
        "jointDataUpdated",
        "pokePositionChanged",
        "isHandTrackingChanged",
        "HandPoseSpace",
        "GripPose",
        "AimPose"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'isActiveChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'poseSpaceChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'posePositionChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'poseRotationChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'jointPositionsChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'jointRotationsChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'jointDataUpdated'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pokePositionChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'isHandTrackingChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'HandPoseSpace'
        QtMocHelpers::EnumData<enum HandPoseSpace>(11, 11, QMC::EnumIsScoped).add({
            {   12, HandPoseSpace::GripPose },
            {   13, HandPoseSpace::AimPose },
        }),
    };
    return QtMocHelpers::metaObjectData<QQuick3DXrHandInput, qt_meta_tag_ZN19QQuick3DXrHandInputE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QQuick3DXrHandInput::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19QQuick3DXrHandInputE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19QQuick3DXrHandInputE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19QQuick3DXrHandInputE_t>.metaTypes,
    nullptr
} };

void QQuick3DXrHandInput::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DXrHandInput *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->isActiveChanged(); break;
        case 1: _t->poseSpaceChanged(); break;
        case 2: _t->posePositionChanged(); break;
        case 3: _t->poseRotationChanged(); break;
        case 4: _t->jointPositionsChanged(); break;
        case 5: _t->jointRotationsChanged(); break;
        case 6: _t->jointDataUpdated(); break;
        case 7: _t->pokePositionChanged(); break;
        case 8: _t->isHandTrackingChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuick3DXrHandInput::*)()>(_a, &QQuick3DXrHandInput::isActiveChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DXrHandInput::*)()>(_a, &QQuick3DXrHandInput::poseSpaceChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DXrHandInput::*)()>(_a, &QQuick3DXrHandInput::posePositionChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DXrHandInput::*)()>(_a, &QQuick3DXrHandInput::poseRotationChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DXrHandInput::*)()>(_a, &QQuick3DXrHandInput::jointPositionsChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DXrHandInput::*)()>(_a, &QQuick3DXrHandInput::jointRotationsChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DXrHandInput::*)()>(_a, &QQuick3DXrHandInput::jointDataUpdated, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DXrHandInput::*)()>(_a, &QQuick3DXrHandInput::pokePositionChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DXrHandInput::*)()>(_a, &QQuick3DXrHandInput::isHandTrackingChanged, 8))
            return;
    }
}

const QMetaObject *QQuick3DXrHandInput::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DXrHandInput::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19QQuick3DXrHandInputE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QQuick3DXrHandInput::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void QQuick3DXrHandInput::isActiveChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QQuick3DXrHandInput::poseSpaceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QQuick3DXrHandInput::posePositionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QQuick3DXrHandInput::poseRotationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QQuick3DXrHandInput::jointPositionsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QQuick3DXrHandInput::jointRotationsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QQuick3DXrHandInput::jointDataUpdated()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void QQuick3DXrHandInput::pokePositionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void QQuick3DXrHandInput::isHandTrackingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
QT_WARNING_POP
