/****************************************************************************
** Meta object code from reading C++ file 'qquick3dscenemanager_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtquick3d/src/quick3d/qquick3dscenemanager_p.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QSet>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquick3dscenemanager_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN24QQuick3DWindowAttachmentE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DWindowAttachment::qt_create_metaobjectdata<qt_meta_tag_ZN24QQuick3DWindowAttachmentE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DWindowAttachment",
        "releaseCachedResources",
        "",
        "renderContextInterfaceChanged",
        "preSync",
        "cleanupResources",
        "synchronize",
        "SyncResult",
        "QSet<QSSGRenderGraphObject*>&",
        "resourceLoaders",
        "requestUpdate",
        "evaluateEol",
        "onReleaseCachedResources",
        "onInvalidated"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'releaseCachedResources'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'renderContextInterfaceChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'preSync'
        QtMocHelpers::MethodData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'cleanupResources'
        QtMocHelpers::MethodData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'synchronize'
        QtMocHelpers::MethodData<SyncResult(QSet<QSSGRenderGraphObject*> &)>(6, 2, QMC::AccessPublic, 0x80000000 | 7, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Method 'requestUpdate'
        QtMocHelpers::MethodData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'evaluateEol'
        QtMocHelpers::MethodData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'onReleaseCachedResources'
        QtMocHelpers::MethodData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Method 'onInvalidated'
        QtMocHelpers::MethodData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QQuick3DWindowAttachment, qt_meta_tag_ZN24QQuick3DWindowAttachmentE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QQuick3DWindowAttachment::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24QQuick3DWindowAttachmentE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24QQuick3DWindowAttachmentE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN24QQuick3DWindowAttachmentE_t>.metaTypes,
    nullptr
} };

void QQuick3DWindowAttachment::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DWindowAttachment *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->releaseCachedResources(); break;
        case 1: _t->renderContextInterfaceChanged(); break;
        case 2: _t->preSync(); break;
        case 3: _t->cleanupResources(); break;
        case 4: { SyncResult _r = _t->synchronize((*reinterpret_cast<std::add_pointer_t<QSet<QSSGRenderGraphObject*>&>>(_a[1])));
            if (_a[0]) *reinterpret_cast<SyncResult*>(_a[0]) = std::move(_r); }  break;
        case 5: _t->requestUpdate(); break;
        case 6: _t->evaluateEol(); break;
        case 7: _t->onReleaseCachedResources(); break;
        case 8: _t->onInvalidated(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuick3DWindowAttachment::*)()>(_a, &QQuick3DWindowAttachment::releaseCachedResources, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DWindowAttachment::*)()>(_a, &QQuick3DWindowAttachment::renderContextInterfaceChanged, 1))
            return;
    }
}

const QMetaObject *QQuick3DWindowAttachment::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DWindowAttachment::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24QQuick3DWindowAttachmentE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QQuick3DWindowAttachment::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void QQuick3DWindowAttachment::releaseCachedResources()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QQuick3DWindowAttachment::renderContextInterfaceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
namespace {
struct qt_meta_tag_ZN20QQuick3DSceneManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DSceneManager::qt_create_metaobjectdata<qt_meta_tag_ZN20QQuick3DSceneManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DSceneManager",
        "needsUpdate",
        "",
        "windowChanged",
        "updateResources",
        "SyncResult",
        "QQuick3DObject**",
        "listHead",
        "updateNodes",
        "updateExtensions"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'needsUpdate'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'windowChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateResources'
        QtMocHelpers::SlotData<SyncResult(QQuick3DObject * *)>(4, 2, QMC::AccessPrivate, 0x80000000 | 5, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'updateNodes'
        QtMocHelpers::SlotData<void(QQuick3DObject * *)>(8, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'updateExtensions'
        QtMocHelpers::SlotData<SyncResult(QQuick3DObject * *)>(9, 2, QMC::AccessPrivate, 0x80000000 | 5, {{
            { 0x80000000 | 6, 7 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QQuick3DSceneManager, qt_meta_tag_ZN20QQuick3DSceneManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QQuick3DSceneManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20QQuick3DSceneManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20QQuick3DSceneManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20QQuick3DSceneManagerE_t>.metaTypes,
    nullptr
} };

void QQuick3DSceneManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DSceneManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->needsUpdate(); break;
        case 1: _t->windowChanged(); break;
        case 2: { SyncResult _r = _t->updateResources((*reinterpret_cast<std::add_pointer_t<QQuick3DObject**>>(_a[1])));
            if (_a[0]) *reinterpret_cast<SyncResult*>(_a[0]) = std::move(_r); }  break;
        case 3: _t->updateNodes((*reinterpret_cast<std::add_pointer_t<QQuick3DObject**>>(_a[1]))); break;
        case 4: { SyncResult _r = _t->updateExtensions((*reinterpret_cast<std::add_pointer_t<QQuick3DObject**>>(_a[1])));
            if (_a[0]) *reinterpret_cast<SyncResult*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSceneManager::*)()>(_a, &QQuick3DSceneManager::needsUpdate, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DSceneManager::*)()>(_a, &QQuick3DSceneManager::windowChanged, 1))
            return;
    }
}

const QMetaObject *QQuick3DSceneManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DSceneManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20QQuick3DSceneManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QQuick3DSceneManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void QQuick3DSceneManager::needsUpdate()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QQuick3DSceneManager::windowChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
namespace {
struct qt_meta_tag_ZN17QSSGCleanupObjectE_t {};
} // unnamed namespace

template <> constexpr inline auto QSSGCleanupObject::qt_create_metaobjectdata<qt_meta_tag_ZN17QSSGCleanupObjectE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QSSGCleanupObject",
        "cleanupResources",
        ""
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'cleanupResources'
        QtMocHelpers::MethodData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QSSGCleanupObject, qt_meta_tag_ZN17QSSGCleanupObjectE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QSSGCleanupObject::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17QSSGCleanupObjectE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17QSSGCleanupObjectE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17QSSGCleanupObjectE_t>.metaTypes,
    nullptr
} };

void QSSGCleanupObject::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QSSGCleanupObject *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->cleanupResources(); break;
        default: ;
        }
    }
    (void)_a;
}

const QMetaObject *QSSGCleanupObject::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QSSGCleanupObject::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17QSSGCleanupObjectE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QSSGCleanupObject::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
QT_WARNING_POP
