/****************************************************************************
** Meta object code from reading C++ file 'qquick3dtexturedata.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtquick3d/src/quick3d/qquick3dtexturedata.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquick3dtexturedata.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19QQuick3DTextureDataE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DTextureData::qt_create_metaobjectdata<qt_meta_tag_ZN19QQuick3DTextureDataE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DTextureData",
        "QML.Element",
        "TextureData",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "TextureData is Abstract",
        "QML.AddedInVersion",
        "1536",
        "textureDataNodeDirty",
        "",
        "Format",
        "None",
        "RGBA8",
        "RGBA16F",
        "RGBA32F",
        "RGBE8",
        "R8",
        "R16",
        "R16F",
        "R32F",
        "BC1",
        "BC2",
        "BC3",
        "BC4",
        "BC5",
        "BC6H",
        "BC7",
        "DXT1_RGBA",
        "DXT1_RGB",
        "DXT3_RGBA",
        "DXT5_RGBA",
        "ETC2_RGB8",
        "ETC2_RGB8A1",
        "ETC2_RGBA8",
        "ASTC_4x4",
        "ASTC_5x4",
        "ASTC_5x5",
        "ASTC_6x5",
        "ASTC_6x6",
        "ASTC_8x5",
        "ASTC_8x6",
        "ASTC_8x8",
        "ASTC_10x5",
        "ASTC_10x6",
        "ASTC_10x8",
        "ASTC_10x10",
        "ASTC_12x10",
        "ASTC_12x12"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'textureDataNodeDirty'
        QtMocHelpers::SignalData<void()>(9, 10, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Format'
        QtMocHelpers::EnumData<enum Format>(11, 11, QMC::EnumFlags{}).add({
            {   12, Format::None },
            {   13, Format::RGBA8 },
            {   14, Format::RGBA16F },
            {   15, Format::RGBA32F },
            {   16, Format::RGBE8 },
            {   17, Format::R8 },
            {   18, Format::R16 },
            {   19, Format::R16F },
            {   20, Format::R32F },
            {   21, Format::BC1 },
            {   22, Format::BC2 },
            {   23, Format::BC3 },
            {   24, Format::BC4 },
            {   25, Format::BC5 },
            {   26, Format::BC6H },
            {   27, Format::BC7 },
            {   28, Format::DXT1_RGBA },
            {   29, Format::DXT1_RGB },
            {   30, Format::DXT3_RGBA },
            {   31, Format::DXT5_RGBA },
            {   32, Format::ETC2_RGB8 },
            {   33, Format::ETC2_RGB8A1 },
            {   34, Format::ETC2_RGBA8 },
            {   35, Format::ASTC_4x4 },
            {   36, Format::ASTC_5x4 },
            {   37, Format::ASTC_5x5 },
            {   38, Format::ASTC_6x5 },
            {   39, Format::ASTC_6x6 },
            {   40, Format::ASTC_8x5 },
            {   41, Format::ASTC_8x6 },
            {   42, Format::ASTC_8x8 },
            {   43, Format::ASTC_10x5 },
            {   44, Format::ASTC_10x6 },
            {   45, Format::ASTC_10x8 },
            {   46, Format::ASTC_10x10 },
            {   47, Format::ASTC_12x10 },
            {   48, Format::ASTC_12x12 },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
            {    7,    8 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DTextureData, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DTextureData::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuick3DObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19QQuick3DTextureDataE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19QQuick3DTextureDataE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19QQuick3DTextureDataE_t>.metaTypes,
    nullptr
} };

void QQuick3DTextureData::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DTextureData *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->textureDataNodeDirty(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuick3DTextureData::*)()>(_a, &QQuick3DTextureData::textureDataNodeDirty, 0))
            return;
    }
}

const QMetaObject *QQuick3DTextureData::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DTextureData::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19QQuick3DTextureDataE_t>.strings))
        return static_cast<void*>(this);
    return QQuick3DObject::qt_metacast(_clname);
}

int QQuick3DTextureData::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuick3DObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void QQuick3DTextureData::textureDataNodeDirty()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
