/****************************************************************************
** Meta object code from reading C++ file 'qquick3dnode_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtquick3d/src/quick3d/qquick3dnode_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquick3dnode_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12QQuick3DNodeE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DNode::qt_create_metaobjectdata<qt_meta_tag_ZN12QQuick3DNodeE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DNode",
        "QML.Element",
        "Node",
        "xChanged",
        "",
        "yChanged",
        "zChanged",
        "rotationChanged",
        "eulerRotationChanged",
        "positionChanged",
        "scaleChanged",
        "pivotChanged",
        "localOpacityChanged",
        "visibleChanged",
        "forwardChanged",
        "upChanged",
        "rightChanged",
        "sceneTransformChanged",
        "scenePositionChanged",
        "sceneRotationChanged",
        "sceneScaleChanged",
        "staticFlagsChanged",
        "layersChanged",
        "setX",
        "x",
        "setY",
        "y",
        "setZ",
        "z",
        "setRotation",
        "QQuaternion",
        "rotation",
        "setEulerRotation",
        "QVector3D",
        "eulerRotation",
        "setPosition",
        "position",
        "setScale",
        "scale",
        "setPivot",
        "pivot",
        "setLocalOpacity",
        "opacity",
        "setVisible",
        "visible",
        "setStaticFlags",
        "staticFlags",
        "setLayers",
        "newLayers",
        "rotate",
        "degrees",
        "axis",
        "QQuick3DNode::TransformSpace",
        "space",
        "mapPositionToScene",
        "localPosition",
        "mapPositionFromScene",
        "scenePosition",
        "mapPositionToNode",
        "const QQuick3DNode*",
        "node",
        "mapPositionFromNode",
        "mapDirectionToScene",
        "localDirection",
        "mapDirectionFromScene",
        "sceneDirection",
        "mapDirectionToNode",
        "mapDirectionFromNode",
        "forward",
        "up",
        "right",
        "sceneRotation",
        "sceneScale",
        "sceneTransform",
        "QMatrix4x4",
        "layers",
        "TransformSpace",
        "LocalSpace",
        "ParentSpace",
        "SceneSpace",
        "StaticFlags",
        "None"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'xChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'yChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'zChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'rotationChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'eulerRotationChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'positionChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scaleChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pivotChanged'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'localOpacityChanged'
        QtMocHelpers::SignalData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'visibleChanged'
        QtMocHelpers::SignalData<void()>(13, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'forwardChanged'
        QtMocHelpers::SignalData<void()>(14, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'upChanged'
        QtMocHelpers::SignalData<void()>(15, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'rightChanged'
        QtMocHelpers::SignalData<void()>(16, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sceneTransformChanged'
        QtMocHelpers::SignalData<void()>(17, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scenePositionChanged'
        QtMocHelpers::SignalData<void()>(18, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sceneRotationChanged'
        QtMocHelpers::SignalData<void()>(19, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sceneScaleChanged'
        QtMocHelpers::SignalData<void()>(20, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'staticFlagsChanged'
        QtMocHelpers::SignalData<void()>(21, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'layersChanged'
        QtMocHelpers::SignalData<void()>(22, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setX'
        QtMocHelpers::SlotData<void(float)>(23, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 24 },
        }}),
        // Slot 'setY'
        QtMocHelpers::SlotData<void(float)>(25, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 26 },
        }}),
        // Slot 'setZ'
        QtMocHelpers::SlotData<void(float)>(27, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 28 },
        }}),
        // Slot 'setRotation'
        QtMocHelpers::SlotData<void(const QQuaternion &)>(29, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 30, 31 },
        }}),
        // Slot 'setEulerRotation'
        QtMocHelpers::SlotData<void(const QVector3D &)>(32, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 33, 34 },
        }}),
        // Slot 'setPosition'
        QtMocHelpers::SlotData<void(const QVector3D &)>(35, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 33, 36 },
        }}),
        // Slot 'setScale'
        QtMocHelpers::SlotData<void(const QVector3D &)>(37, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 33, 38 },
        }}),
        // Slot 'setPivot'
        QtMocHelpers::SlotData<void(const QVector3D &)>(39, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 33, 40 },
        }}),
        // Slot 'setLocalOpacity'
        QtMocHelpers::SlotData<void(float)>(41, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 42 },
        }}),
        // Slot 'setVisible'
        QtMocHelpers::SlotData<void(bool)>(43, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 44 },
        }}),
        // Slot 'setStaticFlags'
        QtMocHelpers::SlotData<void(int)>(45, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 46 },
        }}),
        // Slot 'setLayers'
        QtMocHelpers::SlotData<void(int)>(47, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 48 },
        }}),
        // Method 'rotate'
        QtMocHelpers::MethodData<void(qreal, const QVector3D &, QQuick3DNode::TransformSpace)>(49, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 50 }, { 0x80000000 | 33, 51 }, { 0x80000000 | 52, 53 },
        }}),
        // Method 'mapPositionToScene'
        QtMocHelpers::MethodData<QVector3D(const QVector3D &) const>(54, 4, QMC::AccessPublic, 0x80000000 | 33, {{
            { 0x80000000 | 33, 55 },
        }}),
        // Method 'mapPositionFromScene'
        QtMocHelpers::MethodData<QVector3D(const QVector3D &) const>(56, 4, QMC::AccessPublic, 0x80000000 | 33, {{
            { 0x80000000 | 33, 57 },
        }}),
        // Method 'mapPositionToNode'
        QtMocHelpers::MethodData<QVector3D(const QQuick3DNode *, const QVector3D &) const>(58, 4, QMC::AccessPublic, 0x80000000 | 33, {{
            { 0x80000000 | 59, 60 }, { 0x80000000 | 33, 55 },
        }}),
        // Method 'mapPositionFromNode'
        QtMocHelpers::MethodData<QVector3D(const QQuick3DNode *, const QVector3D &) const>(61, 4, QMC::AccessPublic, 0x80000000 | 33, {{
            { 0x80000000 | 59, 60 }, { 0x80000000 | 33, 55 },
        }}),
        // Method 'mapDirectionToScene'
        QtMocHelpers::MethodData<QVector3D(const QVector3D &) const>(62, 4, QMC::AccessPublic, 0x80000000 | 33, {{
            { 0x80000000 | 33, 63 },
        }}),
        // Method 'mapDirectionFromScene'
        QtMocHelpers::MethodData<QVector3D(const QVector3D &) const>(64, 4, QMC::AccessPublic, 0x80000000 | 33, {{
            { 0x80000000 | 33, 65 },
        }}),
        // Method 'mapDirectionToNode'
        QtMocHelpers::MethodData<QVector3D(const QQuick3DNode *, const QVector3D &) const>(66, 4, QMC::AccessPublic, 0x80000000 | 33, {{
            { 0x80000000 | 59, 60 }, { 0x80000000 | 33, 63 },
        }}),
        // Method 'mapDirectionFromNode'
        QtMocHelpers::MethodData<QVector3D(const QQuick3DNode *, const QVector3D &) const>(67, 4, QMC::AccessPublic, 0x80000000 | 33, {{
            { 0x80000000 | 59, 60 }, { 0x80000000 | 33, 63 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'x'
        QtMocHelpers::PropertyData<float>(24, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'y'
        QtMocHelpers::PropertyData<float>(26, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'z'
        QtMocHelpers::PropertyData<float>(28, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'rotation'
        QtMocHelpers::PropertyData<QQuaternion>(31, 0x80000000 | 30, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'eulerRotation'
        QtMocHelpers::PropertyData<QVector3D>(34, 0x80000000 | 33, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 4),
        // property 'position'
        QtMocHelpers::PropertyData<QVector3D>(36, 0x80000000 | 33, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5),
        // property 'scale'
        QtMocHelpers::PropertyData<QVector3D>(38, 0x80000000 | 33, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 6),
        // property 'pivot'
        QtMocHelpers::PropertyData<QVector3D>(40, 0x80000000 | 33, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 7),
        // property 'opacity'
        QtMocHelpers::PropertyData<float>(42, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable, 8),
        // property 'visible'
        QtMocHelpers::PropertyData<bool>(44, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'forward'
        QtMocHelpers::PropertyData<QVector3D>(68, 0x80000000 | 33, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 10),
        // property 'up'
        QtMocHelpers::PropertyData<QVector3D>(69, 0x80000000 | 33, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 11),
        // property 'right'
        QtMocHelpers::PropertyData<QVector3D>(70, 0x80000000 | 33, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 12),
        // property 'scenePosition'
        QtMocHelpers::PropertyData<QVector3D>(57, 0x80000000 | 33, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 14),
        // property 'sceneRotation'
        QtMocHelpers::PropertyData<QQuaternion>(71, 0x80000000 | 30, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 15),
        // property 'sceneScale'
        QtMocHelpers::PropertyData<QVector3D>(72, 0x80000000 | 33, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 16),
        // property 'sceneTransform'
        QtMocHelpers::PropertyData<QMatrix4x4>(73, 0x80000000 | 74, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 13),
        // property 'staticFlags'
        QtMocHelpers::PropertyData<int>(46, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 17),
        // property 'layers'
        QtMocHelpers::PropertyData<int>(75, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 18, 0x60b),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'TransformSpace'
        QtMocHelpers::EnumData<enum TransformSpace>(76, 76, QMC::EnumFlags{}).add({
            {   77, TransformSpace::LocalSpace },
            {   78, TransformSpace::ParentSpace },
            {   79, TransformSpace::SceneSpace },
        }),
        // enum 'StaticFlags'
        QtMocHelpers::EnumData<enum StaticFlags>(80, 80, QMC::EnumFlags{}).add({
            {   81, StaticFlags::None },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DNode, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DNode::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuick3DObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12QQuick3DNodeE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12QQuick3DNodeE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12QQuick3DNodeE_t>.metaTypes,
    nullptr
} };

void QQuick3DNode::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DNode *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->xChanged(); break;
        case 1: _t->yChanged(); break;
        case 2: _t->zChanged(); break;
        case 3: _t->rotationChanged(); break;
        case 4: _t->eulerRotationChanged(); break;
        case 5: _t->positionChanged(); break;
        case 6: _t->scaleChanged(); break;
        case 7: _t->pivotChanged(); break;
        case 8: _t->localOpacityChanged(); break;
        case 9: _t->visibleChanged(); break;
        case 10: _t->forwardChanged(); break;
        case 11: _t->upChanged(); break;
        case 12: _t->rightChanged(); break;
        case 13: _t->sceneTransformChanged(); break;
        case 14: _t->scenePositionChanged(); break;
        case 15: _t->sceneRotationChanged(); break;
        case 16: _t->sceneScaleChanged(); break;
        case 17: _t->staticFlagsChanged(); break;
        case 18: _t->layersChanged(); break;
        case 19: _t->setX((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 20: _t->setY((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 21: _t->setZ((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 22: _t->setRotation((*reinterpret_cast<std::add_pointer_t<QQuaternion>>(_a[1]))); break;
        case 23: _t->setEulerRotation((*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[1]))); break;
        case 24: _t->setPosition((*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[1]))); break;
        case 25: _t->setScale((*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[1]))); break;
        case 26: _t->setPivot((*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[1]))); break;
        case 27: _t->setLocalOpacity((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 28: _t->setVisible((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 29: _t->setStaticFlags((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 30: _t->setLayers((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 31: _t->rotate((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QQuick3DNode::TransformSpace>>(_a[3]))); break;
        case 32: { QVector3D _r = _t->mapPositionToScene((*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVector3D*>(_a[0]) = std::move(_r); }  break;
        case 33: { QVector3D _r = _t->mapPositionFromScene((*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVector3D*>(_a[0]) = std::move(_r); }  break;
        case 34: { QVector3D _r = _t->mapPositionToNode((*reinterpret_cast<std::add_pointer_t<const QQuick3DNode*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QVector3D*>(_a[0]) = std::move(_r); }  break;
        case 35: { QVector3D _r = _t->mapPositionFromNode((*reinterpret_cast<std::add_pointer_t<const QQuick3DNode*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QVector3D*>(_a[0]) = std::move(_r); }  break;
        case 36: { QVector3D _r = _t->mapDirectionToScene((*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVector3D*>(_a[0]) = std::move(_r); }  break;
        case 37: { QVector3D _r = _t->mapDirectionFromScene((*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVector3D*>(_a[0]) = std::move(_r); }  break;
        case 38: { QVector3D _r = _t->mapDirectionToNode((*reinterpret_cast<std::add_pointer_t<const QQuick3DNode*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QVector3D*>(_a[0]) = std::move(_r); }  break;
        case 39: { QVector3D _r = _t->mapDirectionFromNode((*reinterpret_cast<std::add_pointer_t<const QQuick3DNode*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QVector3D*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuick3DNode::*)()>(_a, &QQuick3DNode::xChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DNode::*)()>(_a, &QQuick3DNode::yChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DNode::*)()>(_a, &QQuick3DNode::zChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DNode::*)()>(_a, &QQuick3DNode::rotationChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DNode::*)()>(_a, &QQuick3DNode::eulerRotationChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DNode::*)()>(_a, &QQuick3DNode::positionChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DNode::*)()>(_a, &QQuick3DNode::scaleChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DNode::*)()>(_a, &QQuick3DNode::pivotChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DNode::*)()>(_a, &QQuick3DNode::localOpacityChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DNode::*)()>(_a, &QQuick3DNode::visibleChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DNode::*)()>(_a, &QQuick3DNode::forwardChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DNode::*)()>(_a, &QQuick3DNode::upChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DNode::*)()>(_a, &QQuick3DNode::rightChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DNode::*)()>(_a, &QQuick3DNode::sceneTransformChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DNode::*)()>(_a, &QQuick3DNode::scenePositionChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DNode::*)()>(_a, &QQuick3DNode::sceneRotationChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DNode::*)()>(_a, &QQuick3DNode::sceneScaleChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DNode::*)()>(_a, &QQuick3DNode::staticFlagsChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DNode::*)()>(_a, &QQuick3DNode::layersChanged, 18))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<float*>(_v) = _t->x(); break;
        case 1: *reinterpret_cast<float*>(_v) = _t->y(); break;
        case 2: *reinterpret_cast<float*>(_v) = _t->z(); break;
        case 3: *reinterpret_cast<QQuaternion*>(_v) = _t->rotation(); break;
        case 4: *reinterpret_cast<QVector3D*>(_v) = _t->eulerRotation(); break;
        case 5: *reinterpret_cast<QVector3D*>(_v) = _t->position(); break;
        case 6: *reinterpret_cast<QVector3D*>(_v) = _t->scale(); break;
        case 7: *reinterpret_cast<QVector3D*>(_v) = _t->pivot(); break;
        case 8: *reinterpret_cast<float*>(_v) = _t->localOpacity(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->visible(); break;
        case 10: *reinterpret_cast<QVector3D*>(_v) = _t->forward(); break;
        case 11: *reinterpret_cast<QVector3D*>(_v) = _t->up(); break;
        case 12: *reinterpret_cast<QVector3D*>(_v) = _t->right(); break;
        case 13: *reinterpret_cast<QVector3D*>(_v) = _t->scenePosition(); break;
        case 14: *reinterpret_cast<QQuaternion*>(_v) = _t->sceneRotation(); break;
        case 15: *reinterpret_cast<QVector3D*>(_v) = _t->sceneScale(); break;
        case 16: *reinterpret_cast<QMatrix4x4*>(_v) = _t->sceneTransform(); break;
        case 17: *reinterpret_cast<int*>(_v) = _t->staticFlags(); break;
        case 18: *reinterpret_cast<int*>(_v) = _t->layers(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setX(*reinterpret_cast<float*>(_v)); break;
        case 1: _t->setY(*reinterpret_cast<float*>(_v)); break;
        case 2: _t->setZ(*reinterpret_cast<float*>(_v)); break;
        case 3: _t->setRotation(*reinterpret_cast<QQuaternion*>(_v)); break;
        case 4: _t->setEulerRotation(*reinterpret_cast<QVector3D*>(_v)); break;
        case 5: _t->setPosition(*reinterpret_cast<QVector3D*>(_v)); break;
        case 6: _t->setScale(*reinterpret_cast<QVector3D*>(_v)); break;
        case 7: _t->setPivot(*reinterpret_cast<QVector3D*>(_v)); break;
        case 8: _t->setLocalOpacity(*reinterpret_cast<float*>(_v)); break;
        case 9: _t->setVisible(*reinterpret_cast<bool*>(_v)); break;
        case 17: _t->setStaticFlags(*reinterpret_cast<int*>(_v)); break;
        case 18: _t->setLayers(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DNode::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DNode::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12QQuick3DNodeE_t>.strings))
        return static_cast<void*>(this);
    return QQuick3DObject::qt_metacast(_clname);
}

int QQuick3DNode::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuick3DObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 40)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 40;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 40)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 40;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    return _id;
}

// SIGNAL 0
void QQuick3DNode::xChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QQuick3DNode::yChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QQuick3DNode::zChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QQuick3DNode::rotationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QQuick3DNode::eulerRotationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QQuick3DNode::positionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QQuick3DNode::scaleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void QQuick3DNode::pivotChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void QQuick3DNode::localOpacityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void QQuick3DNode::visibleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void QQuick3DNode::forwardChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void QQuick3DNode::upChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void QQuick3DNode::rightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void QQuick3DNode::sceneTransformChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void QQuick3DNode::scenePositionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void QQuick3DNode::sceneRotationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void QQuick3DNode::sceneScaleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void QQuick3DNode::staticFlagsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void QQuick3DNode::layersChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}
QT_WARNING_POP
