/****************************************************************************
** Meta object code from reading C++ file 'qquick3dxrcamera_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../qtquick3d/src/xr/quick3dxr/qquick3dxrcamera_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquick3dxrcamera_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19QQuick3DXrEyeCameraE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DXrEyeCamera::qt_create_metaobjectdata<qt_meta_tag_ZN19QQuick3DXrEyeCameraE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DXrEyeCamera",
        "leftTangentChanged",
        "",
        "leftTangent",
        "rightTangentChanged",
        "rightTangent",
        "upTangentChanged",
        "upTangent",
        "downTangentChanged",
        "downTangent",
        "clipNearChanged",
        "clipNear",
        "clipFarChanged",
        "clipFar",
        "setLeftTangent",
        "setRightTangent",
        "setUpTangent",
        "setDownTangent",
        "setClipNear",
        "setClipFar",
        "setProjection",
        "QMatrix4x4",
        "projection"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'leftTangentChanged'
        QtMocHelpers::SignalData<void(float)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 3 },
        }}),
        // Signal 'rightTangentChanged'
        QtMocHelpers::SignalData<void(float)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 5 },
        }}),
        // Signal 'upTangentChanged'
        QtMocHelpers::SignalData<void(float)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 7 },
        }}),
        // Signal 'downTangentChanged'
        QtMocHelpers::SignalData<void(float)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 9 },
        }}),
        // Signal 'clipNearChanged'
        QtMocHelpers::SignalData<void(float)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 11 },
        }}),
        // Signal 'clipFarChanged'
        QtMocHelpers::SignalData<void(float)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 13 },
        }}),
        // Slot 'setLeftTangent'
        QtMocHelpers::SlotData<void(float)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 3 },
        }}),
        // Slot 'setRightTangent'
        QtMocHelpers::SlotData<void(float)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 5 },
        }}),
        // Slot 'setUpTangent'
        QtMocHelpers::SlotData<void(float)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 7 },
        }}),
        // Slot 'setDownTangent'
        QtMocHelpers::SlotData<void(float)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 9 },
        }}),
        // Slot 'setClipNear'
        QtMocHelpers::SlotData<void(float)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 11 },
        }}),
        // Slot 'setClipFar'
        QtMocHelpers::SlotData<void(float)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 13 },
        }}),
        // Slot 'setProjection'
        QtMocHelpers::SlotData<void(const QMatrix4x4 &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 22 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'leftTangent'
        QtMocHelpers::PropertyData<float>(3, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'rightTangent'
        QtMocHelpers::PropertyData<float>(5, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'upTangent'
        QtMocHelpers::PropertyData<float>(7, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'downTangent'
        QtMocHelpers::PropertyData<float>(9, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'clipNear'
        QtMocHelpers::PropertyData<float>(11, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'clipFar'
        QtMocHelpers::PropertyData<float>(13, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QQuick3DXrEyeCamera, qt_meta_tag_ZN19QQuick3DXrEyeCameraE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QQuick3DXrEyeCamera::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuick3DCamera::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19QQuick3DXrEyeCameraE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19QQuick3DXrEyeCameraE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19QQuick3DXrEyeCameraE_t>.metaTypes,
    nullptr
} };

void QQuick3DXrEyeCamera::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DXrEyeCamera *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->leftTangentChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 1: _t->rightTangentChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 2: _t->upTangentChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 3: _t->downTangentChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 4: _t->clipNearChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 5: _t->clipFarChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 6: _t->setLeftTangent((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 7: _t->setRightTangent((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 8: _t->setUpTangent((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 9: _t->setDownTangent((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 10: _t->setClipNear((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 11: _t->setClipFar((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 12: _t->setProjection((*reinterpret_cast<std::add_pointer_t<QMatrix4x4>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuick3DXrEyeCamera::*)(float )>(_a, &QQuick3DXrEyeCamera::leftTangentChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DXrEyeCamera::*)(float )>(_a, &QQuick3DXrEyeCamera::rightTangentChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DXrEyeCamera::*)(float )>(_a, &QQuick3DXrEyeCamera::upTangentChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DXrEyeCamera::*)(float )>(_a, &QQuick3DXrEyeCamera::downTangentChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DXrEyeCamera::*)(float )>(_a, &QQuick3DXrEyeCamera::clipNearChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DXrEyeCamera::*)(float )>(_a, &QQuick3DXrEyeCamera::clipFarChanged, 5))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<float*>(_v) = _t->leftTangent(); break;
        case 1: *reinterpret_cast<float*>(_v) = _t->rightTangent(); break;
        case 2: *reinterpret_cast<float*>(_v) = _t->upTangent(); break;
        case 3: *reinterpret_cast<float*>(_v) = _t->downTangent(); break;
        case 4: *reinterpret_cast<float*>(_v) = _t->clipNear(); break;
        case 5: *reinterpret_cast<float*>(_v) = _t->clipFar(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setLeftTangent(*reinterpret_cast<float*>(_v)); break;
        case 1: _t->setRightTangent(*reinterpret_cast<float*>(_v)); break;
        case 2: _t->setUpTangent(*reinterpret_cast<float*>(_v)); break;
        case 3: _t->setDownTangent(*reinterpret_cast<float*>(_v)); break;
        case 4: _t->setClipNear(*reinterpret_cast<float*>(_v)); break;
        case 5: _t->setClipFar(*reinterpret_cast<float*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DXrEyeCamera::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DXrEyeCamera::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19QQuick3DXrEyeCameraE_t>.strings))
        return static_cast<void*>(this);
    return QQuick3DCamera::qt_metacast(_clname);
}

int QQuick3DXrEyeCamera::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuick3DCamera::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 13;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void QQuick3DXrEyeCamera::leftTangentChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void QQuick3DXrEyeCamera::rightTangentChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void QQuick3DXrEyeCamera::upTangentChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void QQuick3DXrEyeCamera::downTangentChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void QQuick3DXrEyeCamera::clipNearChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void QQuick3DXrEyeCamera::clipFarChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN16QQuick3DXrCameraE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DXrCamera::qt_create_metaobjectdata<qt_meta_tag_ZN16QQuick3DXrCameraE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DXrCamera",
        "QML.Element",
        "XrCamera",
        "QML.AddedInVersion",
        "1544",
        "clipNearChanged",
        "",
        "clipNear",
        "clipFarChanged",
        "clipFar",
        "setClipNear",
        "setClipFar"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'clipNearChanged'
        QtMocHelpers::SignalData<void(float)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 7 },
        }}),
        // Signal 'clipFarChanged'
        QtMocHelpers::SignalData<void(float)>(8, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 9 },
        }}),
        // Slot 'setClipNear'
        QtMocHelpers::SlotData<void(float)>(10, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 7 },
        }}),
        // Slot 'setClipFar'
        QtMocHelpers::SlotData<void(float)>(11, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 9 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'clipNear'
        QtMocHelpers::PropertyData<float>(7, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 0),
        // property 'clipFar'
        QtMocHelpers::PropertyData<float>(9, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 1),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DXrCamera, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DXrCamera::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuick3DNode::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16QQuick3DXrCameraE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16QQuick3DXrCameraE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16QQuick3DXrCameraE_t>.metaTypes,
    nullptr
} };

void QQuick3DXrCamera::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DXrCamera *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->clipNearChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 1: _t->clipFarChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 2: _t->setClipNear((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 3: _t->setClipFar((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuick3DXrCamera::*)(float )>(_a, &QQuick3DXrCamera::clipNearChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DXrCamera::*)(float )>(_a, &QQuick3DXrCamera::clipFarChanged, 1))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<float*>(_v) = _t->clipNear(); break;
        case 1: *reinterpret_cast<float*>(_v) = _t->clipFar(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setClipNear(*reinterpret_cast<float*>(_v)); break;
        case 1: _t->setClipFar(*reinterpret_cast<float*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DXrCamera::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DXrCamera::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16QQuick3DXrCameraE_t>.strings))
        return static_cast<void*>(this);
    return QQuick3DNode::qt_metacast(_clname);
}

int QQuick3DXrCamera::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuick3DNode::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void QQuick3DXrCamera::clipNearChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void QQuick3DXrCamera::clipFarChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
