/****************************************************************************
** Meta object code from reading C++ file 'qquick3dcontentlayer_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtquick3d/src/quick3d/qquick3dcontentlayer_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquick3dcontentlayer_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN20QQuick3DContentLayerE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DContentLayer::qt_create_metaobjectdata<qt_meta_tag_ZN20QQuick3DContentLayerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DContentLayer",
        "QML.Element",
        "ContentLayer",
        "QML.AddedInVersion",
        "1547",
        "QML.Singleton",
        "true",
        "LayerFlags",
        "LayerFlag",
        "LayerNone",
        "Layer0",
        "Layer1",
        "Layer2",
        "Layer3",
        "Layer4",
        "Layer5",
        "Layer6",
        "Layer7",
        "Layer8",
        "Layer9",
        "Layer10",
        "Layer11",
        "Layer12",
        "Layer13",
        "Layer14",
        "Layer15",
        "Layer16",
        "Layer17",
        "Layer18",
        "Layer19",
        "Layer20",
        "Layer21",
        "Layer22",
        "Layer23",
        "LayerAll",
        "Layer24",
        "Layer25",
        "Layer26",
        "Layer27",
        "Layer28",
        "Layer29",
        "Layer30",
        "Layer31",
        "ReservedLayerMask"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // flag 'LayerFlags'
        QtMocHelpers::EnumData<LayerFlags>(7, 8, QMC::EnumIsFlag).add({
            {    9, LayerFlag::LayerNone },
            {   10, LayerFlag::Layer0 },
            {   11, LayerFlag::Layer1 },
            {   12, LayerFlag::Layer2 },
            {   13, LayerFlag::Layer3 },
            {   14, LayerFlag::Layer4 },
            {   15, LayerFlag::Layer5 },
            {   16, LayerFlag::Layer6 },
            {   17, LayerFlag::Layer7 },
            {   18, LayerFlag::Layer8 },
            {   19, LayerFlag::Layer9 },
            {   20, LayerFlag::Layer10 },
            {   21, LayerFlag::Layer11 },
            {   22, LayerFlag::Layer12 },
            {   23, LayerFlag::Layer13 },
            {   24, LayerFlag::Layer14 },
            {   25, LayerFlag::Layer15 },
            {   26, LayerFlag::Layer16 },
            {   27, LayerFlag::Layer17 },
            {   28, LayerFlag::Layer18 },
            {   29, LayerFlag::Layer19 },
            {   30, LayerFlag::Layer20 },
            {   31, LayerFlag::Layer21 },
            {   32, LayerFlag::Layer22 },
            {   33, LayerFlag::Layer23 },
            {   34, LayerFlag::LayerAll },
            {   35, LayerFlag::Layer24 },
            {   36, LayerFlag::Layer25 },
            {   37, LayerFlag::Layer26 },
            {   38, LayerFlag::Layer27 },
            {   39, LayerFlag::Layer28 },
            {   40, LayerFlag::Layer29 },
            {   41, LayerFlag::Layer30 },
            {   42, LayerFlag::Layer31 },
            {   43, LayerFlag::ReservedLayerMask },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DContentLayer, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DContentLayer::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20QQuick3DContentLayerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20QQuick3DContentLayerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20QQuick3DContentLayerE_t>.metaTypes,
    nullptr
} };

void QQuick3DContentLayer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DContentLayer *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *QQuick3DContentLayer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DContentLayer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20QQuick3DContentLayerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QQuick3DContentLayer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
