/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<private/qquick3dparticle_p.h>)
#  include <private/qquick3dparticle_p.h>
#endif
#if __has_include(<private/qquick3dparticleabstractshape_p.h>)
#  include <private/qquick3dparticleabstractshape_p.h>
#endif
#if __has_include(<private/qquick3dparticleaffector_p.h>)
#  include <private/qquick3dparticleaffector_p.h>
#endif
#if __has_include(<private/qquick3dparticleattractor_p.h>)
#  include <private/qquick3dparticleattractor_p.h>
#endif
#if __has_include(<private/qquick3dparticlecustomshape_p.h>)
#  include <private/qquick3dparticlecustomshape_p.h>
#endif
#if __has_include(<private/qquick3dparticledirection_p.h>)
#  include <private/qquick3dparticledirection_p.h>
#endif
#if __has_include(<private/qquick3dparticledynamicburst_p.h>)
#  include <private/qquick3dparticledynamicburst_p.h>
#endif
#if __has_include(<private/qquick3dparticleemitburst_p.h>)
#  include <private/qquick3dparticleemitburst_p.h>
#endif
#if __has_include(<private/qquick3dparticleemitter_p.h>)
#  include <private/qquick3dparticleemitter_p.h>
#endif
#if __has_include(<private/qquick3dparticlegravity_p.h>)
#  include <private/qquick3dparticlegravity_p.h>
#endif
#if __has_include(<private/qquick3dparticlelineparticle_p.h>)
#  include <private/qquick3dparticlelineparticle_p.h>
#endif
#if __has_include(<private/qquick3dparticlemodelblendparticle_p.h>)
#  include <private/qquick3dparticlemodelblendparticle_p.h>
#endif
#if __has_include(<private/qquick3dparticlemodelparticle_p.h>)
#  include <private/qquick3dparticlemodelparticle_p.h>
#endif
#if __has_include(<private/qquick3dparticlemodelshape_p.h>)
#  include <private/qquick3dparticlemodelshape_p.h>
#endif
#if __has_include(<private/qquick3dparticlepointrotator_p.h>)
#  include <private/qquick3dparticlepointrotator_p.h>
#endif
#if __has_include(<private/qquick3dparticlerepeller_p.h>)
#  include <private/qquick3dparticlerepeller_p.h>
#endif
#if __has_include(<private/qquick3dparticlescaleaffector_p.h>)
#  include <private/qquick3dparticlescaleaffector_p.h>
#endif
#if __has_include(<private/qquick3dparticlesceneshape_p.h>)
#  include <private/qquick3dparticlesceneshape_p.h>
#endif
#if __has_include(<private/qquick3dparticleshape_p.h>)
#  include <private/qquick3dparticleshape_p.h>
#endif
#if __has_include(<private/qquick3dparticlespriteparticle_p.h>)
#  include <private/qquick3dparticlespriteparticle_p.h>
#endif
#if __has_include(<private/qquick3dparticlespritesequence_p.h>)
#  include <private/qquick3dparticlespritesequence_p.h>
#endif
#if __has_include(<private/qquick3dparticlesystem_p.h>)
#  include <private/qquick3dparticlesystem_p.h>
#endif
#if __has_include(<private/qquick3dparticlesystemlogging_p.h>)
#  include <private/qquick3dparticlesystemlogging_p.h>
#endif
#if __has_include(<private/qquick3dparticletargetdirection_p.h>)
#  include <private/qquick3dparticletargetdirection_p.h>
#endif
#if __has_include(<private/qquick3dparticletrailemitter_p.h>)
#  include <private/qquick3dparticletrailemitter_p.h>
#endif
#if __has_include(<private/qquick3dparticlevectordirection_p.h>)
#  include <private/qquick3dparticlevectordirection_p.h>
#endif
#if __has_include(<private/qquick3dparticlewander_p.h>)
#  include <private/qquick3dparticlewander_p.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_QtQuick3D_Particles3D()
{
    qmlRegisterModule("QtQuick3D.Particles3D", 6, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<QQuick3DParticle>("QtQuick3D.Particles3D", 6);
    qmlRegisterEnum<QQuick3DParticle::FadeType>("QQuick3DParticle::FadeType");
    qmlRegisterEnum<QQuick3DParticle::AlignMode>("QQuick3DParticle::AlignMode");
    qmlRegisterEnum<QQuick3DParticle::SortMode>("QQuick3DParticle::SortMode");
    qmlRegisterTypesAndRevisions<QQuick3DParticleAbstractShape>("QtQuick3D.Particles3D", 6);
    qmlRegisterTypesAndRevisions<QQuick3DParticleAffector>("QtQuick3D.Particles3D", 6);
    qmlRegisterAnonymousTypesAndRevisions<QQuick3DNode>("QtQuick3D.Particles3D", 6);
    qmlRegisterTypesAndRevisions<QQuick3DParticleAttractor>("QtQuick3D.Particles3D", 6);
    qmlRegisterTypesAndRevisions<QQuick3DParticleCustomShape>("QtQuick3D.Particles3D", 6);
    qmlRegisterTypesAndRevisions<QQuick3DParticleDirection>("QtQuick3D.Particles3D", 6);
    qmlRegisterTypesAndRevisions<QQuick3DParticleDynamicBurst>("QtQuick3D.Particles3D", 6);
    qmlRegisterEnum<QQuick3DParticleDynamicBurst::TriggerMode>("QQuick3DParticleDynamicBurst::TriggerMode");
    qmlRegisterTypesAndRevisions<QQuick3DParticleEmitBurst>("QtQuick3D.Particles3D", 6);
    qmlRegisterTypesAndRevisions<QQuick3DParticleEmitter>("QtQuick3D.Particles3D", 6);
    qmlRegisterEnum<QQuick3DParticleEmitter::EmitMode>("QQuick3DParticleEmitter::EmitMode");
    qmlRegisterTypesAndRevisions<QQuick3DParticleGravity>("QtQuick3D.Particles3D", 6);
    qmlRegisterTypesAndRevisions<QQuick3DParticleLineParticle>("QtQuick3D.Particles3D", 6);
    qmlRegisterEnum<QQuick3DParticleLineParticle::TexcoordMode>("QQuick3DParticleLineParticle::TexcoordMode");
    qmlRegisterTypesAndRevisions<QQuick3DParticleModelBlendParticle>("QtQuick3D.Particles3D", 6);
    qmlRegisterEnum<QQuick3DParticleModelBlendParticle::ModelBlendMode>("QQuick3DParticleModelBlendParticle::ModelBlendMode");
    qmlRegisterEnum<QQuick3DParticleModelBlendParticle::ModelBlendEmitMode>("QQuick3DParticleModelBlendParticle::ModelBlendEmitMode");
    qmlRegisterTypesAndRevisions<QQuick3DParticleModelParticle>("QtQuick3D.Particles3D", 6);
    qmlRegisterTypesAndRevisions<QQuick3DParticleModelShape>("QtQuick3D.Particles3D", 6);
    qmlRegisterTypesAndRevisions<QQuick3DParticlePointRotator>("QtQuick3D.Particles3D", 6);
    qmlRegisterTypesAndRevisions<QQuick3DParticleRepeller>("QtQuick3D.Particles3D", 6);
    qmlRegisterTypesAndRevisions<QQuick3DParticleScaleAffector>("QtQuick3D.Particles3D", 6);
    qmlRegisterEnum<QQuick3DParticleScaleAffector::ScalingType>("QQuick3DParticleScaleAffector::ScalingType");
    qmlRegisterTypesAndRevisions<QQuick3DParticleSceneShape>("QtQuick3D.Particles3D", 6);
    qmlRegisterTypesAndRevisions<QQuick3DParticleShape>("QtQuick3D.Particles3D", 6);
    qmlRegisterEnum<QQuick3DParticleShape::ShapeType>("QQuick3DParticleShape::ShapeType");
    qmlRegisterTypesAndRevisions<QQuick3DParticleSpriteParticle>("QtQuick3D.Particles3D", 6);
    qmlRegisterEnum<QQuick3DParticleSpriteParticle::BlendMode>("QQuick3DParticleSpriteParticle::BlendMode");
    qmlRegisterTypesAndRevisions<QQuick3DParticleSpriteSequence>("QtQuick3D.Particles3D", 6);
    qmlRegisterEnum<QQuick3DParticleSpriteSequence::AnimationDirection>("QQuick3DParticleSpriteSequence::AnimationDirection");
    qmlRegisterTypesAndRevisions<QQuick3DParticleSystem>("QtQuick3D.Particles3D", 6);
    qmlRegisterTypesAndRevisions<QQuick3DParticleSystemLogging>("QtQuick3D.Particles3D", 6);
    qmlRegisterTypesAndRevisions<QQuick3DParticleTargetDirection>("QtQuick3D.Particles3D", 6);
    qmlRegisterTypesAndRevisions<QQuick3DParticleTrailEmitter>("QtQuick3D.Particles3D", 6);
    qmlRegisterTypesAndRevisions<QQuick3DParticleVectorDirection>("QtQuick3D.Particles3D", 6);
    qmlRegisterTypesAndRevisions<QQuick3DParticleWander>("QtQuick3D.Particles3D", 6);
    QT_WARNING_POP
    qmlRegisterModule("QtQuick3D.Particles3D", 6, 11);
}

static const QQmlModuleRegistration qtQuick3DParticles3DRegistration("QtQuick3D.Particles3D", qml_register_types_QtQuick3D_Particles3D);
