// This file is autogenerated. Changes will be overwritten.
#include "5JE3FL2PJN/moc_qquick3drenderextensions.cpp"
#include "5JE3FL2PJN/moc_qquick3dtextureproviderextension.cpp"
#include "EWIEGA46WW/moc_qquick3dabstractlight_p.cpp"
#include "EWIEGA46WW/moc_qquick3dbakedlightmap_p.cpp"
#include "EWIEGA46WW/moc_qquick3dcamera_p.cpp"
#include "EWIEGA46WW/moc_qquick3dcontentlayer_p.cpp"
#include "EWIEGA46WW/moc_qquick3dcubemaptexture_p.cpp"
#include "EWIEGA46WW/moc_qquick3dcustomcamera_p.cpp"
#include "EWIEGA46WW/moc_qquick3dcustommaterial_p.cpp"
#include "EWIEGA46WW/moc_qquick3ddebugsettings_p.cpp"
#include "EWIEGA46WW/moc_qquick3ddefaultmaterial_p.cpp"
#include "EWIEGA46WW/moc_qquick3ddirectionallight_p.cpp"
#include "EWIEGA46WW/moc_qquick3deffect_p.cpp"
#include "EWIEGA46WW/moc_qquick3dfog_p.cpp"
#include "EWIEGA46WW/moc_qquick3dfrustumcamera_p.cpp"
#include "EWIEGA46WW/moc_qquick3dgeometry.cpp"
#include "EWIEGA46WW/moc_qquick3dinstancing.cpp"
#include "EWIEGA46WW/moc_qquick3dinstancing_p.cpp"
#include "EWIEGA46WW/moc_qquick3ditem2d_p.cpp"
#include "EWIEGA46WW/moc_qquick3djoint_p.cpp"
#include "EWIEGA46WW/moc_qquick3dlightmapbaker_p.cpp"
#include "EWIEGA46WW/moc_qquick3dlightmapper_p.cpp"
#include "EWIEGA46WW/moc_qquick3dmaterial_p.cpp"
#include "EWIEGA46WW/moc_qquick3dmodel_p.cpp"
#include "EWIEGA46WW/moc_qquick3dmorphtarget_p.cpp"
#include "EWIEGA46WW/moc_qquick3dnode_p.cpp"
#include "EWIEGA46WW/moc_qquick3dorthographiccamera_p.cpp"
#include "EWIEGA46WW/moc_qquick3dperspectivecamera_p.cpp"
#include "EWIEGA46WW/moc_qquick3dpickresult_p.cpp"
#include "EWIEGA46WW/moc_qquick3dpointlight_p.cpp"
#include "EWIEGA46WW/moc_qquick3dprincipledmaterial_p.cpp"
#include "EWIEGA46WW/moc_qquick3dquaternionanimation_p.cpp"
#include "EWIEGA46WW/moc_qquick3dquaternionutils_p.cpp"
#include "EWIEGA46WW/moc_qquick3dreflectionprobe_p.cpp"
#include "EWIEGA46WW/moc_qquick3drenderpass_p.cpp"
#include "EWIEGA46WW/moc_qquick3drenderstats_p.cpp"
#include "EWIEGA46WW/moc_qquick3dresourceloader_p.cpp"
#include "EWIEGA46WW/moc_qquick3dsceneenvironment_p.cpp"
#include "EWIEGA46WW/moc_qquick3dscenemanager_p.cpp"
#include "EWIEGA46WW/moc_qquick3dscenerenderer_p.cpp"
#include "EWIEGA46WW/moc_qquick3dscenerootnode_p.cpp"
#include "EWIEGA46WW/moc_qquick3dshaderutils_p.cpp"
#include "EWIEGA46WW/moc_qquick3dskeleton_p.cpp"
#include "EWIEGA46WW/moc_qquick3dskin_p.cpp"
#include "EWIEGA46WW/moc_qquick3dspecularglossymaterial_p.cpp"
#include "EWIEGA46WW/moc_qquick3dspotlight_p.cpp"
#include "EWIEGA46WW/moc_qquick3dtexture_p.cpp"
#include "EWIEGA46WW/moc_qquick3dtexturedata.cpp"
#include "EWIEGA46WW/moc_qquick3dviewport_p.cpp"
