/****************************************************************************
** Meta object code from reading C++ file 'qquick3dinstancing.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtquick3d/src/quick3d/qquick3dinstancing.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquick3dinstancing.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18QQuick3DInstancingE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DInstancing::qt_create_metaobjectdata<qt_meta_tag_ZN18QQuick3DInstancingE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DInstancing",
        "QML.Element",
        "Instancing",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Instancing is Abstract",
        "QML.AddedInVersion",
        "1538",
        "instanceTableChanged",
        "",
        "instanceNodeDirty",
        "instanceCountOverrideChanged",
        "hasTransparencyChanged",
        "depthSortingEnabledChanged",
        "shadowBoundsMinimumChanged",
        "shadowBoundsMaximumChanged",
        "setInstanceCountOverride",
        "instanceCountOverride",
        "setHasTransparency",
        "hasTransparency",
        "setDepthSortingEnabled",
        "enabled",
        "setShadowBoundsMinimum",
        "QVector3D",
        "newShadowBoundsMinimum",
        "setShadowBoundsMaximum",
        "instancePosition",
        "index",
        "instanceScale",
        "instanceRotation",
        "QQuaternion",
        "instanceColor",
        "QColor",
        "instanceCustomData",
        "QVector4D",
        "depthSortingEnabled",
        "shadowBoundsMinimum",
        "shadowBoundsMaximum"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'instanceTableChanged'
        QtMocHelpers::SignalData<void()>(9, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'instanceNodeDirty'
        QtMocHelpers::SignalData<void()>(11, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'instanceCountOverrideChanged'
        QtMocHelpers::SignalData<void()>(12, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hasTransparencyChanged'
        QtMocHelpers::SignalData<void()>(13, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'depthSortingEnabledChanged'
        QtMocHelpers::SignalData<void()>(14, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'shadowBoundsMinimumChanged'
        QtMocHelpers::RevisionedSignalData<void()>(15, 10, QMC::AccessPublic, 0x609, QMetaType::Void),
        // Signal 'shadowBoundsMaximumChanged'
        QtMocHelpers::RevisionedSignalData<void()>(16, 10, QMC::AccessPublic, 0x609, QMetaType::Void),
        // Slot 'setInstanceCountOverride'
        QtMocHelpers::SlotData<void(int)>(17, 10, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 18 },
        }}),
        // Slot 'setHasTransparency'
        QtMocHelpers::SlotData<void(bool)>(19, 10, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 20 },
        }}),
        // Slot 'setDepthSortingEnabled'
        QtMocHelpers::SlotData<void(bool)>(21, 10, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 22 },
        }}),
        // Slot 'setShadowBoundsMinimum'
        QtMocHelpers::RevisionedSlotData<void(const QVector3D &)>(23, 10, QMC::AccessPublic, 0x609, QMetaType::Void, {{
            { 0x80000000 | 24, 25 },
        }}),
        // Slot 'setShadowBoundsMaximum'
        QtMocHelpers::RevisionedSlotData<void(const QVector3D &)>(26, 10, QMC::AccessPublic, 0x609, QMetaType::Void, {{
            { 0x80000000 | 24, 25 },
        }}),
        // Method 'instancePosition'
        QtMocHelpers::RevisionedMethodData<QVector3D(int)>(27, 10, QMC::AccessPublic, 0x603, 0x80000000 | 24, {{
            { QMetaType::Int, 28 },
        }}),
        // Method 'instanceScale'
        QtMocHelpers::RevisionedMethodData<QVector3D(int)>(29, 10, QMC::AccessPublic, 0x603, 0x80000000 | 24, {{
            { QMetaType::Int, 28 },
        }}),
        // Method 'instanceRotation'
        QtMocHelpers::RevisionedMethodData<QQuaternion(int)>(30, 10, QMC::AccessPublic, 0x603, 0x80000000 | 31, {{
            { QMetaType::Int, 28 },
        }}),
        // Method 'instanceColor'
        QtMocHelpers::RevisionedMethodData<QColor(int)>(32, 10, QMC::AccessPublic, 0x603, 0x80000000 | 33, {{
            { QMetaType::Int, 28 },
        }}),
        // Method 'instanceCustomData'
        QtMocHelpers::RevisionedMethodData<QVector4D(int)>(34, 10, QMC::AccessPublic, 0x603, 0x80000000 | 35, {{
            { QMetaType::Int, 28 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'instanceCountOverride'
        QtMocHelpers::PropertyData<int>(18, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'hasTransparency'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'depthSortingEnabled'
        QtMocHelpers::PropertyData<bool>(36, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'shadowBoundsMinimum'
        QtMocHelpers::PropertyData<QVector3D>(37, 0x80000000 | 24, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5, 0x609),
        // property 'shadowBoundsMaximum'
        QtMocHelpers::PropertyData<QVector3D>(38, 0x80000000 | 24, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 6, 0x609),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
            {    7,    8 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DInstancing, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DInstancing::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuick3DObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18QQuick3DInstancingE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18QQuick3DInstancingE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18QQuick3DInstancingE_t>.metaTypes,
    nullptr
} };

void QQuick3DInstancing::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DInstancing *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->instanceTableChanged(); break;
        case 1: _t->instanceNodeDirty(); break;
        case 2: _t->instanceCountOverrideChanged(); break;
        case 3: _t->hasTransparencyChanged(); break;
        case 4: _t->depthSortingEnabledChanged(); break;
        case 5: _t->shadowBoundsMinimumChanged(); break;
        case 6: _t->shadowBoundsMaximumChanged(); break;
        case 7: _t->setInstanceCountOverride((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->setHasTransparency((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->setDepthSortingEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->setShadowBoundsMinimum((*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[1]))); break;
        case 11: _t->setShadowBoundsMaximum((*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[1]))); break;
        case 12: { QVector3D _r = _t->instancePosition((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVector3D*>(_a[0]) = std::move(_r); }  break;
        case 13: { QVector3D _r = _t->instanceScale((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVector3D*>(_a[0]) = std::move(_r); }  break;
        case 14: { QQuaternion _r = _t->instanceRotation((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QQuaternion*>(_a[0]) = std::move(_r); }  break;
        case 15: { QColor _r = _t->instanceColor((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QColor*>(_a[0]) = std::move(_r); }  break;
        case 16: { QVector4D _r = _t->instanceCustomData((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVector4D*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuick3DInstancing::*)()>(_a, &QQuick3DInstancing::instanceTableChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DInstancing::*)()>(_a, &QQuick3DInstancing::instanceNodeDirty, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DInstancing::*)()>(_a, &QQuick3DInstancing::instanceCountOverrideChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DInstancing::*)()>(_a, &QQuick3DInstancing::hasTransparencyChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DInstancing::*)()>(_a, &QQuick3DInstancing::depthSortingEnabledChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DInstancing::*)()>(_a, &QQuick3DInstancing::shadowBoundsMinimumChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DInstancing::*)()>(_a, &QQuick3DInstancing::shadowBoundsMaximumChanged, 6))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->instanceCountOverride(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->hasTransparency(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->depthSortingEnabled(); break;
        case 3: *reinterpret_cast<QVector3D*>(_v) = _t->shadowBoundsMinimum(); break;
        case 4: *reinterpret_cast<QVector3D*>(_v) = _t->shadowBoundsMaximum(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setInstanceCountOverride(*reinterpret_cast<int*>(_v)); break;
        case 1: _t->setHasTransparency(*reinterpret_cast<bool*>(_v)); break;
        case 2: _t->setDepthSortingEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setShadowBoundsMinimum(*reinterpret_cast<QVector3D*>(_v)); break;
        case 4: _t->setShadowBoundsMaximum(*reinterpret_cast<QVector3D*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DInstancing::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DInstancing::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18QQuick3DInstancingE_t>.strings))
        return static_cast<void*>(this);
    return QQuick3DObject::qt_metacast(_clname);
}

int QQuick3DInstancing::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuick3DObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 17;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void QQuick3DInstancing::instanceTableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QQuick3DInstancing::instanceNodeDirty()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void QQuick3DInstancing::instanceCountOverrideChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void QQuick3DInstancing::hasTransparencyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void QQuick3DInstancing::depthSortingEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QQuick3DInstancing::shadowBoundsMinimumChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QQuick3DInstancing::shadowBoundsMaximumChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
