/****************************************************************************
** Meta object code from reading C++ file 'materialadapter.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtquick3d/tools/materialeditor/materialadapter.h"
#include <QtGui/qtextcursor.h>
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'materialadapter.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15MaterialAdapterE_t {};
} // unnamed namespace

template <> constexpr inline auto MaterialAdapter::qt_create_metaobjectdata<qt_meta_tag_ZN15MaterialAdapterE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MaterialAdapter",
        "QML.Element",
        "auto",
        "materialChanged",
        "",
        "fragmentShaderChanged",
        "vertexShaderChanged",
        "vertexStatusChanged",
        "uniformModelChanged",
        "fragmentStatusChanged",
        "unsavedChangesChanged",
        "materialSaveFileChanged",
        "errorOccurred",
        "postMaterialSaved",
        "rootNodeChanged",
        "cullModeChanged",
        "depthDrawModeChanged",
        "shadingModeChanged",
        "srcBlendChanged",
        "dstBlendChanged",
        "importFragmentShader",
        "QUrl",
        "shaderFile",
        "importVertexShader",
        "save",
        "saveMaterial",
        "materialFile",
        "loadMaterial",
        "exportQmlComponent",
        "componentFile",
        "vertName",
        "fragName",
        "reset",
        "getSupportedImageFormatsFilter",
        "material",
        "QQuick3DCustomMaterial*",
        "rootNode",
        "QQuick3DNode*",
        "fragmentShader",
        "vertexShader",
        "vertexStatus",
        "ShaderBuildMessage",
        "fragmentStatus",
        "uniformModel",
        "UniformModel*",
        "unsavedChanges",
        "materialSaveFile",
        "cullMode",
        "QQuick3DMaterial::CullMode",
        "depthDrawMode",
        "QQuick3DMaterial::DepthDrawMode",
        "shadingMode",
        "QQuick3DCustomMaterial::ShadingMode",
        "sourceBlend",
        "QQuick3DCustomMaterial::BlendMode",
        "destinationBlend"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'materialChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fragmentShaderChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'vertexShaderChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'vertexStatusChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'uniformModelChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fragmentStatusChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'unsavedChangesChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'materialSaveFileChanged'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'errorOccurred'
        QtMocHelpers::SignalData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'postMaterialSaved'
        QtMocHelpers::SignalData<void()>(13, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'rootNodeChanged'
        QtMocHelpers::SignalData<void()>(14, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'cullModeChanged'
        QtMocHelpers::SignalData<void()>(15, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'depthDrawModeChanged'
        QtMocHelpers::SignalData<void()>(16, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'shadingModeChanged'
        QtMocHelpers::SignalData<void()>(17, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'srcBlendChanged'
        QtMocHelpers::SignalData<void()>(18, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dstBlendChanged'
        QtMocHelpers::SignalData<void()>(19, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'importFragmentShader'
        QtMocHelpers::SlotData<void(const QUrl &)>(20, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 22 },
        }}),
        // Slot 'importVertexShader'
        QtMocHelpers::SlotData<void(const QUrl &)>(23, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 22 },
        }}),
        // Slot 'save'
        QtMocHelpers::SlotData<bool()>(24, 4, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'saveMaterial'
        QtMocHelpers::SlotData<bool(const QUrl &)>(25, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 21, 26 },
        }}),
        // Slot 'loadMaterial'
        QtMocHelpers::SlotData<bool(const QUrl &)>(27, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 21, 26 },
        }}),
        // Slot 'exportQmlComponent'
        QtMocHelpers::SlotData<bool(const QUrl &, const QString &, const QString &)>(28, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 21, 29 }, { QMetaType::QString, 30 }, { QMetaType::QString, 31 },
        }}),
        // Slot 'reset'
        QtMocHelpers::SlotData<void()>(32, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'getSupportedImageFormatsFilter'
        QtMocHelpers::MethodData<QString() const>(33, 4, QMC::AccessPublic, QMetaType::QString),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'material'
        QtMocHelpers::PropertyData<QQuick3DCustomMaterial*>(34, 0x80000000 | 35, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'rootNode'
        QtMocHelpers::PropertyData<QQuick3DNode*>(36, 0x80000000 | 37, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 10),
        // property 'fragmentShader'
        QtMocHelpers::PropertyData<QString>(38, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'vertexShader'
        QtMocHelpers::PropertyData<QString>(39, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'vertexStatus'
        QtMocHelpers::PropertyData<ShaderBuildMessage>(40, 0x80000000 | 41, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 3),
        // property 'fragmentStatus'
        QtMocHelpers::PropertyData<ShaderBuildMessage>(42, 0x80000000 | 41, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 5),
        // property 'uniformModel'
        QtMocHelpers::PropertyData<UniformModel*>(43, 0x80000000 | 44, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 4),
        // property 'unsavedChanges'
        QtMocHelpers::PropertyData<bool>(45, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'materialSaveFile'
        QtMocHelpers::PropertyData<QUrl>(46, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 7),
        // property 'cullMode'
        QtMocHelpers::PropertyData<QQuick3DMaterial::CullMode>(47, 0x80000000 | 48, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 11),
        // property 'depthDrawMode'
        QtMocHelpers::PropertyData<QQuick3DMaterial::DepthDrawMode>(49, 0x80000000 | 50, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 12),
        // property 'shadingMode'
        QtMocHelpers::PropertyData<QQuick3DCustomMaterial::ShadingMode>(51, 0x80000000 | 52, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 13),
        // property 'sourceBlend'
        QtMocHelpers::PropertyData<QQuick3DCustomMaterial::BlendMode>(53, 0x80000000 | 54, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 14),
        // property 'destinationBlend'
        QtMocHelpers::PropertyData<QQuick3DCustomMaterial::BlendMode>(55, 0x80000000 | 54, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 15),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<MaterialAdapter, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN15MaterialAdapterE[] = {
    QMetaObject::SuperData::link<QQuick3DMaterial::staticMetaObject>(),
    QMetaObject::SuperData::link<QQuick3DCustomMaterial::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject MaterialAdapter::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15MaterialAdapterE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15MaterialAdapterE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN15MaterialAdapterE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15MaterialAdapterE_t>.metaTypes,
    nullptr
} };

void MaterialAdapter::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MaterialAdapter *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->materialChanged(); break;
        case 1: _t->fragmentShaderChanged(); break;
        case 2: _t->vertexShaderChanged(); break;
        case 3: _t->vertexStatusChanged(); break;
        case 4: _t->uniformModelChanged(); break;
        case 5: _t->fragmentStatusChanged(); break;
        case 6: _t->unsavedChangesChanged(); break;
        case 7: _t->materialSaveFileChanged(); break;
        case 8: _t->errorOccurred(); break;
        case 9: _t->postMaterialSaved(); break;
        case 10: _t->rootNodeChanged(); break;
        case 11: _t->cullModeChanged(); break;
        case 12: _t->depthDrawModeChanged(); break;
        case 13: _t->shadingModeChanged(); break;
        case 14: _t->srcBlendChanged(); break;
        case 15: _t->dstBlendChanged(); break;
        case 16: _t->importFragmentShader((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 17: _t->importVertexShader((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 18: { bool _r = _t->save();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 19: { bool _r = _t->saveMaterial((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 20: { bool _r = _t->loadMaterial((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 21: { bool _r = _t->exportQmlComponent((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 22: _t->reset(); break;
        case 23: { QString _r = _t->getSupportedImageFormatsFilter();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MaterialAdapter::*)()>(_a, &MaterialAdapter::materialChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MaterialAdapter::*)()>(_a, &MaterialAdapter::fragmentShaderChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MaterialAdapter::*)()>(_a, &MaterialAdapter::vertexShaderChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (MaterialAdapter::*)()>(_a, &MaterialAdapter::vertexStatusChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (MaterialAdapter::*)()>(_a, &MaterialAdapter::uniformModelChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (MaterialAdapter::*)()>(_a, &MaterialAdapter::fragmentStatusChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (MaterialAdapter::*)()>(_a, &MaterialAdapter::unsavedChangesChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (MaterialAdapter::*)()>(_a, &MaterialAdapter::materialSaveFileChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (MaterialAdapter::*)()>(_a, &MaterialAdapter::errorOccurred, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (MaterialAdapter::*)()>(_a, &MaterialAdapter::postMaterialSaved, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (MaterialAdapter::*)()>(_a, &MaterialAdapter::rootNodeChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (MaterialAdapter::*)()>(_a, &MaterialAdapter::cullModeChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (MaterialAdapter::*)()>(_a, &MaterialAdapter::depthDrawModeChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (MaterialAdapter::*)()>(_a, &MaterialAdapter::shadingModeChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (MaterialAdapter::*)()>(_a, &MaterialAdapter::srcBlendChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (MaterialAdapter::*)()>(_a, &MaterialAdapter::dstBlendChanged, 15))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuick3DCustomMaterial* >(); break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuick3DNode* >(); break;
        case 6:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< UniformModel* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QQuick3DCustomMaterial**>(_v) = _t->material(); break;
        case 1: *reinterpret_cast<QQuick3DNode**>(_v) = _t->rootNode(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->fragmentShader(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->vertexShader(); break;
        case 4: *reinterpret_cast<ShaderBuildMessage*>(_v) = _t->vertexStatus(); break;
        case 5: *reinterpret_cast<ShaderBuildMessage*>(_v) = _t->fragmentStatus(); break;
        case 6: *reinterpret_cast<UniformModel**>(_v) = _t->uniformModel(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->unsavedChanges(); break;
        case 8: *reinterpret_cast<QUrl*>(_v) = _t->materialSaveFile(); break;
        case 9: *reinterpret_cast<QQuick3DMaterial::CullMode*>(_v) = _t->cullMode(); break;
        case 10: *reinterpret_cast<QQuick3DMaterial::DepthDrawMode*>(_v) = _t->depthDrawMode(); break;
        case 11: *reinterpret_cast<QQuick3DCustomMaterial::ShadingMode*>(_v) = _t->shadingMode(); break;
        case 12: *reinterpret_cast<QQuick3DCustomMaterial::BlendMode*>(_v) = _t->srcBlend(); break;
        case 13: *reinterpret_cast<QQuick3DCustomMaterial::BlendMode*>(_v) = _t->dstBlend(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setRootNode(*reinterpret_cast<QQuick3DNode**>(_v)); break;
        case 2: _t->setFragmentShader(*reinterpret_cast<QString*>(_v)); break;
        case 3: _t->setVertexShader(*reinterpret_cast<QString*>(_v)); break;
        case 6: _t->setUniformModel(*reinterpret_cast<UniformModel**>(_v)); break;
        case 7: _t->setUnsavedChanges(*reinterpret_cast<bool*>(_v)); break;
        case 8: _t->setMaterialSaveFile(*reinterpret_cast<QUrl*>(_v)); break;
        case 9: _t->setCullMode(*reinterpret_cast<QQuick3DMaterial::CullMode*>(_v)); break;
        case 10: _t->setDepthDrawMode(*reinterpret_cast<QQuick3DMaterial::DepthDrawMode*>(_v)); break;
        case 11: _t->setShadingMode(*reinterpret_cast<QQuick3DCustomMaterial::ShadingMode*>(_v)); break;
        case 12: _t->setSrcBlend(*reinterpret_cast<QQuick3DCustomMaterial::BlendMode*>(_v)); break;
        case 13: _t->setDstBlend(*reinterpret_cast<QQuick3DCustomMaterial::BlendMode*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *MaterialAdapter::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MaterialAdapter::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15MaterialAdapterE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int MaterialAdapter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 24)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 24)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 24;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void MaterialAdapter::materialChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void MaterialAdapter::fragmentShaderChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void MaterialAdapter::vertexShaderChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void MaterialAdapter::vertexStatusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void MaterialAdapter::uniformModelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void MaterialAdapter::fragmentStatusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void MaterialAdapter::unsavedChangesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void MaterialAdapter::materialSaveFileChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void MaterialAdapter::errorOccurred()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void MaterialAdapter::postMaterialSaved()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void MaterialAdapter::rootNodeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void MaterialAdapter::cullModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void MaterialAdapter::depthDrawModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void MaterialAdapter::shadingModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void MaterialAdapter::srcBlendChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void MaterialAdapter::dstBlendChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}
QT_WARNING_POP
