/****************************************************************************
** Meta object code from reading C++ file 'qquick3dxrvirtualmouse_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../qtquick3d/src/xr/quick3dxr/qquick3dxrvirtualmouse_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquick3dxrvirtualmouse_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN22QQuick3DXrVirtualMouseE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DXrVirtualMouse::qt_create_metaobjectdata<qt_meta_tag_ZN22QQuick3DXrVirtualMouseE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DXrVirtualMouse",
        "QML.Element",
        "XrVirtualMouse",
        "QML.AddedInVersion",
        "1544",
        "rightMouseButtonChanged",
        "",
        "rightMouseButton",
        "leftMouseButtonChanged",
        "leftMouseButton",
        "middleMouseButtonChanged",
        "middleMouseButton",
        "scrollWheelXChanged",
        "scrollWheelX",
        "scrollWheelYChanged",
        "scrollWheelY",
        "scrollTimerIntervalChanged",
        "scrollTimerInterval",
        "scrollPixelDeltaChanged",
        "scrollPixelDelta",
        "sourceChanged",
        "QQuick3DNode*",
        "source",
        "viewChanged",
        "QQuick3DXrView*",
        "view",
        "enabledChanged",
        "enabled",
        "setRightMouseButton",
        "setLeftMouseButton",
        "setMiddleMouseButton",
        "setScrollWheelX",
        "setScrollWheelY",
        "setScrollTimerInterval",
        "setScrollPixelDelta",
        "setSource",
        "setView",
        "setEnabled",
        "moveEvent",
        "generateWheelEvent"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'rightMouseButtonChanged'
        QtMocHelpers::SignalData<void(bool)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Signal 'leftMouseButtonChanged'
        QtMocHelpers::SignalData<void(bool)>(8, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 9 },
        }}),
        // Signal 'middleMouseButtonChanged'
        QtMocHelpers::SignalData<void(bool)>(10, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Signal 'scrollWheelXChanged'
        QtMocHelpers::SignalData<void(float)>(12, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 13 },
        }}),
        // Signal 'scrollWheelYChanged'
        QtMocHelpers::SignalData<void(float)>(14, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 15 },
        }}),
        // Signal 'scrollTimerIntervalChanged'
        QtMocHelpers::SignalData<void(int)>(16, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 17 },
        }}),
        // Signal 'scrollPixelDeltaChanged'
        QtMocHelpers::SignalData<void(int)>(18, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 19 },
        }}),
        // Signal 'sourceChanged'
        QtMocHelpers::SignalData<void(QQuick3DNode *)>(20, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 22 },
        }}),
        // Signal 'viewChanged'
        QtMocHelpers::SignalData<void(QQuick3DXrView *)>(23, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 24, 25 },
        }}),
        // Signal 'enabledChanged'
        QtMocHelpers::SignalData<void(bool)>(26, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 27 },
        }}),
        // Slot 'setRightMouseButton'
        QtMocHelpers::SlotData<void(bool)>(28, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Slot 'setLeftMouseButton'
        QtMocHelpers::SlotData<void(bool)>(29, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 9 },
        }}),
        // Slot 'setMiddleMouseButton'
        QtMocHelpers::SlotData<void(bool)>(30, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Slot 'setScrollWheelX'
        QtMocHelpers::SlotData<void(float)>(31, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 13 },
        }}),
        // Slot 'setScrollWheelY'
        QtMocHelpers::SlotData<void(float)>(32, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 15 },
        }}),
        // Slot 'setScrollTimerInterval'
        QtMocHelpers::SlotData<void(int)>(33, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 17 },
        }}),
        // Slot 'setScrollPixelDelta'
        QtMocHelpers::SlotData<void(int)>(34, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 19 },
        }}),
        // Slot 'setSource'
        QtMocHelpers::SlotData<void(QQuick3DNode *)>(35, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 22 },
        }}),
        // Slot 'setView'
        QtMocHelpers::SlotData<void(QQuick3DXrView *)>(36, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 24, 25 },
        }}),
        // Slot 'setEnabled'
        QtMocHelpers::SlotData<void(bool)>(37, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 27 },
        }}),
        // Slot 'moveEvent'
        QtMocHelpers::SlotData<void()>(38, 6, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'generateWheelEvent'
        QtMocHelpers::SlotData<void()>(39, 6, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'rightMouseButton'
        QtMocHelpers::PropertyData<bool>(7, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'leftMouseButton'
        QtMocHelpers::PropertyData<bool>(9, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'middleMouseButton'
        QtMocHelpers::PropertyData<bool>(11, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'scrollWheelX'
        QtMocHelpers::PropertyData<float>(13, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'scrollWheelY'
        QtMocHelpers::PropertyData<float>(15, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'scrollTimerInterval'
        QtMocHelpers::PropertyData<int>(17, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'scrollPixelDelta'
        QtMocHelpers::PropertyData<int>(19, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'source'
        QtMocHelpers::PropertyData<QQuick3DNode*>(22, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 7),
        // property 'view'
        QtMocHelpers::PropertyData<QQuick3DXrView*>(25, 0x80000000 | 24, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 8),
        // property 'enabled'
        QtMocHelpers::PropertyData<bool>(27, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DXrVirtualMouse, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DXrVirtualMouse::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22QQuick3DXrVirtualMouseE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22QQuick3DXrVirtualMouseE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22QQuick3DXrVirtualMouseE_t>.metaTypes,
    nullptr
} };

void QQuick3DXrVirtualMouse::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DXrVirtualMouse *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->rightMouseButtonChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->leftMouseButtonChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->middleMouseButtonChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->scrollWheelXChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 4: _t->scrollWheelYChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 5: _t->scrollTimerIntervalChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->scrollPixelDeltaChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 7: _t->sourceChanged((*reinterpret_cast<std::add_pointer_t<QQuick3DNode*>>(_a[1]))); break;
        case 8: _t->viewChanged((*reinterpret_cast<std::add_pointer_t<QQuick3DXrView*>>(_a[1]))); break;
        case 9: _t->enabledChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->setRightMouseButton((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->setLeftMouseButton((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->setMiddleMouseButton((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->setScrollWheelX((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 14: _t->setScrollWheelY((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 15: _t->setScrollTimerInterval((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 16: _t->setScrollPixelDelta((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 17: _t->setSource((*reinterpret_cast<std::add_pointer_t<QQuick3DNode*>>(_a[1]))); break;
        case 18: _t->setView((*reinterpret_cast<std::add_pointer_t<QQuick3DXrView*>>(_a[1]))); break;
        case 19: _t->setEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 20: _t->moveEvent(); break;
        case 21: _t->generateWheelEvent(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QQuick3DXrVirtualMouse::*)(bool )>(_a, &QQuick3DXrVirtualMouse::rightMouseButtonChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DXrVirtualMouse::*)(bool )>(_a, &QQuick3DXrVirtualMouse::leftMouseButtonChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DXrVirtualMouse::*)(bool )>(_a, &QQuick3DXrVirtualMouse::middleMouseButtonChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DXrVirtualMouse::*)(float )>(_a, &QQuick3DXrVirtualMouse::scrollWheelXChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DXrVirtualMouse::*)(float )>(_a, &QQuick3DXrVirtualMouse::scrollWheelYChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DXrVirtualMouse::*)(int )>(_a, &QQuick3DXrVirtualMouse::scrollTimerIntervalChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DXrVirtualMouse::*)(int )>(_a, &QQuick3DXrVirtualMouse::scrollPixelDeltaChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DXrVirtualMouse::*)(QQuick3DNode * )>(_a, &QQuick3DXrVirtualMouse::sourceChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DXrVirtualMouse::*)(QQuick3DXrView * )>(_a, &QQuick3DXrVirtualMouse::viewChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (QQuick3DXrVirtualMouse::*)(bool )>(_a, &QQuick3DXrVirtualMouse::enabledChanged, 9))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->rightMouseButton(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->leftMouseButton(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->middleMouseButton(); break;
        case 3: *reinterpret_cast<float*>(_v) = _t->scrollWheelX(); break;
        case 4: *reinterpret_cast<float*>(_v) = _t->scrollWheelY(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->scrollTimerInterval(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->scrollPixelDelta(); break;
        case 7: *reinterpret_cast<QQuick3DNode**>(_v) = _t->source(); break;
        case 8: *reinterpret_cast<QQuick3DXrView**>(_v) = _t->view(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->enabled(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setRightMouseButton(*reinterpret_cast<bool*>(_v)); break;
        case 1: _t->setLeftMouseButton(*reinterpret_cast<bool*>(_v)); break;
        case 2: _t->setMiddleMouseButton(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setScrollWheelX(*reinterpret_cast<float*>(_v)); break;
        case 4: _t->setScrollWheelY(*reinterpret_cast<float*>(_v)); break;
        case 5: _t->setScrollTimerInterval(*reinterpret_cast<int*>(_v)); break;
        case 6: _t->setScrollPixelDelta(*reinterpret_cast<int*>(_v)); break;
        case 7: _t->setSource(*reinterpret_cast<QQuick3DNode**>(_v)); break;
        case 8: _t->setView(*reinterpret_cast<QQuick3DXrView**>(_v)); break;
        case 9: _t->setEnabled(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *QQuick3DXrVirtualMouse::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DXrVirtualMouse::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22QQuick3DXrVirtualMouseE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QQuick3DXrVirtualMouse::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 22)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 22)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 22;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void QQuick3DXrVirtualMouse::rightMouseButtonChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void QQuick3DXrVirtualMouse::leftMouseButtonChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void QQuick3DXrVirtualMouse::middleMouseButtonChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void QQuick3DXrVirtualMouse::scrollWheelXChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void QQuick3DXrVirtualMouse::scrollWheelYChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void QQuick3DXrVirtualMouse::scrollTimerIntervalChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void QQuick3DXrVirtualMouse::scrollPixelDeltaChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void QQuick3DXrVirtualMouse::sourceChanged(QQuick3DNode * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void QQuick3DXrVirtualMouse::viewChanged(QQuick3DXrView * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void QQuick3DXrVirtualMouse::enabledChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}
QT_WARNING_POP
