/****************************************************************************
** Meta object code from reading C++ file 'qquick3dquaternionutils_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtquick3d/src/quick3d/qquick3dquaternionutils_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquick3dquaternionutils_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN23QQuick3DQuaternionUtilsE_t {};
} // unnamed namespace

template <> constexpr inline auto QQuick3DQuaternionUtils::qt_create_metaobjectdata<qt_meta_tag_ZN23QQuick3DQuaternionUtilsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QQuick3DQuaternionUtils",
        "QML.Element",
        "Quaternion",
        "QML.Singleton",
        "true",
        "fromAxesAndAngles",
        "QQuaternion",
        "",
        "QVector3D",
        "axis1",
        "angle1",
        "axis2",
        "angle2",
        "axis3",
        "angle3",
        "fromAxisAndAngle",
        "x",
        "y",
        "z",
        "angle",
        "axis",
        "fromEulerAngles",
        "eulerAngles",
        "lookAt",
        "sourcePosition",
        "targetPosition",
        "forwardDirection",
        "upDirection"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'fromAxesAndAngles'
        QtMocHelpers::MethodData<QQuaternion(const QVector3D &, float, const QVector3D &, float, const QVector3D &, float)>(5, 7, QMC::AccessPublic, 0x80000000 | 6, {{
            { 0x80000000 | 8, 9 }, { QMetaType::Float, 10 }, { 0x80000000 | 8, 11 }, { QMetaType::Float, 12 },
            { 0x80000000 | 8, 13 }, { QMetaType::Float, 14 },
        }}),
        // Method 'fromAxesAndAngles'
        QtMocHelpers::MethodData<QQuaternion(const QVector3D &, float, const QVector3D &, float)>(5, 7, QMC::AccessPublic, 0x80000000 | 6, {{
            { 0x80000000 | 8, 9 }, { QMetaType::Float, 10 }, { 0x80000000 | 8, 11 }, { QMetaType::Float, 12 },
        }}),
        // Method 'fromAxisAndAngle'
        QtMocHelpers::MethodData<QQuaternion(float, float, float, float)>(15, 7, QMC::AccessPublic, 0x80000000 | 6, {{
            { QMetaType::Float, 16 }, { QMetaType::Float, 17 }, { QMetaType::Float, 18 }, { QMetaType::Float, 19 },
        }}),
        // Method 'fromAxisAndAngle'
        QtMocHelpers::MethodData<QQuaternion(const QVector3D &, float)>(15, 7, QMC::AccessPublic, 0x80000000 | 6, {{
            { 0x80000000 | 8, 20 }, { QMetaType::Float, 19 },
        }}),
        // Method 'fromEulerAngles'
        QtMocHelpers::MethodData<QQuaternion(float, float, float)>(21, 7, QMC::AccessPublic, 0x80000000 | 6, {{
            { QMetaType::Float, 16 }, { QMetaType::Float, 17 }, { QMetaType::Float, 18 },
        }}),
        // Method 'fromEulerAngles'
        QtMocHelpers::MethodData<QQuaternion(const QVector3D &)>(21, 7, QMC::AccessPublic, 0x80000000 | 6, {{
            { 0x80000000 | 8, 22 },
        }}),
        // Method 'lookAt'
        QtMocHelpers::MethodData<QQuaternion(const QVector3D &, const QVector3D &, const QVector3D &, const QVector3D &)>(23, 7, QMC::AccessPublic, 0x80000000 | 6, {{
            { 0x80000000 | 8, 24 }, { 0x80000000 | 8, 25 }, { 0x80000000 | 8, 26 }, { 0x80000000 | 8, 27 },
        }}),
        // Method 'lookAt'
        QtMocHelpers::MethodData<QQuaternion(const QVector3D &, const QVector3D &, const QVector3D &)>(23, 7, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 6, {{
            { 0x80000000 | 8, 24 }, { 0x80000000 | 8, 25 }, { 0x80000000 | 8, 26 },
        }}),
        // Method 'lookAt'
        QtMocHelpers::MethodData<QQuaternion(const QVector3D &, const QVector3D &)>(23, 7, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 6, {{
            { 0x80000000 | 8, 24 }, { 0x80000000 | 8, 25 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<QQuick3DQuaternionUtils, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject QQuick3DQuaternionUtils::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23QQuick3DQuaternionUtilsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23QQuick3DQuaternionUtilsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23QQuick3DQuaternionUtilsE_t>.metaTypes,
    nullptr
} };

void QQuick3DQuaternionUtils::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QQuick3DQuaternionUtils *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QQuaternion _r = _t->fromAxesAndAngles((*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<float>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<float>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<float>>(_a[6])));
            if (_a[0]) *reinterpret_cast<QQuaternion*>(_a[0]) = std::move(_r); }  break;
        case 1: { QQuaternion _r = _t->fromAxesAndAngles((*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<float>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<float>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QQuaternion*>(_a[0]) = std::move(_r); }  break;
        case 2: { QQuaternion _r = _t->fromAxisAndAngle((*reinterpret_cast<std::add_pointer_t<float>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<float>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<float>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<float>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QQuaternion*>(_a[0]) = std::move(_r); }  break;
        case 3: { QQuaternion _r = _t->fromAxisAndAngle((*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<float>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QQuaternion*>(_a[0]) = std::move(_r); }  break;
        case 4: { QQuaternion _r = _t->fromEulerAngles((*reinterpret_cast<std::add_pointer_t<float>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<float>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<float>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QQuaternion*>(_a[0]) = std::move(_r); }  break;
        case 5: { QQuaternion _r = _t->fromEulerAngles((*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QQuaternion*>(_a[0]) = std::move(_r); }  break;
        case 6: { QQuaternion _r = _t->lookAt((*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QQuaternion*>(_a[0]) = std::move(_r); }  break;
        case 7: { QQuaternion _r = _t->lookAt((*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QQuaternion*>(_a[0]) = std::move(_r); }  break;
        case 8: { QQuaternion _r = _t->lookAt((*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVector3D>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QQuaternion*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *QQuick3DQuaternionUtils::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuick3DQuaternionUtils::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23QQuick3DQuaternionUtilsE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int QQuick3DQuaternionUtils::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    return _id;
}
QT_WARNING_POP
