// This file is autogenerated. Changes will be overwritten.
#include "7IHICACP7F/moc_qopenxrinputmanager_p.cpp"
#include "7IHICACP7F/moc_qquick3dxranchormanager_openxr_p.cpp"
#include "EWIEGA46WW/moc_qquick3dxrabstracthapticeffect_p.cpp"
#include "EWIEGA46WW/moc_qquick3dxractionmapper_p.cpp"
#include "EWIEGA46WW/moc_qquick3dxrcamera_p.cpp"
#include "EWIEGA46WW/moc_qquick3dxrcontroller_p.cpp"
#include "EWIEGA46WW/moc_qquick3dxrhandinput_p.cpp"
#include "EWIEGA46WW/moc_qquick3dxrhandmodel_p.cpp"
#include "EWIEGA46WW/moc_qquick3dxrinputmanager_p.cpp"
#include "EWIEGA46WW/moc_qquick3dxritem_p.cpp"
#include "EWIEGA46WW/moc_qquick3dxrmanager_p.cpp"
#include "EWIEGA46WW/moc_qquick3dxrorigin_p.cpp"
#include "EWIEGA46WW/moc_qquick3dxrruntimeinfo_p.cpp"
#include "EWIEGA46WW/moc_qquick3dxrspatialanchor_p.cpp"
#include "EWIEGA46WW/moc_qquick3dxrspatialanchorlistmodel_p.cpp"
#include "EWIEGA46WW/moc_qquick3dxrview_p.cpp"
#include "EWIEGA46WW/moc_qquick3dxrvirtualmouse_p.cpp"
